Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseBackupProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Properties of the Autonomous Database Backup resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseBackupProperties

Returns a new instance of AutonomousDatabaseBackupProperties.



426
427
428
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_till_timeString

Output only. Timestamp until when the backup will be available. Corresponds to the JSON property availableTillTime

Returns:

  • (String)


319
320
321
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 319

def available_till_time
  @available_till_time
end

#compartment_idString

Output only. The OCID of the compartment. Corresponds to the JSON property compartmentId

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 324

def compartment_id
  @compartment_id
end

#database_size_tbFloat

Output only. The quantity of data in the database, in terabytes. Corresponds to the JSON property databaseSizeTb

Returns:

  • (Float)


329
330
331
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 329

def database_size_tb
  @database_size_tb
end

#db_versionString

Output only. A valid Oracle Database version for Autonomous Database. Corresponds to the JSON property dbVersion

Returns:

  • (String)


334
335
336
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 334

def db_version
  @db_version
end

#end_timeString

Output only. The date and time the backup completed. Corresponds to the JSON property endTime

Returns:

  • (String)


339
340
341
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 339

def end_time
  @end_time
end

#is_automatic_backupBoolean Also known as: is_automatic_backup?

Output only. Indicates if the backup is automatic or user initiated. Corresponds to the JSON property isAutomaticBackup

Returns:

  • (Boolean)


344
345
346
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 344

def is_automatic_backup
  @is_automatic_backup
end

#is_long_term_backupBoolean Also known as: is_long_term_backup?

Output only. Indicates if the backup is long term backup. Corresponds to the JSON property isLongTermBackup

Returns:

  • (Boolean)


350
351
352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 350

def is_long_term_backup
  @is_long_term_backup
end

#is_restorableBoolean Also known as: is_restorable?

Output only. Indicates if the backup can be used to restore the Autonomous Database. Corresponds to the JSON property isRestorable

Returns:

  • (Boolean)


357
358
359
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 357

def is_restorable
  @is_restorable
end

#key_store_idString

Optional. The OCID of the key store of Oracle Vault. Corresponds to the JSON property keyStoreId

Returns:

  • (String)


363
364
365
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 363

def key_store_id
  @key_store_id
end

#key_store_walletString

Optional. The wallet name for Oracle Key Vault. Corresponds to the JSON property keyStoreWallet

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 368

def key_store_wallet
  @key_store_wallet
end

#kms_key_idString

Optional. The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations. Corresponds to the JSON property kmsKeyId

Returns:

  • (String)


374
375
376
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 374

def kms_key_id
  @kms_key_id
end

#kms_key_version_idString

Optional. The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation. Autonomous Database Serverless does not use key versions, hence is not applicable for Autonomous Database Serverless instances. Corresponds to the JSON property kmsKeyVersionId

Returns:

  • (String)


383
384
385
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 383

def kms_key_version_id
  @kms_key_version_id
end

#lifecycle_detailsString

Output only. Additional information about the current lifecycle state. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


388
389
390
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 388

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. The lifecycle state of the backup. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


393
394
395
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 393

def lifecycle_state
  @lifecycle_state
end

#ocidString

Output only. OCID of the Autonomous Database backup. https://docs.oracle.com/ en-us/iaas/Content/General/Concepts/identifiers.htm#Oracle Corresponds to the JSON property ocid

Returns:

  • (String)


399
400
401
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 399

def ocid
  @ocid
end

#retention_period_daysFixnum

Optional. Retention period in days for the backup. Corresponds to the JSON property retentionPeriodDays

Returns:

  • (Fixnum)


404
405
406
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 404

def retention_period_days
  @retention_period_days
end

#size_tbFloat

Output only. The backup size in terabytes. Corresponds to the JSON property sizeTb

Returns:

  • (Float)


409
410
411
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 409

def size_tb
  @size_tb
end

#start_timeString

Output only. The date and time the backup started. Corresponds to the JSON property startTime

Returns:

  • (String)


414
415
416
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 414

def start_time
  @start_time
end

#typeString

Output only. The type of the backup. Corresponds to the JSON property type

Returns:

  • (String)


419
420
421
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 419

def type
  @type
end

#vault_idString

Optional. The OCID of the vault. Corresponds to the JSON property vaultId

Returns:

  • (String)


424
425
426
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 424

def vault_id
  @vault_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 431

def update!(**args)
  @available_till_time = args[:available_till_time] if args.key?(:available_till_time)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @database_size_tb = args[:database_size_tb] if args.key?(:database_size_tb)
  @db_version = args[:db_version] if args.key?(:db_version)
  @end_time = args[:end_time] if args.key?(:end_time)
  @is_automatic_backup = args[:is_automatic_backup] if args.key?(:is_automatic_backup)
  @is_long_term_backup = args[:is_long_term_backup] if args.key?(:is_long_term_backup)
  @is_restorable = args[:is_restorable] if args.key?(:is_restorable)
  @key_store_id = args[:key_store_id] if args.key?(:key_store_id)
  @key_store_wallet = args[:key_store_wallet] if args.key?(:key_store_wallet)
  @kms_key_id = args[:kms_key_id] if args.key?(:kms_key_id)
  @kms_key_version_id = args[:kms_key_version_id] if args.key?(:kms_key_version_id)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @ocid = args[:ocid] if args.key?(:ocid)
  @retention_period_days = args[:retention_period_days] if args.key?(:retention_period_days)
  @size_tb = args[:size_tb] if args.key?(:size_tb)
  @start_time = args[:start_time] if args.key?(:start_time)
  @type = args[:type] if args.key?(:type)
  @vault_id = args[:vault_id] if args.key?(:vault_id)
end