Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseCharacterSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Autonomous Database character set resource. https://docs.oracle. com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabaseCharacterSets/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseCharacterSet

Returns a new instance of AutonomousDatabaseCharacterSet.



429
430
431
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_setString

Output only. The character set name for the Autonomous Database which is the ID in the resource name. Corresponds to the JSON property characterSet

Returns:

  • (String)


415
416
417
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 415

def character_set
  @character_set
end

#character_set_typeString

Output only. The character set type for the Autonomous Database. Corresponds to the JSON property characterSetType

Returns:

  • (String)


420
421
422
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 420

def character_set_type
  @character_set_type
end

#nameString

Identifier. The name of the Autonomous Database Character Set resource in the following format: projects/project/locations/region/ autonomousDatabaseCharacterSets/autonomous_database_character_set Corresponds to the JSON property name

Returns:

  • (String)


427
428
429
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 427

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



434
435
436
437
438
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 434

def update!(**args)
  @character_set = args[:character_set] if args.key?(:character_set)
  @character_set_type = args[:character_set_type] if args.key?(:character_set_type)
  @name = args[:name] if args.key?(:name)
end