Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionUrls
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionUrls
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The URLs for accessing Oracle Application Express (APEX) and SQL Developer Web with a browser from a Compute instance. https://docs.oracle.com/en-us/iaas/api/
/en/database/20160918/datatypes/AutonomousDatabaseConnectionUrls
Instance Attribute Summary collapse
-
#apex_uri ⇒ String
Output only.
-
#database_transforms_uri ⇒ String
Output only.
-
#graph_studio_uri ⇒ String
Output only.
-
#machine_learning_notebook_uri ⇒ String
Output only.
-
#machine_learning_user_management_uri ⇒ String
Output only.
-
#mongo_db_uri ⇒ String
Output only.
-
#ords_uri ⇒ String
Output only.
-
#sql_dev_web_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutonomousDatabaseConnectionUrls
constructor
A new instance of AutonomousDatabaseConnectionUrls.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutonomousDatabaseConnectionUrls
Returns a new instance of AutonomousDatabaseConnectionUrls.
597 598 599 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apex_uri ⇒ String
Output only. Oracle Application Express (APEX) URL.
Corresponds to the JSON property apexUri
556 557 558 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 556 def apex_uri @apex_uri end |
#database_transforms_uri ⇒ String
Output only. The URL of the Database Transforms for the Autonomous Database.
Corresponds to the JSON property databaseTransformsUri
561 562 563 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 561 def database_transforms_uri @database_transforms_uri end |
#graph_studio_uri ⇒ String
Output only. The URL of the Graph Studio for the Autonomous Database.
Corresponds to the JSON property graphStudioUri
566 567 568 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 566 def graph_studio_uri @graph_studio_uri end |
#machine_learning_notebook_uri ⇒ String
Output only. The URL of the Oracle Machine Learning (OML) Notebook for the
Autonomous Database.
Corresponds to the JSON property machineLearningNotebookUri
572 573 574 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 572 def machine_learning_notebook_uri @machine_learning_notebook_uri end |
#machine_learning_user_management_uri ⇒ String
Output only. The URL of Machine Learning user management the Autonomous
Database.
Corresponds to the JSON property machineLearningUserManagementUri
578 579 580 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 578 def machine_learning_user_management_uri @machine_learning_user_management_uri end |
#mongo_db_uri ⇒ String
Output only. The URL of the MongoDB API for the Autonomous Database.
Corresponds to the JSON property mongoDbUri
583 584 585 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 583 def mongo_db_uri @mongo_db_uri end |
#ords_uri ⇒ String
Output only. The Oracle REST Data Services (ORDS) URL of the Web Access for
the Autonomous Database.
Corresponds to the JSON property ordsUri
589 590 591 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 589 def ords_uri @ords_uri end |
#sql_dev_web_uri ⇒ String
Output only. The URL of the Oracle SQL Developer Web for the Autonomous
Database.
Corresponds to the JSON property sqlDevWebUri
595 596 597 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 595 def sql_dev_web_uri @sql_dev_web_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
602 603 604 605 606 607 608 609 610 611 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 602 def update!(**args) @apex_uri = args[:apex_uri] if args.key?(:apex_uri) @database_transforms_uri = args[:database_transforms_uri] if args.key?(:database_transforms_uri) @graph_studio_uri = args[:graph_studio_uri] if args.key?(:graph_studio_uri) @machine_learning_notebook_uri = args[:machine_learning_notebook_uri] if args.key?(:machine_learning_notebook_uri) @machine_learning_user_management_uri = args[:machine_learning_user_management_uri] if args.key?(:machine_learning_user_management_uri) @mongo_db_uri = args[:mongo_db_uri] if args.key?(:mongo_db_uri) @ords_uri = args[:ords_uri] if args.key?(:ords_uri) @sql_dev_web_uri = args[:sql_dev_web_uri] if args.key?(:sql_dev_web_uri) end |