Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseStandbySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Autonomous Data Guard standby database details. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseStandbySummary

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseStandbySummary

Returns a new instance of AutonomousDatabaseStandbySummary.



1158
1159
1160
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_guard_role_changed_timeString

Output only. The date and time the Autonomous Data Guard role was switched for the standby Autonomous Database. Corresponds to the JSON property dataGuardRoleChangedTime

Returns:

  • (String)


1133
1134
1135
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1133

def data_guard_role_changed_time
  @data_guard_role_changed_time
end

#disaster_recovery_role_changed_timeString

Output only. The date and time the Disaster Recovery role was switched for the standby Autonomous Database. Corresponds to the JSON property disasterRecoveryRoleChangedTime

Returns:

  • (String)


1139
1140
1141
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1139

def disaster_recovery_role_changed_time
  @disaster_recovery_role_changed_time
end

#lag_time_durationString

Output only. The amount of time, in seconds, that the data of the standby database lags in comparison to the data of the primary database. Corresponds to the JSON property lagTimeDuration

Returns:

  • (String)


1145
1146
1147
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1145

def lag_time_duration
  @lag_time_duration
end

#lifecycle_detailsString

Output only. The additional details about the current lifecycle state of the Autonomous Database. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


1151
1152
1153
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1151

def lifecycle_details
  @lifecycle_details
end

#stateString

Output only. The current lifecycle state of the Autonomous Database. Corresponds to the JSON property state

Returns:

  • (String)


1156
1157
1158
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1156

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1163
1164
1165
1166
1167
1168
1169
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1163

def update!(**args)
  @data_guard_role_changed_time = args[:data_guard_role_changed_time] if args.key?(:data_guard_role_changed_time)
  @disaster_recovery_role_changed_time = args[:disaster_recovery_role_changed_time] if args.key?(:disaster_recovery_role_changed_time)
  @lag_time_duration = args[:lag_time_duration] if args.key?(:lag_time_duration)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @state = args[:state] if args.key?(:state)
end