Class: Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties of Exadata Infrastructure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudExadataInfrastructureProperties

Returns a new instance of CloudExadataInfrastructureProperties.



1551
1552
1553
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activated_storage_countFixnum

Output only. The requested number of additional storage servers activated for the Exadata Infrastructure. Corresponds to the JSON property activatedStorageCount

Returns:

  • (Fixnum)


1388
1389
1390
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1388

def activated_storage_count
  @activated_storage_count
end

#additional_storage_countFixnum

Output only. The requested number of additional storage servers for the Exadata Infrastructure. Corresponds to the JSON property additionalStorageCount

Returns:

  • (Fixnum)


1394
1395
1396
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1394

def additional_storage_count
  @additional_storage_count
end

#available_storage_size_gbFixnum

Output only. The available storage can be allocated to the Exadata Infrastructure resource, in gigabytes (GB). Corresponds to the JSON property availableStorageSizeGb

Returns:

  • (Fixnum)


1400
1401
1402
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1400

def available_storage_size_gb
  @available_storage_size_gb
end

#compute_countFixnum

Optional. The number of compute servers for the Exadata Infrastructure. Corresponds to the JSON property computeCount

Returns:

  • (Fixnum)


1405
1406
1407
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1405

def compute_count
  @compute_count
end

#compute_modelString

Output only. The compute model of the Exadata Infrastructure. Corresponds to the JSON property computeModel

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1410

def compute_model
  @compute_model
end

#cpu_countFixnum

Output only. The number of enabled CPU cores. Corresponds to the JSON property cpuCount

Returns:

  • (Fixnum)


1415
1416
1417
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1415

def cpu_count
  @cpu_count
end

#customer_contactsArray<Google::Apis::OracledatabaseV1::CustomerContact>

Optional. The list of customer contacts. Corresponds to the JSON property customerContacts



1420
1421
1422
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1420

def customer_contacts
  @customer_contacts
end

#data_storage_size_tbFloat

Output only. Size, in terabytes, of the DATA disk group. Corresponds to the JSON property dataStorageSizeTb

Returns:

  • (Float)


1425
1426
1427
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1425

def data_storage_size_tb
  @data_storage_size_tb
end

#database_server_typeString

Output only. The database server type of the Exadata Infrastructure. Corresponds to the JSON property databaseServerType

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1430

def database_server_type
  @database_server_type
end

#db_node_storage_size_gbFixnum

Output only. The local node storage allocated in GBs. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


1435
1436
1437
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1435

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#db_server_versionString

Output only. The software version of the database servers (dom0) in the Exadata Infrastructure. Corresponds to the JSON property dbServerVersion

Returns:

  • (String)


1441
1442
1443
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1441

def db_server_version
  @db_server_version
end

#exascale_configGoogle::Apis::OracledatabaseV1::ExascaleConfig

Details of the Exascale configuration for the Exadata Infrastructure. Corresponds to the JSON property exascaleConfig



1446
1447
1448
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1446

def exascale_config
  @exascale_config
end

#maintenance_windowGoogle::Apis::OracledatabaseV1::MaintenanceWindow

Maintenance window as defined by Oracle. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/datatypes/MaintenanceWindow Corresponds to the JSON property maintenanceWindow



1452
1453
1454
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1452

def maintenance_window
  @maintenance_window
end

#max_cpu_countFixnum

Output only. The total number of CPU cores available. Corresponds to the JSON property maxCpuCount

Returns:

  • (Fixnum)


1457
1458
1459
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1457

def max_cpu_count
  @max_cpu_count
end

#max_data_storage_tbFloat

Output only. The total available DATA disk group size. Corresponds to the JSON property maxDataStorageTb

Returns:

  • (Float)


1462
1463
1464
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1462

def max_data_storage_tb
  @max_data_storage_tb
end

#max_db_node_storage_size_gbFixnum

Output only. The total local node storage available in GBs. Corresponds to the JSON property maxDbNodeStorageSizeGb

Returns:

  • (Fixnum)


1467
1468
1469
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1467

def max_db_node_storage_size_gb
  @max_db_node_storage_size_gb
end

#max_memory_gbFixnum

Output only. The total memory available in GBs. Corresponds to the JSON property maxMemoryGb

Returns:

  • (Fixnum)


1472
1473
1474
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1472

def max_memory_gb
  @max_memory_gb
end

#memory_size_gbFixnum

Output only. The memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


1477
1478
1479
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1477

def memory_size_gb
  @memory_size_gb
end

#monthly_db_server_versionString

Output only. The monthly software version of the database servers (dom0) in the Exadata Infrastructure. Example: 20.1.15 Corresponds to the JSON property monthlyDbServerVersion

Returns:

  • (String)


1483
1484
1485
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1483

def monthly_db_server_version
  @monthly_db_server_version
end

#monthly_storage_server_versionString

Output only. The monthly software version of the storage servers (cells) in the Exadata Infrastructure. Example: 20.1.15 Corresponds to the JSON property monthlyStorageServerVersion

Returns:

  • (String)


1489
1490
1491
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1489

def monthly_storage_server_version
  @monthly_storage_server_version
end

#next_maintenance_run_idString

Output only. The OCID of the next maintenance run. Corresponds to the JSON property nextMaintenanceRunId

Returns:

  • (String)


1494
1495
1496
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1494

def next_maintenance_run_id
  @next_maintenance_run_id
end

#next_maintenance_run_timeString

Output only. The time when the next maintenance run will occur. Corresponds to the JSON property nextMaintenanceRunTime

Returns:

  • (String)


1499
1500
1501
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1499

def next_maintenance_run_time
  @next_maintenance_run_time
end

#next_security_maintenance_run_timeString

Output only. The time when the next security maintenance run will occur. Corresponds to the JSON property nextSecurityMaintenanceRunTime

Returns:

  • (String)


1504
1505
1506
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1504

def next_security_maintenance_run_time
  @next_security_maintenance_run_time
end

#oci_urlString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUrl

Returns:

  • (String)


1509
1510
1511
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1509

def oci_url
  @oci_url
end

#ocidString

Output only. OCID of created infra. https://docs.oracle.com/en-us/iaas/Content/ General/Concepts/identifiers.htm#Oracle Corresponds to the JSON property ocid

Returns:

  • (String)


1515
1516
1517
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1515

def ocid
  @ocid
end

#shapeString

Required. The shape of the Exadata Infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance. Corresponds to the JSON property shape

Returns:

  • (String)


1521
1522
1523
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1521

def shape
  @shape
end

#stateString

Output only. The current lifecycle state of the Exadata Infrastructure. Corresponds to the JSON property state

Returns:

  • (String)


1526
1527
1528
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1526

def state
  @state
end

#storage_countFixnum

Optional. The number of Cloud Exadata storage servers for the Exadata Infrastructure. Corresponds to the JSON property storageCount

Returns:

  • (Fixnum)


1532
1533
1534
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1532

def storage_count
  @storage_count
end

#storage_server_typeString

Output only. The storage server type of the Exadata Infrastructure. Corresponds to the JSON property storageServerType

Returns:

  • (String)


1537
1538
1539
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1537

def storage_server_type
  @storage_server_type
end

#storage_server_versionString

Output only. The software version of the storage servers (cells) in the Exadata Infrastructure. Corresponds to the JSON property storageServerVersion

Returns:

  • (String)


1543
1544
1545
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1543

def storage_server_version
  @storage_server_version
end

#total_storage_size_gbFixnum

Optional. The total storage allocated to the Exadata Infrastructure resource, in gigabytes (GB). Corresponds to the JSON property totalStorageSizeGb

Returns:

  • (Fixnum)


1549
1550
1551
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1549

def total_storage_size_gb
  @total_storage_size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1556

def update!(**args)
  @activated_storage_count = args[:activated_storage_count] if args.key?(:activated_storage_count)
  @additional_storage_count = args[:additional_storage_count] if args.key?(:additional_storage_count)
  @available_storage_size_gb = args[:available_storage_size_gb] if args.key?(:available_storage_size_gb)
  @compute_count = args[:compute_count] if args.key?(:compute_count)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @cpu_count = args[:cpu_count] if args.key?(:cpu_count)
  @customer_contacts = args[:customer_contacts] if args.key?(:customer_contacts)
  @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb)
  @database_server_type = args[:database_server_type] if args.key?(:database_server_type)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @db_server_version = args[:db_server_version] if args.key?(:db_server_version)
  @exascale_config = args[:exascale_config] if args.key?(:exascale_config)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @max_cpu_count = args[:max_cpu_count] if args.key?(:max_cpu_count)
  @max_data_storage_tb = args[:max_data_storage_tb] if args.key?(:max_data_storage_tb)
  @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb)
  @max_memory_gb = args[:max_memory_gb] if args.key?(:max_memory_gb)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @monthly_db_server_version = args[:monthly_db_server_version] if args.key?(:monthly_db_server_version)
  @monthly_storage_server_version = args[:monthly_storage_server_version] if args.key?(:monthly_storage_server_version)
  @next_maintenance_run_id = args[:next_maintenance_run_id] if args.key?(:next_maintenance_run_id)
  @next_maintenance_run_time = args[:next_maintenance_run_time] if args.key?(:next_maintenance_run_time)
  @next_security_maintenance_run_time = args[:next_security_maintenance_run_time] if args.key?(:next_security_maintenance_run_time)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ocid = args[:ocid] if args.key?(:ocid)
  @shape = args[:shape] if args.key?(:shape)
  @state = args[:state] if args.key?(:state)
  @storage_count = args[:storage_count] if args.key?(:storage_count)
  @storage_server_type = args[:storage_server_type] if args.key?(:storage_server_type)
  @storage_server_version = args[:storage_server_version] if args.key?(:storage_server_version)
  @total_storage_size_gb = args[:total_storage_size_gb] if args.key?(:total_storage_size_gb)
end