Class: Google::Apis::OracledatabaseV1::CloudVmCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Cloud VM Cluster resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/CloudVmCluster/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudVmCluster

Returns a new instance of CloudVmCluster.



1621
1622
1623
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_odb_subnetString

Optional. The name of the backup OdbSubnet associated with the VM Cluster. Format: projects/project/locations/location/odbNetworks/odb_network/ odbSubnets/odb_subnet Corresponds to the JSON property backupOdbSubnet

Returns:

  • (String)


1542
1543
1544
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1542

def backup_odb_subnet
  @backup_odb_subnet
end

#backup_subnet_cidrString

Optional. CIDR range of the backup subnet. Corresponds to the JSON property backupSubnetCidr

Returns:

  • (String)


1547
1548
1549
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1547

def backup_subnet_cidr
  @backup_subnet_cidr
end

#cidrString

Optional. Network settings. CIDR to use for cluster IP allocation. Corresponds to the JSON property cidr

Returns:

  • (String)


1552
1553
1554
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1552

def cidr
  @cidr
end

#create_timeString

Output only. The date and time that the VM cluster was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1557
1558
1559
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1557

def create_time
  @create_time
end

#display_nameString

Optional. User friendly name for this resource. Corresponds to the JSON property displayName

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1562

def display_name
  @display_name
end

#exadata_infrastructureString

Required. The name of the Exadata Infrastructure resource on which VM cluster resource is created, in the following format: projects/project/locations/ region/cloudExadataInfrastuctures/cloud_extradata_infrastructure Corresponds to the JSON property exadataInfrastructure

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1569

def exadata_infrastructure
  @exadata_infrastructure
end

#gcp_oracle_zoneString

Output only. The GCP Oracle zone where Oracle CloudVmCluster is hosted. This will be the same as the gcp_oracle_zone of the CloudExadataInfrastructure. Example: us-east4-b-r2. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1576

def gcp_oracle_zone
  @gcp_oracle_zone
end

#identity_connectorGoogle::Apis::OracledatabaseV1::IdentityConnector

The identity connector details which will allow OCI to securely access the resources in the customer project. Corresponds to the JSON property identityConnector



1582
1583
1584
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1582

def identity_connector
  @identity_connector
end

#labelsHash<String,String>

Optional. Labels or tags associated with the VM Cluster. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1587
1588
1589
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1587

def labels
  @labels
end

#nameString

Identifier. The name of the VM Cluster resource with the format: projects/ project/locations/region/cloudVmClusters/cloud_vm_cluster Corresponds to the JSON property name

Returns:

  • (String)


1593
1594
1595
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1593

def name
  @name
end

#networkString

Optional. The name of the VPC network. Format: projects/project/global/ networks/network Corresponds to the JSON property network

Returns:

  • (String)


1599
1600
1601
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1599

def network
  @network
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the VM Cluster. Format: projects/project/locations/location/odbNetworks/odb_network It is optional but if specified, this should match the parent ODBNetwork of the odb_subnet and backup_odb_subnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1607

def odb_network
  @odb_network
end

#odb_subnetString

Optional. The name of the OdbSubnet associated with the VM Cluster for IP allocation. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


1614
1615
1616
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1614

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::CloudVmClusterProperties

Various properties and settings associated with Exadata VM cluster. Corresponds to the JSON property properties



1619
1620
1621
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1619

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1626

def update!(**args)
  @backup_odb_subnet = args[:backup_odb_subnet] if args.key?(:backup_odb_subnet)
  @backup_subnet_cidr = args[:backup_subnet_cidr] if args.key?(:backup_subnet_cidr)
  @cidr = args[:cidr] if args.key?(:cidr)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exadata_infrastructure = args[:exadata_infrastructure] if args.key?(:exadata_infrastructure)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @identity_connector = args[:identity_connector] if args.key?(:identity_connector)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end