Class: Google::Apis::OracledatabaseV1::CloudVmClusterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata VM cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudVmClusterProperties

Returns a new instance of CloudVmClusterProperties.



1891
1892
1893
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_nameString

Optional. OCI Cluster name. Corresponds to the JSON property clusterName

Returns:

  • (String)


1718
1719
1720
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1718

def cluster_name
  @cluster_name
end

#compartment_idString

Output only. Compartment ID of cluster. Corresponds to the JSON property compartmentId

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1723

def compartment_id
  @compartment_id
end

#compute_modelString

Output only. The compute model of the VM Cluster. Corresponds to the JSON property computeModel

Returns:

  • (String)


1728
1729
1730
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1728

def compute_model
  @compute_model
end

#cpu_core_countFixnum

Required. Number of enabled CPU cores. Corresponds to the JSON property cpuCoreCount

Returns:

  • (Fixnum)


1733
1734
1735
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1733

def cpu_core_count
  @cpu_core_count
end

#data_storage_size_tbFloat

Optional. The data disk group size to be allocated in TBs. Corresponds to the JSON property dataStorageSizeTb

Returns:

  • (Float)


1738
1739
1740
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1738

def data_storage_size_tb
  @data_storage_size_tb
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


1743
1744
1745
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1743

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#db_server_ocidsArray<String>

Optional. OCID of database servers. Corresponds to the JSON property dbServerOcids

Returns:

  • (Array<String>)


1748
1749
1750
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1748

def db_server_ocids
  @db_server_ocids
end

#diagnostics_data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptions

Data collection options for diagnostics. Corresponds to the JSON property diagnosticsDataCollectionOptions



1753
1754
1755
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1753

def diagnostics_data_collection_options
  @diagnostics_data_collection_options
end

#disk_redundancyString

Optional. The type of redundancy. Corresponds to the JSON property diskRedundancy

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1758

def disk_redundancy
  @disk_redundancy
end

#dns_listener_ipString

Output only. DNS listener IP. Corresponds to the JSON property dnsListenerIp

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1763

def dns_listener_ip
  @dns_listener_ip
end

#domainString

Output only. Parent DNS domain where SCAN DNS and hosts names are qualified. ex: ocispdelegated.ocisp10jvnet.oraclevcn.com Corresponds to the JSON property domain

Returns:

  • (String)


1769
1770
1771
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1769

def domain
  @domain
end

#gi_versionString

Optional. Grid Infrastructure Version. Corresponds to the JSON property giVersion

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1774

def gi_version
  @gi_version
end

#hostnameString

Output only. host name without domain. format: "-" with some suffix. ex: sp2- yi0xq where "sp2" is the hostname_prefix. Corresponds to the JSON property hostname

Returns:

  • (String)


1780
1781
1782
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1780

def hostname
  @hostname
end

#hostname_prefixString

Optional. Prefix for VM cluster host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


1785
1786
1787
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1785

def hostname_prefix
  @hostname_prefix
end

#license_typeString

Required. License type of VM Cluster. Corresponds to the JSON property licenseType

Returns:

  • (String)


1790
1791
1792
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1790

def license_type
  @license_type
end

#local_backup_enabledBoolean Also known as: local_backup_enabled?

Optional. Use local backup. Corresponds to the JSON property localBackupEnabled

Returns:

  • (Boolean)


1795
1796
1797
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1795

def local_backup_enabled
  @local_backup_enabled
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


1801
1802
1803
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1801

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Optional. Number of database servers. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


1806
1807
1808
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1806

def node_count
  @node_count
end

#oci_urlString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUrl

Returns:

  • (String)


1811
1812
1813
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1811

def oci_url
  @oci_url
end

#ocidString

Output only. Oracle Cloud Infrastructure ID of VM Cluster. Corresponds to the JSON property ocid

Returns:

  • (String)


1816
1817
1818
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1816

def ocid
  @ocid
end

#ocpu_countFloat

Optional. OCPU count per VM. Minimum is 0.1. Corresponds to the JSON property ocpuCount

Returns:

  • (Float)


1821
1822
1823
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1821

def ocpu_count
  @ocpu_count
end

#scan_dnsString

Output only. SCAN DNS name. ex: sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet. oraclevcn.com Corresponds to the JSON property scanDns

Returns:

  • (String)


1827
1828
1829
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1827

def scan_dns
  @scan_dns
end

#scan_dns_record_idString

Output only. OCID of scan DNS record. Corresponds to the JSON property scanDnsRecordId

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1832

def scan_dns_record_id
  @scan_dns_record_id
end

#scan_ip_idsArray<String>

Output only. OCIDs of scan IPs. Corresponds to the JSON property scanIpIds

Returns:

  • (Array<String>)


1837
1838
1839
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1837

def scan_ip_ids
  @scan_ip_ids
end

#scan_listener_port_tcpFixnum

Optional. SCAN listener port - TCP Corresponds to the JSON property scanListenerPortTcp

Returns:

  • (Fixnum)


1842
1843
1844
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1842

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#scan_listener_port_tcp_sslFixnum

Optional. SCAN listener port - TLS Corresponds to the JSON property scanListenerPortTcpSsl

Returns:

  • (Fixnum)


1847
1848
1849
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1847

def scan_listener_port_tcp_ssl
  @scan_listener_port_tcp_ssl
end

#shapeString

Output only. Shape of VM Cluster. Corresponds to the JSON property shape

Returns:

  • (String)


1852
1853
1854
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1852

def shape
  @shape
end

#sparse_diskgroup_enabledBoolean Also known as: sparse_diskgroup_enabled?

Optional. Use exadata sparse snapshots. Corresponds to the JSON property sparseDiskgroupEnabled

Returns:

  • (Boolean)


1857
1858
1859
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1857

def sparse_diskgroup_enabled
  @sparse_diskgroup_enabled
end

#ssh_public_keysArray<String>

Optional. SSH public keys to be stored with cluster. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


1863
1864
1865
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1863

def ssh_public_keys
  @ssh_public_keys
end

#stateString

Output only. State of the cluster. Corresponds to the JSON property state

Returns:

  • (String)


1868
1869
1870
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1868

def state
  @state
end

#storage_management_typeString

Output only. The storage management type of the VM Cluster. Corresponds to the JSON property storageManagementType

Returns:

  • (String)


1873
1874
1875
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1873

def storage_management_type
  @storage_management_type
end

#storage_size_gbFixnum

Output only. The storage allocation for the disk group, in gigabytes (GB). Corresponds to the JSON property storageSizeGb

Returns:

  • (Fixnum)


1878
1879
1880
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1878

def storage_size_gb
  @storage_size_gb
end

#system_versionString

Optional. Operating system version of the image. Corresponds to the JSON property systemVersion

Returns:

  • (String)


1883
1884
1885
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1883

def system_version
  @system_version
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



1889
1890
1891
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1889

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1896

def update!(**args)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count)
  @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @db_server_ocids = args[:db_server_ocids] if args.key?(:db_server_ocids)
  @diagnostics_data_collection_options = args[:diagnostics_data_collection_options] if args.key?(:diagnostics_data_collection_options)
  @disk_redundancy = args[:disk_redundancy] if args.key?(:disk_redundancy)
  @dns_listener_ip = args[:dns_listener_ip] if args.key?(:dns_listener_ip)
  @domain = args[:domain] if args.key?(:domain)
  @gi_version = args[:gi_version] if args.key?(:gi_version)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @license_type = args[:license_type] if args.key?(:license_type)
  @local_backup_enabled = args[:local_backup_enabled] if args.key?(:local_backup_enabled)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @scan_dns = args[:scan_dns] if args.key?(:scan_dns)
  @scan_dns_record_id = args[:scan_dns_record_id] if args.key?(:scan_dns_record_id)
  @scan_ip_ids = args[:scan_ip_ids] if args.key?(:scan_ip_ids)
  @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp)
  @scan_listener_port_tcp_ssl = args[:scan_listener_port_tcp_ssl] if args.key?(:scan_listener_port_tcp_ssl)
  @shape = args[:shape] if args.key?(:shape)
  @sparse_diskgroup_enabled = args[:sparse_diskgroup_enabled] if args.key?(:sparse_diskgroup_enabled)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @state = args[:state] if args.key?(:state)
  @storage_management_type = args[:storage_management_type] if args.key?(:storage_management_type)
  @storage_size_gb = args[:storage_size_gb] if args.key?(:storage_size_gb)
  @system_version = args[:system_version] if args.key?(:system_version)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end