Class: Google::Apis::OracledatabaseV1::DatabaseCharacterSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database character set resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseCharacterSet

Returns a new instance of DatabaseCharacterSet.



2257
2258
2259
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_setString

Output only. The character set name for the Database which is the ID in the resource name. Corresponds to the JSON property characterSet

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2243

def character_set
  @character_set
end

#character_set_typeString

Output only. The character set type for the Database. Corresponds to the JSON property characterSetType

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2248

def character_set_type
  @character_set_type
end

#nameString

Identifier. The name of the Database Character Set resource in the following format: projects/project/locations/region/databaseCharacterSets/ database_character_set Corresponds to the JSON property name

Returns:

  • (String)


2255
2256
2257
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2255

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2262
2263
2264
2265
2266
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2262

def update!(**args)
  @character_set = args[:character_set] if args.key?(:character_set)
  @character_set_type = args[:character_set_type] if args.key?(:character_set_type)
  @name = args[:name] if args.key?(:name)
end