Class: Google::Apis::OracledatabaseV1::DatabaseConnectionStringProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The connection string profile to allow clients to group. https://docs.oracle. com/en-us/iaas/api/#/en/database/20160918/datatypes/ DatabaseConnectionStringProfile

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseConnectionStringProfile

Returns a new instance of DatabaseConnectionStringProfile.



2250
2251
2252
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_groupString

Output only. The current consumer group being used by the connection. Corresponds to the JSON property consumerGroup

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2205

def consumer_group
  @consumer_group
end

#display_nameString

Output only. The display name for the database connection. Corresponds to the JSON property displayName

Returns:

  • (String)


2210
2211
2212
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2210

def display_name
  @display_name
end

#host_formatString

Output only. The host name format being currently used in connection string. Corresponds to the JSON property hostFormat

Returns:

  • (String)


2215
2216
2217
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2215

def host_format
  @host_format
end

#is_regionalBoolean Also known as: is_regional?

Output only. This field indicates if the connection string is regional and is only applicable for cross-region Data Guard. Corresponds to the JSON property isRegional

Returns:

  • (Boolean)


2221
2222
2223
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2221

def is_regional
  @is_regional
end

#protocolString

Output only. The protocol being used by the connection. Corresponds to the JSON property protocol

Returns:

  • (String)


2227
2228
2229
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2227

def protocol
  @protocol
end

#session_modeString

Output only. The current session mode of the connection. Corresponds to the JSON property sessionMode

Returns:

  • (String)


2232
2233
2234
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2232

def session_mode
  @session_mode
end

#syntax_formatString

Output only. The syntax of the connection string. Corresponds to the JSON property syntaxFormat

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2237

def syntax_format
  @syntax_format
end

#tls_authenticationString

Output only. This field indicates the TLS authentication type of the connection. Corresponds to the JSON property tlsAuthentication

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2243

def tls_authentication
  @tls_authentication
end

#valueString

Output only. The value of the connection string. Corresponds to the JSON property value

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2248

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2255

def update!(**args)
  @consumer_group = args[:consumer_group] if args.key?(:consumer_group)
  @display_name = args[:display_name] if args.key?(:display_name)
  @host_format = args[:host_format] if args.key?(:host_format)
  @is_regional = args[:is_regional] if args.key?(:is_regional)
  @protocol = args[:protocol] if args.key?(:protocol)
  @session_mode = args[:session_mode] if args.key?(:session_mode)
  @syntax_format = args[:syntax_format] if args.key?(:syntax_format)
  @tls_authentication = args[:tls_authentication] if args.key?(:tls_authentication)
  @value = args[:value] if args.key?(:value)
end