Class: Google::Apis::OracledatabaseV1::DbHome

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database Home resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbHome

Returns a new instance of DbHome.



2474
2475
2476
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseGoogle::Apis::OracledatabaseV1::Database

Details of the Database resource. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/Database/ Corresponds to the JSON property database



2454
2455
2456
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2454

def database
  @database
end

#db_versionString

Required. A valid Oracle Database version. For a list of supported versions, use the ListDbVersions operation. Corresponds to the JSON property dbVersion

Returns:

  • (String)


2460
2461
2462
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2460

def db_version
  @db_version
end

#display_nameString

Optional. The display name for the Database Home. The name does not have to be unique within your project. Corresponds to the JSON property displayName

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2466

def display_name
  @display_name
end

#is_unified_auditing_enabledBoolean Also known as: is_unified_auditing_enabled?

Optional. Whether unified auditing is enabled for the Database Home. Corresponds to the JSON property isUnifiedAuditingEnabled

Returns:

  • (Boolean)


2471
2472
2473
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2471

def is_unified_auditing_enabled
  @is_unified_auditing_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2479
2480
2481
2482
2483
2484
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2479

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @db_version = args[:db_version] if args.key?(:db_version)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_unified_auditing_enabled = args[:is_unified_auditing_enabled] if args.key?(:is_unified_auditing_enabled)
end