Class: Google::Apis::OracledatabaseV1::DbServerProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbServerProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Various properties and settings associated with Exadata database server.
Instance Attribute Summary collapse
-
#db_node_ids ⇒ Array<String>
Output only.
-
#db_node_storage_size_gb ⇒ Fixnum
Optional.
-
#max_db_node_storage_size_gb ⇒ Fixnum
Optional.
-
#max_memory_size_gb ⇒ Fixnum
Optional.
-
#max_ocpu_count ⇒ Fixnum
Optional.
-
#memory_size_gb ⇒ Fixnum
Optional.
-
#ocid ⇒ String
Output only.
-
#ocpu_count ⇒ Fixnum
Optional.
-
#state ⇒ String
Output only.
-
#vm_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbServerProperties
constructor
A new instance of DbServerProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbServerProperties
Returns a new instance of DbServerProperties.
2670 2671 2672 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_node_ids ⇒ Array<String>
Output only. OCID of database nodes associated with the database server.
Corresponds to the JSON property dbNodeIds
2623 2624 2625 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2623 def db_node_ids @db_node_ids end |
#db_node_storage_size_gb ⇒ Fixnum
Optional. Local storage per VM.
Corresponds to the JSON property dbNodeStorageSizeGb
2628 2629 2630 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2628 def db_node_storage_size_gb @db_node_storage_size_gb end |
#max_db_node_storage_size_gb ⇒ Fixnum
Optional. Maximum local storage per VM.
Corresponds to the JSON property maxDbNodeStorageSizeGb
2633 2634 2635 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2633 def max_db_node_storage_size_gb @max_db_node_storage_size_gb end |
#max_memory_size_gb ⇒ Fixnum
Optional. Maximum memory allocated in GBs.
Corresponds to the JSON property maxMemorySizeGb
2638 2639 2640 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2638 def max_memory_size_gb @max_memory_size_gb end |
#max_ocpu_count ⇒ Fixnum
Optional. Maximum OCPU count per database.
Corresponds to the JSON property maxOcpuCount
2643 2644 2645 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2643 def max_ocpu_count @max_ocpu_count end |
#memory_size_gb ⇒ Fixnum
Optional. Memory allocated in GBs.
Corresponds to the JSON property memorySizeGb
2648 2649 2650 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2648 def memory_size_gb @memory_size_gb end |
#ocid ⇒ String
Output only. OCID of database server.
Corresponds to the JSON property ocid
2653 2654 2655 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2653 def ocid @ocid end |
#ocpu_count ⇒ Fixnum
Optional. OCPU count per database.
Corresponds to the JSON property ocpuCount
2658 2659 2660 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2658 def ocpu_count @ocpu_count end |
#state ⇒ String
Output only. State of the database server.
Corresponds to the JSON property state
2663 2664 2665 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2663 def state @state end |
#vm_count ⇒ Fixnum
Optional. Vm count per database.
Corresponds to the JSON property vmCount
2668 2669 2670 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2668 def vm_count @vm_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2675 def update!(**args) @db_node_ids = args[:db_node_ids] if args.key?(:db_node_ids) @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb) @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb) @max_memory_size_gb = args[:max_memory_size_gb] if args.key?(:max_memory_size_gb) @max_ocpu_count = args[:max_ocpu_count] if args.key?(:max_ocpu_count) @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb) @ocid = args[:ocid] if args.key?(:ocid) @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count) @state = args[:state] if args.key?(:state) @vm_count = args[:vm_count] if args.key?(:vm_count) end |