Class: Google::Apis::OracledatabaseV1::DbSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the DbSystem (BaseDB) resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/DbSystem/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbSystem

Returns a new instance of DbSystem.



2754
2755
2756
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the DbSystem was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2697
2698
2699
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2697

def create_time
  @create_time
end

#display_nameString

Required. The display name for the System db. The name does not have to be unique within your project. Corresponds to the JSON property displayName

Returns:

  • (String)


2703
2704
2705
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2703

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the DbSystem Corresponds to the JSON property entitlementId

Returns:

  • (String)


2709
2710
2711
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2709

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us- east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


2716
2717
2718
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2716

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the DbSystem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2721
2722
2723
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2721

def labels
  @labels
end

#nameString

Identifier. The name of the DbSystem resource in the following format: projects/project/locations/region/dbSystems/db_system Corresponds to the JSON property name

Returns:

  • (String)


2727
2728
2729
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2727

def name
  @name
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


2732
2733
2734
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2732

def oci_url
  @oci_url
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the DbSystem. Format: projects/project/locations/location/odbNetworks/odb_network It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2740

def odb_network
  @odb_network
end

#odb_subnetString

Required. The name of the OdbSubnet associated with the DbSystem for IP allocation. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


2747
2748
2749
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2747

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::DbSystemProperties

The properties of a DbSystem. Corresponds to the JSON property properties



2752
2753
2754
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2752

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2759

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end