Class: Google::Apis::OracledatabaseV1::ExadbVmCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExadbVmCluster represents a cluster of VMs that are used to run Exadata workloads. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExadbVmCluster/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExadbVmCluster

Returns a new instance of ExadbVmCluster.



3350
3351
3352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_odb_subnetString

Required. Immutable. The name of the backup OdbSubnet associated with the ExadbVmCluster. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property backupOdbSubnet

Returns:

  • (String)


3292
3293
3294
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3292

def backup_odb_subnet
  @backup_odb_subnet
end

#create_timeString

Output only. The date and time that the ExadbVmCluster was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3297
3298
3299
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3297

def create_time
  @create_time
end

#display_nameString

Required. Immutable. The display name for the ExadbVmCluster. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3304
3305
3306
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3304

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExadbVmCluster. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3310
3311
3312
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3310

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Output only. Immutable. The GCP Oracle zone where Oracle ExadbVmCluster is hosted. Example: us-east4-b-r2. During creation, the system will pick the zone assigned to the ExascaleDbStorageVault. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3317
3318
3319
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3317

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExadbVmCluster. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3322
3323
3324
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3322

def labels
  @labels
end

#nameString

Identifier. The name of the ExadbVmCluster resource in the following format: projects/project/locations/region/exadbVmClusters/exadb_vm_cluster Corresponds to the JSON property name

Returns:

  • (String)


3328
3329
3330
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3328

def name
  @name
end

#odb_networkString

Optional. Immutable. The name of the OdbNetwork associated with the ExadbVmCluster. Format: projects/project/locations/location/odbNetworks/ odb_network It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


3336
3337
3338
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3336

def odb_network
  @odb_network
end

#odb_subnetString

Required. Immutable. The name of the OdbSubnet associated with the ExadbVmCluster for IP allocation. Format: projects/project/locations/ location/odbNetworks/odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


3343
3344
3345
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3343

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::ExadbVmClusterProperties

The properties of an ExadbVmCluster. Corresponds to the JSON property properties



3348
3349
3350
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3348

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3355

def update!(**args)
  @backup_odb_subnet = args[:backup_odb_subnet] if args.key?(:backup_odb_subnet)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end