Class: Google::Apis::OracledatabaseV1::ExadbVmClusterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of an ExadbVmCluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExadbVmClusterProperties

Returns a new instance of ExadbVmClusterProperties.



3437
3438
3439
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_ecpu_count_per_nodeFixnum

Optional. Immutable. The number of additional ECPUs per node for an Exadata VM cluster on exascale infrastructure. Corresponds to the JSON property additionalEcpuCountPerNode

Returns:

  • (Fixnum)


3332
3333
3334
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3332

def additional_ecpu_count_per_node
  @additional_ecpu_count_per_node
end

#cluster_nameString

Optional. Immutable. The cluster name for Exascale vm cluster. The cluster name must begin with an alphabetic character and may contain hyphens(-) but can not contain underscores(_). It should be not more than 11 characters and is not case sensitive. OCI Cluster name. Corresponds to the JSON property clusterName

Returns:

  • (String)


3340
3341
3342
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3340

def cluster_name
  @cluster_name
end

#data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptionsCommon

Data collection options for diagnostics. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/datatypes/DataCollectionOptions Corresponds to the JSON property dataCollectionOptions



3346
3347
3348
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3346

def data_collection_options
  @data_collection_options
end

#enabled_ecpu_count_per_nodeFixnum

Required. Immutable. The number of ECPUs enabled per node for an exadata vm cluster on exascale infrastructure. Corresponds to the JSON property enabledEcpuCountPerNode

Returns:

  • (Fixnum)


3352
3353
3354
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3352

def enabled_ecpu_count_per_node
  @enabled_ecpu_count_per_node
end

#exascale_db_storage_vaultString

Required. Immutable. The name of ExascaleDbStorageVault associated with the ExadbVmCluster. It can refer to an existing ExascaleDbStorageVault. Or a new one can be created during the ExadbVmCluster creation (requires storage_vault_properties to be set). Format: projects/project/locations/ location/exascaleDbStorageVaults/exascale_db_storage_vault Corresponds to the JSON property exascaleDbStorageVault

Returns:

  • (String)


3361
3362
3363
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3361

def exascale_db_storage_vault
  @exascale_db_storage_vault
end

#gi_versionString

Output only. The Oracle Grid Infrastructure (GI) software version. Corresponds to the JSON property giVersion

Returns:

  • (String)


3366
3367
3368
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3366

def gi_version
  @gi_version
end

#grid_image_idString

Required. Immutable. Grid Infrastructure Version. Corresponds to the JSON property gridImageId

Returns:

  • (String)


3371
3372
3373
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3371

def grid_image_id
  @grid_image_id
end

#hostnameString

Output only. The hostname of the ExadbVmCluster. Corresponds to the JSON property hostname

Returns:

  • (String)


3376
3377
3378
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3376

def hostname
  @hostname
end

#hostname_prefixString

Required. Immutable. Prefix for VM cluster host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3381

def hostname_prefix
  @hostname_prefix
end

#license_modelString

Optional. Immutable. The license type of the ExadbVmCluster. Corresponds to the JSON property licenseModel

Returns:

  • (String)


3386
3387
3388
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3386

def license_model
  @license_model
end

#lifecycle_stateString

Output only. State of the cluster. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


3391
3392
3393
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3391

def lifecycle_state
  @lifecycle_state
end

#memory_size_gbFixnum

Output only. Memory per VM (GB) (Read-only): Shows the amount of memory allocated to each VM. Memory is calculated based on 2.75 GB per Total ECPUs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


3397
3398
3399
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3397

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Required. The number of nodes/VMs in the ExadbVmCluster. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


3402
3403
3404
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3402

def node_count
  @node_count
end

#oci_uriString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUri

Returns:

  • (String)


3407
3408
3409
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3407

def oci_uri
  @oci_uri
end

#scan_listener_port_tcpFixnum

Optional. Immutable. SCAN listener port - TCP Corresponds to the JSON property scanListenerPortTcp

Returns:

  • (Fixnum)


3412
3413
3414
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3412

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#shape_attributeString

Required. Immutable. The shape attribute of the VM cluster. The type of Exascale storage used for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle Database 23ai and later Corresponds to the JSON property shapeAttribute

Returns:

  • (String)


3419
3420
3421
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3419

def shape_attribute
  @shape_attribute
end

#ssh_public_keysArray<String>

Required. Immutable. The SSH public keys for the ExadbVmCluster. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


3424
3425
3426
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3424

def ssh_public_keys
  @ssh_public_keys
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



3430
3431
3432
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3430

def time_zone
  @time_zone
end

#vm_file_system_storageGoogle::Apis::OracledatabaseV1::ExadbVmClusterStorageDetails

The storage allocation for the exadbvmcluster, in gigabytes (GB). Corresponds to the JSON property vmFileSystemStorage



3435
3436
3437
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3435

def vm_file_system_storage
  @vm_file_system_storage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3442

def update!(**args)
  @additional_ecpu_count_per_node = args[:additional_ecpu_count_per_node] if args.key?(:additional_ecpu_count_per_node)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @data_collection_options = args[:data_collection_options] if args.key?(:data_collection_options)
  @enabled_ecpu_count_per_node = args[:enabled_ecpu_count_per_node] if args.key?(:enabled_ecpu_count_per_node)
  @exascale_db_storage_vault = args[:exascale_db_storage_vault] if args.key?(:exascale_db_storage_vault)
  @gi_version = args[:gi_version] if args.key?(:gi_version)
  @grid_image_id = args[:grid_image_id] if args.key?(:grid_image_id)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @license_model = args[:license_model] if args.key?(:license_model)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @oci_uri = args[:oci_uri] if args.key?(:oci_uri)
  @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp)
  @shape_attribute = args[:shape_attribute] if args.key?(:shape_attribute)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @vm_file_system_storage = args[:vm_file_system_storage] if args.key?(:vm_file_system_storage)
end