Class: Google::Apis::OracledatabaseV1::ExascaleDbStorageVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExascaleDbStorageVault represents a storage vault exadb vm cluster resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExascaleDbStorageVault/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExascaleDbStorageVault

Returns a new instance of ExascaleDbStorageVault.



3691
3692
3693
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time when the ExascaleDbStorageVault was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3645

def create_time
  @create_time
end

#display_nameString

Required. The display name for the ExascaleDbStorageVault. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3652
3653
3654
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3652

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExascaleDbStorageVault. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3658
3659
3660
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3658

def entitlement_id
  @entitlement_id
end

#exadata_infrastructureString

Optional. The Exadata Infrastructure resource on which ExascaleDbStorageVault resource is created, in the following format: projects/project/locations/ region/cloudExadataInfrastuctures/cloud_extradata_infrastructure Corresponds to the JSON property exadataInfrastructure

Returns:

  • (String)


3665
3666
3667
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3665

def exadata_infrastructure
  @exadata_infrastructure
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle ExascaleDbStorageVault is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3672
3673
3674
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3672

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExascaleDbStorageVault. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3677
3678
3679
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3677

def labels
  @labels
end

#nameString

Identifier. The resource name of the ExascaleDbStorageVault. Format: projects/ project/locations/location/exascaleDbStorageVaults/ exascale_db_storage_vault Corresponds to the JSON property name

Returns:

  • (String)


3684
3685
3686
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3684

def name
  @name
end

#propertiesGoogle::Apis::OracledatabaseV1::ExascaleDbStorageVaultProperties

The properties of the ExascaleDbStorageVault. next ID: 12 Corresponds to the JSON property properties



3689
3690
3691
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3689

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3696

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @exadata_infrastructure = args[:exadata_infrastructure] if args.key?(:exadata_infrastructure)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end