Class: Google::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateAzureSynapseAnalyticsConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateAzureSynapseAnalyticsConnectionProperties

Returns a new instance of GoldengateAzureSynapseAnalyticsConnectionProperties.



4197
4198
4199
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. JDBC connection string. e.g.: 'jdbc:sqlserver://.sql.azuresynapse. net:1433;database=;encrypt=true;trustServerCertificate=false; hostNameInCertificate=*.sql.azuresynapse.net;loginTimeout=300;' Corresponds to the JSON property connectionString

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4171

def connection_string
  @connection_string
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Azure Synapse Analytics connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


4177
4178
4179
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4177

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Azure Synapse Analytics connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


4184
4185
4186
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4184

def password_secret_version
  @password_secret_version
end

#technology_typeString

Optional. The technology type of AzureSynapseAnalyticsConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


4189
4190
4191
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4189

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4195

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4202
4203
4204
4205
4206
4207
4208
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4202

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end