Class: Google::Apis::OracledatabaseV1::GoldengateConnection
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the GoldengateConnection resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#oci_url ⇒ String
Output only.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Optional.
-
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateConnection
constructor
A new instance of GoldengateConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateConnection
Returns a new instance of GoldengateConnection.
4320 4321 4322 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the GoldengateConnection was created.
Corresponds to the JSON property createTime
4268 4269 4270 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4268 def create_time @create_time end |
#entitlement_id ⇒ String
Output only. The ID of the subscription entitlement associated with the
GoldengateConnection.
Corresponds to the JSON property entitlementId
4274 4275 4276 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4274 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted.
Example: us-east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
4281 4282 4283 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4281 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. The labels or tags associated with the GoldengateConnection.
Corresponds to the JSON property labels
4286 4287 4288 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4286 def labels @labels end |
#name ⇒ String
Identifier. The name of the GoldengateConnection resource in the following
format: projects/project/locations/region/goldengateConnections/
goldengate_connection
Corresponds to the JSON property name
4293 4294 4295 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4293 def name @name end |
#oci_url ⇒ String
Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
Corresponds to the JSON property ociUrl
4298 4299 4300 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4298 def oci_url @oci_url end |
#odb_network ⇒ String
Optional. The name of the OdbNetwork associated with the GoldengateConnection.
The format is projects/project/locations/location/odbNetworks/odb_network
. It is optional but if specified, this should match the parent ODBNetwork of
the OdbSubnet.
Corresponds to the JSON property odbNetwork
4306 4307 4308 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4306 def odb_network @odb_network end |
#odb_subnet ⇒ String
Optional. The name of the OdbSubnet associated with the GoldengateConnection
for IP allocation. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
4313 4314 4315 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4313 def odb_subnet @odb_subnet end |
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Corresponds to the JSON property properties
4318 4319 4320 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4318 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4325 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @oci_url = args[:oci_url] if args.key?(:oci_url) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @properties = args[:properties] if args.key?(:properties) end |