Class: Google::Apis::OracledatabaseV1::GoldengateConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of a GoldengateConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateConnectionProperties

Returns a new instance of GoldengateConnectionProperties.



4664
4665
4666
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amazon_kinesis_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonKinesisConnectionProperties

The properties of GoldengateAmazonKinesisConnection. Corresponds to the JSON property amazonKinesisConnectionProperties



4476
4477
4478
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4476

def amazon_kinesis_connection_properties
  @amazon_kinesis_connection_properties
end

#amazon_redshift_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonRedshiftConnectionProperties

The properties of GoldengateAmazonRedshiftConnection. Corresponds to the JSON property amazonRedshiftConnectionProperties



4481
4482
4483
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4481

def amazon_redshift_connection_properties
  @amazon_redshift_connection_properties
end

#amazon_s3_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonS3ConnectionProperties

The properties of GoldengateAmazonS3Connection. Corresponds to the JSON property amazonS3ConnectionProperties



4486
4487
4488
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4486

def amazon_s3_connection_properties
  @amazon_s3_connection_properties
end

#azure_data_lake_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAzureDataLakeStorageConnectionProperties

The properties of GoldengateAzureDataLakeStorageConnection. Corresponds to the JSON property azureDataLakeStorageConnectionProperties



4491
4492
4493
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4491

def azure_data_lake_storage_connection_properties
  @azure_data_lake_storage_connection_properties
end

#azure_synapse_analytics_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties

The properties of GoldengateAzureSynapseAnalyticsConnection. Corresponds to the JSON property azureSynapseAnalyticsConnectionProperties



4496
4497
4498
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4496

def azure_synapse_analytics_connection_properties
  @azure_synapse_analytics_connection_properties
end

#connection_typeString

Required. The connection type. Corresponds to the JSON property connectionType

Returns:

  • (String)


4501
4502
4503
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4501

def connection_type
  @connection_type
end

#databricks_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties

The properties of GoldengateDatabricksConnection. Corresponds to the JSON property databricksConnectionProperties



4506
4507
4508
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4506

def databricks_connection_properties
  @databricks_connection_properties
end

#db2_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateDb2ConnectionProperties

The properties of GoldengateDb2Connection. Corresponds to the JSON property db2ConnectionProperties



4511
4512
4513
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4511

def db2_connection_properties
  @db2_connection_properties
end

#descriptionString

Optional. Metadata about this specific object. Corresponds to the JSON property description

Returns:

  • (String)


4516
4517
4518
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4516

def description
  @description
end

#display_nameString

Required. An object's Display Name. Corresponds to the JSON property displayName

Returns:

  • (String)


4521
4522
4523
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4521

def display_name
  @display_name
end

#elasticsearch_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties

The properties of GoldengateElasticsearchConnection. Corresponds to the JSON property elasticsearchConnectionProperties



4526
4527
4528
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4526

def elasticsearch_connection_properties
  @elasticsearch_connection_properties
end

#generic_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGenericConnectionProperties

The properties of GoldengateGenericConnectionProperties. Corresponds to the JSON property genericConnectionProperties



4531
4532
4533
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4531

def generic_connection_properties
  @generic_connection_properties
end

#goldengate_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties

The properties of GoldengateGoldengateConnectionProperties. Corresponds to the JSON property goldengateConnectionProperties



4536
4537
4538
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4536

def goldengate_connection_properties
  @goldengate_connection_properties
end

#google_big_query_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoogleBigQueryConnectionProperties

The properties of GoldengateGoogleBigQueryConnectionProperties. Corresponds to the JSON property googleBigQueryConnectionProperties



4541
4542
4543
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4541

def google_big_query_connection_properties
  @google_big_query_connection_properties
end

#google_cloud_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoogleCloudStorageConnectionProperties

The properties of GoldengateGoogleCloudStorageConnectionProperties. Corresponds to the JSON property googleCloudStorageConnectionProperties



4546
4547
4548
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4546

def google_cloud_storage_connection_properties
  @google_cloud_storage_connection_properties
end

#google_pubsub_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGooglePubsubConnectionProperties

The properties of GoldengateGooglePubsubConnection. Corresponds to the JSON property googlePubsubConnectionProperties



4551
4552
4553
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4551

def google_pubsub_connection_properties
  @google_pubsub_connection_properties
end

#hdfs_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateHdfsConnectionProperties

The properties of GoldengateHdfsConnection. Corresponds to the JSON property hdfsConnectionProperties



4556
4557
4558
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4556

def hdfs_connection_properties
  @hdfs_connection_properties
end

#iceberg_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateIcebergConnectionProperties

The properties of GoldengateIcebergConnection. Corresponds to the JSON property icebergConnectionProperties



4561
4562
4563
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4561

def iceberg_connection_properties
  @iceberg_connection_properties
end

#ingress_ip_addressesArray<String>

Output only. The Ingress IPs of the GoldengateConnection. Corresponds to the JSON property ingressIpAddresses

Returns:

  • (Array<String>)


4566
4567
4568
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4566

def ingress_ip_addresses
  @ingress_ip_addresses
end

#java_message_service_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties

The properties of GoldengateJavaMessageServiceConnection. Corresponds to the JSON property javaMessageServiceConnectionProperties



4571
4572
4573
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4571

def java_message_service_connection_properties
  @java_message_service_connection_properties
end

#kafka_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties

The properties of GoldengateKafkaConnection. Corresponds to the JSON property kafkaConnectionProperties



4576
4577
4578
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4576

def kafka_connection_properties
  @kafka_connection_properties
end

#kafka_schema_registry_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties

The properties of GoldengateKafkaSchemaRegistryConnection. Corresponds to the JSON property kafkaSchemaRegistryConnectionProperties



4581
4582
4583
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4581

def kafka_schema_registry_connection_properties
  @kafka_schema_registry_connection_properties
end

#lifecycle_detailsString

Output only. Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


4587
4588
4589
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4587

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. The lifecycle state of the connection. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


4592
4593
4594
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4592

def lifecycle_state
  @lifecycle_state
end

#microsoft_fabric_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMicrosoftFabricConnectionProperties

The properties of GoldengateMicrosoftFabricConnection. Corresponds to the JSON property microsoftFabricConnectionProperties



4597
4598
4599
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4597

def microsoft_fabric_connection_properties
  @microsoft_fabric_connection_properties
end

#microsoft_sqlserver_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties

The properties of GoldengateMicrosoftSqlserverConnection. Corresponds to the JSON property microsoftSqlserverConnectionProperties



4602
4603
4604
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4602

def microsoft_sqlserver_connection_properties
  @microsoft_sqlserver_connection_properties
end

#mongodb_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

The properties of GoldengateMongodbConnection. Corresponds to the JSON property mongodbConnectionProperties



4607
4608
4609
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4607

def mongodb_connection_properties
  @mongodb_connection_properties
end

#mysql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties

Properties of GoldengateMysqlConnection. Corresponds to the JSON property mysqlConnectionProperties



4612
4613
4614
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4612

def mysql_connection_properties
  @mysql_connection_properties
end

#oci_object_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties

The properties of GoldengateOciObjectStorageConnection. Corresponds to the JSON property ociObjectStorageConnectionProperties



4617
4618
4619
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4617

def oci_object_storage_connection_properties
  @oci_object_storage_connection_properties
end

#ocidString

Output only. The [OCID] of the connection being referenced. Corresponds to the JSON property ocid

Returns:

  • (String)


4622
4623
4624
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4622

def ocid
  @ocid
end

#oracle_ai_data_platform_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties

The properties of GoldengateOracleAIDataPlatformConnection. Corresponds to the JSON property oracleAiDataPlatformConnectionProperties



4627
4628
4629
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4627

def oracle_ai_data_platform_connection_properties
  @oracle_ai_data_platform_connection_properties
end

#oracle_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties

The properties of Goldengate Oracle Database Connection. Corresponds to the JSON property oracleConnectionProperties



4632
4633
4634
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4632

def oracle_connection_properties
  @oracle_connection_properties
end

#oracle_nosql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties

The properties of GoldengateOracleNosqlConnection. Corresponds to the JSON property oracleNosqlConnectionProperties



4637
4638
4639
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4637

def oracle_nosql_connection_properties
  @oracle_nosql_connection_properties
end

#postgresql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties

The properties of GoldengatePostgresqlConnection. Corresponds to the JSON property postgresqlConnectionProperties



4642
4643
4644
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4642

def postgresql_connection_properties
  @postgresql_connection_properties
end

#redis_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties

The properties of GoldengateRedisConnection. Corresponds to the JSON property redisConnectionProperties



4647
4648
4649
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4647

def redis_connection_properties
  @redis_connection_properties
end

#routing_methodString

Optional. The routing method for the GoldengateConnection. Corresponds to the JSON property routingMethod

Returns:

  • (String)


4652
4653
4654
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4652

def routing_method
  @routing_method
end

#snowflake_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties

The properties of GoldengateSnowflakeConnection. Corresponds to the JSON property snowflakeConnectionProperties



4657
4658
4659
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4657

def snowflake_connection_properties
  @snowflake_connection_properties
end

#update_timeString

Output only. The time the resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4662
4663
4664
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4662

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4669

def update!(**args)
  @amazon_kinesis_connection_properties = args[:amazon_kinesis_connection_properties] if args.key?(:amazon_kinesis_connection_properties)
  @amazon_redshift_connection_properties = args[:amazon_redshift_connection_properties] if args.key?(:amazon_redshift_connection_properties)
  @amazon_s3_connection_properties = args[:amazon_s3_connection_properties] if args.key?(:amazon_s3_connection_properties)
  @azure_data_lake_storage_connection_properties = args[:azure_data_lake_storage_connection_properties] if args.key?(:azure_data_lake_storage_connection_properties)
  @azure_synapse_analytics_connection_properties = args[:azure_synapse_analytics_connection_properties] if args.key?(:azure_synapse_analytics_connection_properties)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @databricks_connection_properties = args[:databricks_connection_properties] if args.key?(:databricks_connection_properties)
  @db2_connection_properties = args[:db2_connection_properties] if args.key?(:db2_connection_properties)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @elasticsearch_connection_properties = args[:elasticsearch_connection_properties] if args.key?(:elasticsearch_connection_properties)
  @generic_connection_properties = args[:generic_connection_properties] if args.key?(:generic_connection_properties)
  @goldengate_connection_properties = args[:goldengate_connection_properties] if args.key?(:goldengate_connection_properties)
  @google_big_query_connection_properties = args[:google_big_query_connection_properties] if args.key?(:google_big_query_connection_properties)
  @google_cloud_storage_connection_properties = args[:google_cloud_storage_connection_properties] if args.key?(:google_cloud_storage_connection_properties)
  @google_pubsub_connection_properties = args[:google_pubsub_connection_properties] if args.key?(:google_pubsub_connection_properties)
  @hdfs_connection_properties = args[:hdfs_connection_properties] if args.key?(:hdfs_connection_properties)
  @iceberg_connection_properties = args[:iceberg_connection_properties] if args.key?(:iceberg_connection_properties)
  @ingress_ip_addresses = args[:ingress_ip_addresses] if args.key?(:ingress_ip_addresses)
  @java_message_service_connection_properties = args[:java_message_service_connection_properties] if args.key?(:java_message_service_connection_properties)
  @kafka_connection_properties = args[:kafka_connection_properties] if args.key?(:kafka_connection_properties)
  @kafka_schema_registry_connection_properties = args[:kafka_schema_registry_connection_properties] if args.key?(:kafka_schema_registry_connection_properties)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @microsoft_fabric_connection_properties = args[:microsoft_fabric_connection_properties] if args.key?(:microsoft_fabric_connection_properties)
  @microsoft_sqlserver_connection_properties = args[:microsoft_sqlserver_connection_properties] if args.key?(:microsoft_sqlserver_connection_properties)
  @mongodb_connection_properties = args[:mongodb_connection_properties] if args.key?(:mongodb_connection_properties)
  @mysql_connection_properties = args[:mysql_connection_properties] if args.key?(:mysql_connection_properties)
  @oci_object_storage_connection_properties = args[:oci_object_storage_connection_properties] if args.key?(:oci_object_storage_connection_properties)
  @ocid = args[:ocid] if args.key?(:ocid)
  @oracle_ai_data_platform_connection_properties = args[:oracle_ai_data_platform_connection_properties] if args.key?(:oracle_ai_data_platform_connection_properties)
  @oracle_connection_properties = args[:oracle_connection_properties] if args.key?(:oracle_connection_properties)
  @oracle_nosql_connection_properties = args[:oracle_nosql_connection_properties] if args.key?(:oracle_nosql_connection_properties)
  @postgresql_connection_properties = args[:postgresql_connection_properties] if args.key?(:postgresql_connection_properties)
  @redis_connection_properties = args[:redis_connection_properties] if args.key?(:redis_connection_properties)
  @routing_method = args[:routing_method] if args.key?(:routing_method)
  @snowflake_connection_properties = args[:snowflake_connection_properties] if args.key?(:snowflake_connection_properties)
  @update_time = args[:update_time] if args.key?(:update_time)
end