Class: Google::Apis::OracledatabaseV1::GoldengateDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

GoldengateDeployment Goldengate Deployment resource model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeployment

Returns a new instance of GoldengateDeployment.



4964
4965
4966
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the GoldengateDeployment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4911
4912
4913
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4911

def create_time
  @create_time
end

#display_nameString

Required. The display name for the GoldengateDeployment. Corresponds to the JSON property displayName

Returns:

  • (String)


4916
4917
4918
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4916

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the GoldengateDeployment Corresponds to the JSON property entitlementId

Returns:

  • (String)


4922
4923
4924
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4922

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle GoldengateDeployment is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


4929
4930
4931
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4929

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the GoldengateDeployment. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4934
4935
4936
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4934

def labels
  @labels
end

#nameString

Identifier. The name of the GoldengateDeployment resource in the following format: projects/project/locations/region/goldengateDeployments/ goldengate_deployment Corresponds to the JSON property name

Returns:

  • (String)


4941
4942
4943
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4941

def name
  @name
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


4946
4947
4948
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4946

def oci_url
  @oci_url
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the GoldengateDeployment. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


4951
4952
4953
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4951

def odb_network
  @odb_network
end

#odb_subnetString

Required. The name of the OdbSubnet associated with the GoldengateDeployment for IP allocation. Corresponds to the JSON property odbSubnet

Returns:

  • (String)


4957
4958
4959
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4957

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::GoldengateDeploymentProperties

Properties of GoldengateDeployment. Corresponds to the JSON property properties



4962
4963
4964
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4962

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4969

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end