Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the Goldengate Deployment Environment resource.
Instance Attribute Summary collapse
-
#auto_scaling_enabled ⇒ Boolean
(also: #auto_scaling_enabled?)
Output only.
-
#category ⇒ String
Output only.
-
#default_cpu_core_count ⇒ Fixnum
Output only.
-
#display_name ⇒ String
The display name of the Goldengate Deployment Environment resource.
-
#environment_type ⇒ String
Output only.
-
#max_cpu_core_count ⇒ Fixnum
Output only.
-
#memory_gb_per_cpu_core ⇒ Fixnum
Output only.
-
#min_cpu_core_count ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#network_bandwidth_gbps_per_cpu_core ⇒ Fixnum
Output only.
-
#storage_usage_limit_gb_per_cpu_core ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentEnvironment
constructor
A new instance of GoldengateDeploymentEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentEnvironment
Returns a new instance of GoldengateDeploymentEnvironment.
5053 5054 5055 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_scaling_enabled ⇒ Boolean Also known as: auto_scaling_enabled?
Output only. Whether auto scaling is enabled by default for the Goldengate
Deployment Environment resource.
Corresponds to the JSON property autoScalingEnabled
4991 4992 4993 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4991 def auto_scaling_enabled @auto_scaling_enabled end |
#category ⇒ String
Output only. The category of the Goldengate Deployment Environment resource.
Corresponds to the JSON property category
4997 4998 4999 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4997 def category @category end |
#default_cpu_core_count ⇒ Fixnum
Output only. The default CPU core count of the Goldengate Deployment
Environment resource.
Corresponds to the JSON property defaultCpuCoreCount
5003 5004 5005 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5003 def default_cpu_core_count @default_cpu_core_count end |
#display_name ⇒ String
The display name of the Goldengate Deployment Environment resource.
Corresponds to the JSON property displayName
5008 5009 5010 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5008 def display_name @display_name end |
#environment_type ⇒ String
Output only. The environment type of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property environmentType
5014 5015 5016 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5014 def environment_type @environment_type end |
#max_cpu_core_count ⇒ Fixnum
Output only. The max CPU core count of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property maxCpuCoreCount
5020 5021 5022 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5020 def max_cpu_core_count @max_cpu_core_count end |
#memory_gb_per_cpu_core ⇒ Fixnum
Output only. The memory per CPU core in GBs of the Goldengate Deployment
Environment resource.
Corresponds to the JSON property memoryGbPerCpuCore
5026 5027 5028 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5026 def memory_gb_per_cpu_core @memory_gb_per_cpu_core end |
#min_cpu_core_count ⇒ Fixnum
Output only. The min CPU core count of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property minCpuCoreCount
5032 5033 5034 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5032 def min_cpu_core_count @min_cpu_core_count end |
#name ⇒ String
Identifier. The name of the Goldengate Deployment Environment resource with
the format: projects/project/locations/location/
goldengateDeploymentEnvironments/goldengate_deployment_environment
Corresponds to the JSON property name
5039 5040 5041 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5039 def name @name end |
#network_bandwidth_gbps_per_cpu_core ⇒ Fixnum
Output only. The network bandwidth per CPU core in Gbps of the Goldengate
Deployment Environment resource.
Corresponds to the JSON property networkBandwidthGbpsPerCpuCore
5045 5046 5047 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5045 def network_bandwidth_gbps_per_cpu_core @network_bandwidth_gbps_per_cpu_core end |
#storage_usage_limit_gb_per_cpu_core ⇒ Fixnum
Output only. The storage usage limit per CPU core in GBs of the Goldengate
Deployment Environment resource.
Corresponds to the JSON property storageUsageLimitGbPerCpuCore
5051 5052 5053 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5051 def storage_usage_limit_gb_per_cpu_core @storage_usage_limit_gb_per_cpu_core end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5058 def update!(**args) @auto_scaling_enabled = args[:auto_scaling_enabled] if args.key?(:auto_scaling_enabled) @category = args[:category] if args.key?(:category) @default_cpu_core_count = args[:default_cpu_core_count] if args.key?(:default_cpu_core_count) @display_name = args[:display_name] if args.key?(:display_name) @environment_type = args[:environment_type] if args.key?(:environment_type) @max_cpu_core_count = args[:max_cpu_core_count] if args.key?(:max_cpu_core_count) @memory_gb_per_cpu_core = args[:memory_gb_per_cpu_core] if args.key?(:memory_gb_per_cpu_core) @min_cpu_core_count = args[:min_cpu_core_count] if args.key?(:min_cpu_core_count) @name = args[:name] if args.key?(:name) @network_bandwidth_gbps_per_cpu_core = args[:network_bandwidth_gbps_per_cpu_core] if args.key?(:network_bandwidth_gbps_per_cpu_core) @storage_usage_limit_gb_per_cpu_core = args[:storage_usage_limit_gb_per_cpu_core] if args.key?(:storage_usage_limit_gb_per_cpu_core) end |