Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Properties of GoldengateDeployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeploymentProperties

Returns a new instance of GoldengateDeploymentProperties.



5338
5339
5340
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_scheduleGoogle::Apis::OracledatabaseV1::GoldengateBackupSchedule

The backup schedule of the GoldengateDeployment. Corresponds to the JSON property backupSchedule



5123
5124
5125
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5123

def backup_schedule
  @backup_schedule
end

#categoryString

Output only. The category of the GoldengateDeployment. Corresponds to the JSON property category

Returns:

  • (String)


5128
5129
5130
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5128

def category
  @category
end

#cpu_core_countFixnum

Optional. The Minimum number of OCPUs to be made available for this Deployment. Corresponds to the JSON property cpuCoreCount

Returns:

  • (Fixnum)


5133
5134
5135
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5133

def cpu_core_count
  @cpu_core_count
end

#deployment_backup_idString

Output only. The deployment backup id of the GoldengateDeployment. Corresponds to the JSON property deploymentBackupId

Returns:

  • (String)


5138
5139
5140
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5138

def deployment_backup_id
  @deployment_backup_id
end

#deployment_diagnostic_dataGoogle::Apis::OracledatabaseV1::DeploymentDiagnosticData

The deployment diagnostic data. Corresponds to the JSON property deploymentDiagnosticData



5143
5144
5145
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5143

def deployment_diagnostic_data
  @deployment_diagnostic_data
end

#deployment_roleString

Output only. The deployment role of the GoldengateDeployment. Corresponds to the JSON property deploymentRole

Returns:

  • (String)


5148
5149
5150
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5148

def deployment_role
  @deployment_role
end

#deployment_typeString

Required. A valid Goldengate Deployment type. For a list of supported types, use the ListGoldengateDeploymentTypes operation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


5154
5155
5156
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5154

def deployment_type
  @deployment_type
end

#deployment_urlString

Output only. The deployment url of the GoldengateDeployment. Corresponds to the JSON property deploymentUrl

Returns:

  • (String)


5159
5160
5161
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5159

def deployment_url
  @deployment_url
end

#descriptionString

Optional. The description of the GoldengateDeployment. Corresponds to the JSON property description

Returns:

  • (String)


5164
5165
5166
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5164

def description
  @description
end

#environment_typeString

Optional. The environment type of the GoldengateDeployment. Corresponds to the JSON property environmentType

Returns:

  • (String)


5169
5170
5171
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5169

def environment_type
  @environment_type
end

#fqdnString

Output only. The Fully Qualified Domain Name of the GoldengateDeployment. Corresponds to the JSON property fqdn

Returns:

  • (String)


5174
5175
5176
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5174

def fqdn
  @fqdn
end

#healthyBoolean Also known as: healthy?

Output only. Whether the GoldengateDeployment is healthy. Corresponds to the JSON property healthy

Returns:

  • (Boolean)


5179
5180
5181
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5179

def healthy
  @healthy
end

#ingress_ipsArray<Google::Apis::OracledatabaseV1::IngressIp>

Output only. The ingress ips of the GoldengateDeployment. Corresponds to the JSON property ingressIps



5185
5186
5187
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5185

def ingress_ips
  @ingress_ips
end

#is_auto_scaling_enabledBoolean Also known as: is_auto_scaling_enabled?

Optional. Indicates if auto scaling is enabled for the Deployment's CPU core count. Corresponds to the JSON property isAutoScalingEnabled

Returns:

  • (Boolean)


5191
5192
5193
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5191

def is_auto_scaling_enabled
  @is_auto_scaling_enabled
end

#is_latest_versionBoolean Also known as: is_latest_version?

Output only. Whether the GoldengateDeployment is of the latest version. Corresponds to the JSON property isLatestVersion

Returns:

  • (Boolean)


5197
5198
5199
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5197

def is_latest_version
  @is_latest_version
end

#is_publicBoolean Also known as: is_public?

Output only. Whether the GoldengateDeployment is public. Corresponds to the JSON property isPublic

Returns:

  • (Boolean)


5203
5204
5205
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5203

def is_public
  @is_public
end

#is_storage_utilization_limit_exceededBoolean Also known as: is_storage_utilization_limit_exceeded?

Output only. Whether storage utilization limit is exceeded of the GoldengateDeployment. Corresponds to the JSON property isStorageUtilizationLimitExceeded

Returns:

  • (Boolean)


5210
5211
5212
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5210

def is_storage_utilization_limit_exceeded
  @is_storage_utilization_limit_exceeded
end

#last_backup_schedule_timeString

Output only. The time last backup scheduled of the GoldengateDeployment. Corresponds to the JSON property lastBackupScheduleTime

Returns:

  • (String)


5216
5217
5218
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5216

def last_backup_schedule_time
  @last_backup_schedule_time
end

#license_modelString

Optional. The Oracle license model that applies to a Deployment. Corresponds to the JSON property licenseModel

Returns:

  • (String)


5221
5222
5223
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5221

def license_model
  @license_model
end

#lifecycle_detailsString

Output only. The lifecycle details of the GoldengateDeployment. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


5226
5227
5228
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5226

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. State of the GoldengateDeployment. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


5231
5232
5233
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5231

def lifecycle_state
  @lifecycle_state
end

#lifecycle_sub_stateString

Output only. The lifecycle sub-state of the GoldengateDeployment. Corresponds to the JSON property lifecycleSubState

Returns:

  • (String)


5236
5237
5238
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5236

def lifecycle_sub_state
  @lifecycle_sub_state
end

#load_balancer_idString

Output only. The load balancer id of the GoldengateDeployment. Corresponds to the JSON property loadBalancerId

Returns:

  • (String)


5241
5242
5243
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5241

def load_balancer_id
  @load_balancer_id
end

#load_balancer_subnet_idString

Output only. The load balancer subnet id of the GoldengateDeployment. Corresponds to the JSON property loadBalancerSubnetId

Returns:

  • (String)


5246
5247
5248
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5246

def load_balancer_subnet_id
  @load_balancer_subnet_id
end

#locksArray<Google::Apis::OracledatabaseV1::GoldengateDeploymentLock>

Output only. The locks of the GoldengateDeployment. Corresponds to the JSON property locks



5251
5252
5253
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5251

def locks
  @locks
end

#maintenance_configGoogle::Apis::OracledatabaseV1::GoldengateMaintenanceConfig

The maintenance configuration of the GoldengateDeployment. Corresponds to the JSON property maintenanceConfig



5256
5257
5258
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5256

def maintenance_config
  @maintenance_config
end

#maintenance_windowGoogle::Apis::OracledatabaseV1::GoldengateMaintenanceWindow

The maintenance window of the GoldengateDeployment. Corresponds to the JSON property maintenanceWindow



5261
5262
5263
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5261

def maintenance_window
  @maintenance_window
end

#next_backup_schedule_timeString

Output only. The time next backup scheduled of the GoldengateDeployment. Corresponds to the JSON property nextBackupScheduleTime

Returns:

  • (String)


5266
5267
5268
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5266

def next_backup_schedule_time
  @next_backup_schedule_time
end

#next_maintenance_action_typeString

Output only. The next maintenance action type of the GoldengateDeployment. Corresponds to the JSON property nextMaintenanceActionType

Returns:

  • (String)


5271
5272
5273
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5271

def next_maintenance_action_type
  @next_maintenance_action_type
end

#next_maintenance_descriptionString

Output only. The next maintenance description of the GoldengateDeployment. Corresponds to the JSON property nextMaintenanceDescription

Returns:

  • (String)


5276
5277
5278
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5276

def next_maintenance_description
  @next_maintenance_description
end

#next_maintenance_timeString

Output only. The time of next maintenance of the GoldengateDeployment. Corresponds to the JSON property nextMaintenanceTime

Returns:

  • (String)


5281
5282
5283
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5281

def next_maintenance_time
  @next_maintenance_time
end

#nsg_idsArray<String>

Output only. The nsg ids of the GoldengateDeployment. Corresponds to the JSON property nsgIds

Returns:

  • (Array<String>)


5286
5287
5288
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5286

def nsg_ids
  @nsg_ids
end

#ocidString

Output only. OCID of the GoldengateDeployment. Corresponds to the JSON property ocid

Returns:

  • (String)


5291
5292
5293
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5291

def ocid
  @ocid
end

#ogg_dataGoogle::Apis::OracledatabaseV1::GoldengateOggDeployment

The Ogg data of the GoldengateDeployment. Corresponds to the JSON property oggData



5296
5297
5298
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5296

def ogg_data
  @ogg_data
end

#ogg_version_support_end_timeString

Output only. The time ogg version supported until of the GoldengateDeployment. Corresponds to the JSON property oggVersionSupportEndTime

Returns:

  • (String)


5301
5302
5303
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5301

def ogg_version_support_end_time
  @ogg_version_support_end_time
end

#placementsArray<Google::Apis::OracledatabaseV1::GoldengatePlacement>

Output only. The placements of the GoldengateDeployment. Corresponds to the JSON property placements



5306
5307
5308
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5306

def placements
  @placements
end

#private_ip_addressString

Output only. The private ip address of the GoldengateDeployment. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5311

def private_ip_address
  @private_ip_address
end

#public_ip_addressString

Output only. The public ip address of the GoldengateDeployment. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


5316
5317
5318
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5316

def public_ip_address
  @public_ip_address
end

#role_change_timeString

Output only. The time when the role of the GoldengateDeployment was changed. Corresponds to the JSON property roleChangeTime

Returns:

  • (String)


5321
5322
5323
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5321

def role_change_time
  @role_change_time
end

#storage_utilization_bytesFixnum

Output only. The storage utilization in bytes of the GoldengateDeployment. Corresponds to the JSON property storageUtilizationBytes

Returns:

  • (Fixnum)


5326
5327
5328
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5326

def storage_utilization_bytes
  @storage_utilization_bytes
end

#update_timeString

Output only. The time the GoldengateDeployment was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5331

def update_time
  @update_time
end

#upgrade_required_timeString

Output only. The time upgrade required of the GoldengateDeployment. Corresponds to the JSON property upgradeRequiredTime

Returns:

  • (String)


5336
5337
5338
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5336

def upgrade_required_time
  @upgrade_required_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
5383
5384
5385
5386
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5343

def update!(**args)
  @backup_schedule = args[:backup_schedule] if args.key?(:backup_schedule)
  @category = args[:category] if args.key?(:category)
  @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count)
  @deployment_backup_id = args[:deployment_backup_id] if args.key?(:deployment_backup_id)
  @deployment_diagnostic_data = args[:deployment_diagnostic_data] if args.key?(:deployment_diagnostic_data)
  @deployment_role = args[:deployment_role] if args.key?(:deployment_role)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @deployment_url = args[:deployment_url] if args.key?(:deployment_url)
  @description = args[:description] if args.key?(:description)
  @environment_type = args[:environment_type] if args.key?(:environment_type)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @healthy = args[:healthy] if args.key?(:healthy)
  @ingress_ips = args[:ingress_ips] if args.key?(:ingress_ips)
  @is_auto_scaling_enabled = args[:is_auto_scaling_enabled] if args.key?(:is_auto_scaling_enabled)
  @is_latest_version = args[:is_latest_version] if args.key?(:is_latest_version)
  @is_public = args[:is_public] if args.key?(:is_public)
  @is_storage_utilization_limit_exceeded = args[:is_storage_utilization_limit_exceeded] if args.key?(:is_storage_utilization_limit_exceeded)
  @last_backup_schedule_time = args[:last_backup_schedule_time] if args.key?(:last_backup_schedule_time)
  @license_model = args[:license_model] if args.key?(:license_model)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @lifecycle_sub_state = args[:lifecycle_sub_state] if args.key?(:lifecycle_sub_state)
  @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id)
  @load_balancer_subnet_id = args[:load_balancer_subnet_id] if args.key?(:load_balancer_subnet_id)
  @locks = args[:locks] if args.key?(:locks)
  @maintenance_config = args[:maintenance_config] if args.key?(:maintenance_config)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @next_backup_schedule_time = args[:next_backup_schedule_time] if args.key?(:next_backup_schedule_time)
  @next_maintenance_action_type = args[:next_maintenance_action_type] if args.key?(:next_maintenance_action_type)
  @next_maintenance_description = args[:next_maintenance_description] if args.key?(:next_maintenance_description)
  @next_maintenance_time = args[:next_maintenance_time] if args.key?(:next_maintenance_time)
  @nsg_ids = args[:nsg_ids] if args.key?(:nsg_ids)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ogg_data = args[:ogg_data] if args.key?(:ogg_data)
  @ogg_version_support_end_time = args[:ogg_version_support_end_time] if args.key?(:ogg_version_support_end_time)
  @placements = args[:placements] if args.key?(:placements)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @role_change_time = args[:role_change_time] if args.key?(:role_change_time)
  @storage_utilization_bytes = args[:storage_utilization_bytes] if args.key?(:storage_utilization_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade_required_time = args[:upgrade_required_time] if args.key?(:upgrade_required_time)
end