Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Goldengate Deployment Version resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeploymentVersion

Returns a new instance of GoldengateDeploymentVersion.



5496
5497
5498
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The name of the Goldengate Deployment Version resource with the format: projects/project/locations/location/goldengateDeploymentVersions/ goldengate_deployment_version Corresponds to the JSON property name

Returns:

  • (String)


5483
5484
5485
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5483

def name
  @name
end

#ocidString

Output only. The deployment version ocid of the Goldengate Deployment Version resource. Corresponds to the JSON property ocid

Returns:

  • (String)


5489
5490
5491
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5489

def ocid
  @ocid
end

#propertiesGoogle::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties

Properties of GoldengateDeploymentVersion. Corresponds to the JSON property properties



5494
5495
5496
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5494

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5501
5502
5503
5504
5505
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5501

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @ocid = args[:ocid] if args.key?(:ocid)
  @properties = args[:properties] if args.key?(:properties)
end