Class: Google::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateElasticsearchConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateElasticsearchConnectionProperties

Returns a new instance of GoldengateElasticsearchConnectionProperties.



5547
5548
5549
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Authentication type for Elasticsearch. Corresponds to the JSON property authenticationType

Returns:

  • (String)


5503
5504
5505
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5503

def authentication_type
  @authentication_type
end

#fingerprintString

Optional. Fingerprint required by TLS security protocol. Eg.: ' 6152b2dfbff200f973c5074a5b91d06ab3b472c07c09a1ea57bb7fd406cdce9c' Corresponds to the JSON property fingerprint

Returns:

  • (String)


5509
5510
5511
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5509

def fingerprint
  @fingerprint
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Elastic Search connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


5515
5516
5517
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5515

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Elastic Search connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


5522
5523
5524
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5522

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security protocol for Elasticsearch. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


5527
5528
5529
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5527

def security_protocol
  @security_protocol
end

#serversString

Optional. Comma separated list of Elasticsearch server addresses, specified as host:port entries, where :port is optional. If port is not specified, it defaults to 9200. Example: "server1.example.com:4000,server2.example.com:4000" Corresponds to the JSON property servers

Returns:

  • (String)


5534
5535
5536
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5534

def servers
  @servers
end

#technology_typeString

Optional. The technology type of ElasticsearchConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


5539
5540
5541
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5539

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


5545
5546
5547
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5545

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5552

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @servers = args[:servers] if args.key?(:servers)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end