Class: Google::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateKafkaSchemaRegistryConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateKafkaSchemaRegistryConnectionProperties

Returns a new instance of GoldengateKafkaSchemaRegistryConnectionProperties.



6244
6245
6246
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Used authentication mechanism to access Schema Registry. Corresponds to the JSON property authenticationType

Returns:

  • (String)


6166
6167
6168
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6166

def authentication_type
  @authentication_type
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


6171
6172
6173
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6171

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


6176
6177
6178
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6176

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


6183
6184
6185
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6183

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password to access Schema Registry in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6188
6189
6190
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6188

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password to access Schema Registry using basic authentication. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6195
6196
6197
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6195

def password_secret_version
  @password_secret_version
end

#ssl_key_passwordString

Optional. Input only. The password for the cert inside the KeyStore in plain text. Corresponds to the JSON property sslKeyPassword

Returns:

  • (String)


6201
6202
6203
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6201

def ssl_key_password
  @ssl_key_password
end

#ssl_key_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside the KeyStore. Format: projects/ project/secrets/secret/versions/version. Corresponds to the JSON property sslKeyPasswordSecretVersion

Returns:

  • (String)


6208
6209
6210
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6208

def ssl_key_password_secret_version
  @ssl_key_password_secret_version
end

#technology_typeString

Optional. The technology type of KafkaSchemaRegistryConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6213
6214
6215
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6213

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


6218
6219
6220
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6218

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


6223
6224
6225
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6223

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


6230
6231
6232
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6230

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#urlString

Optional. Kafka Schema Registry URL. e.g.: 'https://server1.us.oracle.com:8081' Corresponds to the JSON property url

Returns:

  • (String)


6235
6236
6237
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6235

def url
  @url
end

#usernameString

Optional. The username to access Schema Registry using basic authentication. This value is injected into 'schema.registry.basic.auth.user.info=user: password' configuration property. Corresponds to the JSON property username

Returns:

  • (String)


6242
6243
6244
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6242

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6249

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password)
  @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @url = args[:url] if args.key?(:url)
  @username = args[:username] if args.key?(:username)
end