Class: Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateMicrosoftSqlserverConnection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#server_certificate_validation_required ⇒ Boolean
(also: #server_certificate_validation_required?)
Optional.
-
#ssl_ca_file ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
constructor
A new instance of GoldengateMicrosoftSqlserverConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
Returns a new instance of GoldengateMicrosoftSqlserverConnectionProperties.
6458 6459 6460 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6458 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
6399 6400 6401 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6399 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
6404 6405 6406 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6404 def database @database end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
6409 6410 6411 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6409 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL
Server connection in plain text.
Corresponds to the JSON property password
6415 6416 6417 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6415 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Microsoft SQL Server
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6422 6423 6424 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6422 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
6427 6428 6429 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6427 def port @port end |
#security_protocol ⇒ String
Optional. Security Type for Microsoft SQL Server.
Corresponds to the JSON property securityProtocol
6432 6433 6434 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6432 def security_protocol @security_protocol end |
#server_certificate_validation_required ⇒ Boolean Also known as: server_certificate_validation_required?
Optional. If set to true, the driver validates the certificate that is sent by
the database server.
Corresponds to the JSON property serverCertificateValidationRequired
6438 6439 6440 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6438 def server_certificate_validation_required @server_certificate_validation_required end |
#ssl_ca_file ⇒ String
Optional. Database Certificate - The base64 encoded content of a .pem or .crt
file containing the server public key (for 1-way SSL).
Corresponds to the JSON property sslCaFile
6445 6446 6447 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6445 def ssl_ca_file @ssl_ca_file end |
#technology_type ⇒ String
Optional. The technology type of MicrosoftSqlserverConnection.
Corresponds to the JSON property technologyType
6450 6451 6452 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6450 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL
Server.
Corresponds to the JSON property username
6456 6457 6458 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6456 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6463 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @server_certificate_validation_required = args[:server_certificate_validation_required] if args.key?(:server_certificate_validation_required) @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |