Class: Google::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateMongodbConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMongodbConnectionProperties

Returns a new instance of GoldengateMongodbConnectionProperties.



6577
6578
6579
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com: 27017/recordsrecords' Corresponds to the JSON property connectionString

Returns:

  • (String)


6518
6519
6520
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6518

def connection_string
  @connection_string
end

#database_idString

Optional. The OCID of the Oracle Autonomous Json Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


6523
6524
6525
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6523

def database_id
  @database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6529
6530
6531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6529

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6536
6537
6538
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6536

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security Type for MongoDB. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6541
6542
6543
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6541

def security_protocol
  @security_protocol
end

#technology_typeString

Optional. The technology type of MongodbConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6546
6547
6548
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6546

def technology_type
  @technology_type
end

#tls_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property tlsCaFile

Returns:

  • (String)


6552
6553
6554
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6552

def tls_ca_file
  @tls_ca_file
end

#tls_certificate_key_fileString

Optional. Client Certificate - The base64 encoded content of a .pem file, containing the client public key (for 2-way SSL). Corresponds to the JSON property tlsCertificateKeyFile

Returns:

  • (String)


6558
6559
6560
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6558

def tls_certificate_key_file
  @tls_certificate_key_file
end

#tls_certificate_key_file_passwordString

Optional. Input only. The Client Certificate key file password in plain text. Corresponds to the JSON property tlsCertificateKeyFilePassword

Returns:

  • (String)


6563
6564
6565
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6563

def tls_certificate_key_file_password
  @tls_certificate_key_file_password
end

#tls_certificate_key_file_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property tlsCertificateKeyFilePasswordSecretVersion

Returns:

  • (String)


6570
6571
6572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6570

def tls_certificate_key_file_password_secret_version
  @tls_certificate_key_file_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


6575
6576
6577
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6575

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6582

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @database_id = args[:database_id] if args.key?(:database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tls_ca_file = args[:tls_ca_file] if args.key?(:tls_ca_file)
  @tls_certificate_key_file = args[:tls_certificate_key_file] if args.key?(:tls_certificate_key_file)
  @tls_certificate_key_file_password = args[:tls_certificate_key_file_password] if args.key?(:tls_certificate_key_file_password)
  @tls_certificate_key_file_password_secret_version = args[:tls_certificate_key_file_password_secret_version] if args.key?(:tls_certificate_key_file_password_secret_version)
  @username = args[:username] if args.key?(:username)
end