Class: Google::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Properties of GoldengateMysqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMysqlConnectionProperties

Returns a new instance of GoldengateMysqlConnectionProperties.



6653
6654
6655
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



6573
6574
6575
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6573

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


6578
6579
6580
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6578

def database
  @database
end

#db_system_idString

Optional. The OCID of the database system being referenced. Corresponds to the JSON property dbSystemId

Returns:

  • (String)


6583
6584
6585
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6583

def db_system_id
  @db_system_id
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


6588
6589
6590
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6588

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect to MySQL in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6594
6595
6596
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6594

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to MySQL. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6601
6602
6603
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6601

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6606
6607
6608
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6606

def port
  @port
end

#security_protocolString

Optional. Security Type for MySQL. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6611
6612
6613
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6611

def security_protocol
  @security_protocol
end

#ssl_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property sslCaFile

Returns:

  • (String)


6617
6618
6619
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6617

def ssl_ca_file
  @ssl_ca_file
end

#ssl_cert_fileString

Optional. Client Certificate - The base64 encoded content of a .pem or .crt file containing the client public key (for 2-way SSL). Corresponds to the JSON property sslCertFile

Returns:

  • (String)


6623
6624
6625
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6623

def ssl_cert_file
  @ssl_cert_file
end

#ssl_crl_fileString

Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA). Corresponds to the JSON property sslCrlFile

Returns:

  • (String)


6629
6630
6631
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6629

def ssl_crl_file
  @ssl_crl_file
end

#ssl_key_fileString

Optional. Client Key - The base64 encoded content of a .pem or .crt file containing the client private key (for 2-way SSL). Corresponds to the JSON property sslKeyFile

Returns:

  • (String)


6635
6636
6637
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6635

def ssl_key_file
  @ssl_key_file
end

#ssl_modeString

Optional. SSL modes for MySQL. Corresponds to the JSON property sslMode

Returns:

  • (String)


6640
6641
6642
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6640

def ssl_mode
  @ssl_mode
end

#technology_typeString

Optional. The technology type of MysqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6645
6646
6647
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6645

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


6651
6652
6653
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6651

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6658

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @db_system_id = args[:db_system_id] if args.key?(:db_system_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file)
  @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file)
  @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file)
  @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file)
  @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end