Class: Google::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOciObjectStorageConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOciObjectStorageConnectionProperties

Returns a new instance of GoldengateOciObjectStorageConnectionProperties.



6758
6759
6760
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6717
6718
6719
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6717

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6722
6723
6724
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6722

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the userId. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6727

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region of OCI Object Storage. e.g.: us-ashburn-1 If the region is not provided, backend will default to the default region. Corresponds to the JSON property region

Returns:

  • (String)


6733
6734
6735
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6733

def region
  @region
end

#technology_typeString

Optional. The technology type of OciObjectStorageConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6738
6739
6740
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6738

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the related OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6743
6744
6745
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6743

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6749
6750
6751
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6749

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access the Object Storage. The user must have write access to the bucket they want to connect to. Corresponds to the JSON property userId

Returns:

  • (String)


6756
6757
6758
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6756

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6763

def update!(**args)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end