Class: Google::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleAIDataPlatformConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleAiDataPlatformConnectionProperties

Returns a new instance of GoldengateOracleAiDataPlatformConnectionProperties.



6903
6904
6905
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_urlString

Optional. Connection URL. It must start with 'jdbc:spark://' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


6858
6859
6860
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6858

def connection_url
  @connection_url
end

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6864
6865
6866
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6864

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6869
6870
6871
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6869

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the user_id. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6874
6875
6876
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6874

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6879
6880
6881
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6879

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleAiDataPlatformConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6884
6885
6886
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6884

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the related OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6889
6890
6891
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6889

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6895
6896
6897
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6895

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access. Corresponds to the JSON property userId

Returns:

  • (String)


6901
6902
6903
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6901

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6908

def update!(**args)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end