Class: Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateOracleNosqlConnection.
Instance Attribute Summary collapse
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#public_key_fingerprint ⇒ String
Optional.
-
#region ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#tenancy_id ⇒ String
Optional.
-
#use_resource_principal ⇒ Boolean
(also: #use_resource_principal?)
Optional.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties
constructor
A new instance of GoldengateOracleNosqlConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties
Returns a new instance of GoldengateOracleNosqlConnectionProperties.
7043 7044 7045 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_key_file ⇒ String
Optional. The content of the private key file (PEM file) corresponding to the
API key of the fingerprint.
Corresponds to the JSON property privateKeyFile
7004 7005 7006 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7004 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. The passphrase of the private key.
Corresponds to the JSON property privateKeyPassphraseSecret
7009 7010 7011 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7009 def private_key_passphrase_secret @private_key_passphrase_secret end |
#public_key_fingerprint ⇒ String
Optional. The fingerprint of the API Key of the user specified by the userId.
Corresponds to the JSON property publicKeyFingerprint
7014 7015 7016 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7014 def public_key_fingerprint @public_key_fingerprint end |
#region ⇒ String
Optional. The name of the region. e.g.: us-ashburn-1
Corresponds to the JSON property region
7019 7020 7021 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7019 def region @region end |
#technology_type ⇒ String
Optional. The technology type of OracleNosqlConnection.
Corresponds to the JSON property technologyType
7024 7025 7026 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7024 def technology_type @technology_type end |
#tenancy_id ⇒ String
Optional. The OCID of the OCI tenancy.
Corresponds to the JSON property tenancyId
7029 7030 7031 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7029 def tenancy_id @tenancy_id end |
#use_resource_principal ⇒ Boolean Also known as: use_resource_principal?
Optional. Specifies that the user intends to authenticate to the instance
using a resource principal.
Corresponds to the JSON property useResourcePrincipal
7035 7036 7037 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7035 def use_resource_principal @use_resource_principal end |
#user_id ⇒ String
Optional. The OCID of the OCI user who will access the Oracle NoSQL database.
Corresponds to the JSON property userId
7041 7042 7043 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7041 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7048 def update!(**args) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint) @region = args[:region] if args.key?(:region) @technology_type = args[:technology_type] if args.key?(:technology_type) @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id) @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal) @user_id = args[:user_id] if args.key?(:user_id) end |