Class: Google::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengatePostgresqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengatePostgresqlConnectionProperties

Returns a new instance of GoldengatePostgresqlConnectionProperties.



7139
7140
7141
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



7061
7062
7063
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7061

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


7066
7067
7068
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7066

def database
  @database
end

#db_system_idString

Optional. The OCID of the database system being referenced. Corresponds to the JSON property dbSystemId

Returns:

  • (String)


7071
7072
7073
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7071

def db_system_id
  @db_system_id
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


7076
7077
7078
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7076

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for PostgreSQL connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


7082
7083
7084
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7082

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for PostgreSQL connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


7089
7090
7091
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7089

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


7094
7095
7096
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7094

def port
  @port
end

#security_protocolString

Optional. Security protocol for PostgreSQL. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


7099
7100
7101
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7099

def security_protocol
  @security_protocol
end

#ssl_ca_fileString

Optional. The base64 encoded certificate of the trusted certificate authorities (Trusted CA) for PostgreSQL. Corresponds to the JSON property sslCaFile

Returns:

  • (String)


7105
7106
7107
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7105

def ssl_ca_file
  @ssl_ca_file
end

#ssl_cert_fileString

Optional. The base64 encoded certificate of the PostgreSQL server. Corresponds to the JSON property sslCertFile

Returns:

  • (String)


7110
7111
7112
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7110

def ssl_cert_file
  @ssl_cert_file
end

#ssl_crl_fileString

Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA). Corresponds to the JSON property sslCrlFile

Returns:

  • (String)


7116
7117
7118
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7116

def ssl_crl_file
  @ssl_crl_file
end

#ssl_key_fileString

Optional. The base64 encoded private key of the PostgreSQL server. Corresponds to the JSON property sslKeyFile

Returns:

  • (String)


7121
7122
7123
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7121

def ssl_key_file
  @ssl_key_file
end

#ssl_modeString

Optional. SSL modes for PostgreSQL. Corresponds to the JSON property sslMode

Returns:

  • (String)


7126
7127
7128
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7126

def ssl_mode
  @ssl_mode
end

#technology_typeString

Optional. The technology type of PostgresqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


7131
7132
7133
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7131

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


7137
7138
7139
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7137

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
7158
7159
7160
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7144

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @db_system_id = args[:db_system_id] if args.key?(:db_system_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file)
  @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file)
  @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file)
  @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file)
  @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end