Class: Google::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateRedisConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#redis_cluster_id ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#servers ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateRedisConnectionProperties
constructor
A new instance of GoldengateRedisConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateRedisConnectionProperties
Returns a new instance of GoldengateRedisConnectionProperties.
7279 7280 7281 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Redis.
Corresponds to the JSON property authenticationType
7202 7203 7204 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7202 def authentication_type @authentication_type end |
#key_store_file ⇒ String
Optional. The base64 encoded content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
7207 7208 7209 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7207 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
7212 7213 7214 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7212 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
7219 7220 7221 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7219 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Redis connection
in plain text.
Corresponds to the JSON property password
7225 7226 7227 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7225 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Redis connection.
Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
7232 7233 7234 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7232 def password_secret_version @password_secret_version end |
#redis_cluster_id ⇒ String
Optional. The OCID of the Redis cluster.
Corresponds to the JSON property redisClusterId
7237 7238 7239 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7237 def redis_cluster_id @redis_cluster_id end |
#security_protocol ⇒ String
Optional. Security protocol for Redis.
Corresponds to the JSON property securityProtocol
7242 7243 7244 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7242 def security_protocol @security_protocol end |
#servers ⇒ String
Optional. Comma separated list of Redis server addresses, specified as host:
port entries, where :port is optional. If port is not specified, it defaults
to 6379. Example: "server1.example.com:6379,server2.example.com:6379"
Corresponds to the JSON property servers
7249 7250 7251 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7249 def servers @servers end |
#technology_type ⇒ String
Optional. The technology type of RedisConnection.
Corresponds to the JSON property technologyType
7254 7255 7256 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7254 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The base64 encoded content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
7259 7260 7261 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7259 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
7264 7265 7266 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7264 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
7271 7272 7273 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7271 def trust_store_password_secret_version @trust_store_password_secret_version end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
7277 7278 7279 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7277 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7284 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @redis_cluster_id = args[:redis_cluster_id] if args.key?(:redis_cluster_id) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @servers = args[:servers] if args.key?(:servers) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @username = args[:username] if args.key?(:username) end |