Class: Google::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateSnowflakeConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateSnowflakeConnectionProperties

Returns a new instance of GoldengateSnowflakeConnectionProperties.



7350
7351
7352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Used authentication mechanism to access Snowflake. Corresponds to the JSON property authenticationType

Returns:

  • (String)


7309
7310
7311
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7309

def authentication_type
  @authentication_type
end

#connection_urlString

Optional. JDBC connection URL. e.g.: 'jdbc:snowflake://.snowflakecomputing.com/ ?warehouse=&db=' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


7315
7316
7317
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7315

def connection_url
  @connection_url
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect to Snowflake platform in plain text. Corresponds to the JSON property password

Returns:

  • (String)


7321
7322
7323
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7321

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to Snowflake platform. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


7328
7329
7330
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7328

def password_secret_version
  @password_secret_version
end

#private_key_fileString

Optional. The content of private key file in PEM format. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


7333
7334
7335
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7333

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. Password if the private key file is encrypted. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


7338
7339
7340
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7338

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#technology_typeString

Optional. The technology type of SnowflakeConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


7343
7344
7345
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7343

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to Snowflake. Corresponds to the JSON property username

Returns:

  • (String)


7348
7349
7350
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7348

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7355

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end