Class: Google::Apis::OracledatabaseV1::IdentityConnector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The identity connector details which will allow OCI to securely access the resources in the customer project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityConnector

Returns a new instance of IdentityConnector.



7300
7301
7302
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stateString

Output only. The connection state of the identity connector. Corresponds to the JSON property connectionState

Returns:

  • (String)


7291
7292
7293
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7291

def connection_state
  @connection_state
end

#service_agent_emailString

Output only. A google managed service account on which customers can grant roles to access resources in the customer project. Example: p176944527254-55- 75119d87fd8f@gcp-sa-oci.iam.gserviceaccount.com Corresponds to the JSON property serviceAgentEmail

Returns:

  • (String)


7298
7299
7300
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7298

def service_agent_email
  @service_agent_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7305
7306
7307
7308
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7305

def update!(**args)
  @connection_state = args[:connection_state] if args.key?(:connection_state)
  @service_agent_email = args[:service_agent_email] if args.key?(:service_agent_email)
end