Class: Google::Apis::OracledatabaseV1::ListCloudExadataInfrastructuresResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListCloudExadataInfrastructuresResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for CloudExadataInfrastructures.list.
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructures ⇒ Array<Google::Apis::OracledatabaseV1::CloudExadataInfrastructure>
The list of Exadata Infrastructures.
-
#next_page_token ⇒ String
A token for fetching next page of response.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCloudExadataInfrastructuresResponse
constructor
A new instance of ListCloudExadataInfrastructuresResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCloudExadataInfrastructuresResponse
Returns a new instance of ListCloudExadataInfrastructuresResponse.
7494 7495 7496 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_exadata_infrastructures ⇒ Array<Google::Apis::OracledatabaseV1::CloudExadataInfrastructure>
The list of Exadata Infrastructures.
Corresponds to the JSON property cloudExadataInfrastructures
7481 7482 7483 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7481 def cloud_exadata_infrastructures @cloud_exadata_infrastructures end |
#next_page_token ⇒ String
A token for fetching next page of response.
Corresponds to the JSON property nextPageToken
7486 7487 7488 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7486 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
7492 7493 7494 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7492 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7499 7500 7501 7502 7503 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7499 def update!(**args) @cloud_exadata_infrastructures = args[:cloud_exadata_infrastructures] if args.key?(:cloud_exadata_infrastructures) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |