Class: Google::Apis::OracledatabaseV1::ListCloudVmClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The response for CloudVmCluster.List.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCloudVmClustersResponse

Returns a new instance of ListCloudVmClustersResponse.



7526
7527
7528
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_vm_clustersArray<Google::Apis::OracledatabaseV1::CloudVmCluster>

The list of VM Clusters. Corresponds to the JSON property cloudVmClusters



7513
7514
7515
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7513

def cloud_vm_clusters
  @cloud_vm_clusters
end

#next_page_tokenString

A token to fetch the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7518
7519
7520
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7518

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable locations when listing resources across all locations using wildcard location '-'. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


7524
7525
7526
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7524

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7531
7532
7533
7534
7535
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7531

def update!(**args)
  @cloud_vm_clusters = args[:cloud_vm_clusters] if args.key?(:cloud_vm_clusters)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end