Class: Google::Apis::OracledatabaseV1::ListDatabaseCharacterSetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDatabaseCharacterSetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DatabaseCharacterSet.List.
Instance Attribute Summary collapse
-
#database_character_sets ⇒ Array<Google::Apis::OracledatabaseV1::DatabaseCharacterSet>
The list of DatabaseCharacterSets.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDatabaseCharacterSetsResponse
constructor
A new instance of ListDatabaseCharacterSetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDatabaseCharacterSetsResponse
Returns a new instance of ListDatabaseCharacterSetsResponse.
3821 3822 3823 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_character_sets ⇒ Array<Google::Apis::OracledatabaseV1::DatabaseCharacterSet>
The list of DatabaseCharacterSets.
Corresponds to the JSON property databaseCharacterSets
3814 3815 3816 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3814 def database_character_sets @database_character_sets end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3819 3820 3821 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3819 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3826 3827 3828 3829 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3826 def update!(**args) @database_character_sets = args[:database_character_sets] if args.key?(:database_character_sets) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |