Class: Google::Apis::OracledatabaseV1::ListDbNodesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDbNodesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DbNode.List.
Instance Attribute Summary collapse
-
#db_nodes ⇒ Array<Google::Apis::OracledatabaseV1::DbNode>
The list of DB Nodes Corresponds to the JSON property
dbNodes. -
#next_page_token ⇒ String
A token identifying a page of results the node should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDbNodesResponse
constructor
A new instance of ListDbNodesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDbNodesResponse
Returns a new instance of ListDbNodesResponse.
7602 7603 7604 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_nodes ⇒ Array<Google::Apis::OracledatabaseV1::DbNode>
The list of DB Nodes
Corresponds to the JSON property dbNodes
7595 7596 7597 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7595 def db_nodes @db_nodes end |
#next_page_token ⇒ String
A token identifying a page of results the node should return.
Corresponds to the JSON property nextPageToken
7600 7601 7602 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7600 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7607 7608 7609 7610 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7607 def update!(**args) @db_nodes = args[:db_nodes] if args.key?(:db_nodes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |