Class: Google::Apis::OracledatabaseV1::ListDbSystemInitialStorageSizesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDbSystemInitialStorageSizesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DbSystemInitialStorageSizes.List.
Instance Attribute Summary collapse
-
#db_system_initial_storage_sizes ⇒ Array<Google::Apis::OracledatabaseV1::DbSystemInitialStorageSize>
The list of DbSystemInitialStorageSizes.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDbSystemInitialStorageSizesResponse
constructor
A new instance of ListDbSystemInitialStorageSizesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDbSystemInitialStorageSizesResponse
Returns a new instance of ListDbSystemInitialStorageSizesResponse.
3921 3922 3923 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_system_initial_storage_sizes ⇒ Array<Google::Apis::OracledatabaseV1::DbSystemInitialStorageSize>
The list of DbSystemInitialStorageSizes.
Corresponds to the JSON property dbSystemInitialStorageSizes
3914 3915 3916 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3914 def db_system_initial_storage_sizes @db_system_initial_storage_sizes end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3919 3920 3921 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3919 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3926 3927 3928 3929 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3926 def update!(**args) @db_system_initial_storage_sizes = args[:db_system_initial_storage_sizes] if args.key?(:db_system_initial_storage_sizes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |