Class: Google::Apis::OracledatabaseV1::ListDbSystemShapesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDbSystemShapesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DbSystemShape.List.
Instance Attribute Summary collapse
-
#db_system_shapes ⇒ Array<Google::Apis::OracledatabaseV1::DbSystemShape>
The list of Database System shapes.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDbSystemShapesResponse
constructor
A new instance of ListDbSystemShapesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDbSystemShapesResponse
Returns a new instance of ListDbSystemShapesResponse.
3967 3968 3969 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_system_shapes ⇒ Array<Google::Apis::OracledatabaseV1::DbSystemShape>
The list of Database System shapes.
Corresponds to the JSON property dbSystemShapes
3960 3961 3962 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3960 def db_system_shapes @db_system_shapes end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3965 3966 3967 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3965 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3972 3973 3974 3975 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3972 def update!(**args) @db_system_shapes = args[:db_system_shapes] if args.key?(:db_system_shapes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |