Class: Google::Apis::OracledatabaseV1::ListGoldengateConnectionAssignmentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Response message for listing GoldengateConnectionAssignments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGoldengateConnectionAssignmentsResponse

Returns a new instance of ListGoldengateConnectionAssignmentsResponse.



8080
8081
8082
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#goldengate_connection_assignmentsArray<Google::Apis::OracledatabaseV1::GoldengateConnectionAssignment>

The list of GoldengateConnectionAssignments. Corresponds to the JSON property goldengateConnectionAssignments



8066
8067
8068
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8066

def goldengate_connection_assignments
  @goldengate_connection_assignments
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8072
8073
8074
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8072

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable locations when listing resources across all locations using wildcard location '-'. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


8078
8079
8080
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8078

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8085
8086
8087
8088
8089
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8085

def update!(**args)
  @goldengate_connection_assignments = args[:goldengate_connection_assignments] if args.key?(:goldengate_connection_assignments)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end