Class: Google::Apis::OracledatabaseV1::ListGoldengateConnectionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListGoldengateConnectionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for GoldengateConnection.List.
Instance Attribute Summary collapse
-
#goldengate_connections ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateConnection>
The list of GoldengateConnections.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGoldengateConnectionsResponse
constructor
A new instance of ListGoldengateConnectionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGoldengateConnectionsResponse
Returns a new instance of ListGoldengateConnectionsResponse.
7946 7947 7948 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goldengate_connections ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateConnection>
The list of GoldengateConnections.
Corresponds to the JSON property goldengateConnections
7934 7935 7936 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7934 def goldengate_connections @goldengate_connections end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
7939 7940 7941 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7939 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Optional. Locations that could not be reached.
Corresponds to the JSON property unreachable
7944 7945 7946 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7944 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7951 7952 7953 7954 7955 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7951 def update!(**args) @goldengate_connections = args[:goldengate_connections] if args.key?(:goldengate_connections) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |