Class: Google::Apis::OracledatabaseV1::ListGoldengateDeploymentEnvironmentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Message for response to listing GoldengateDeploymentEnvironments

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGoldengateDeploymentEnvironmentsResponse

Returns a new instance of ListGoldengateDeploymentEnvironmentsResponse.



8059
8060
8061
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#goldengate_deployment_environmentsArray<Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment>

The list of GoldengateDeploymentEnvironment Corresponds to the JSON property goldengateDeploymentEnvironments



8046
8047
8048
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8046

def goldengate_deployment_environments
  @goldengate_deployment_environments
end

#next_page_tokenString

A token identifying a page of results the server should return. If this field is empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8052
8053
8054
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8052

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


8057
8058
8059
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8057

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8064
8065
8066
8067
8068
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8064

def update!(**args)
  @goldengate_deployment_environments = args[:goldengate_deployment_environments] if args.key?(:goldengate_deployment_environments)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end