Class: Google::Apis::OracledatabaseV1::ListGoldengateDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListGoldengateDeploymentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for GoldengateDeployment.List.
Instance Attribute Summary collapse
-
#goldengate_deployments ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeployment>
The list of GoldengateDeployments.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGoldengateDeploymentsResponse
constructor
A new instance of ListGoldengateDeploymentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGoldengateDeploymentsResponse
Returns a new instance of ListGoldengateDeploymentsResponse.
8073 8074 8075 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goldengate_deployments ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeployment>
The list of GoldengateDeployments.
Corresponds to the JSON property goldengateDeployments
8061 8062 8063 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8061 def goldengate_deployments @goldengate_deployments end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
8066 8067 8068 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8066 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Optional. Locations that could not be reached.
Corresponds to the JSON property unreachable
8071 8072 8073 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8071 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8078 8079 8080 8081 8082 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8078 def update!(**args) @goldengate_deployments = args[:goldengate_deployments] if args.key?(:goldengate_deployments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |