Class: Google::Apis::OracledatabaseV1::ListOdbNetworksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The response for OdbNetwork.List.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOdbNetworksResponse

Returns a new instance of ListOdbNetworksResponse.



8289
8290
8291
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8276
8277
8278
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8276

def next_page_token
  @next_page_token
end

#odb_networksArray<Google::Apis::OracledatabaseV1::OdbNetwork>

The list of ODB Networks. Corresponds to the JSON property odbNetworks



8281
8282
8283
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8281

def odb_networks
  @odb_networks
end

#unreachableArray<String>

Unreachable locations when listing resources across all locations using wildcard location '-'. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


8287
8288
8289
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8287

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8294
8295
8296
8297
8298
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8294

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @odb_networks = args[:odb_networks] if args.key?(:odb_networks)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end