Class: Google::Apis::OracledatabaseV1::ListOdbSubnetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The response for OdbSubnet.List.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOdbSubnetsResponse

Returns a new instance of ListOdbSubnetsResponse.



8187
8188
8189
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8174
8175
8176
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8174

def next_page_token
  @next_page_token
end

#odb_subnetsArray<Google::Apis::OracledatabaseV1::OdbSubnet>

The list of ODB Subnets. Corresponds to the JSON property odbSubnets



8179
8180
8181
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8179

def odb_subnets
  @odb_subnets
end

#unreachableArray<String>

Unreachable locations when listing resources across all locations using wildcard location '-'. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


8185
8186
8187
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8185

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8192
8193
8194
8195
8196
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8192

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @odb_subnets = args[:odb_subnets] if args.key?(:odb_subnets)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end