Class: Google::Apis::OracledatabaseV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::OracledatabaseV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
8355 8356 8357 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
8340 8341 8342 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8340 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::OracledatabaseV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
8345 8346 8347 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8345 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
8353 8354 8355 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8353 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8360 8361 8362 8363 8364 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8360 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |