Class: Google::Apis::OracledatabaseV1::ListPluggableDatabasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListPluggableDatabasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for PluggableDatabase.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#pluggable_databases ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabase>
The list of PluggableDatabases.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPluggableDatabasesResponse
constructor
A new instance of ListPluggableDatabasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPluggableDatabasesResponse
Returns a new instance of ListPluggableDatabasesResponse.
4314 4315 4316 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4307 4308 4309 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4307 def next_page_token @next_page_token end |
#pluggable_databases ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabase>
The list of PluggableDatabases.
Corresponds to the JSON property pluggableDatabases
4312 4313 4314 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4312 def pluggable_databases @pluggable_databases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4319 4320 4321 4322 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4319 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pluggable_databases = args[:pluggable_databases] if args.key?(:pluggable_databases) end |