Class: Google::Apis::OracledatabaseV1::OdbNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents OdbNetwork resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OdbNetwork

Returns a new instance of OdbNetwork.



8536
8537
8538
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the OdbNetwork was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8500
8501
8502
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8500

def create_time
  @create_time
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the OdbNetwork. Corresponds to the JSON property entitlementId

Returns:

  • (String)


8506
8507
8508
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8506

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where OdbNetwork is hosted. Example: us-east4-b- r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


8512
8513
8514
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8512

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. Labels or tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8517
8518
8519
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8517

def labels
  @labels
end

#nameString

Identifier. The name of the OdbNetwork resource in the following format: projects/project/locations/region/odbNetworks/odb_network Corresponds to the JSON property name

Returns:

  • (String)


8523
8524
8525
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8523

def name
  @name
end

#networkString

Required. The name of the VPC network in the following format: projects/ project/global/networks/network Corresponds to the JSON property network

Returns:

  • (String)


8529
8530
8531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8529

def network
  @network
end

#stateString

Output only. State of the ODB Network. Corresponds to the JSON property state

Returns:

  • (String)


8534
8535
8536
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8534

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8541
8542
8543
8544
8545
8546
8547
8548
8549
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8541

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @state = args[:state] if args.key?(:state)
end