Class: Google::Apis::OracledatabaseV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



8908
8909
8910
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


8866
8867
8868
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8866

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8871
8872
8873
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8871

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


8876
8877
8878
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8876

def end_time
  @end_time
end

#percent_completeFloat

Output only. An estimated percentage of the operation that has been completed at a given moment of time, between 0 and 100. Corresponds to the JSON property percentComplete

Returns:

  • (Float)


8882
8883
8884
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8882

def percent_complete
  @percent_complete
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


8890
8891
8892
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8890

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. The status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


8896
8897
8898
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8896

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


8901
8902
8903
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8901

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


8906
8907
8908
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8906

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8913
8914
8915
8916
8917
8918
8919
8920
8921
8922
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8913

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @percent_complete = args[:percent_complete] if args.key?(:percent_complete)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end