Class: Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The connection strings used to connect to the Oracle Database.
Instance Attribute Summary collapse
-
#all_connection_strings ⇒ Hash<String,String>
Optional.
-
#pdb_default ⇒ String
Optional.
-
#pdb_ip_default ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PluggableDatabaseConnectionStrings
constructor
A new instance of PluggableDatabaseConnectionStrings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PluggableDatabaseConnectionStrings
Returns a new instance of PluggableDatabaseConnectionStrings.
8791 8792 8793 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_connection_strings ⇒ Hash<String,String>
Optional. All connection strings to use to connect to the pluggable database.
Corresponds to the JSON property allConnectionStrings
8777 8778 8779 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8777 def all_connection_strings @all_connection_strings end |
#pdb_default ⇒ String
Optional. The default connection string to use to connect to the pluggable
database.
Corresponds to the JSON property pdbDefault
8783 8784 8785 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8783 def pdb_default @pdb_default end |
#pdb_ip_default ⇒ String
Optional. The default connection string to use to connect to the pluggable
database using IP.
Corresponds to the JSON property pdbIpDefault
8789 8790 8791 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8789 def pdb_ip_default @pdb_ip_default end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8796 8797 8798 8799 8800 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8796 def update!(**args) @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings) @pdb_default = args[:pdb_default] if args.key?(:pdb_default) @pdb_ip_default = args[:pdb_ip_default] if args.key?(:pdb_ip_default) end |