Class: Google::Apis::OracledatabaseV1::RefreshAutonomousDatabaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Request message for RefreshAutonomousDatabase method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RefreshAutonomousDatabaseRequest

Returns a new instance of RefreshAutonomousDatabaseRequest.



9178
9179
9180
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#refresh_cutoff_timeString

Required. The timestamp to which the Autonomous Database refreshable clone will be refreshed. Changes made in the primary database after this timestamp are not part of the data refresh. Corresponds to the JSON property refreshCutoffTime

Returns:

  • (String)


9176
9177
9178
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9176

def refresh_cutoff_time
  @refresh_cutoff_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9183
9184
9185
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9183

def update!(**args)
  @refresh_cutoff_time = args[:refresh_cutoff_time] if args.key?(:refresh_cutoff_time)
end