Class: Google::Apis::OracledatabaseV1::ScheduledOperationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of scheduled operation. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/datatypes/ScheduledOperationDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledOperationDetails

Returns a new instance of ScheduledOperationDetails.



9301
9302
9303
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Output only. Day of week. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


9285
9286
9287
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9285

def day_of_week
  @day_of_week
end

#start_timeGoogle::Apis::OracledatabaseV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



9292
9293
9294
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9292

def start_time
  @start_time
end

#stop_timeGoogle::Apis::OracledatabaseV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property stopTime



9299
9300
9301
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9299

def stop_time
  @stop_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9306
9307
9308
9309
9310
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9306

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @start_time = args[:start_time] if args.key?(:start_time)
  @stop_time = args[:stop_time] if args.key?(:stop_time)
end