Class: Google::Apis::OracledatabaseV1::AutonomousDatabase
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::AutonomousDatabase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the Autonomous Database resource. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/AutonomousDatabase/
Instance Attribute Summary collapse
-
#admin_password ⇒ String
Optional.
-
#admin_password_secret_version ⇒ String
Optional.
-
#cidr ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#database ⇒ String
Optional.
-
#disaster_recovery_supported_locations ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Optional.
-
#entitlement_id ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Optional.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Optional.
-
#peer_autonomous_databases ⇒ Array<String>
Output only.
-
#properties ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseProperties
The properties of an Autonomous Database.
-
#source_config ⇒ Google::Apis::OracledatabaseV1::SourceConfig
The source configuration for the standby Autonomous Database.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutonomousDatabase
constructor
A new instance of AutonomousDatabase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutonomousDatabase
Returns a new instance of AutonomousDatabase.
163 164 165 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_password ⇒ String
Optional. Immutable. The password for the default ADMIN user. Note: Only one
of admin_password_secret_version or admin_password can be populated.
Corresponds to the JSON property adminPassword
69 70 71 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 69 def admin_password @admin_password end |
#admin_password_secret_version ⇒ String
Optional. Immutable. The resource name of a secret version in Secret Manager
which contains the database admin user's password. Format: projects/project/
secrets/secret/versions/version. Note: Only one of
admin_password_secret_version or admin_password can be populated.
Corresponds to the JSON property adminPasswordSecretVersion
77 78 79 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 77 def admin_password_secret_version @admin_password_secret_version end |
#cidr ⇒ String
Optional. Immutable. The subnet CIDR range for the Autonomous Database.
Corresponds to the JSON property cidr
82 83 84 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 82 def cidr @cidr end |
#create_time ⇒ String
Output only. The date and time that the Autonomous Database was created.
Corresponds to the JSON property createTime
87 88 89 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 87 def create_time @create_time end |
#database ⇒ String
Optional. Immutable. The name of the Autonomous Database. The database name
must be unique in the project. The name must begin with a letter and can
contain a maximum of 30 alphanumeric characters.
Corresponds to the JSON property database
94 95 96 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 94 def database @database end |
#disaster_recovery_supported_locations ⇒ Array<String>
Output only. List of supported GCP region to clone the Autonomous Database for
disaster recovery. Format: project/project/locations/location`.
Corresponds to the JSON propertydisasterRecoverySupportedLocations`
100 101 102 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 100 def disaster_recovery_supported_locations @disaster_recovery_supported_locations end |
#display_name ⇒ String
Optional. Immutable. The display name for the Autonomous Database. The name
does not have to be unique within your project.
Corresponds to the JSON property displayName
106 107 108 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 106 def display_name @display_name end |
#entitlement_id ⇒ String
Output only. The ID of the subscription entitlement associated with the
Autonomous Database.
Corresponds to the JSON property entitlementId
112 113 114 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 112 def entitlement_id @entitlement_id end |
#labels ⇒ Hash<String,String>
Optional. The labels or tags associated with the Autonomous Database.
Corresponds to the JSON property labels
117 118 119 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 117 def labels @labels end |
#name ⇒ String
Identifier. The name of the Autonomous Database resource in the following
format: projects/project/locations/region/autonomousDatabases/
autonomous_database
Corresponds to the JSON property name
124 125 126 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 124 def name @name end |
#network ⇒ String
Optional. Immutable. The name of the VPC network used by the Autonomous
Database in the following format: projects/project/global/networks/network
Corresponds to the JSON property network
130 131 132 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 130 def network @network end |
#odb_network ⇒ String
Optional. Immutable. The name of the OdbNetwork associated with the Autonomous
Database. Format: projects/project/locations/location/odbNetworks/
odb_network It is optional but if specified, this should match the parent
ODBNetwork of the OdbSubnet.
Corresponds to the JSON property odbNetwork
138 139 140 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 138 def odb_network @odb_network end |
#odb_subnet ⇒ String
Optional. Immutable. The name of the OdbSubnet associated with the Autonomous
Database. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
145 146 147 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 145 def odb_subnet @odb_subnet end |
#peer_autonomous_databases ⇒ Array<String>
Output only. The peer Autonomous Database names of the given Autonomous
Database.
Corresponds to the JSON property peerAutonomousDatabases
151 152 153 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 151 def peer_autonomous_databases @peer_autonomous_databases end |
#properties ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseProperties
The properties of an Autonomous Database.
Corresponds to the JSON property properties
156 157 158 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 156 def properties @properties end |
#source_config ⇒ Google::Apis::OracledatabaseV1::SourceConfig
The source configuration for the standby Autonomous Database.
Corresponds to the JSON property sourceConfig
161 162 163 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 161 def source_config @source_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 168 def update!(**args) @admin_password = args[:admin_password] if args.key?(:admin_password) @admin_password_secret_version = args[:admin_password_secret_version] if args.key?(:admin_password_secret_version) @cidr = args[:cidr] if args.key?(:cidr) @create_time = args[:create_time] if args.key?(:create_time) @database = args[:database] if args.key?(:database) @disaster_recovery_supported_locations = args[:disaster_recovery_supported_locations] if args.key?(:disaster_recovery_supported_locations) @display_name = args[:display_name] if args.key?(:display_name) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @peer_autonomous_databases = args[:peer_autonomous_databases] if args.key?(:peer_autonomous_databases) @properties = args[:properties] if args.key?(:properties) @source_config = args[:source_config] if args.key?(:source_config) end |