Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionStrings
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionStrings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The connection string used to connect to the Autonomous Database. https://docs. oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/ AutonomousDatabaseConnectionStrings
Instance Attribute Summary collapse
-
#all_connection_strings ⇒ Google::Apis::OracledatabaseV1::AllConnectionStrings
A list of all connection strings that can be used to connect to the Autonomous Database.
-
#dedicated ⇒ String
Output only.
-
#high ⇒ String
Output only.
-
#low ⇒ String
Output only.
-
#medium ⇒ String
Output only.
-
#profiles ⇒ Array<Google::Apis::OracledatabaseV1::DatabaseConnectionStringProfile>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutonomousDatabaseConnectionStrings
constructor
A new instance of AutonomousDatabaseConnectionStrings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutonomousDatabaseConnectionStrings
Returns a new instance of AutonomousDatabaseConnectionStrings.
532 533 534 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_connection_strings ⇒ Google::Apis::OracledatabaseV1::AllConnectionStrings
A list of all connection strings that can be used to connect to the Autonomous
Database.
Corresponds to the JSON property allConnectionStrings
500 501 502 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 500 def all_connection_strings @all_connection_strings end |
#dedicated ⇒ String
Output only. The database service provides the least level of resources to
each SQL statement, but supports the most number of concurrent SQL statements.
Corresponds to the JSON property dedicated
506 507 508 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 506 def dedicated @dedicated end |
#high ⇒ String
Output only. The database service provides the highest level of resources to
each SQL statement.
Corresponds to the JSON property high
512 513 514 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 512 def high @high end |
#low ⇒ String
Output only. The database service provides the least level of resources to
each SQL statement.
Corresponds to the JSON property low
518 519 520 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 518 def low @low end |
#medium ⇒ String
Output only. The database service provides a lower level of resources to each
SQL statement.
Corresponds to the JSON property medium
524 525 526 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 524 def medium @medium end |
#profiles ⇒ Array<Google::Apis::OracledatabaseV1::DatabaseConnectionStringProfile>
Output only. A list of connection string profiles to allow clients to group,
filter, and select values based on the structured metadata.
Corresponds to the JSON property profiles
530 531 532 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 530 def profiles @profiles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
537 538 539 540 541 542 543 544 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 537 def update!(**args) @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings) @dedicated = args[:dedicated] if args.key?(:dedicated) @high = args[:high] if args.key?(:high) @low = args[:low] if args.key?(:low) @medium = args[:medium] if args.key?(:medium) @profiles = args[:profiles] if args.key?(:profiles) end |