Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionStrings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The connection string used to connect to the Autonomous Database. https://docs. oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/ AutonomousDatabaseConnectionStrings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseConnectionStrings

Returns a new instance of AutonomousDatabaseConnectionStrings.



483
484
485
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_connection_stringsGoogle::Apis::OracledatabaseV1::AllConnectionStrings

A list of all connection strings that can be used to connect to the Autonomous Database. Corresponds to the JSON property allConnectionStrings



451
452
453
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 451

def all_connection_strings
  @all_connection_strings
end

#dedicatedString

Output only. The database service provides the least level of resources to each SQL statement, but supports the most number of concurrent SQL statements. Corresponds to the JSON property dedicated

Returns:

  • (String)


457
458
459
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 457

def dedicated
  @dedicated
end

#highString

Output only. The database service provides the highest level of resources to each SQL statement. Corresponds to the JSON property high

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 463

def high
  @high
end

#lowString

Output only. The database service provides the least level of resources to each SQL statement. Corresponds to the JSON property low

Returns:

  • (String)


469
470
471
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 469

def low
  @low
end

#mediumString

Output only. The database service provides a lower level of resources to each SQL statement. Corresponds to the JSON property medium

Returns:

  • (String)


475
476
477
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 475

def medium
  @medium
end

#profilesArray<Google::Apis::OracledatabaseV1::DatabaseConnectionStringProfile>

Output only. A list of connection string profiles to allow clients to group, filter, and select values based on the structured metadata. Corresponds to the JSON property profiles



481
482
483
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 481

def profiles
  @profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



488
489
490
491
492
493
494
495
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 488

def update!(**args)
  @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings)
  @dedicated = args[:dedicated] if args.key?(:dedicated)
  @high = args[:high] if args.key?(:high)
  @low = args[:low] if args.key?(:low)
  @medium = args[:medium] if args.key?(:medium)
  @profiles = args[:profiles] if args.key?(:profiles)
end