Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionUrls

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The URLs for accessing Oracle Application Express (APEX) and SQL Developer Web with a browser from a Compute instance. https://docs.oracle.com/en-us/iaas/api/

/en/database/20160918/datatypes/AutonomousDatabaseConnectionUrls

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseConnectionUrls

Returns a new instance of AutonomousDatabaseConnectionUrls.



548
549
550
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apex_uriString

Output only. Oracle Application Express (APEX) URL. Corresponds to the JSON property apexUri

Returns:

  • (String)


507
508
509
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 507

def apex_uri
  @apex_uri
end

#database_transforms_uriString

Output only. The URL of the Database Transforms for the Autonomous Database. Corresponds to the JSON property databaseTransformsUri

Returns:

  • (String)


512
513
514
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 512

def database_transforms_uri
  @database_transforms_uri
end

#graph_studio_uriString

Output only. The URL of the Graph Studio for the Autonomous Database. Corresponds to the JSON property graphStudioUri

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 517

def graph_studio_uri
  @graph_studio_uri
end

#machine_learning_notebook_uriString

Output only. The URL of the Oracle Machine Learning (OML) Notebook for the Autonomous Database. Corresponds to the JSON property machineLearningNotebookUri

Returns:

  • (String)


523
524
525
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 523

def machine_learning_notebook_uri
  @machine_learning_notebook_uri
end

#machine_learning_user_management_uriString

Output only. The URL of Machine Learning user management the Autonomous Database. Corresponds to the JSON property machineLearningUserManagementUri

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 529

def machine_learning_user_management_uri
  @machine_learning_user_management_uri
end

#mongo_db_uriString

Output only. The URL of the MongoDB API for the Autonomous Database. Corresponds to the JSON property mongoDbUri

Returns:

  • (String)


534
535
536
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 534

def mongo_db_uri
  @mongo_db_uri
end

#ords_uriString

Output only. The Oracle REST Data Services (ORDS) URL of the Web Access for the Autonomous Database. Corresponds to the JSON property ordsUri

Returns:

  • (String)


540
541
542
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 540

def ords_uri
  @ords_uri
end

#sql_dev_web_uriString

Output only. The URL of the Oracle SQL Developer Web for the Autonomous Database. Corresponds to the JSON property sqlDevWebUri

Returns:

  • (String)


546
547
548
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 546

def sql_dev_web_uri
  @sql_dev_web_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



553
554
555
556
557
558
559
560
561
562
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 553

def update!(**args)
  @apex_uri = args[:apex_uri] if args.key?(:apex_uri)
  @database_transforms_uri = args[:database_transforms_uri] if args.key?(:database_transforms_uri)
  @graph_studio_uri = args[:graph_studio_uri] if args.key?(:graph_studio_uri)
  @machine_learning_notebook_uri = args[:machine_learning_notebook_uri] if args.key?(:machine_learning_notebook_uri)
  @machine_learning_user_management_uri = args[:machine_learning_user_management_uri] if args.key?(:machine_learning_user_management_uri)
  @mongo_db_uri = args[:mongo_db_uri] if args.key?(:mongo_db_uri)
  @ords_uri = args[:ords_uri] if args.key?(:ords_uri)
  @sql_dev_web_uri = args[:sql_dev_web_uri] if args.key?(:sql_dev_web_uri)
end