Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::AutonomousDatabaseProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of an Autonomous Database.
Instance Attribute Summary collapse
-
#actual_used_data_storage_size_tb ⇒ Float
Output only.
-
#allocated_storage_size_tb ⇒ Float
Output only.
-
#allowlisted_ips ⇒ Array<String>
Optional.
-
#apex_details ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseApex
Oracle APEX Application Development.
-
#are_primary_allowlisted_ips_used ⇒ Boolean
(also: #are_primary_allowlisted_ips_used?)
Output only.
-
#autonomous_container_database_id ⇒ String
Output only.
-
#available_upgrade_versions ⇒ Array<String>
Output only.
-
#backup_retention_period_days ⇒ Fixnum
Optional.
-
#character_set ⇒ String
Optional.
-
#compute_count ⇒ Float
Optional.
-
#connection_strings ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database.
-
#connection_urls ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionUrls
The URLs for accessing Oracle Application Express (APEX) and SQL Developer Web with a browser from a Compute instance.
-
#cpu_core_count ⇒ Fixnum
Optional.
-
#customer_contacts ⇒ Array<Google::Apis::OracledatabaseV1::CustomerContact>
Optional.
-
#data_guard_role_changed_time ⇒ String
Output only.
-
#data_safe_state ⇒ String
Output only.
-
#data_storage_size_gb ⇒ Fixnum
Optional.
-
#data_storage_size_tb ⇒ Fixnum
Optional.
-
#database_management_state ⇒ String
Output only.
-
#db_edition ⇒ String
Optional.
-
#db_version ⇒ String
Optional.
-
#db_workload ⇒ String
Required.
-
#disaster_recovery_role_changed_time ⇒ String
Output only.
-
#encryption_key ⇒ Google::Apis::OracledatabaseV1::EncryptionKey
The encryption key used to encrypt the Autonomous Database.
-
#encryption_key_history_entries ⇒ Array<Google::Apis::OracledatabaseV1::EncryptionKeyHistoryEntry>
Output only.
-
#failed_data_recovery_duration ⇒ String
Output only.
-
#is_auto_scaling_enabled ⇒ Boolean
(also: #is_auto_scaling_enabled?)
Optional.
-
#is_local_data_guard_enabled ⇒ Boolean
(also: #is_local_data_guard_enabled?)
Output only.
-
#is_storage_auto_scaling_enabled ⇒ Boolean
(also: #is_storage_auto_scaling_enabled?)
Optional.
-
#license_type ⇒ String
Required.
-
#lifecycle_details ⇒ String
Output only.
-
#local_adg_auto_failover_max_data_loss_limit ⇒ Fixnum
Output only.
-
#local_adg_auto_failover_max_data_loss_limit_duration ⇒ Fixnum
Optional.
-
#local_data_guard_enabled ⇒ Boolean
(also: #local_data_guard_enabled?)
Optional.
-
#local_disaster_recovery_type ⇒ String
Output only.
-
#local_standby_db ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseStandbySummary
Autonomous Data Guard standby database details.
-
#maintenance_begin_time ⇒ String
Output only.
-
#maintenance_end_time ⇒ String
Output only.
-
#maintenance_schedule_type ⇒ String
Optional.
-
#memory_per_oracle_compute_unit_gbs ⇒ Fixnum
Output only.
-
#memory_table_gbs ⇒ Fixnum
Output only.
-
#mtls_connection_required ⇒ Boolean
(also: #mtls_connection_required?)
Optional.
-
#n_character_set ⇒ String
Optional.
-
#next_long_term_backup_time ⇒ String
Output only.
-
#oci_url ⇒ String
Output only.
-
#ocid ⇒ String
Output only.
-
#open_mode ⇒ String
Output only.
-
#operations_insights_state ⇒ String
Output only.
-
#peer_db_ids ⇒ Array<String>
Output only.
-
#permission_level ⇒ String
Output only.
-
#private_endpoint ⇒ String
Output only.
-
#private_endpoint_ip ⇒ String
Optional.
-
#private_endpoint_label ⇒ String
Optional.
-
#refreshable_mode ⇒ String
Output only.
-
#refreshable_state ⇒ String
Output only.
-
#role ⇒ String
Output only.
-
#scheduled_operation_details ⇒ Array<Google::Apis::OracledatabaseV1::ScheduledOperationDetails>
Output only.
-
#secret_id ⇒ String
Optional.
-
#service_agent_email ⇒ String
Output only.
-
#sql_web_developer_url ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supported_clone_regions ⇒ Array<String>
Output only.
-
#total_auto_backup_storage_size_gbs ⇒ Float
Output only.
-
#used_data_storage_size_tbs ⇒ Fixnum
Output only.
-
#vault_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutonomousDatabaseProperties
constructor
A new instance of AutonomousDatabaseProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutonomousDatabaseProperties
Returns a new instance of AutonomousDatabaseProperties.
948 949 950 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_used_data_storage_size_tb ⇒ Float
Output only. The amount of storage currently being used for user and system
data, in terabytes.
Corresponds to the JSON property actualUsedDataStorageSizeTb
573 574 575 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 573 def actual_used_data_storage_size_tb @actual_used_data_storage_size_tb end |
#allocated_storage_size_tb ⇒ Float
Output only. The amount of storage currently allocated for the database tables
and billed for, rounded up in terabytes.
Corresponds to the JSON property allocatedStorageSizeTb
579 580 581 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 579 def allocated_storage_size_tb @allocated_storage_size_tb end |
#allowlisted_ips ⇒ Array<String>
Optional. Immutable. The list of allowlisted IP addresses for the Autonomous
Database.
Corresponds to the JSON property allowlistedIps
585 586 587 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 585 def allowlisted_ips @allowlisted_ips end |
#apex_details ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseApex
Oracle APEX Application Development. https://docs.oracle.com/en-us/iaas/api/#/
en/database/20160918/datatypes/AutonomousDatabaseApex
Corresponds to the JSON property apexDetails
591 592 593 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 591 def apex_details @apex_details end |
#are_primary_allowlisted_ips_used ⇒ Boolean Also known as: are_primary_allowlisted_ips_used?
Output only. This field indicates the status of Data Guard and Access control
for the Autonomous Database. The field's value is null if Data Guard is
disabled or Access Control is disabled. The field's value is TRUE if both Data
Guard and Access Control are enabled, and the Autonomous Database is using
primary IP access control list (ACL) for standby. The field's value is FALSE
if both Data Guard and Access Control are enabled, and the Autonomous Database
is using a different IP access control list (ACL) for standby compared to
primary.
Corresponds to the JSON property arePrimaryAllowlistedIpsUsed
603 604 605 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 603 def are_primary_allowlisted_ips_used @are_primary_allowlisted_ips_used end |
#autonomous_container_database_id ⇒ String
Output only. The Autonomous Container Database OCID.
Corresponds to the JSON property autonomousContainerDatabaseId
609 610 611 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 609 def autonomous_container_database_id @autonomous_container_database_id end |
#available_upgrade_versions ⇒ Array<String>
Output only. The list of available Oracle Database upgrade versions for an
Autonomous Database.
Corresponds to the JSON property availableUpgradeVersions
615 616 617 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 615 def available_upgrade_versions @available_upgrade_versions end |
#backup_retention_period_days ⇒ Fixnum
Optional. Immutable. The retention period for the Autonomous Database. This
field is specified in days, can range from 1 day to 60 days, and has a default
value of 60 days.
Corresponds to the JSON property backupRetentionPeriodDays
622 623 624 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 622 def backup_retention_period_days @backup_retention_period_days end |
#character_set ⇒ String
Optional. Immutable. The character set for the Autonomous Database. The
default is AL32UTF8.
Corresponds to the JSON property characterSet
628 629 630 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 628 def character_set @character_set end |
#compute_count ⇒ Float
Optional. Immutable. The number of compute servers for the Autonomous Database.
Corresponds to the JSON property computeCount
633 634 635 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 633 def compute_count @compute_count end |
#connection_strings ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database. https://docs.
oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/
AutonomousDatabaseConnectionStrings
Corresponds to the JSON property connectionStrings
640 641 642 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 640 def connection_strings @connection_strings end |
#connection_urls ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseConnectionUrls
The URLs for accessing Oracle Application Express (APEX) and SQL Developer Web with a browser from a Compute instance. https://docs.oracle.com/en-us/iaas/api/
/en/database/20160918/datatypes/AutonomousDatabaseConnectionUrls
Corresponds to the JSON property connectionUrls
647 648 649 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 647 def connection_urls @connection_urls end |
#cpu_core_count ⇒ Fixnum
Optional. Immutable. The number of CPU cores to be made available to the
database.
Corresponds to the JSON property cpuCoreCount
653 654 655 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 653 def cpu_core_count @cpu_core_count end |
#customer_contacts ⇒ Array<Google::Apis::OracledatabaseV1::CustomerContact>
Optional. Immutable. The list of customer contacts.
Corresponds to the JSON property customerContacts
658 659 660 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 658 def customer_contacts @customer_contacts end |
#data_guard_role_changed_time ⇒ String
Output only. The date and time the Autonomous Data Guard role was changed for
the standby Autonomous Database.
Corresponds to the JSON property dataGuardRoleChangedTime
664 665 666 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 664 def data_guard_role_changed_time @data_guard_role_changed_time end |
#data_safe_state ⇒ String
Output only. The current state of the Data Safe registration for the
Autonomous Database.
Corresponds to the JSON property dataSafeState
670 671 672 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 670 def data_safe_state @data_safe_state end |
#data_storage_size_gb ⇒ Fixnum
Optional. Immutable. The size of the data stored in the database, in gigabytes.
Corresponds to the JSON property dataStorageSizeGb
675 676 677 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 675 def data_storage_size_gb @data_storage_size_gb end |
#data_storage_size_tb ⇒ Fixnum
Optional. Immutable. The size of the data stored in the database, in terabytes.
Corresponds to the JSON property dataStorageSizeTb
680 681 682 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 680 def data_storage_size_tb @data_storage_size_tb end |
#database_management_state ⇒ String
Output only. The current state of database management for the Autonomous
Database.
Corresponds to the JSON property databaseManagementState
686 687 688 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 686 def database_management_state @database_management_state end |
#db_edition ⇒ String
Optional. Immutable. The edition of the Autonomous Databases.
Corresponds to the JSON property dbEdition
691 692 693 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 691 def db_edition @db_edition end |
#db_version ⇒ String
Optional. Immutable. The Oracle Database version for the Autonomous Database.
Corresponds to the JSON property dbVersion
696 697 698 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 696 def db_version @db_version end |
#db_workload ⇒ String
Required. Immutable. The workload type of the Autonomous Database.
Corresponds to the JSON property dbWorkload
701 702 703 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 701 def db_workload @db_workload end |
#disaster_recovery_role_changed_time ⇒ String
Output only. The date and time the Disaster Recovery role was changed for the
standby Autonomous Database.
Corresponds to the JSON property disasterRecoveryRoleChangedTime
707 708 709 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 707 def disaster_recovery_role_changed_time @disaster_recovery_role_changed_time end |
#encryption_key ⇒ Google::Apis::OracledatabaseV1::EncryptionKey
The encryption key used to encrypt the Autonomous Database.
Corresponds to the JSON property encryptionKey
712 713 714 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 712 def encryption_key @encryption_key end |
#encryption_key_history_entries ⇒ Array<Google::Apis::OracledatabaseV1::EncryptionKeyHistoryEntry>
Output only. The history of the encryption keys used to encrypt the Autonomous
Database.
Corresponds to the JSON property encryptionKeyHistoryEntries
718 719 720 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 718 def encryption_key_history_entries @encryption_key_history_entries end |
#failed_data_recovery_duration ⇒ String
Output only. This field indicates the number of seconds of data loss during a
Data Guard failover.
Corresponds to the JSON property failedDataRecoveryDuration
724 725 726 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 724 def failed_data_recovery_duration @failed_data_recovery_duration end |
#is_auto_scaling_enabled ⇒ Boolean Also known as: is_auto_scaling_enabled?
Optional. Immutable. This field indicates if auto scaling is enabled for the
Autonomous Database CPU core count.
Corresponds to the JSON property isAutoScalingEnabled
730 731 732 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 730 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_local_data_guard_enabled ⇒ Boolean Also known as: is_local_data_guard_enabled?
Output only. Deprecated: Please use local_data_guard_enabled instead. This
field indicates whether the Autonomous Database has local (in-region) Data
Guard enabled.
Corresponds to the JSON property isLocalDataGuardEnabled
738 739 740 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 738 def is_local_data_guard_enabled @is_local_data_guard_enabled end |
#is_storage_auto_scaling_enabled ⇒ Boolean Also known as: is_storage_auto_scaling_enabled?
Optional. Immutable. This field indicates if auto scaling is enabled for the
Autonomous Database storage.
Corresponds to the JSON property isStorageAutoScalingEnabled
745 746 747 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 745 def is_storage_auto_scaling_enabled @is_storage_auto_scaling_enabled end |
#license_type ⇒ String
Required. Immutable. The license type used for the Autonomous Database.
Corresponds to the JSON property licenseType
751 752 753 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 751 def license_type @license_type end |
#lifecycle_details ⇒ String
Output only. The details of the current lifestyle state of the Autonomous
Database.
Corresponds to the JSON property lifecycleDetails
757 758 759 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 757 def lifecycle_details @lifecycle_details end |
#local_adg_auto_failover_max_data_loss_limit ⇒ Fixnum
Output only. Deprecated: Please use
local_adg_auto_failover_max_data_loss_limit_duration instead. This field
indicates the maximum data loss limit for an Autonomous Database, in seconds.
Corresponds to the JSON property localAdgAutoFailoverMaxDataLossLimit
764 765 766 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 764 def local_adg_auto_failover_max_data_loss_limit @local_adg_auto_failover_max_data_loss_limit end |
#local_adg_auto_failover_max_data_loss_limit_duration ⇒ Fixnum
Optional. This field indicates the maximum data loss limit for an Autonomous
Database, in seconds.
Corresponds to the JSON property localAdgAutoFailoverMaxDataLossLimitDuration
770 771 772 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 770 def local_adg_auto_failover_max_data_loss_limit_duration @local_adg_auto_failover_max_data_loss_limit_duration end |
#local_data_guard_enabled ⇒ Boolean Also known as: local_data_guard_enabled?
Optional. Indicates whether the Autonomous Database has a local (in-region)
standby database. Not applicable to cross-region Data Guard or dedicated
Exadata infrastructure.
Corresponds to the JSON property localDataGuardEnabled
777 778 779 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 777 def local_data_guard_enabled @local_data_guard_enabled end |
#local_disaster_recovery_type ⇒ String
Output only. This field indicates the local disaster recovery (DR) type of an
Autonomous Database.
Corresponds to the JSON property localDisasterRecoveryType
784 785 786 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 784 def local_disaster_recovery_type @local_disaster_recovery_type end |
#local_standby_db ⇒ Google::Apis::OracledatabaseV1::AutonomousDatabaseStandbySummary
Autonomous Data Guard standby database details. https://docs.oracle.com/en-us/
iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseStandbySummary
Corresponds to the JSON property localStandbyDb
790 791 792 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 790 def local_standby_db @local_standby_db end |
#maintenance_begin_time ⇒ String
Output only. The date and time when maintenance will begin.
Corresponds to the JSON property maintenanceBeginTime
795 796 797 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 795 def maintenance_begin_time @maintenance_begin_time end |
#maintenance_end_time ⇒ String
Output only. The date and time when maintenance will end.
Corresponds to the JSON property maintenanceEndTime
800 801 802 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 800 def maintenance_end_time @maintenance_end_time end |
#maintenance_schedule_type ⇒ String
Optional. Immutable. The maintenance schedule of the Autonomous Database.
Corresponds to the JSON property maintenanceScheduleType
805 806 807 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 805 def maintenance_schedule_type @maintenance_schedule_type end |
#memory_per_oracle_compute_unit_gbs ⇒ Fixnum
Output only. The amount of memory enabled per ECPU, in gigabytes.
Corresponds to the JSON property memoryPerOracleComputeUnitGbs
810 811 812 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 810 def memory_per_oracle_compute_unit_gbs @memory_per_oracle_compute_unit_gbs end |
#memory_table_gbs ⇒ Fixnum
Output only. The memory assigned to in-memory tables in an Autonomous Database.
Corresponds to the JSON property memoryTableGbs
815 816 817 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 815 def memory_table_gbs @memory_table_gbs end |
#mtls_connection_required ⇒ Boolean Also known as: mtls_connection_required?
Optional. Immutable. This field specifies if the Autonomous Database requires
mTLS connections.
Corresponds to the JSON property mtlsConnectionRequired
821 822 823 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 821 def mtls_connection_required @mtls_connection_required end |
#n_character_set ⇒ String
Optional. Immutable. The national character set for the Autonomous Database.
The default is AL16UTF16.
Corresponds to the JSON property nCharacterSet
828 829 830 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 828 def n_character_set @n_character_set end |
#next_long_term_backup_time ⇒ String
Output only. The long term backup schedule of the Autonomous Database.
Corresponds to the JSON property nextLongTermBackupTime
833 834 835 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 833 def next_long_term_backup_time @next_long_term_backup_time end |
#oci_url ⇒ String
Output only. The Oracle Cloud Infrastructure link for the Autonomous Database.
Corresponds to the JSON property ociUrl
838 839 840 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 838 def oci_url @oci_url end |
#ocid ⇒ String
Output only. OCID of the Autonomous Database. https://docs.oracle.com/en-us/
iaas/Content/General/Concepts/identifiers.htm#Oracle
Corresponds to the JSON property ocid
844 845 846 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 844 def ocid @ocid end |
#open_mode ⇒ String
Output only. This field indicates the current mode of the Autonomous Database.
Corresponds to the JSON property openMode
849 850 851 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 849 def open_mode @open_mode end |
#operations_insights_state ⇒ String
Output only. This field indicates the state of Operations Insights for the
Autonomous Database.
Corresponds to the JSON property operationsInsightsState
855 856 857 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 855 def operations_insights_state @operations_insights_state end |
#peer_db_ids ⇒ Array<String>
Output only. The list of OCIDs of standby databases located in Autonomous Data
Guard remote regions that are associated with the source database.
Corresponds to the JSON property peerDbIds
861 862 863 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 861 def peer_db_ids @peer_db_ids end |
#permission_level ⇒ String
Output only. The permission level of the Autonomous Database.
Corresponds to the JSON property permissionLevel
866 867 868 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 866 def @permission_level end |
#private_endpoint ⇒ String
Output only. The private endpoint for the Autonomous Database.
Corresponds to the JSON property privateEndpoint
871 872 873 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 871 def private_endpoint @private_endpoint end |
#private_endpoint_ip ⇒ String
Optional. Immutable. The private endpoint IP address for the Autonomous
Database.
Corresponds to the JSON property privateEndpointIp
877 878 879 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 877 def private_endpoint_ip @private_endpoint_ip end |
#private_endpoint_label ⇒ String
Optional. Immutable. The private endpoint label for the Autonomous Database.
Corresponds to the JSON property privateEndpointLabel
882 883 884 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 882 def private_endpoint_label @private_endpoint_label end |
#refreshable_mode ⇒ String
Output only. The refresh mode of the cloned Autonomous Database.
Corresponds to the JSON property refreshableMode
887 888 889 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 887 def refreshable_mode @refreshable_mode end |
#refreshable_state ⇒ String
Output only. The refresh State of the clone.
Corresponds to the JSON property refreshableState
892 893 894 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 892 def refreshable_state @refreshable_state end |
#role ⇒ String
Output only. The Data Guard role of the Autonomous Database.
Corresponds to the JSON property role
897 898 899 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 897 def role @role end |
#scheduled_operation_details ⇒ Array<Google::Apis::OracledatabaseV1::ScheduledOperationDetails>
Output only. The list and details of the scheduled operations of the
Autonomous Database.
Corresponds to the JSON property scheduledOperationDetails
903 904 905 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 903 def scheduled_operation_details @scheduled_operation_details end |
#secret_id ⇒ String
Optional. Immutable. The ID of the Oracle Cloud Infrastructure vault secret.
Corresponds to the JSON property secretId
908 909 910 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 908 def secret_id @secret_id end |
#service_agent_email ⇒ String
Output only. An Oracle-managed Google Cloud service account on which customers
can grant roles to access resources in the customer project.
Corresponds to the JSON property serviceAgentEmail
914 915 916 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 914 def service_agent_email @service_agent_email end |
#sql_web_developer_url ⇒ String
Output only. The SQL Web Developer URL for the Autonomous Database.
Corresponds to the JSON property sqlWebDeveloperUrl
919 920 921 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 919 def sql_web_developer_url @sql_web_developer_url end |
#state ⇒ String
Output only. The current lifecycle state of the Autonomous Database.
Corresponds to the JSON property state
924 925 926 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 924 def state @state end |
#supported_clone_regions ⇒ Array<String>
Output only. The list of available regions that can be used to create a clone
for the Autonomous Database.
Corresponds to the JSON property supportedCloneRegions
930 931 932 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 930 def supported_clone_regions @supported_clone_regions end |
#total_auto_backup_storage_size_gbs ⇒ Float
Output only. The storage space used by automatic backups of Autonomous
Database, in gigabytes.
Corresponds to the JSON property totalAutoBackupStorageSizeGbs
936 937 938 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 936 def total_auto_backup_storage_size_gbs @total_auto_backup_storage_size_gbs end |
#used_data_storage_size_tbs ⇒ Fixnum
Output only. The storage space used by Autonomous Database, in gigabytes.
Corresponds to the JSON property usedDataStorageSizeTbs
941 942 943 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 941 def used_data_storage_size_tbs @used_data_storage_size_tbs end |
#vault_id ⇒ String
Optional. Immutable. The ID of the Oracle Cloud Infrastructure vault.
Corresponds to the JSON property vaultId
946 947 948 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 946 def vault_id @vault_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 953 def update!(**args) @actual_used_data_storage_size_tb = args[:actual_used_data_storage_size_tb] if args.key?(:actual_used_data_storage_size_tb) @allocated_storage_size_tb = args[:allocated_storage_size_tb] if args.key?(:allocated_storage_size_tb) @allowlisted_ips = args[:allowlisted_ips] if args.key?(:allowlisted_ips) @apex_details = args[:apex_details] if args.key?(:apex_details) @are_primary_allowlisted_ips_used = args[:are_primary_allowlisted_ips_used] if args.key?(:are_primary_allowlisted_ips_used) @autonomous_container_database_id = args[:autonomous_container_database_id] if args.key?(:autonomous_container_database_id) @available_upgrade_versions = args[:available_upgrade_versions] if args.key?(:available_upgrade_versions) @backup_retention_period_days = args[:backup_retention_period_days] if args.key?(:backup_retention_period_days) @character_set = args[:character_set] if args.key?(:character_set) @compute_count = args[:compute_count] if args.key?(:compute_count) @connection_strings = args[:connection_strings] if args.key?(:connection_strings) @connection_urls = args[:connection_urls] if args.key?(:connection_urls) @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count) @customer_contacts = args[:customer_contacts] if args.key?(:customer_contacts) @data_guard_role_changed_time = args[:data_guard_role_changed_time] if args.key?(:data_guard_role_changed_time) @data_safe_state = args[:data_safe_state] if args.key?(:data_safe_state) @data_storage_size_gb = args[:data_storage_size_gb] if args.key?(:data_storage_size_gb) @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb) @database_management_state = args[:database_management_state] if args.key?(:database_management_state) @db_edition = args[:db_edition] if args.key?(:db_edition) @db_version = args[:db_version] if args.key?(:db_version) @db_workload = args[:db_workload] if args.key?(:db_workload) @disaster_recovery_role_changed_time = args[:disaster_recovery_role_changed_time] if args.key?(:disaster_recovery_role_changed_time) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @encryption_key_history_entries = args[:encryption_key_history_entries] if args.key?(:encryption_key_history_entries) @failed_data_recovery_duration = args[:failed_data_recovery_duration] if args.key?(:failed_data_recovery_duration) @is_auto_scaling_enabled = args[:is_auto_scaling_enabled] if args.key?(:is_auto_scaling_enabled) @is_local_data_guard_enabled = args[:is_local_data_guard_enabled] if args.key?(:is_local_data_guard_enabled) @is_storage_auto_scaling_enabled = args[:is_storage_auto_scaling_enabled] if args.key?(:is_storage_auto_scaling_enabled) @license_type = args[:license_type] if args.key?(:license_type) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @local_adg_auto_failover_max_data_loss_limit = args[:local_adg_auto_failover_max_data_loss_limit] if args.key?(:local_adg_auto_failover_max_data_loss_limit) @local_adg_auto_failover_max_data_loss_limit_duration = args[:local_adg_auto_failover_max_data_loss_limit_duration] if args.key?(:local_adg_auto_failover_max_data_loss_limit_duration) @local_data_guard_enabled = args[:local_data_guard_enabled] if args.key?(:local_data_guard_enabled) @local_disaster_recovery_type = args[:local_disaster_recovery_type] if args.key?(:local_disaster_recovery_type) @local_standby_db = args[:local_standby_db] if args.key?(:local_standby_db) @maintenance_begin_time = args[:maintenance_begin_time] if args.key?(:maintenance_begin_time) @maintenance_end_time = args[:maintenance_end_time] if args.key?(:maintenance_end_time) @maintenance_schedule_type = args[:maintenance_schedule_type] if args.key?(:maintenance_schedule_type) @memory_per_oracle_compute_unit_gbs = args[:memory_per_oracle_compute_unit_gbs] if args.key?(:memory_per_oracle_compute_unit_gbs) @memory_table_gbs = args[:memory_table_gbs] if args.key?(:memory_table_gbs) @mtls_connection_required = args[:mtls_connection_required] if args.key?(:mtls_connection_required) @n_character_set = args[:n_character_set] if args.key?(:n_character_set) @next_long_term_backup_time = args[:next_long_term_backup_time] if args.key?(:next_long_term_backup_time) @oci_url = args[:oci_url] if args.key?(:oci_url) @ocid = args[:ocid] if args.key?(:ocid) @open_mode = args[:open_mode] if args.key?(:open_mode) @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state) @peer_db_ids = args[:peer_db_ids] if args.key?(:peer_db_ids) @permission_level = args[:permission_level] if args.key?(:permission_level) @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint) @private_endpoint_ip = args[:private_endpoint_ip] if args.key?(:private_endpoint_ip) @private_endpoint_label = args[:private_endpoint_label] if args.key?(:private_endpoint_label) @refreshable_mode = args[:refreshable_mode] if args.key?(:refreshable_mode) @refreshable_state = args[:refreshable_state] if args.key?(:refreshable_state) @role = args[:role] if args.key?(:role) @scheduled_operation_details = args[:scheduled_operation_details] if args.key?(:scheduled_operation_details) @secret_id = args[:secret_id] if args.key?(:secret_id) @service_agent_email = args[:service_agent_email] if args.key?(:service_agent_email) @sql_web_developer_url = args[:sql_web_developer_url] if args.key?(:sql_web_developer_url) @state = args[:state] if args.key?(:state) @supported_clone_regions = args[:supported_clone_regions] if args.key?(:supported_clone_regions) @total_auto_backup_storage_size_gbs = args[:total_auto_backup_storage_size_gbs] if args.key?(:total_auto_backup_storage_size_gbs) @used_data_storage_size_tbs = args[:used_data_storage_size_tbs] if args.key?(:used_data_storage_size_tbs) @vault_id = args[:vault_id] if args.key?(:vault_id) end |