Class: Google::Apis::OracledatabaseV1::AutonomousDatabaseStandbySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Autonomous Data Guard standby database details. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseStandbySummary

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDatabaseStandbySummary

Returns a new instance of AutonomousDatabaseStandbySummary.



1056
1057
1058
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_guard_role_changed_timeString

Output only. The date and time the Autonomous Data Guard role was switched for the standby Autonomous Database. Corresponds to the JSON property dataGuardRoleChangedTime

Returns:

  • (String)


1031
1032
1033
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1031

def data_guard_role_changed_time
  @data_guard_role_changed_time
end

#disaster_recovery_role_changed_timeString

Output only. The date and time the Disaster Recovery role was switched for the standby Autonomous Database. Corresponds to the JSON property disasterRecoveryRoleChangedTime

Returns:

  • (String)


1037
1038
1039
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1037

def disaster_recovery_role_changed_time
  @disaster_recovery_role_changed_time
end

#lag_time_durationString

Output only. The amount of time, in seconds, that the data of the standby database lags in comparison to the data of the primary database. Corresponds to the JSON property lagTimeDuration

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1043

def lag_time_duration
  @lag_time_duration
end

#lifecycle_detailsString

Output only. The additional details about the current lifecycle state of the Autonomous Database. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1049

def lifecycle_details
  @lifecycle_details
end

#stateString

Output only. The current lifecycle state of the Autonomous Database. Corresponds to the JSON property state

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1054

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1061
1062
1063
1064
1065
1066
1067
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1061

def update!(**args)
  @data_guard_role_changed_time = args[:data_guard_role_changed_time] if args.key?(:data_guard_role_changed_time)
  @disaster_recovery_role_changed_time = args[:disaster_recovery_role_changed_time] if args.key?(:disaster_recovery_role_changed_time)
  @lag_time_duration = args[:lag_time_duration] if args.key?(:lag_time_duration)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @state = args[:state] if args.key?(:state)
end