Class: Google::Apis::OracledatabaseV1::AutonomousDbVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Autonomous Database version. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/AutonomousDbVersionSummary/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutonomousDbVersion

Returns a new instance of AutonomousDbVersion.



1098
1099
1100
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#db_workloadString

Output only. The Autonomous Database workload type. Corresponds to the JSON property dbWorkload

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1078

def db_workload
  @db_workload
end

#nameString

Identifier. The name of the Autonomous Database Version resource with the format: projects/project/locations/region/autonomousDbVersions/ autonomous_db_version Corresponds to the JSON property name

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1085

def name
  @name
end

#versionString

Output only. An Oracle Database version for Autonomous Database. Corresponds to the JSON property version

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1090

def version
  @version
end

#workload_uriString

Output only. A URL that points to a detailed description of the Autonomous Database version. Corresponds to the JSON property workloadUri

Returns:

  • (String)


1096
1097
1098
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1096

def workload_uri
  @workload_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1103
1104
1105
1106
1107
1108
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1103

def update!(**args)
  @db_workload = args[:db_workload] if args.key?(:db_workload)
  @name = args[:name] if args.key?(:name)
  @version = args[:version] if args.key?(:version)
  @workload_uri = args[:workload_uri] if args.key?(:workload_uri)
end