Class: Google::Apis::OracledatabaseV1::CloudExadataInfrastructure
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::CloudExadataInfrastructure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents CloudExadataInfrastructure resource. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/CloudExadataInfrastructure/
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#properties ⇒ Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties
Various properties of Exadata Infrastructure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudExadataInfrastructure
constructor
A new instance of CloudExadataInfrastructure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudExadataInfrastructure
Returns a new instance of CloudExadataInfrastructure.
1364 1365 1366 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the Exadata Infrastructure was created.
Corresponds to the JSON property createTime
1327 1328 1329 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1327 def create_time @create_time end |
#display_name ⇒ String
Optional. User friendly name for this resource.
Corresponds to the JSON property displayName
1332 1333 1334 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1332 def display_name @display_name end |
#entitlement_id ⇒ String
Output only. Entitlement ID of the private offer against which this
infrastructure resource is provisioned.
Corresponds to the JSON property entitlementId
1338 1339 1340 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1338 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle Exadata Infrastructure is hosted.
Example: us-east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
1345 1346 1347 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1345 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. Labels or tags associated with the resource.
Corresponds to the JSON property labels
1350 1351 1352 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1350 def labels @labels end |
#name ⇒ String
Identifier. The name of the Exadata Infrastructure resource with the format:
projects/project/locations/region/cloudExadataInfrastructures/
cloud_exadata_infrastructure
Corresponds to the JSON property name
1357 1358 1359 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1357 def name @name end |
#properties ⇒ Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties
Various properties of Exadata Infrastructure.
Corresponds to the JSON property properties
1362 1363 1364 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1362 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1369 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) end |