Class: Google::Apis::OracledatabaseV1::CloudExadataInfrastructure
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::CloudExadataInfrastructure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents CloudExadataInfrastructure resource. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/CloudExadataInfrastructure/
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#properties ⇒ Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties
Various properties of Exadata Infrastructure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudExadataInfrastructure
constructor
A new instance of CloudExadataInfrastructure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudExadataInfrastructure
Returns a new instance of CloudExadataInfrastructure.
1311 1312 1313 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the Exadata Infrastructure was created.
Corresponds to the JSON property createTime
1274 1275 1276 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1274 def create_time @create_time end |
#display_name ⇒ String
Optional. User friendly name for this resource.
Corresponds to the JSON property displayName
1279 1280 1281 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1279 def display_name @display_name end |
#entitlement_id ⇒ String
Output only. Entitlement ID of the private offer against which this
infrastructure resource is provisioned.
Corresponds to the JSON property entitlementId
1285 1286 1287 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1285 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle Exadata Infrastructure is hosted.
Example: us-east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
1292 1293 1294 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1292 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. Labels or tags associated with the resource.
Corresponds to the JSON property labels
1297 1298 1299 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1297 def labels @labels end |
#name ⇒ String
Identifier. The name of the Exadata Infrastructure resource with the format:
projects/project/locations/region/cloudExadataInfrastructures/
cloud_exadata_infrastructure
Corresponds to the JSON property name
1304 1305 1306 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1304 def name @name end |
#properties ⇒ Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties
Various properties of Exadata Infrastructure.
Corresponds to the JSON property properties
1309 1310 1311 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1309 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1316 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) end |