Class: Google::Apis::OracledatabaseV1::CloudExadataInfrastructure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents CloudExadataInfrastructure resource. https://docs.oracle.com/en-us/ iaas/api/#/en/database/20160918/CloudExadataInfrastructure/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudExadataInfrastructure

Returns a new instance of CloudExadataInfrastructure.



1225
1226
1227
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the Exadata Infrastructure was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1188
1189
1190
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1188

def create_time
  @create_time
end

#display_nameString

Optional. User friendly name for this resource. Corresponds to the JSON property displayName

Returns:

  • (String)


1193
1194
1195
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1193

def display_name
  @display_name
end

#entitlement_idString

Output only. Entitlement ID of the private offer against which this infrastructure resource is provisioned. Corresponds to the JSON property entitlementId

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1199

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle Exadata Infrastructure is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1206

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. Labels or tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1211
1212
1213
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1211

def labels
  @labels
end

#nameString

Identifier. The name of the Exadata Infrastructure resource with the format: projects/project/locations/region/cloudExadataInfrastructures/ cloud_exadata_infrastructure Corresponds to the JSON property name

Returns:

  • (String)


1218
1219
1220
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1218

def name
  @name
end

#propertiesGoogle::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties

Various properties of Exadata Infrastructure. Corresponds to the JSON property properties



1223
1224
1225
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1223

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1230

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end