Class: Google::Apis::OracledatabaseV1::CloudExadataInfrastructureProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties of Exadata Infrastructure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudExadataInfrastructureProperties

Returns a new instance of CloudExadataInfrastructureProperties.



1407
1408
1409
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activated_storage_countFixnum

Output only. The requested number of additional storage servers activated for the Exadata Infrastructure. Corresponds to the JSON property activatedStorageCount

Returns:

  • (Fixnum)


1249
1250
1251
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1249

def activated_storage_count
  @activated_storage_count
end

#additional_storage_countFixnum

Output only. The requested number of additional storage servers for the Exadata Infrastructure. Corresponds to the JSON property additionalStorageCount

Returns:

  • (Fixnum)


1255
1256
1257
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1255

def additional_storage_count
  @additional_storage_count
end

#available_storage_size_gbFixnum

Output only. The available storage can be allocated to the Exadata Infrastructure resource, in gigabytes (GB). Corresponds to the JSON property availableStorageSizeGb

Returns:

  • (Fixnum)


1261
1262
1263
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1261

def available_storage_size_gb
  @available_storage_size_gb
end

#compute_countFixnum

Optional. The number of compute servers for the Exadata Infrastructure. Corresponds to the JSON property computeCount

Returns:

  • (Fixnum)


1266
1267
1268
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1266

def compute_count
  @compute_count
end

#compute_modelString

Output only. The compute model of the Exadata Infrastructure. Corresponds to the JSON property computeModel

Returns:

  • (String)


1271
1272
1273
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1271

def compute_model
  @compute_model
end

#cpu_countFixnum

Output only. The number of enabled CPU cores. Corresponds to the JSON property cpuCount

Returns:

  • (Fixnum)


1276
1277
1278
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1276

def cpu_count
  @cpu_count
end

#customer_contactsArray<Google::Apis::OracledatabaseV1::CustomerContact>

Optional. The list of customer contacts. Corresponds to the JSON property customerContacts



1281
1282
1283
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1281

def customer_contacts
  @customer_contacts
end

#data_storage_size_tbFloat

Output only. Size, in terabytes, of the DATA disk group. Corresponds to the JSON property dataStorageSizeTb

Returns:

  • (Float)


1286
1287
1288
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1286

def data_storage_size_tb
  @data_storage_size_tb
end

#database_server_typeString

Output only. The database server type of the Exadata Infrastructure. Corresponds to the JSON property databaseServerType

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1291

def database_server_type
  @database_server_type
end

#db_node_storage_size_gbFixnum

Output only. The local node storage allocated in GBs. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


1296
1297
1298
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1296

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#db_server_versionString

Output only. The software version of the database servers (dom0) in the Exadata Infrastructure. Corresponds to the JSON property dbServerVersion

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1302

def db_server_version
  @db_server_version
end

#maintenance_windowGoogle::Apis::OracledatabaseV1::MaintenanceWindow

Maintenance window as defined by Oracle. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/datatypes/MaintenanceWindow Corresponds to the JSON property maintenanceWindow



1308
1309
1310
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1308

def maintenance_window
  @maintenance_window
end

#max_cpu_countFixnum

Output only. The total number of CPU cores available. Corresponds to the JSON property maxCpuCount

Returns:

  • (Fixnum)


1313
1314
1315
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1313

def max_cpu_count
  @max_cpu_count
end

#max_data_storage_tbFloat

Output only. The total available DATA disk group size. Corresponds to the JSON property maxDataStorageTb

Returns:

  • (Float)


1318
1319
1320
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1318

def max_data_storage_tb
  @max_data_storage_tb
end

#max_db_node_storage_size_gbFixnum

Output only. The total local node storage available in GBs. Corresponds to the JSON property maxDbNodeStorageSizeGb

Returns:

  • (Fixnum)


1323
1324
1325
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1323

def max_db_node_storage_size_gb
  @max_db_node_storage_size_gb
end

#max_memory_gbFixnum

Output only. The total memory available in GBs. Corresponds to the JSON property maxMemoryGb

Returns:

  • (Fixnum)


1328
1329
1330
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1328

def max_memory_gb
  @max_memory_gb
end

#memory_size_gbFixnum

Output only. The memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


1333
1334
1335
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1333

def memory_size_gb
  @memory_size_gb
end

#monthly_db_server_versionString

Output only. The monthly software version of the database servers (dom0) in the Exadata Infrastructure. Example: 20.1.15 Corresponds to the JSON property monthlyDbServerVersion

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1339

def monthly_db_server_version
  @monthly_db_server_version
end

#monthly_storage_server_versionString

Output only. The monthly software version of the storage servers (cells) in the Exadata Infrastructure. Example: 20.1.15 Corresponds to the JSON property monthlyStorageServerVersion

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1345

def monthly_storage_server_version
  @monthly_storage_server_version
end

#next_maintenance_run_idString

Output only. The OCID of the next maintenance run. Corresponds to the JSON property nextMaintenanceRunId

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1350

def next_maintenance_run_id
  @next_maintenance_run_id
end

#next_maintenance_run_timeString

Output only. The time when the next maintenance run will occur. Corresponds to the JSON property nextMaintenanceRunTime

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1355

def next_maintenance_run_time
  @next_maintenance_run_time
end

#next_security_maintenance_run_timeString

Output only. The time when the next security maintenance run will occur. Corresponds to the JSON property nextSecurityMaintenanceRunTime

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1360

def next_security_maintenance_run_time
  @next_security_maintenance_run_time
end

#oci_urlString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUrl

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1365

def oci_url
  @oci_url
end

#ocidString

Output only. OCID of created infra. https://docs.oracle.com/en-us/iaas/Content/ General/Concepts/identifiers.htm#Oracle Corresponds to the JSON property ocid

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1371

def ocid
  @ocid
end

#shapeString

Required. The shape of the Exadata Infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance. Corresponds to the JSON property shape

Returns:

  • (String)


1377
1378
1379
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1377

def shape
  @shape
end

#stateString

Output only. The current lifecycle state of the Exadata Infrastructure. Corresponds to the JSON property state

Returns:

  • (String)


1382
1383
1384
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1382

def state
  @state
end

#storage_countFixnum

Optional. The number of Cloud Exadata storage servers for the Exadata Infrastructure. Corresponds to the JSON property storageCount

Returns:

  • (Fixnum)


1388
1389
1390
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1388

def storage_count
  @storage_count
end

#storage_server_typeString

Output only. The storage server type of the Exadata Infrastructure. Corresponds to the JSON property storageServerType

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1393

def storage_server_type
  @storage_server_type
end

#storage_server_versionString

Output only. The software version of the storage servers (cells) in the Exadata Infrastructure. Corresponds to the JSON property storageServerVersion

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1399

def storage_server_version
  @storage_server_version
end

#total_storage_size_gbFixnum

Optional. The total storage allocated to the Exadata Infrastructure resource, in gigabytes (GB). Corresponds to the JSON property totalStorageSizeGb

Returns:

  • (Fixnum)


1405
1406
1407
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1405

def total_storage_size_gb
  @total_storage_size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1412

def update!(**args)
  @activated_storage_count = args[:activated_storage_count] if args.key?(:activated_storage_count)
  @additional_storage_count = args[:additional_storage_count] if args.key?(:additional_storage_count)
  @available_storage_size_gb = args[:available_storage_size_gb] if args.key?(:available_storage_size_gb)
  @compute_count = args[:compute_count] if args.key?(:compute_count)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @cpu_count = args[:cpu_count] if args.key?(:cpu_count)
  @customer_contacts = args[:customer_contacts] if args.key?(:customer_contacts)
  @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb)
  @database_server_type = args[:database_server_type] if args.key?(:database_server_type)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @db_server_version = args[:db_server_version] if args.key?(:db_server_version)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @max_cpu_count = args[:max_cpu_count] if args.key?(:max_cpu_count)
  @max_data_storage_tb = args[:max_data_storage_tb] if args.key?(:max_data_storage_tb)
  @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb)
  @max_memory_gb = args[:max_memory_gb] if args.key?(:max_memory_gb)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @monthly_db_server_version = args[:monthly_db_server_version] if args.key?(:monthly_db_server_version)
  @monthly_storage_server_version = args[:monthly_storage_server_version] if args.key?(:monthly_storage_server_version)
  @next_maintenance_run_id = args[:next_maintenance_run_id] if args.key?(:next_maintenance_run_id)
  @next_maintenance_run_time = args[:next_maintenance_run_time] if args.key?(:next_maintenance_run_time)
  @next_security_maintenance_run_time = args[:next_security_maintenance_run_time] if args.key?(:next_security_maintenance_run_time)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ocid = args[:ocid] if args.key?(:ocid)
  @shape = args[:shape] if args.key?(:shape)
  @state = args[:state] if args.key?(:state)
  @storage_count = args[:storage_count] if args.key?(:storage_count)
  @storage_server_type = args[:storage_server_type] if args.key?(:storage_server_type)
  @storage_server_version = args[:storage_server_version] if args.key?(:storage_server_version)
  @total_storage_size_gb = args[:total_storage_size_gb] if args.key?(:total_storage_size_gb)
end