Class: Google::Apis::OracledatabaseV1::CloudVmCluster
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::CloudVmCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the Cloud VM Cluster resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/CloudVmCluster/
Instance Attribute Summary collapse
-
#backup_odb_subnet ⇒ String
Optional.
-
#backup_subnet_cidr ⇒ String
Optional.
-
#cidr ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#exadata_infrastructure ⇒ String
Required.
-
#gcp_oracle_zone ⇒ String
Output only.
-
#identity_connector ⇒ Google::Apis::OracledatabaseV1::IdentityConnector
The identity connector details which will allow OCI to securely access the resources in the customer project.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Optional.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Optional.
-
#properties ⇒ Google::Apis::OracledatabaseV1::CloudVmClusterProperties
Various properties and settings associated with Exadata VM cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudVmCluster
constructor
A new instance of CloudVmCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudVmCluster
Returns a new instance of CloudVmCluster.
1535 1536 1537 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_odb_subnet ⇒ String
Optional. The name of the backup OdbSubnet associated with the VM Cluster.
Format: projects/project/locations/location/odbNetworks/odb_network/
odbSubnets/odb_subnet
Corresponds to the JSON property backupOdbSubnet
1456 1457 1458 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1456 def backup_odb_subnet @backup_odb_subnet end |
#backup_subnet_cidr ⇒ String
Optional. CIDR range of the backup subnet.
Corresponds to the JSON property backupSubnetCidr
1461 1462 1463 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1461 def backup_subnet_cidr @backup_subnet_cidr end |
#cidr ⇒ String
Optional. Network settings. CIDR to use for cluster IP allocation.
Corresponds to the JSON property cidr
1466 1467 1468 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1466 def cidr @cidr end |
#create_time ⇒ String
Output only. The date and time that the VM cluster was created.
Corresponds to the JSON property createTime
1471 1472 1473 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1471 def create_time @create_time end |
#display_name ⇒ String
Optional. User friendly name for this resource.
Corresponds to the JSON property displayName
1476 1477 1478 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1476 def display_name @display_name end |
#exadata_infrastructure ⇒ String
Required. The name of the Exadata Infrastructure resource on which VM cluster
resource is created, in the following format: projects/project/locations/
region/cloudExadataInfrastuctures/cloud_extradata_infrastructure
Corresponds to the JSON property exadataInfrastructure
1483 1484 1485 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1483 def exadata_infrastructure @exadata_infrastructure end |
#gcp_oracle_zone ⇒ String
Output only. The GCP Oracle zone where Oracle CloudVmCluster is hosted. This
will be the same as the gcp_oracle_zone of the CloudExadataInfrastructure.
Example: us-east4-b-r2.
Corresponds to the JSON property gcpOracleZone
1490 1491 1492 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1490 def gcp_oracle_zone @gcp_oracle_zone end |
#identity_connector ⇒ Google::Apis::OracledatabaseV1::IdentityConnector
The identity connector details which will allow OCI to securely access the
resources in the customer project.
Corresponds to the JSON property identityConnector
1496 1497 1498 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1496 def identity_connector @identity_connector end |
#labels ⇒ Hash<String,String>
Optional. Labels or tags associated with the VM Cluster.
Corresponds to the JSON property labels
1501 1502 1503 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1501 def labels @labels end |
#name ⇒ String
Identifier. The name of the VM Cluster resource with the format: projects/
project/locations/region/cloudVmClusters/cloud_vm_cluster
Corresponds to the JSON property name
1507 1508 1509 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1507 def name @name end |
#network ⇒ String
Optional. The name of the VPC network. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
1513 1514 1515 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1513 def network @network end |
#odb_network ⇒ String
Optional. The name of the OdbNetwork associated with the VM Cluster. Format:
projects/project/locations/location/odbNetworks/odb_network It is
optional but if specified, this should match the parent ODBNetwork of the
odb_subnet and backup_odb_subnet.
Corresponds to the JSON property odbNetwork
1521 1522 1523 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1521 def odb_network @odb_network end |
#odb_subnet ⇒ String
Optional. The name of the OdbSubnet associated with the VM Cluster for IP
allocation. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
1528 1529 1530 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1528 def odb_subnet @odb_subnet end |
#properties ⇒ Google::Apis::OracledatabaseV1::CloudVmClusterProperties
Various properties and settings associated with Exadata VM cluster.
Corresponds to the JSON property properties
1533 1534 1535 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1533 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1540 def update!(**args) @backup_odb_subnet = args[:backup_odb_subnet] if args.key?(:backup_odb_subnet) @backup_subnet_cidr = args[:backup_subnet_cidr] if args.key?(:backup_subnet_cidr) @cidr = args[:cidr] if args.key?(:cidr) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @exadata_infrastructure = args[:exadata_infrastructure] if args.key?(:exadata_infrastructure) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @identity_connector = args[:identity_connector] if args.key?(:identity_connector) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @properties = args[:properties] if args.key?(:properties) end |