Class: Google::Apis::OracledatabaseV1::CloudVmClusterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata VM cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudVmClusterProperties

Returns a new instance of CloudVmClusterProperties.



1838
1839
1840
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_nameString

Optional. OCI Cluster name. Corresponds to the JSON property clusterName

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1665

def cluster_name
  @cluster_name
end

#compartment_idString

Output only. Compartment ID of cluster. Corresponds to the JSON property compartmentId

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1670

def compartment_id
  @compartment_id
end

#compute_modelString

Output only. The compute model of the VM Cluster. Corresponds to the JSON property computeModel

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1675

def compute_model
  @compute_model
end

#cpu_core_countFixnum

Required. Number of enabled CPU cores. Corresponds to the JSON property cpuCoreCount

Returns:

  • (Fixnum)


1680
1681
1682
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1680

def cpu_core_count
  @cpu_core_count
end

#data_storage_size_tbFloat

Optional. The data disk group size to be allocated in TBs. Corresponds to the JSON property dataStorageSizeTb

Returns:

  • (Float)


1685
1686
1687
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1685

def data_storage_size_tb
  @data_storage_size_tb
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


1690
1691
1692
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1690

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#db_server_ocidsArray<String>

Optional. OCID of database servers. Corresponds to the JSON property dbServerOcids

Returns:

  • (Array<String>)


1695
1696
1697
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1695

def db_server_ocids
  @db_server_ocids
end

#diagnostics_data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptions

Data collection options for diagnostics. Corresponds to the JSON property diagnosticsDataCollectionOptions



1700
1701
1702
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1700

def diagnostics_data_collection_options
  @diagnostics_data_collection_options
end

#disk_redundancyString

Optional. The type of redundancy. Corresponds to the JSON property diskRedundancy

Returns:

  • (String)


1705
1706
1707
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1705

def disk_redundancy
  @disk_redundancy
end

#dns_listener_ipString

Output only. DNS listener IP. Corresponds to the JSON property dnsListenerIp

Returns:

  • (String)


1710
1711
1712
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1710

def dns_listener_ip
  @dns_listener_ip
end

#domainString

Output only. Parent DNS domain where SCAN DNS and hosts names are qualified. ex: ocispdelegated.ocisp10jvnet.oraclevcn.com Corresponds to the JSON property domain

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1716

def domain
  @domain
end

#gi_versionString

Optional. Grid Infrastructure Version. Corresponds to the JSON property giVersion

Returns:

  • (String)


1721
1722
1723
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1721

def gi_version
  @gi_version
end

#hostnameString

Output only. host name without domain. format: "-" with some suffix. ex: sp2- yi0xq where "sp2" is the hostname_prefix. Corresponds to the JSON property hostname

Returns:

  • (String)


1727
1728
1729
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1727

def hostname
  @hostname
end

#hostname_prefixString

Optional. Prefix for VM cluster host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


1732
1733
1734
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1732

def hostname_prefix
  @hostname_prefix
end

#license_typeString

Required. License type of VM Cluster. Corresponds to the JSON property licenseType

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1737

def license_type
  @license_type
end

#local_backup_enabledBoolean Also known as: local_backup_enabled?

Optional. Use local backup. Corresponds to the JSON property localBackupEnabled

Returns:

  • (Boolean)


1742
1743
1744
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1742

def local_backup_enabled
  @local_backup_enabled
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


1748
1749
1750
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1748

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Optional. Number of database servers. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


1753
1754
1755
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1753

def node_count
  @node_count
end

#oci_urlString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUrl

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1758

def oci_url
  @oci_url
end

#ocidString

Output only. Oracle Cloud Infrastructure ID of VM Cluster. Corresponds to the JSON property ocid

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1763

def ocid
  @ocid
end

#ocpu_countFloat

Optional. OCPU count per VM. Minimum is 0.1. Corresponds to the JSON property ocpuCount

Returns:

  • (Float)


1768
1769
1770
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1768

def ocpu_count
  @ocpu_count
end

#scan_dnsString

Output only. SCAN DNS name. ex: sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet. oraclevcn.com Corresponds to the JSON property scanDns

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1774

def scan_dns
  @scan_dns
end

#scan_dns_record_idString

Output only. OCID of scan DNS record. Corresponds to the JSON property scanDnsRecordId

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1779

def scan_dns_record_id
  @scan_dns_record_id
end

#scan_ip_idsArray<String>

Output only. OCIDs of scan IPs. Corresponds to the JSON property scanIpIds

Returns:

  • (Array<String>)


1784
1785
1786
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1784

def scan_ip_ids
  @scan_ip_ids
end

#scan_listener_port_tcpFixnum

Optional. SCAN listener port - TCP Corresponds to the JSON property scanListenerPortTcp

Returns:

  • (Fixnum)


1789
1790
1791
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1789

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#scan_listener_port_tcp_sslFixnum

Optional. SCAN listener port - TLS Corresponds to the JSON property scanListenerPortTcpSsl

Returns:

  • (Fixnum)


1794
1795
1796
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1794

def scan_listener_port_tcp_ssl
  @scan_listener_port_tcp_ssl
end

#shapeString

Output only. Shape of VM Cluster. Corresponds to the JSON property shape

Returns:

  • (String)


1799
1800
1801
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1799

def shape
  @shape
end

#sparse_diskgroup_enabledBoolean Also known as: sparse_diskgroup_enabled?

Optional. Use exadata sparse snapshots. Corresponds to the JSON property sparseDiskgroupEnabled

Returns:

  • (Boolean)


1804
1805
1806
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1804

def sparse_diskgroup_enabled
  @sparse_diskgroup_enabled
end

#ssh_public_keysArray<String>

Optional. SSH public keys to be stored with cluster. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


1810
1811
1812
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1810

def ssh_public_keys
  @ssh_public_keys
end

#stateString

Output only. State of the cluster. Corresponds to the JSON property state

Returns:

  • (String)


1815
1816
1817
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1815

def state
  @state
end

#storage_management_typeString

Output only. The storage management type of the VM Cluster. Corresponds to the JSON property storageManagementType

Returns:

  • (String)


1820
1821
1822
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1820

def storage_management_type
  @storage_management_type
end

#storage_size_gbFixnum

Output only. The storage allocation for the disk group, in gigabytes (GB). Corresponds to the JSON property storageSizeGb

Returns:

  • (Fixnum)


1825
1826
1827
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1825

def storage_size_gb
  @storage_size_gb
end

#system_versionString

Optional. Operating system version of the image. Corresponds to the JSON property systemVersion

Returns:

  • (String)


1830
1831
1832
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1830

def system_version
  @system_version
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



1836
1837
1838
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1836

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1843

def update!(**args)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count)
  @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @db_server_ocids = args[:db_server_ocids] if args.key?(:db_server_ocids)
  @diagnostics_data_collection_options = args[:diagnostics_data_collection_options] if args.key?(:diagnostics_data_collection_options)
  @disk_redundancy = args[:disk_redundancy] if args.key?(:disk_redundancy)
  @dns_listener_ip = args[:dns_listener_ip] if args.key?(:dns_listener_ip)
  @domain = args[:domain] if args.key?(:domain)
  @gi_version = args[:gi_version] if args.key?(:gi_version)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @license_type = args[:license_type] if args.key?(:license_type)
  @local_backup_enabled = args[:local_backup_enabled] if args.key?(:local_backup_enabled)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @scan_dns = args[:scan_dns] if args.key?(:scan_dns)
  @scan_dns_record_id = args[:scan_dns_record_id] if args.key?(:scan_dns_record_id)
  @scan_ip_ids = args[:scan_ip_ids] if args.key?(:scan_ip_ids)
  @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp)
  @scan_listener_port_tcp_ssl = args[:scan_listener_port_tcp_ssl] if args.key?(:scan_listener_port_tcp_ssl)
  @shape = args[:shape] if args.key?(:shape)
  @sparse_diskgroup_enabled = args[:sparse_diskgroup_enabled] if args.key?(:sparse_diskgroup_enabled)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @state = args[:state] if args.key?(:state)
  @storage_management_type = args[:storage_management_type] if args.key?(:storage_management_type)
  @storage_size_gb = args[:storage_size_gb] if args.key?(:storage_size_gb)
  @system_version = args[:system_version] if args.key?(:system_version)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end