Class: Google::Apis::OracledatabaseV1::CloudVmClusterProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::CloudVmClusterProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Various properties and settings associated with Exadata VM cluster.
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
Optional.
-
#compartment_id ⇒ String
Output only.
-
#compute_model ⇒ String
Output only.
-
#cpu_core_count ⇒ Fixnum
Required.
-
#data_storage_size_tb ⇒ Float
Optional.
-
#db_node_storage_size_gb ⇒ Fixnum
Optional.
-
#db_server_ocids ⇒ Array<String>
Optional.
-
#diagnostics_data_collection_options ⇒ Google::Apis::OracledatabaseV1::DataCollectionOptions
Data collection options for diagnostics.
-
#disk_redundancy ⇒ String
Optional.
-
#dns_listener_ip ⇒ String
Output only.
-
#domain ⇒ String
Output only.
-
#gi_version ⇒ String
Optional.
-
#hostname ⇒ String
Output only.
-
#hostname_prefix ⇒ String
Optional.
-
#license_type ⇒ String
Required.
-
#local_backup_enabled ⇒ Boolean
(also: #local_backup_enabled?)
Optional.
-
#memory_size_gb ⇒ Fixnum
Optional.
-
#node_count ⇒ Fixnum
Optional.
-
#oci_url ⇒ String
Output only.
-
#ocid ⇒ String
Output only.
-
#ocpu_count ⇒ Float
Optional.
-
#scan_dns ⇒ String
Output only.
-
#scan_dns_record_id ⇒ String
Output only.
-
#scan_ip_ids ⇒ Array<String>
Output only.
-
#scan_listener_port_tcp ⇒ Fixnum
Output only.
-
#scan_listener_port_tcp_ssl ⇒ Fixnum
Output only.
-
#shape ⇒ String
Output only.
-
#sparse_diskgroup_enabled ⇒ Boolean
(also: #sparse_diskgroup_enabled?)
Optional.
-
#ssh_public_keys ⇒ Array<String>
Optional.
-
#state ⇒ String
Output only.
-
#storage_size_gb ⇒ Fixnum
Output only.
-
#system_version ⇒ String
Optional.
-
#time_zone ⇒ Google::Apis::OracledatabaseV1::TimeZone
Represents a time zone from the IANA Time Zone Database.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudVmClusterProperties
constructor
A new instance of CloudVmClusterProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudVmClusterProperties
Returns a new instance of CloudVmClusterProperties.
1819 1820 1821 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_name ⇒ String
Optional. OCI Cluster name.
Corresponds to the JSON property clusterName
1651 1652 1653 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1651 def cluster_name @cluster_name end |
#compartment_id ⇒ String
Output only. Compartment ID of cluster.
Corresponds to the JSON property compartmentId
1656 1657 1658 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1656 def compartment_id @compartment_id end |
#compute_model ⇒ String
Output only. The compute model of the VM Cluster.
Corresponds to the JSON property computeModel
1661 1662 1663 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1661 def compute_model @compute_model end |
#cpu_core_count ⇒ Fixnum
Required. Number of enabled CPU cores.
Corresponds to the JSON property cpuCoreCount
1666 1667 1668 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1666 def cpu_core_count @cpu_core_count end |
#data_storage_size_tb ⇒ Float
Optional. The data disk group size to be allocated in TBs.
Corresponds to the JSON property dataStorageSizeTb
1671 1672 1673 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1671 def data_storage_size_tb @data_storage_size_tb end |
#db_node_storage_size_gb ⇒ Fixnum
Optional. Local storage per VM.
Corresponds to the JSON property dbNodeStorageSizeGb
1676 1677 1678 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1676 def db_node_storage_size_gb @db_node_storage_size_gb end |
#db_server_ocids ⇒ Array<String>
Optional. OCID of database servers.
Corresponds to the JSON property dbServerOcids
1681 1682 1683 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1681 def db_server_ocids @db_server_ocids end |
#diagnostics_data_collection_options ⇒ Google::Apis::OracledatabaseV1::DataCollectionOptions
Data collection options for diagnostics.
Corresponds to the JSON property diagnosticsDataCollectionOptions
1686 1687 1688 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1686 def @diagnostics_data_collection_options end |
#disk_redundancy ⇒ String
Optional. The type of redundancy.
Corresponds to the JSON property diskRedundancy
1691 1692 1693 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1691 def disk_redundancy @disk_redundancy end |
#dns_listener_ip ⇒ String
Output only. DNS listener IP.
Corresponds to the JSON property dnsListenerIp
1696 1697 1698 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1696 def dns_listener_ip @dns_listener_ip end |
#domain ⇒ String
Output only. Parent DNS domain where SCAN DNS and hosts names are qualified.
ex: ocispdelegated.ocisp10jvnet.oraclevcn.com
Corresponds to the JSON property domain
1702 1703 1704 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1702 def domain @domain end |
#gi_version ⇒ String
Optional. Grid Infrastructure Version.
Corresponds to the JSON property giVersion
1707 1708 1709 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1707 def gi_version @gi_version end |
#hostname ⇒ String
Output only. host name without domain. format: "-" with some suffix. ex: sp2-
yi0xq where "sp2" is the hostname_prefix.
Corresponds to the JSON property hostname
1713 1714 1715 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1713 def hostname @hostname end |
#hostname_prefix ⇒ String
Optional. Prefix for VM cluster host names.
Corresponds to the JSON property hostnamePrefix
1718 1719 1720 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1718 def hostname_prefix @hostname_prefix end |
#license_type ⇒ String
Required. License type of VM Cluster.
Corresponds to the JSON property licenseType
1723 1724 1725 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1723 def license_type @license_type end |
#local_backup_enabled ⇒ Boolean Also known as: local_backup_enabled?
Optional. Use local backup.
Corresponds to the JSON property localBackupEnabled
1728 1729 1730 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1728 def local_backup_enabled @local_backup_enabled end |
#memory_size_gb ⇒ Fixnum
Optional. Memory allocated in GBs.
Corresponds to the JSON property memorySizeGb
1734 1735 1736 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1734 def memory_size_gb @memory_size_gb end |
#node_count ⇒ Fixnum
Optional. Number of database servers.
Corresponds to the JSON property nodeCount
1739 1740 1741 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1739 def node_count @node_count end |
#oci_url ⇒ String
Output only. Deep link to the OCI console to view this resource.
Corresponds to the JSON property ociUrl
1744 1745 1746 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1744 def oci_url @oci_url end |
#ocid ⇒ String
Output only. Oracle Cloud Infrastructure ID of VM Cluster.
Corresponds to the JSON property ocid
1749 1750 1751 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1749 def ocid @ocid end |
#ocpu_count ⇒ Float
Optional. OCPU count per VM. Minimum is 0.1.
Corresponds to the JSON property ocpuCount
1754 1755 1756 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1754 def ocpu_count @ocpu_count end |
#scan_dns ⇒ String
Output only. SCAN DNS name. ex: sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet.
oraclevcn.com
Corresponds to the JSON property scanDns
1760 1761 1762 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1760 def scan_dns @scan_dns end |
#scan_dns_record_id ⇒ String
Output only. OCID of scan DNS record.
Corresponds to the JSON property scanDnsRecordId
1765 1766 1767 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1765 def scan_dns_record_id @scan_dns_record_id end |
#scan_ip_ids ⇒ Array<String>
Output only. OCIDs of scan IPs.
Corresponds to the JSON property scanIpIds
1770 1771 1772 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1770 def scan_ip_ids @scan_ip_ids end |
#scan_listener_port_tcp ⇒ Fixnum
Output only. SCAN listener port - TCP
Corresponds to the JSON property scanListenerPortTcp
1775 1776 1777 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1775 def scan_listener_port_tcp @scan_listener_port_tcp end |
#scan_listener_port_tcp_ssl ⇒ Fixnum
Output only. SCAN listener port - TLS
Corresponds to the JSON property scanListenerPortTcpSsl
1780 1781 1782 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1780 def scan_listener_port_tcp_ssl @scan_listener_port_tcp_ssl end |
#shape ⇒ String
Output only. Shape of VM Cluster.
Corresponds to the JSON property shape
1785 1786 1787 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1785 def shape @shape end |
#sparse_diskgroup_enabled ⇒ Boolean Also known as: sparse_diskgroup_enabled?
Optional. Use exadata sparse snapshots.
Corresponds to the JSON property sparseDiskgroupEnabled
1790 1791 1792 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1790 def sparse_diskgroup_enabled @sparse_diskgroup_enabled end |
#ssh_public_keys ⇒ Array<String>
Optional. SSH public keys to be stored with cluster.
Corresponds to the JSON property sshPublicKeys
1796 1797 1798 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1796 def ssh_public_keys @ssh_public_keys end |
#state ⇒ String
Output only. State of the cluster.
Corresponds to the JSON property state
1801 1802 1803 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1801 def state @state end |
#storage_size_gb ⇒ Fixnum
Output only. The storage allocation for the disk group, in gigabytes (GB).
Corresponds to the JSON property storageSizeGb
1806 1807 1808 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1806 def storage_size_gb @storage_size_gb end |
#system_version ⇒ String
Optional. Operating system version of the image.
Corresponds to the JSON property systemVersion
1811 1812 1813 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1811 def system_version @system_version end |
#time_zone ⇒ Google::Apis::OracledatabaseV1::TimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property timeZone
1817 1818 1819 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1817 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1824 def update!(**args) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @compartment_id = args[:compartment_id] if args.key?(:compartment_id) @compute_model = args[:compute_model] if args.key?(:compute_model) @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count) @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb) @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb) @db_server_ocids = args[:db_server_ocids] if args.key?(:db_server_ocids) @diagnostics_data_collection_options = args[:diagnostics_data_collection_options] if args.key?(:diagnostics_data_collection_options) @disk_redundancy = args[:disk_redundancy] if args.key?(:disk_redundancy) @dns_listener_ip = args[:dns_listener_ip] if args.key?(:dns_listener_ip) @domain = args[:domain] if args.key?(:domain) @gi_version = args[:gi_version] if args.key?(:gi_version) @hostname = args[:hostname] if args.key?(:hostname) @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix) @license_type = args[:license_type] if args.key?(:license_type) @local_backup_enabled = args[:local_backup_enabled] if args.key?(:local_backup_enabled) @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb) @node_count = args[:node_count] if args.key?(:node_count) @oci_url = args[:oci_url] if args.key?(:oci_url) @ocid = args[:ocid] if args.key?(:ocid) @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count) @scan_dns = args[:scan_dns] if args.key?(:scan_dns) @scan_dns_record_id = args[:scan_dns_record_id] if args.key?(:scan_dns_record_id) @scan_ip_ids = args[:scan_ip_ids] if args.key?(:scan_ip_ids) @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp) @scan_listener_port_tcp_ssl = args[:scan_listener_port_tcp_ssl] if args.key?(:scan_listener_port_tcp_ssl) @shape = args[:shape] if args.key?(:shape) @sparse_diskgroup_enabled = args[:sparse_diskgroup_enabled] if args.key?(:sparse_diskgroup_enabled) @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys) @state = args[:state] if args.key?(:state) @storage_size_gb = args[:storage_size_gb] if args.key?(:storage_size_gb) @system_version = args[:system_version] if args.key?(:system_version) @time_zone = args[:time_zone] if args.key?(:time_zone) end |