Class: Google::Apis::OracledatabaseV1::CloudVmClusterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata VM cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudVmClusterProperties

Returns a new instance of CloudVmClusterProperties.



1733
1734
1735
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_nameString

Optional. OCI Cluster name. Corresponds to the JSON property clusterName

Returns:

  • (String)


1565
1566
1567
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1565

def cluster_name
  @cluster_name
end

#compartment_idString

Output only. Compartment ID of cluster. Corresponds to the JSON property compartmentId

Returns:

  • (String)


1570
1571
1572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1570

def compartment_id
  @compartment_id
end

#compute_modelString

Output only. The compute model of the VM Cluster. Corresponds to the JSON property computeModel

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1575

def compute_model
  @compute_model
end

#cpu_core_countFixnum

Required. Number of enabled CPU cores. Corresponds to the JSON property cpuCoreCount

Returns:

  • (Fixnum)


1580
1581
1582
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1580

def cpu_core_count
  @cpu_core_count
end

#data_storage_size_tbFloat

Optional. The data disk group size to be allocated in TBs. Corresponds to the JSON property dataStorageSizeTb

Returns:

  • (Float)


1585
1586
1587
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1585

def data_storage_size_tb
  @data_storage_size_tb
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


1590
1591
1592
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1590

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#db_server_ocidsArray<String>

Optional. OCID of database servers. Corresponds to the JSON property dbServerOcids

Returns:

  • (Array<String>)


1595
1596
1597
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1595

def db_server_ocids
  @db_server_ocids
end

#diagnostics_data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptions

Data collection options for diagnostics. Corresponds to the JSON property diagnosticsDataCollectionOptions



1600
1601
1602
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1600

def diagnostics_data_collection_options
  @diagnostics_data_collection_options
end

#disk_redundancyString

Optional. The type of redundancy. Corresponds to the JSON property diskRedundancy

Returns:

  • (String)


1605
1606
1607
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1605

def disk_redundancy
  @disk_redundancy
end

#dns_listener_ipString

Output only. DNS listener IP. Corresponds to the JSON property dnsListenerIp

Returns:

  • (String)


1610
1611
1612
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1610

def dns_listener_ip
  @dns_listener_ip
end

#domainString

Output only. Parent DNS domain where SCAN DNS and hosts names are qualified. ex: ocispdelegated.ocisp10jvnet.oraclevcn.com Corresponds to the JSON property domain

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1616

def domain
  @domain
end

#gi_versionString

Optional. Grid Infrastructure Version. Corresponds to the JSON property giVersion

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1621

def gi_version
  @gi_version
end

#hostnameString

Output only. host name without domain. format: "-" with some suffix. ex: sp2- yi0xq where "sp2" is the hostname_prefix. Corresponds to the JSON property hostname

Returns:

  • (String)


1627
1628
1629
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1627

def hostname
  @hostname
end

#hostname_prefixString

Optional. Prefix for VM cluster host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


1632
1633
1634
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1632

def hostname_prefix
  @hostname_prefix
end

#license_typeString

Required. License type of VM Cluster. Corresponds to the JSON property licenseType

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1637

def license_type
  @license_type
end

#local_backup_enabledBoolean Also known as: local_backup_enabled?

Optional. Use local backup. Corresponds to the JSON property localBackupEnabled

Returns:

  • (Boolean)


1642
1643
1644
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1642

def local_backup_enabled
  @local_backup_enabled
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


1648
1649
1650
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1648

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Optional. Number of database servers. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


1653
1654
1655
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1653

def node_count
  @node_count
end

#oci_urlString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUrl

Returns:

  • (String)


1658
1659
1660
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1658

def oci_url
  @oci_url
end

#ocidString

Output only. Oracle Cloud Infrastructure ID of VM Cluster. Corresponds to the JSON property ocid

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1663

def ocid
  @ocid
end

#ocpu_countFloat

Optional. OCPU count per VM. Minimum is 0.1. Corresponds to the JSON property ocpuCount

Returns:

  • (Float)


1668
1669
1670
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1668

def ocpu_count
  @ocpu_count
end

#scan_dnsString

Output only. SCAN DNS name. ex: sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet. oraclevcn.com Corresponds to the JSON property scanDns

Returns:

  • (String)


1674
1675
1676
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1674

def scan_dns
  @scan_dns
end

#scan_dns_record_idString

Output only. OCID of scan DNS record. Corresponds to the JSON property scanDnsRecordId

Returns:

  • (String)


1679
1680
1681
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1679

def scan_dns_record_id
  @scan_dns_record_id
end

#scan_ip_idsArray<String>

Output only. OCIDs of scan IPs. Corresponds to the JSON property scanIpIds

Returns:

  • (Array<String>)


1684
1685
1686
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1684

def scan_ip_ids
  @scan_ip_ids
end

#scan_listener_port_tcpFixnum

Output only. SCAN listener port - TCP Corresponds to the JSON property scanListenerPortTcp

Returns:

  • (Fixnum)


1689
1690
1691
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1689

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#scan_listener_port_tcp_sslFixnum

Output only. SCAN listener port - TLS Corresponds to the JSON property scanListenerPortTcpSsl

Returns:

  • (Fixnum)


1694
1695
1696
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1694

def scan_listener_port_tcp_ssl
  @scan_listener_port_tcp_ssl
end

#shapeString

Output only. Shape of VM Cluster. Corresponds to the JSON property shape

Returns:

  • (String)


1699
1700
1701
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1699

def shape
  @shape
end

#sparse_diskgroup_enabledBoolean Also known as: sparse_diskgroup_enabled?

Optional. Use exadata sparse snapshots. Corresponds to the JSON property sparseDiskgroupEnabled

Returns:

  • (Boolean)


1704
1705
1706
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1704

def sparse_diskgroup_enabled
  @sparse_diskgroup_enabled
end

#ssh_public_keysArray<String>

Optional. SSH public keys to be stored with cluster. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


1710
1711
1712
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1710

def ssh_public_keys
  @ssh_public_keys
end

#stateString

Output only. State of the cluster. Corresponds to the JSON property state

Returns:

  • (String)


1715
1716
1717
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1715

def state
  @state
end

#storage_size_gbFixnum

Output only. The storage allocation for the disk group, in gigabytes (GB). Corresponds to the JSON property storageSizeGb

Returns:

  • (Fixnum)


1720
1721
1722
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1720

def storage_size_gb
  @storage_size_gb
end

#system_versionString

Optional. Operating system version of the image. Corresponds to the JSON property systemVersion

Returns:

  • (String)


1725
1726
1727
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1725

def system_version
  @system_version
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



1731
1732
1733
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1731

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1738

def update!(**args)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count)
  @data_storage_size_tb = args[:data_storage_size_tb] if args.key?(:data_storage_size_tb)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @db_server_ocids = args[:db_server_ocids] if args.key?(:db_server_ocids)
  @diagnostics_data_collection_options = args[:diagnostics_data_collection_options] if args.key?(:diagnostics_data_collection_options)
  @disk_redundancy = args[:disk_redundancy] if args.key?(:disk_redundancy)
  @dns_listener_ip = args[:dns_listener_ip] if args.key?(:dns_listener_ip)
  @domain = args[:domain] if args.key?(:domain)
  @gi_version = args[:gi_version] if args.key?(:gi_version)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @license_type = args[:license_type] if args.key?(:license_type)
  @local_backup_enabled = args[:local_backup_enabled] if args.key?(:local_backup_enabled)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @scan_dns = args[:scan_dns] if args.key?(:scan_dns)
  @scan_dns_record_id = args[:scan_dns_record_id] if args.key?(:scan_dns_record_id)
  @scan_ip_ids = args[:scan_ip_ids] if args.key?(:scan_ip_ids)
  @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp)
  @scan_listener_port_tcp_ssl = args[:scan_listener_port_tcp_ssl] if args.key?(:scan_listener_port_tcp_ssl)
  @shape = args[:shape] if args.key?(:shape)
  @sparse_diskgroup_enabled = args[:sparse_diskgroup_enabled] if args.key?(:sparse_diskgroup_enabled)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @state = args[:state] if args.key?(:state)
  @storage_size_gb = args[:storage_size_gb] if args.key?(:storage_size_gb)
  @system_version = args[:system_version] if args.key?(:system_version)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end