Class: Google::Apis::OracledatabaseV1::Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database resource. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/Database/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Database

Returns a new instance of Database.



2188
2189
2190
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_passwordString

Optional. The password for the default ADMIN user. Note: Only one of admin_password_secret_version or admin_password can be populated. Corresponds to the JSON property adminPassword

Returns:

  • (String)


2087
2088
2089
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2087

def admin_password
  @admin_password
end

#admin_password_secret_versionString

Optional. The resource name of a secret version in Secret Manager which contains the database admin user's password. Format: projects/project/ secrets/secret/versions/version. Note: Only one of admin_password_secret_version or admin_password can be populated. Corresponds to the JSON property adminPasswordSecretVersion

Returns:

  • (String)


2095
2096
2097
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2095

def admin_password_secret_version
  @admin_password_secret_version
end

#character_setString

Optional. The character set for the database. The default is AL32UTF8. Corresponds to the JSON property characterSet

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2100

def character_set
  @character_set
end

#create_timeString

Output only. The date and time that the Database was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2105
2106
2107
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2105

def create_time
  @create_time
end

#database_idString

Optional. The database ID of the Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2110

def database_id
  @database_id
end

#db_home_nameString

Optional. The name of the DbHome resource associated with the Database. Corresponds to the JSON property dbHomeName

Returns:

  • (String)


2115
2116
2117
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2115

def db_home_name
  @db_home_name
end

#db_nameString

Optional. The database name. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted. Corresponds to the JSON property dbName

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2122

def db_name
  @db_name
end

#db_unique_nameString

Optional. The DB_UNIQUE_NAME of the Oracle Database being backed up. Corresponds to the JSON property dbUniqueName

Returns:

  • (String)


2127
2128
2129
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2127

def db_unique_name
  @db_unique_name
end

#gcp_oracle_zoneString

Output only. The GCP Oracle zone where the Database is created. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


2132
2133
2134
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2132

def gcp_oracle_zone
  @gcp_oracle_zone
end

#nameString

Identifier. The name of the Database resource in the following format: projects/project/locations/region/databases/database Corresponds to the JSON property name

Returns:

  • (String)


2138
2139
2140
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2138

def name
  @name
end

#ncharacter_setString

Optional. The national character set for the database. The default is AL16UTF16. Corresponds to the JSON property ncharacterSet

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2144

def ncharacter_set
  @ncharacter_set
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2149

def oci_url
  @oci_url
end

#ops_insights_statusString

Output only. The Status of Operations Insights for this Database. Corresponds to the JSON property opsInsightsStatus

Returns:

  • (String)


2154
2155
2156
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2154

def ops_insights_status
  @ops_insights_status
end

#pluggable_database_idString

Optional. The ID of the pluggable database associated with the Database. The ID must be unique within the project and location. Corresponds to the JSON property pluggableDatabaseId

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2160

def pluggable_database_id
  @pluggable_database_id
end

#pluggable_database_nameString

Optional. The pluggable database associated with the Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Corresponds to the JSON property pluggableDatabaseName

Returns:

  • (String)


2167
2168
2169
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2167

def pluggable_database_name
  @pluggable_database_name
end

#propertiesGoogle::Apis::OracledatabaseV1::DatabaseProperties

The properties of a Database. Corresponds to the JSON property properties



2172
2173
2174
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2172

def properties
  @properties
end

#tde_wallet_passwordString

Optional. The TDE wallet password for the database. Note: Only one of tde_wallet_password_secret_version or tde_wallet_password can be populated. Corresponds to the JSON property tdeWalletPassword

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2178

def tde_wallet_password
  @tde_wallet_password
end

#tde_wallet_password_secret_versionString

Optional. The resource name of a secret version in Secret Manager which contains the TDE wallet password for the database. Format: projects/project/ secrets/secret/versions/version. Note: Only one of tde_wallet_password_secret_version or tde_wallet_password can be populated. Corresponds to the JSON property tdeWalletPasswordSecretVersion

Returns:

  • (String)


2186
2187
2188
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2186

def tde_wallet_password_secret_version
  @tde_wallet_password_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2193

def update!(**args)
  @admin_password = args[:admin_password] if args.key?(:admin_password)
  @admin_password_secret_version = args[:admin_password_secret_version] if args.key?(:admin_password_secret_version)
  @character_set = args[:character_set] if args.key?(:character_set)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_id = args[:database_id] if args.key?(:database_id)
  @db_home_name = args[:db_home_name] if args.key?(:db_home_name)
  @db_name = args[:db_name] if args.key?(:db_name)
  @db_unique_name = args[:db_unique_name] if args.key?(:db_unique_name)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @name = args[:name] if args.key?(:name)
  @ncharacter_set = args[:ncharacter_set] if args.key?(:ncharacter_set)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ops_insights_status = args[:ops_insights_status] if args.key?(:ops_insights_status)
  @pluggable_database_id = args[:pluggable_database_id] if args.key?(:pluggable_database_id)
  @pluggable_database_name = args[:pluggable_database_name] if args.key?(:pluggable_database_name)
  @properties = args[:properties] if args.key?(:properties)
  @tde_wallet_password = args[:tde_wallet_password] if args.key?(:tde_wallet_password)
  @tde_wallet_password_secret_version = args[:tde_wallet_password_secret_version] if args.key?(:tde_wallet_password_secret_version)
end