Class: Google::Apis::OracledatabaseV1::Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database resource. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/Database/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Database

Returns a new instance of Database.



2090
2091
2092
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_passwordString

Optional. The password for the default ADMIN user. Note: Only one of admin_password_secret_version or admin_password can be populated. Corresponds to the JSON property adminPassword

Returns:

  • (String)


1989
1990
1991
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1989

def admin_password
  @admin_password
end

#admin_password_secret_versionString

Optional. The resource name of a secret version in Secret Manager which contains the database admin user's password. Format: projects/project/ secrets/secret/versions/version. Note: Only one of admin_password_secret_version or admin_password can be populated. Corresponds to the JSON property adminPasswordSecretVersion

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 1997

def admin_password_secret_version
  @admin_password_secret_version
end

#character_setString

Optional. The character set for the database. The default is AL32UTF8. Corresponds to the JSON property characterSet

Returns:

  • (String)


2002
2003
2004
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2002

def character_set
  @character_set
end

#create_timeString

Output only. The date and time that the Database was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2007
2008
2009
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2007

def create_time
  @create_time
end

#database_idString

Optional. The database ID of the Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2012

def database_id
  @database_id
end

#db_home_nameString

Optional. The name of the DbHome resource associated with the Database. Corresponds to the JSON property dbHomeName

Returns:

  • (String)


2017
2018
2019
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2017

def db_home_name
  @db_home_name
end

#db_nameString

Optional. The database name. The name must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted. Corresponds to the JSON property dbName

Returns:

  • (String)


2024
2025
2026
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2024

def db_name
  @db_name
end

#db_unique_nameString

Optional. The DB_UNIQUE_NAME of the Oracle Database being backed up. Corresponds to the JSON property dbUniqueName

Returns:

  • (String)


2029
2030
2031
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2029

def db_unique_name
  @db_unique_name
end

#gcp_oracle_zoneString

Output only. The GCP Oracle zone where the Database is created. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


2034
2035
2036
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2034

def gcp_oracle_zone
  @gcp_oracle_zone
end

#nameString

Identifier. The name of the Database resource in the following format: projects/project/locations/region/databases/database Corresponds to the JSON property name

Returns:

  • (String)


2040
2041
2042
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2040

def name
  @name
end

#ncharacter_setString

Optional. The national character set for the database. The default is AL16UTF16. Corresponds to the JSON property ncharacterSet

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2046

def ncharacter_set
  @ncharacter_set
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2051

def oci_url
  @oci_url
end

#ops_insights_statusString

Output only. The Status of Operations Insights for this Database. Corresponds to the JSON property opsInsightsStatus

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2056

def ops_insights_status
  @ops_insights_status
end

#pluggable_database_idString

Optional. The ID of the pluggable database associated with the Database. The ID must be unique within the project and location. Corresponds to the JSON property pluggableDatabaseId

Returns:

  • (String)


2062
2063
2064
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2062

def pluggable_database_id
  @pluggable_database_id
end

#pluggable_database_nameString

Optional. The pluggable database associated with the Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Corresponds to the JSON property pluggableDatabaseName

Returns:

  • (String)


2069
2070
2071
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2069

def pluggable_database_name
  @pluggable_database_name
end

#propertiesGoogle::Apis::OracledatabaseV1::DatabaseProperties

The properties of a Database. Corresponds to the JSON property properties



2074
2075
2076
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2074

def properties
  @properties
end

#tde_wallet_passwordString

Optional. The TDE wallet password for the database. Note: Only one of tde_wallet_password_secret_version or tde_wallet_password can be populated. Corresponds to the JSON property tdeWalletPassword

Returns:

  • (String)


2080
2081
2082
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2080

def tde_wallet_password
  @tde_wallet_password
end

#tde_wallet_password_secret_versionString

Optional. The resource name of a secret version in Secret Manager which contains the TDE wallet password for the database. Format: projects/project/ secrets/secret/versions/version. Note: Only one of tde_wallet_password_secret_version or tde_wallet_password can be populated. Corresponds to the JSON property tdeWalletPasswordSecretVersion

Returns:

  • (String)


2088
2089
2090
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2088

def tde_wallet_password_secret_version
  @tde_wallet_password_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2095

def update!(**args)
  @admin_password = args[:admin_password] if args.key?(:admin_password)
  @admin_password_secret_version = args[:admin_password_secret_version] if args.key?(:admin_password_secret_version)
  @character_set = args[:character_set] if args.key?(:character_set)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_id = args[:database_id] if args.key?(:database_id)
  @db_home_name = args[:db_home_name] if args.key?(:db_home_name)
  @db_name = args[:db_name] if args.key?(:db_name)
  @db_unique_name = args[:db_unique_name] if args.key?(:db_unique_name)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @name = args[:name] if args.key?(:name)
  @ncharacter_set = args[:ncharacter_set] if args.key?(:ncharacter_set)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @ops_insights_status = args[:ops_insights_status] if args.key?(:ops_insights_status)
  @pluggable_database_id = args[:pluggable_database_id] if args.key?(:pluggable_database_id)
  @pluggable_database_name = args[:pluggable_database_name] if args.key?(:pluggable_database_name)
  @properties = args[:properties] if args.key?(:properties)
  @tde_wallet_password = args[:tde_wallet_password] if args.key?(:tde_wallet_password)
  @tde_wallet_password_secret_version = args[:tde_wallet_password_secret_version] if args.key?(:tde_wallet_password_secret_version)
end