Class: Google::Apis::OracledatabaseV1::DatabaseCharacterSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database character set resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseCharacterSet

Returns a new instance of DatabaseCharacterSet.



2184
2185
2186
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_setString

Output only. The character set name for the Database which is the ID in the resource name. Corresponds to the JSON property characterSet

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2170

def character_set
  @character_set
end

#character_set_typeString

Output only. The character set type for the Database. Corresponds to the JSON property characterSetType

Returns:

  • (String)


2175
2176
2177
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2175

def character_set_type
  @character_set_type
end

#nameString

Identifier. The name of the Database Character Set resource in the following format: projects/project/locations/region/databaseCharacterSets/ database_character_set Corresponds to the JSON property name

Returns:

  • (String)


2182
2183
2184
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2182

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2189
2190
2191
2192
2193
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2189

def update!(**args)
  @character_set = args[:character_set] if args.key?(:character_set)
  @character_set_type = args[:character_set_type] if args.key?(:character_set_type)
  @name = args[:name] if args.key?(:name)
end