Class: Google::Apis::OracledatabaseV1::DatabaseCharacterSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Database character set resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseCharacterSet

Returns a new instance of DatabaseCharacterSet.



2053
2054
2055
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_setString

Output only. The character set name for the Database which is the ID in the resource name. Corresponds to the JSON property characterSet

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2039

def character_set
  @character_set
end

#character_set_typeString

Output only. The character set type for the Database. Corresponds to the JSON property characterSetType

Returns:

  • (String)


2044
2045
2046
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2044

def character_set_type
  @character_set_type
end

#nameString

Identifier. The name of the Database Character Set resource in the following format: projects/project/locations/region/databaseCharacterSets/ database_character_set Corresponds to the JSON property name

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2051

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2058
2059
2060
2061
2062
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2058

def update!(**args)
  @character_set = args[:character_set] if args.key?(:character_set)
  @character_set_type = args[:character_set_type] if args.key?(:character_set_type)
  @name = args[:name] if args.key?(:name)
end