Class: Google::Apis::OracledatabaseV1::DbBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Backup Options for the Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbBackupConfig

Returns a new instance of DbBackupConfig.



2430
2431
2432
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_backup_enabledBoolean Also known as: auto_backup_enabled?

Optional. If set to true, enables automatic backups on the database. Corresponds to the JSON property autoBackupEnabled

Returns:

  • (Boolean)


2390
2391
2392
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2390

def auto_backup_enabled
  @auto_backup_enabled
end

#auto_full_backup_dayString

Optional. The day of the week on which the full backup should be performed on the database. If no value is provided, it will default to Sunday. Corresponds to the JSON property autoFullBackupDay

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2397

def auto_full_backup_day
  @auto_full_backup_day
end

#auto_full_backup_windowString

Optional. The window in which the full backup should be performed on the database. If no value is provided, the default is anytime. Corresponds to the JSON property autoFullBackupWindow

Returns:

  • (String)


2403
2404
2405
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2403

def auto_full_backup_window
  @auto_full_backup_window
end

#auto_incremental_backup_windowString

Optional. The window in which the incremental backup should be performed on the database. If no value is provided, the default is anytime except the auto full backup day. Corresponds to the JSON property autoIncrementalBackupWindow

Returns:

  • (String)


2410
2411
2412
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2410

def auto_incremental_backup_window
  @auto_incremental_backup_window
end

#backup_deletion_policyString

Optional. This defines when the backups will be deleted after Database termination. Corresponds to the JSON property backupDeletionPolicy

Returns:

  • (String)


2416
2417
2418
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2416

def backup_deletion_policy
  @backup_deletion_policy
end

#backup_destination_detailsArray<Google::Apis::OracledatabaseV1::BackupDestinationDetails>

Optional. Details of the database backup destinations. Corresponds to the JSON property backupDestinationDetails



2421
2422
2423
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2421

def backup_destination_details
  @backup_destination_details
end

#retention_period_daysFixnum

Optional. The number of days an automatic backup is retained before being automatically deleted. This value determines the earliest point in time to which a database can be restored. Min: 1, Max: 60. Corresponds to the JSON property retentionPeriodDays

Returns:

  • (Fixnum)


2428
2429
2430
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2428

def retention_period_days
  @retention_period_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2435
2436
2437
2438
2439
2440
2441
2442
2443
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2435

def update!(**args)
  @auto_backup_enabled = args[:auto_backup_enabled] if args.key?(:auto_backup_enabled)
  @auto_full_backup_day = args[:auto_full_backup_day] if args.key?(:auto_full_backup_day)
  @auto_full_backup_window = args[:auto_full_backup_window] if args.key?(:auto_full_backup_window)
  @auto_incremental_backup_window = args[:auto_incremental_backup_window] if args.key?(:auto_incremental_backup_window)
  @backup_deletion_policy = args[:backup_deletion_policy] if args.key?(:backup_deletion_policy)
  @backup_destination_details = args[:backup_destination_details] if args.key?(:backup_destination_details)
  @retention_period_days = args[:retention_period_days] if args.key?(:retention_period_days)
end