Class: Google::Apis::OracledatabaseV1::DbBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Backup Options for the Database.
Instance Attribute Summary collapse
-
#auto_backup_enabled ⇒ Boolean
(also: #auto_backup_enabled?)
Optional.
-
#auto_full_backup_day ⇒ String
Optional.
-
#auto_full_backup_window ⇒ String
Optional.
-
#auto_incremental_backup_window ⇒ String
Optional.
-
#backup_deletion_policy ⇒ String
Optional.
-
#backup_destination_details ⇒ Array<Google::Apis::OracledatabaseV1::BackupDestinationDetails>
Optional.
-
#retention_period_days ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbBackupConfig
constructor
A new instance of DbBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbBackupConfig
Returns a new instance of DbBackupConfig.
2377 2378 2379 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_backup_enabled ⇒ Boolean Also known as: auto_backup_enabled?
Optional. If set to true, enables automatic backups on the database.
Corresponds to the JSON property autoBackupEnabled
2337 2338 2339 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2337 def auto_backup_enabled @auto_backup_enabled end |
#auto_full_backup_day ⇒ String
Optional. The day of the week on which the full backup should be performed on
the database. If no value is provided, it will default to Sunday.
Corresponds to the JSON property autoFullBackupDay
2344 2345 2346 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2344 def auto_full_backup_day @auto_full_backup_day end |
#auto_full_backup_window ⇒ String
Optional. The window in which the full backup should be performed on the
database. If no value is provided, the default is anytime.
Corresponds to the JSON property autoFullBackupWindow
2350 2351 2352 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2350 def auto_full_backup_window @auto_full_backup_window end |
#auto_incremental_backup_window ⇒ String
Optional. The window in which the incremental backup should be performed on
the database. If no value is provided, the default is anytime except the auto
full backup day.
Corresponds to the JSON property autoIncrementalBackupWindow
2357 2358 2359 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2357 def auto_incremental_backup_window @auto_incremental_backup_window end |
#backup_deletion_policy ⇒ String
Optional. This defines when the backups will be deleted after Database
termination.
Corresponds to the JSON property backupDeletionPolicy
2363 2364 2365 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2363 def backup_deletion_policy @backup_deletion_policy end |
#backup_destination_details ⇒ Array<Google::Apis::OracledatabaseV1::BackupDestinationDetails>
Optional. Details of the database backup destinations.
Corresponds to the JSON property backupDestinationDetails
2368 2369 2370 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2368 def backup_destination_details @backup_destination_details end |
#retention_period_days ⇒ Fixnum
Optional. The number of days an automatic backup is retained before being
automatically deleted. This value determines the earliest point in time to
which a database can be restored. Min: 1, Max: 60.
Corresponds to the JSON property retentionPeriodDays
2375 2376 2377 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2375 def retention_period_days @retention_period_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2382 def update!(**args) @auto_backup_enabled = args[:auto_backup_enabled] if args.key?(:auto_backup_enabled) @auto_full_backup_day = args[:auto_full_backup_day] if args.key?(:auto_full_backup_day) @auto_full_backup_window = args[:auto_full_backup_window] if args.key?(:auto_full_backup_window) @auto_incremental_backup_window = args[:auto_incremental_backup_window] if args.key?(:auto_incremental_backup_window) @backup_deletion_policy = args[:backup_deletion_policy] if args.key?(:backup_deletion_policy) @backup_destination_details = args[:backup_destination_details] if args.key?(:backup_destination_details) @retention_period_days = args[:retention_period_days] if args.key?(:retention_period_days) end |