Class: Google::Apis::OracledatabaseV1::DbBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Backup Options for the Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbBackupConfig

Returns a new instance of DbBackupConfig.



2332
2333
2334
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_backup_enabledBoolean Also known as: auto_backup_enabled?

Optional. If set to true, enables automatic backups on the database. Corresponds to the JSON property autoBackupEnabled

Returns:

  • (Boolean)


2292
2293
2294
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2292

def auto_backup_enabled
  @auto_backup_enabled
end

#auto_full_backup_dayString

Optional. The day of the week on which the full backup should be performed on the database. If no value is provided, it will default to Sunday. Corresponds to the JSON property autoFullBackupDay

Returns:

  • (String)


2299
2300
2301
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2299

def auto_full_backup_day
  @auto_full_backup_day
end

#auto_full_backup_windowString

Optional. The window in which the full backup should be performed on the database. If no value is provided, the default is anytime. Corresponds to the JSON property autoFullBackupWindow

Returns:

  • (String)


2305
2306
2307
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2305

def auto_full_backup_window
  @auto_full_backup_window
end

#auto_incremental_backup_windowString

Optional. The window in which the incremental backup should be performed on the database. If no value is provided, the default is anytime except the auto full backup day. Corresponds to the JSON property autoIncrementalBackupWindow

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2312

def auto_incremental_backup_window
  @auto_incremental_backup_window
end

#backup_deletion_policyString

Optional. This defines when the backups will be deleted after Database termination. Corresponds to the JSON property backupDeletionPolicy

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2318

def backup_deletion_policy
  @backup_deletion_policy
end

#backup_destination_detailsArray<Google::Apis::OracledatabaseV1::BackupDestinationDetails>

Optional. Details of the database backup destinations. Corresponds to the JSON property backupDestinationDetails



2323
2324
2325
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2323

def backup_destination_details
  @backup_destination_details
end

#retention_period_daysFixnum

Optional. The number of days an automatic backup is retained before being automatically deleted. This value determines the earliest point in time to which a database can be restored. Min: 1, Max: 60. Corresponds to the JSON property retentionPeriodDays

Returns:

  • (Fixnum)


2330
2331
2332
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2330

def retention_period_days
  @retention_period_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2337

def update!(**args)
  @auto_backup_enabled = args[:auto_backup_enabled] if args.key?(:auto_backup_enabled)
  @auto_full_backup_day = args[:auto_full_backup_day] if args.key?(:auto_full_backup_day)
  @auto_full_backup_window = args[:auto_full_backup_window] if args.key?(:auto_full_backup_window)
  @auto_incremental_backup_window = args[:auto_incremental_backup_window] if args.key?(:auto_incremental_backup_window)
  @backup_deletion_policy = args[:backup_deletion_policy] if args.key?(:backup_deletion_policy)
  @backup_destination_details = args[:backup_destination_details] if args.key?(:backup_destination_details)
  @retention_period_days = args[:retention_period_days] if args.key?(:retention_period_days)
end