Class: Google::Apis::OracledatabaseV1::DbServer
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the database server resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/DbServer/
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#properties ⇒ Google::Apis::OracledatabaseV1::DbServerProperties
Various properties and settings associated with Exadata database server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbServer
constructor
A new instance of DbServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbServer
Returns a new instance of DbServer.
2551 2552 2553 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. User friendly name for this resource.
Corresponds to the JSON property displayName
2537 2538 2539 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2537 def display_name @display_name end |
#name ⇒ String
Identifier. The name of the database server resource with the format: projects/
project/locations/location/cloudExadataInfrastructures/
cloud_exadata_infrastructure/dbServers/db_server
Corresponds to the JSON property name
2544 2545 2546 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2544 def name @name end |
#properties ⇒ Google::Apis::OracledatabaseV1::DbServerProperties
Various properties and settings associated with Exadata database server.
Corresponds to the JSON property properties
2549 2550 2551 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2549 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2556 2557 2558 2559 2560 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2556 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) end |