Class: Google::Apis::OracledatabaseV1::DbServer
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the database server resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/DbServer/
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#properties ⇒ Google::Apis::OracledatabaseV1::DbServerProperties
Various properties and settings associated with Exadata database server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbServer
constructor
A new instance of DbServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbServer
Returns a new instance of DbServer.
2420 2421 2422 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. User friendly name for this resource.
Corresponds to the JSON property displayName
2406 2407 2408 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2406 def display_name @display_name end |
#name ⇒ String
Identifier. The name of the database server resource with the format: projects/
project/locations/location/cloudExadataInfrastructures/
cloud_exadata_infrastructure/dbServers/db_server
Corresponds to the JSON property name
2413 2414 2415 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2413 def name @name end |
#properties ⇒ Google::Apis::OracledatabaseV1::DbServerProperties
Various properties and settings associated with Exadata database server.
Corresponds to the JSON property properties
2418 2419 2420 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2418 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2425 2426 2427 2428 2429 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2425 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) end |