Class: Google::Apis::OracledatabaseV1::DbServerProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata database server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbServerProperties

Returns a new instance of DbServerProperties.



2617
2618
2619
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#db_node_idsArray<String>

Output only. OCID of database nodes associated with the database server. Corresponds to the JSON property dbNodeIds

Returns:

  • (Array<String>)


2570
2571
2572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2570

def db_node_ids
  @db_node_ids
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


2575
2576
2577
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2575

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#max_db_node_storage_size_gbFixnum

Optional. Maximum local storage per VM. Corresponds to the JSON property maxDbNodeStorageSizeGb

Returns:

  • (Fixnum)


2580
2581
2582
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2580

def max_db_node_storage_size_gb
  @max_db_node_storage_size_gb
end

#max_memory_size_gbFixnum

Optional. Maximum memory allocated in GBs. Corresponds to the JSON property maxMemorySizeGb

Returns:

  • (Fixnum)


2585
2586
2587
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2585

def max_memory_size_gb
  @max_memory_size_gb
end

#max_ocpu_countFixnum

Optional. Maximum OCPU count per database. Corresponds to the JSON property maxOcpuCount

Returns:

  • (Fixnum)


2590
2591
2592
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2590

def max_ocpu_count
  @max_ocpu_count
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


2595
2596
2597
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2595

def memory_size_gb
  @memory_size_gb
end

#ocidString

Output only. OCID of database server. Corresponds to the JSON property ocid

Returns:

  • (String)


2600
2601
2602
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2600

def ocid
  @ocid
end

#ocpu_countFixnum

Optional. OCPU count per database. Corresponds to the JSON property ocpuCount

Returns:

  • (Fixnum)


2605
2606
2607
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2605

def ocpu_count
  @ocpu_count
end

#stateString

Output only. State of the database server. Corresponds to the JSON property state

Returns:

  • (String)


2610
2611
2612
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2610

def state
  @state
end

#vm_countFixnum

Optional. Vm count per database. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


2615
2616
2617
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2615

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2622

def update!(**args)
  @db_node_ids = args[:db_node_ids] if args.key?(:db_node_ids)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb)
  @max_memory_size_gb = args[:max_memory_size_gb] if args.key?(:max_memory_size_gb)
  @max_ocpu_count = args[:max_ocpu_count] if args.key?(:max_ocpu_count)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @state = args[:state] if args.key?(:state)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end