Class: Google::Apis::OracledatabaseV1::DbServerProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata database server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbServerProperties

Returns a new instance of DbServerProperties.



2572
2573
2574
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#db_node_idsArray<String>

Output only. OCID of database nodes associated with the database server. Corresponds to the JSON property dbNodeIds

Returns:

  • (Array<String>)


2525
2526
2527
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2525

def db_node_ids
  @db_node_ids
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


2530
2531
2532
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2530

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#max_db_node_storage_size_gbFixnum

Optional. Maximum local storage per VM. Corresponds to the JSON property maxDbNodeStorageSizeGb

Returns:

  • (Fixnum)


2535
2536
2537
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2535

def max_db_node_storage_size_gb
  @max_db_node_storage_size_gb
end

#max_memory_size_gbFixnum

Optional. Maximum memory allocated in GBs. Corresponds to the JSON property maxMemorySizeGb

Returns:

  • (Fixnum)


2540
2541
2542
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2540

def max_memory_size_gb
  @max_memory_size_gb
end

#max_ocpu_countFixnum

Optional. Maximum OCPU count per database. Corresponds to the JSON property maxOcpuCount

Returns:

  • (Fixnum)


2545
2546
2547
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2545

def max_ocpu_count
  @max_ocpu_count
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


2550
2551
2552
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2550

def memory_size_gb
  @memory_size_gb
end

#ocidString

Output only. OCID of database server. Corresponds to the JSON property ocid

Returns:

  • (String)


2555
2556
2557
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2555

def ocid
  @ocid
end

#ocpu_countFixnum

Optional. OCPU count per database. Corresponds to the JSON property ocpuCount

Returns:

  • (Fixnum)


2560
2561
2562
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2560

def ocpu_count
  @ocpu_count
end

#stateString

Output only. State of the database server. Corresponds to the JSON property state

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2565

def state
  @state
end

#vm_countFixnum

Optional. Vm count per database. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


2570
2571
2572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2570

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2577

def update!(**args)
  @db_node_ids = args[:db_node_ids] if args.key?(:db_node_ids)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb)
  @max_memory_size_gb = args[:max_memory_size_gb] if args.key?(:max_memory_size_gb)
  @max_ocpu_count = args[:max_ocpu_count] if args.key?(:max_ocpu_count)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @state = args[:state] if args.key?(:state)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end