Class: Google::Apis::OracledatabaseV1::DbServerProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Various properties and settings associated with Exadata database server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbServerProperties

Returns a new instance of DbServerProperties.



2486
2487
2488
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#db_node_idsArray<String>

Output only. OCID of database nodes associated with the database server. Corresponds to the JSON property dbNodeIds

Returns:

  • (Array<String>)


2439
2440
2441
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2439

def db_node_ids
  @db_node_ids
end

#db_node_storage_size_gbFixnum

Optional. Local storage per VM. Corresponds to the JSON property dbNodeStorageSizeGb

Returns:

  • (Fixnum)


2444
2445
2446
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2444

def db_node_storage_size_gb
  @db_node_storage_size_gb
end

#max_db_node_storage_size_gbFixnum

Optional. Maximum local storage per VM. Corresponds to the JSON property maxDbNodeStorageSizeGb

Returns:

  • (Fixnum)


2449
2450
2451
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2449

def max_db_node_storage_size_gb
  @max_db_node_storage_size_gb
end

#max_memory_size_gbFixnum

Optional. Maximum memory allocated in GBs. Corresponds to the JSON property maxMemorySizeGb

Returns:

  • (Fixnum)


2454
2455
2456
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2454

def max_memory_size_gb
  @max_memory_size_gb
end

#max_ocpu_countFixnum

Optional. Maximum OCPU count per database. Corresponds to the JSON property maxOcpuCount

Returns:

  • (Fixnum)


2459
2460
2461
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2459

def max_ocpu_count
  @max_ocpu_count
end

#memory_size_gbFixnum

Optional. Memory allocated in GBs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


2464
2465
2466
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2464

def memory_size_gb
  @memory_size_gb
end

#ocidString

Output only. OCID of database server. Corresponds to the JSON property ocid

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2469

def ocid
  @ocid
end

#ocpu_countFixnum

Optional. OCPU count per database. Corresponds to the JSON property ocpuCount

Returns:

  • (Fixnum)


2474
2475
2476
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2474

def ocpu_count
  @ocpu_count
end

#stateString

Output only. State of the database server. Corresponds to the JSON property state

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2479

def state
  @state
end

#vm_countFixnum

Optional. Vm count per database. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


2484
2485
2486
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2484

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2491

def update!(**args)
  @db_node_ids = args[:db_node_ids] if args.key?(:db_node_ids)
  @db_node_storage_size_gb = args[:db_node_storage_size_gb] if args.key?(:db_node_storage_size_gb)
  @max_db_node_storage_size_gb = args[:max_db_node_storage_size_gb] if args.key?(:max_db_node_storage_size_gb)
  @max_memory_size_gb = args[:max_memory_size_gb] if args.key?(:max_memory_size_gb)
  @max_ocpu_count = args[:max_ocpu_count] if args.key?(:max_ocpu_count)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @ocid = args[:ocid] if args.key?(:ocid)
  @ocpu_count = args[:ocpu_count] if args.key?(:ocpu_count)
  @state = args[:state] if args.key?(:state)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end