Class: Google::Apis::OracledatabaseV1::DbSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the DbSystem (BaseDB) resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/DbSystem/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbSystem

Returns a new instance of DbSystem.



2701
2702
2703
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the DbSystem was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2644
2645
2646
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2644

def create_time
  @create_time
end

#display_nameString

Required. The display name for the System db. The name does not have to be unique within your project. Corresponds to the JSON property displayName

Returns:

  • (String)


2650
2651
2652
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2650

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the DbSystem Corresponds to the JSON property entitlementId

Returns:

  • (String)


2656
2657
2658
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2656

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us- east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


2663
2664
2665
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2663

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the DbSystem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2668
2669
2670
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2668

def labels
  @labels
end

#nameString

Identifier. The name of the DbSystem resource in the following format: projects/project/locations/region/dbSystems/db_system Corresponds to the JSON property name

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2674

def name
  @name
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


2679
2680
2681
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2679

def oci_url
  @oci_url
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the DbSystem. Format: projects/project/locations/location/odbNetworks/odb_network It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


2687
2688
2689
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2687

def odb_network
  @odb_network
end

#odb_subnetString

Required. The name of the OdbSubnet associated with the DbSystem for IP allocation. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2694

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::DbSystemProperties

The properties of a DbSystem. Corresponds to the JSON property properties



2699
2700
2701
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2699

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2706

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end