Class: Google::Apis::OracledatabaseV1::DbSystem
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the DbSystem (BaseDB) resource. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/DbSystem/
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#oci_url ⇒ String
Output only.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Required.
-
#properties ⇒ Google::Apis::OracledatabaseV1::DbSystemProperties
The properties of a DbSystem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbSystem
constructor
A new instance of DbSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbSystem
Returns a new instance of DbSystem.
2570 2571 2572 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the DbSystem was created.
Corresponds to the JSON property createTime
2513 2514 2515 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2513 def create_time @create_time end |
#display_name ⇒ String
Required. The display name for the System db. The name does not have to be
unique within your project.
Corresponds to the JSON property displayName
2519 2520 2521 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2519 def display_name @display_name end |
#entitlement_id ⇒ String
Output only. The ID of the subscription entitlement associated with the
DbSystem
Corresponds to the JSON property entitlementId
2525 2526 2527 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2525 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us-
east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
2532 2533 2534 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2532 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. The labels or tags associated with the DbSystem.
Corresponds to the JSON property labels
2537 2538 2539 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2537 def labels @labels end |
#name ⇒ String
Identifier. The name of the DbSystem resource in the following format:
projects/project/locations/region/dbSystems/db_system
Corresponds to the JSON property name
2543 2544 2545 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2543 def name @name end |
#oci_url ⇒ String
Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
Corresponds to the JSON property ociUrl
2548 2549 2550 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2548 def oci_url @oci_url end |
#odb_network ⇒ String
Optional. The name of the OdbNetwork associated with the DbSystem. Format:
projects/project/locations/location/odbNetworks/odb_network It is
optional but if specified, this should match the parent ODBNetwork of the
OdbSubnet.
Corresponds to the JSON property odbNetwork
2556 2557 2558 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2556 def odb_network @odb_network end |
#odb_subnet ⇒ String
Required. The name of the OdbSubnet associated with the DbSystem for IP
allocation. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
2563 2564 2565 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2563 def odb_subnet @odb_subnet end |
#properties ⇒ Google::Apis::OracledatabaseV1::DbSystemProperties
The properties of a DbSystem.
Corresponds to the JSON property properties
2568 2569 2570 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2568 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2575 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @oci_url = args[:oci_url] if args.key?(:oci_url) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @properties = args[:properties] if args.key?(:properties) end |