Class: Google::Apis::OracledatabaseV1::DbSystemProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of a DbSystem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DbSystemProperties

Returns a new instance of DbSystemProperties.



2970
2971
2972
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compute_countFixnum

Required. The number of CPU cores to enable for the DbSystem. Corresponds to the JSON property computeCount

Returns:

  • (Fixnum)


2861
2862
2863
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2861

def compute_count
  @compute_count
end

#compute_modelString

Optional. The compute model of the DbSystem. Corresponds to the JSON property computeModel

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2866

def compute_model
  @compute_model
end

#data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptionsDbSystem

Data collection options for DbSystem. Corresponds to the JSON property dataCollectionOptions



2871
2872
2873
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2871

def data_collection_options
  @data_collection_options
end

#data_storage_size_gbFixnum

Optional. The data storage size in GB that is currently available to DbSystems. The value is same as initial_data_storage_size_gb. This can be modified from OCI console. Corresponds to the JSON property dataStorageSizeGb

Returns:

  • (Fixnum)


2878
2879
2880
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2878

def data_storage_size_gb
  @data_storage_size_gb
end

#database_editionString

Required. The database edition of the DbSystem. Corresponds to the JSON property databaseEdition

Returns:

  • (String)


2883
2884
2885
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2883

def database_edition
  @database_edition
end

#db_homeGoogle::Apis::OracledatabaseV1::DbHome

Details of the Database Home resource. Corresponds to the JSON property dbHome



2888
2889
2890
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2888

def db_home
  @db_home
end

#db_system_optionsGoogle::Apis::OracledatabaseV1::DbSystemOptions

Details of the DbSystem Options. Corresponds to the JSON property dbSystemOptions



2893
2894
2895
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2893

def db_system_options
  @db_system_options
end

#domainString

Optional. The host domain name of the DbSystem. Corresponds to the JSON property domain

Returns:

  • (String)


2898
2899
2900
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2898

def domain
  @domain
end

#hostnameString

Output only. The hostname of the DbSystem. Corresponds to the JSON property hostname

Returns:

  • (String)


2903
2904
2905
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2903

def hostname
  @hostname
end

#hostname_prefixString

Optional. Prefix for DB System host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


2908
2909
2910
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2908

def hostname_prefix
  @hostname_prefix
end

#initial_data_storage_size_gbFixnum

Required. The initial data storage size in GB. Corresponds to the JSON property initialDataStorageSizeGb

Returns:

  • (Fixnum)


2913
2914
2915
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2913

def initial_data_storage_size_gb
  @initial_data_storage_size_gb
end

#license_modelString

Required. The license model of the DbSystem. Corresponds to the JSON property licenseModel

Returns:

  • (String)


2918
2919
2920
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2918

def license_model
  @license_model
end

#lifecycle_stateString

Output only. State of the DbSystem. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2923

def lifecycle_state
  @lifecycle_state
end

#memory_size_gbFixnum

Optional. The memory size in GB. This value can not be set and is automatically calculated based on the number of ECPUs allocated to the DbSystem. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


2930
2931
2932
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2930

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Optional. The number of nodes to launch for a virtual machine DbSystem. By default this will be set to 1. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


2936
2937
2938
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2936

def node_count
  @node_count
end

#ocidString

Output only. OCID of the DbSystem. Corresponds to the JSON property ocid

Returns:

  • (String)


2941
2942
2943
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2941

def ocid
  @ocid
end

#private_ipString

Optional. The private IP address of the DbSystem. Corresponds to the JSON property privateIp

Returns:

  • (String)


2946
2947
2948
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2946

def private_ip
  @private_ip
end

#reco_storage_size_gbFixnum

Optional. The reco/redo storage size in GB. The value for recovery storage size is based on the available data storage size. Corresponds to the JSON property recoStorageSizeGb

Returns:

  • (Fixnum)


2952
2953
2954
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2952

def reco_storage_size_gb
  @reco_storage_size_gb
end

#shapeString

Required. Shape of DB System. Corresponds to the JSON property shape

Returns:

  • (String)


2957
2958
2959
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2957

def shape
  @shape
end

#ssh_public_keysArray<String>

Required. SSH public keys to be stored with the DbSystem. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


2962
2963
2964
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2962

def ssh_public_keys
  @ssh_public_keys
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



2968
2969
2970
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2968

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 2975

def update!(**args)
  @compute_count = args[:compute_count] if args.key?(:compute_count)
  @compute_model = args[:compute_model] if args.key?(:compute_model)
  @data_collection_options = args[:data_collection_options] if args.key?(:data_collection_options)
  @data_storage_size_gb = args[:data_storage_size_gb] if args.key?(:data_storage_size_gb)
  @database_edition = args[:database_edition] if args.key?(:database_edition)
  @db_home = args[:db_home] if args.key?(:db_home)
  @db_system_options = args[:db_system_options] if args.key?(:db_system_options)
  @domain = args[:domain] if args.key?(:domain)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @initial_data_storage_size_gb = args[:initial_data_storage_size_gb] if args.key?(:initial_data_storage_size_gb)
  @license_model = args[:license_model] if args.key?(:license_model)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @ocid = args[:ocid] if args.key?(:ocid)
  @private_ip = args[:private_ip] if args.key?(:private_ip)
  @reco_storage_size_gb = args[:reco_storage_size_gb] if args.key?(:reco_storage_size_gb)
  @shape = args[:shape] if args.key?(:shape)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end