Class: Google::Apis::OracledatabaseV1::DbVersionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbVersionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of a DbVersion.
Instance Attribute Summary collapse
-
#is_latest_for_major_version ⇒ Boolean
(also: #is_latest_for_major_version?)
Output only.
-
#is_preview_db_version ⇒ Boolean
(also: #is_preview_db_version?)
Output only.
-
#is_upgrade_supported ⇒ Boolean
(also: #is_upgrade_supported?)
Output only.
-
#supports_pdb ⇒ Boolean
(also: #supports_pdb?)
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbVersionProperties
constructor
A new instance of DbVersionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbVersionProperties
Returns a new instance of DbVersionProperties.
3144 3145 3146 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_latest_for_major_version ⇒ Boolean Also known as: is_latest_for_major_version?
Output only. True if this version of the Oracle Database software is the
latest version for a release.
Corresponds to the JSON property isLatestForMajorVersion
3115 3116 3117 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3115 def is_latest_for_major_version @is_latest_for_major_version end |
#is_preview_db_version ⇒ Boolean Also known as: is_preview_db_version?
Output only. True if this version of the Oracle Database software is the
preview version.
Corresponds to the JSON property isPreviewDbVersion
3122 3123 3124 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3122 def is_preview_db_version @is_preview_db_version end |
#is_upgrade_supported ⇒ Boolean Also known as: is_upgrade_supported?
Output only. True if this version of the Oracle Database software is supported
for Upgrade.
Corresponds to the JSON property isUpgradeSupported
3129 3130 3131 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3129 def is_upgrade_supported @is_upgrade_supported end |
#supports_pdb ⇒ Boolean Also known as: supports_pdb?
Output only. True if this version of the Oracle Database software supports
pluggable databases.
Corresponds to the JSON property supportsPdb
3136 3137 3138 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3136 def supports_pdb @supports_pdb end |
#version ⇒ String
Output only. A valid Oracle Database version.
Corresponds to the JSON property version
3142 3143 3144 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3142 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3149 3150 3151 3152 3153 3154 3155 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3149 def update!(**args) @is_latest_for_major_version = args[:is_latest_for_major_version] if args.key?(:is_latest_for_major_version) @is_preview_db_version = args[:is_preview_db_version] if args.key?(:is_preview_db_version) @is_upgrade_supported = args[:is_upgrade_supported] if args.key?(:is_upgrade_supported) @supports_pdb = args[:supports_pdb] if args.key?(:supports_pdb) @version = args[:version] if args.key?(:version) end |