Class: Google::Apis::OracledatabaseV1::DbVersionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::DbVersionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of a DbVersion.
Instance Attribute Summary collapse
-
#is_latest_for_major_version ⇒ Boolean
(also: #is_latest_for_major_version?)
Output only.
-
#is_preview_db_version ⇒ Boolean
(also: #is_preview_db_version?)
Output only.
-
#is_upgrade_supported ⇒ Boolean
(also: #is_upgrade_supported?)
Output only.
-
#supports_pdb ⇒ Boolean
(also: #supports_pdb?)
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DbVersionProperties
constructor
A new instance of DbVersionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DbVersionProperties
Returns a new instance of DbVersionProperties.
3091 3092 3093 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_latest_for_major_version ⇒ Boolean Also known as: is_latest_for_major_version?
Output only. True if this version of the Oracle Database software is the
latest version for a release.
Corresponds to the JSON property isLatestForMajorVersion
3062 3063 3064 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3062 def is_latest_for_major_version @is_latest_for_major_version end |
#is_preview_db_version ⇒ Boolean Also known as: is_preview_db_version?
Output only. True if this version of the Oracle Database software is the
preview version.
Corresponds to the JSON property isPreviewDbVersion
3069 3070 3071 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3069 def is_preview_db_version @is_preview_db_version end |
#is_upgrade_supported ⇒ Boolean Also known as: is_upgrade_supported?
Output only. True if this version of the Oracle Database software is supported
for Upgrade.
Corresponds to the JSON property isUpgradeSupported
3076 3077 3078 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3076 def is_upgrade_supported @is_upgrade_supported end |
#supports_pdb ⇒ Boolean Also known as: supports_pdb?
Output only. True if this version of the Oracle Database software supports
pluggable databases.
Corresponds to the JSON property supportsPdb
3083 3084 3085 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3083 def supports_pdb @supports_pdb end |
#version ⇒ String
Output only. A valid Oracle Database version.
Corresponds to the JSON property version
3089 3090 3091 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3089 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3096 3097 3098 3099 3100 3101 3102 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3096 def update!(**args) @is_latest_for_major_version = args[:is_latest_for_major_version] if args.key?(:is_latest_for_major_version) @is_preview_db_version = args[:is_preview_db_version] if args.key?(:is_preview_db_version) @is_upgrade_supported = args[:is_upgrade_supported] if args.key?(:is_upgrade_supported) @supports_pdb = args[:supports_pdb] if args.key?(:supports_pdb) @version = args[:version] if args.key?(:version) end |