Class: Google::Apis::OracledatabaseV1::EncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The encryption key used to encrypt the Autonomous Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionKey

Returns a new instance of EncryptionKey.



3283
3284
3285
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_keyString

Optional. The KMS key used to encrypt the Autonomous Database. This field is required if the provider is GOOGLE_MANAGED. The name of the KMS key resource in the following format: projects/project/locations/location/keyRings/ key_ring/cryptoKeys/crypto_key`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3276

def kms_key
  @kms_key
end

#providerString

Optional. The provider of the encryption key. Corresponds to the JSON property provider

Returns:

  • (String)


3281
3282
3283
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3281

def provider
  @provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3288
3289
3290
3291
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3288

def update!(**args)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @provider = args[:provider] if args.key?(:provider)
end