Class: Google::Apis::OracledatabaseV1::EncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The encryption key used to encrypt the Autonomous Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionKey

Returns a new instance of EncryptionKey.



3161
3162
3163
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_keyString

Optional. The KMS key used to encrypt the Autonomous Database. This field is required if the provider is GOOGLE_MANAGED. The name of the KMS key resource in the following format: projects/project/locations/location/keyRings/ key_ring/cryptoKeys/crypto_key`. Corresponds to the JSON propertykmsKey`

Returns:

  • (String)


3154
3155
3156
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3154

def kms_key
  @kms_key
end

#providerString

Optional. The provider of the encryption key. Corresponds to the JSON property provider

Returns:

  • (String)


3159
3160
3161
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3159

def provider
  @provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3166
3167
3168
3169
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3166

def update!(**args)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @provider = args[:provider] if args.key?(:provider)
end