Class: Google::Apis::OracledatabaseV1::EncryptionKeyHistoryEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The history of the encryption keys used to encrypt the Autonomous Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionKeyHistoryEntry

Returns a new instance of EncryptionKeyHistoryEntry.



3232
3233
3234
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_timeString

Output only. The date and time when the encryption key was activated on the Autonomous Database.. Corresponds to the JSON property activationTime

Returns:

  • (String)


3225
3226
3227
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3225

def activation_time
  @activation_time
end

#encryption_keyGoogle::Apis::OracledatabaseV1::EncryptionKey

The encryption key used to encrypt the Autonomous Database. Corresponds to the JSON property encryptionKey



3230
3231
3232
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3230

def encryption_key
  @encryption_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3237
3238
3239
3240
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3237

def update!(**args)
  @activation_time = args[:activation_time] if args.key?(:activation_time)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
end