Class: Google::Apis::OracledatabaseV1::EncryptionKeyHistoryEntry
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::EncryptionKeyHistoryEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The history of the encryption keys used to encrypt the Autonomous Database.
Instance Attribute Summary collapse
-
#activation_time ⇒ String
Output only.
-
#encryption_key ⇒ Google::Apis::OracledatabaseV1::EncryptionKey
The encryption key used to encrypt the Autonomous Database.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionKeyHistoryEntry
constructor
A new instance of EncryptionKeyHistoryEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionKeyHistoryEntry
Returns a new instance of EncryptionKeyHistoryEntry.
3187 3188 3189 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_time ⇒ String
Output only. The date and time when the encryption key was activated on the
Autonomous Database..
Corresponds to the JSON property activationTime
3180 3181 3182 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3180 def activation_time @activation_time end |
#encryption_key ⇒ Google::Apis::OracledatabaseV1::EncryptionKey
The encryption key used to encrypt the Autonomous Database.
Corresponds to the JSON property encryptionKey
3185 3186 3187 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3185 def encryption_key @encryption_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3192 3193 3194 3195 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3192 def update!(**args) @activation_time = args[:activation_time] if args.key?(:activation_time) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) end |