Class: Google::Apis::OracledatabaseV1::ExadbVmCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExadbVmCluster represents a cluster of VMs that are used to run Exadata workloads. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExadbVmCluster/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExadbVmCluster

Returns a new instance of ExadbVmCluster.



3170
3171
3172
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_odb_subnetString

Required. Immutable. The name of the backup OdbSubnet associated with the ExadbVmCluster. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property backupOdbSubnet

Returns:

  • (String)


3112
3113
3114
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3112

def backup_odb_subnet
  @backup_odb_subnet
end

#create_timeString

Output only. The date and time that the ExadbVmCluster was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3117
3118
3119
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3117

def create_time
  @create_time
end

#display_nameString

Required. Immutable. The display name for the ExadbVmCluster. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3124
3125
3126
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3124

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExadbVmCluster. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3130
3131
3132
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3130

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Output only. Immutable. The GCP Oracle zone where Oracle ExadbVmCluster is hosted. Example: us-east4-b-r2. During creation, the system will pick the zone assigned to the ExascaleDbStorageVault. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3137
3138
3139
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3137

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExadbVmCluster. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3142
3143
3144
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3142

def labels
  @labels
end

#nameString

Identifier. The name of the ExadbVmCluster resource in the following format: projects/project/locations/region/exadbVmClusters/exadb_vm_cluster Corresponds to the JSON property name

Returns:

  • (String)


3148
3149
3150
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3148

def name
  @name
end

#odb_networkString

Optional. Immutable. The name of the OdbNetwork associated with the ExadbVmCluster. Format: projects/project/locations/location/odbNetworks/ odb_network It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


3156
3157
3158
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3156

def odb_network
  @odb_network
end

#odb_subnetString

Required. Immutable. The name of the OdbSubnet associated with the ExadbVmCluster for IP allocation. Format: projects/project/locations/ location/odbNetworks/odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


3163
3164
3165
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3163

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::ExadbVmClusterProperties

The properties of an ExadbVmCluster. Corresponds to the JSON property properties



3168
3169
3170
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3168

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3175
3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3175

def update!(**args)
  @backup_odb_subnet = args[:backup_odb_subnet] if args.key?(:backup_odb_subnet)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end