Class: Google::Apis::OracledatabaseV1::ExadbVmClusterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of an ExadbVmCluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExadbVmClusterProperties

Returns a new instance of ExadbVmClusterProperties.



3302
3303
3304
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_ecpu_count_per_nodeFixnum

Optional. Immutable. The number of additional ECPUs per node for an Exadata VM cluster on exascale infrastructure. Corresponds to the JSON property additionalEcpuCountPerNode

Returns:

  • (Fixnum)


3197
3198
3199
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3197

def additional_ecpu_count_per_node
  @additional_ecpu_count_per_node
end

#cluster_nameString

Optional. Immutable. The cluster name for Exascale vm cluster. The cluster name must begin with an alphabetic character and may contain hyphens(-) but can not contain underscores(_). It should be not more than 11 characters and is not case sensitive. OCI Cluster name. Corresponds to the JSON property clusterName

Returns:

  • (String)


3205
3206
3207
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3205

def cluster_name
  @cluster_name
end

#data_collection_optionsGoogle::Apis::OracledatabaseV1::DataCollectionOptionsCommon

Data collection options for diagnostics. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/datatypes/DataCollectionOptions Corresponds to the JSON property dataCollectionOptions



3211
3212
3213
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3211

def data_collection_options
  @data_collection_options
end

#enabled_ecpu_count_per_nodeFixnum

Required. Immutable. The number of ECPUs enabled per node for an exadata vm cluster on exascale infrastructure. Corresponds to the JSON property enabledEcpuCountPerNode

Returns:

  • (Fixnum)


3217
3218
3219
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3217

def enabled_ecpu_count_per_node
  @enabled_ecpu_count_per_node
end

#exascale_db_storage_vaultString

Required. Immutable. The name of ExascaleDbStorageVault associated with the ExadbVmCluster. It can refer to an existing ExascaleDbStorageVault. Or a new one can be created during the ExadbVmCluster creation (requires storage_vault_properties to be set). Format: projects/project/locations/ location/exascaleDbStorageVaults/exascale_db_storage_vault Corresponds to the JSON property exascaleDbStorageVault

Returns:

  • (String)


3226
3227
3228
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3226

def exascale_db_storage_vault
  @exascale_db_storage_vault
end

#gi_versionString

Output only. The Oracle Grid Infrastructure (GI) software version. Corresponds to the JSON property giVersion

Returns:

  • (String)


3231
3232
3233
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3231

def gi_version
  @gi_version
end

#grid_image_idString

Required. Immutable. Grid Infrastructure Version. Corresponds to the JSON property gridImageId

Returns:

  • (String)


3236
3237
3238
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3236

def grid_image_id
  @grid_image_id
end

#hostnameString

Output only. The hostname of the ExadbVmCluster. Corresponds to the JSON property hostname

Returns:

  • (String)


3241
3242
3243
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3241

def hostname
  @hostname
end

#hostname_prefixString

Required. Immutable. Prefix for VM cluster host names. Corresponds to the JSON property hostnamePrefix

Returns:

  • (String)


3246
3247
3248
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3246

def hostname_prefix
  @hostname_prefix
end

#license_modelString

Optional. Immutable. The license type of the ExadbVmCluster. Corresponds to the JSON property licenseModel

Returns:

  • (String)


3251
3252
3253
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3251

def license_model
  @license_model
end

#lifecycle_stateString

Output only. State of the cluster. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


3256
3257
3258
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3256

def lifecycle_state
  @lifecycle_state
end

#memory_size_gbFixnum

Output only. Memory per VM (GB) (Read-only): Shows the amount of memory allocated to each VM. Memory is calculated based on 2.75 GB per Total ECPUs. Corresponds to the JSON property memorySizeGb

Returns:

  • (Fixnum)


3262
3263
3264
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3262

def memory_size_gb
  @memory_size_gb
end

#node_countFixnum

Required. The number of nodes/VMs in the ExadbVmCluster. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


3267
3268
3269
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3267

def node_count
  @node_count
end

#oci_uriString

Output only. Deep link to the OCI console to view this resource. Corresponds to the JSON property ociUri

Returns:

  • (String)


3272
3273
3274
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3272

def oci_uri
  @oci_uri
end

#scan_listener_port_tcpFixnum

Optional. Immutable. SCAN listener port - TCP Corresponds to the JSON property scanListenerPortTcp

Returns:

  • (Fixnum)


3277
3278
3279
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3277

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#shape_attributeString

Required. Immutable. The shape attribute of the VM cluster. The type of Exascale storage used for Exadata VM cluster. The default is SMART_STORAGE which supports Oracle Database 23ai and later Corresponds to the JSON property shapeAttribute

Returns:

  • (String)


3284
3285
3286
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3284

def shape_attribute
  @shape_attribute
end

#ssh_public_keysArray<String>

Required. Immutable. The SSH public keys for the ExadbVmCluster. Corresponds to the JSON property sshPublicKeys

Returns:

  • (Array<String>)


3289
3290
3291
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3289

def ssh_public_keys
  @ssh_public_keys
end

#time_zoneGoogle::Apis::OracledatabaseV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



3295
3296
3297
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3295

def time_zone
  @time_zone
end

#vm_file_system_storageGoogle::Apis::OracledatabaseV1::ExadbVmClusterStorageDetails

The storage allocation for the exadbvmcluster, in gigabytes (GB). Corresponds to the JSON property vmFileSystemStorage



3300
3301
3302
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3300

def vm_file_system_storage
  @vm_file_system_storage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3307

def update!(**args)
  @additional_ecpu_count_per_node = args[:additional_ecpu_count_per_node] if args.key?(:additional_ecpu_count_per_node)
  @cluster_name = args[:cluster_name] if args.key?(:cluster_name)
  @data_collection_options = args[:data_collection_options] if args.key?(:data_collection_options)
  @enabled_ecpu_count_per_node = args[:enabled_ecpu_count_per_node] if args.key?(:enabled_ecpu_count_per_node)
  @exascale_db_storage_vault = args[:exascale_db_storage_vault] if args.key?(:exascale_db_storage_vault)
  @gi_version = args[:gi_version] if args.key?(:gi_version)
  @grid_image_id = args[:grid_image_id] if args.key?(:grid_image_id)
  @hostname = args[:hostname] if args.key?(:hostname)
  @hostname_prefix = args[:hostname_prefix] if args.key?(:hostname_prefix)
  @license_model = args[:license_model] if args.key?(:license_model)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @memory_size_gb = args[:memory_size_gb] if args.key?(:memory_size_gb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @oci_uri = args[:oci_uri] if args.key?(:oci_uri)
  @scan_listener_port_tcp = args[:scan_listener_port_tcp] if args.key?(:scan_listener_port_tcp)
  @shape_attribute = args[:shape_attribute] if args.key?(:shape_attribute)
  @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @vm_file_system_storage = args[:vm_file_system_storage] if args.key?(:vm_file_system_storage)
end