Class: Google::Apis::OracledatabaseV1::ExadbVmClusterStorageDetails
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ExadbVmClusterStorageDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The storage allocation for the exadbvmcluster, in gigabytes (GB).
Instance Attribute Summary collapse
-
#size_in_gbs_per_node ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExadbVmClusterStorageDetails
constructor
A new instance of ExadbVmClusterStorageDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExadbVmClusterStorageDetails
Returns a new instance of ExadbVmClusterStorageDetails.
3625 3626 3627 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#size_in_gbs_per_node ⇒ Fixnum
Required. The storage allocation for the exadbvmcluster per node, in gigabytes
(GB). This field is used to calculate the total storage allocation for the
exadbvmcluster.
Corresponds to the JSON property sizeInGbsPerNode
3623 3624 3625 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3623 def size_in_gbs_per_node @size_in_gbs_per_node end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3630 3631 3632 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3630 def update!(**args) @size_in_gbs_per_node = args[:size_in_gbs_per_node] if args.key?(:size_in_gbs_per_node) end |