Class: Google::Apis::OracledatabaseV1::ExadbVmClusterStorageDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The storage allocation for the exadbvmcluster, in gigabytes (GB).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExadbVmClusterStorageDetails

Returns a new instance of ExadbVmClusterStorageDetails.



3476
3477
3478
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#size_in_gbs_per_nodeFixnum

Required. The storage allocation for the exadbvmcluster per node, in gigabytes (GB). This field is used to calculate the total storage allocation for the exadbvmcluster. Corresponds to the JSON property sizeInGbsPerNode

Returns:

  • (Fixnum)


3474
3475
3476
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3474

def size_in_gbs_per_node
  @size_in_gbs_per_node
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3481
3482
3483
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3481

def update!(**args)
  @size_in_gbs_per_node = args[:size_in_gbs_per_node] if args.key?(:size_in_gbs_per_node)
end