Class: Google::Apis::OracledatabaseV1::ExascaleDbStorageVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExascaleDbStorageVault represents a storage vault exadb vm cluster resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExascaleDbStorageVault/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExascaleDbStorageVault

Returns a new instance of ExascaleDbStorageVault.



3638
3639
3640
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time when the ExascaleDbStorageVault was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3592
3593
3594
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3592

def create_time
  @create_time
end

#display_nameString

Required. The display name for the ExascaleDbStorageVault. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3599
3600
3601
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3599

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExascaleDbStorageVault. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3605
3606
3607
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3605

def entitlement_id
  @entitlement_id
end

#exadata_infrastructureString

Optional. The Exadata Infrastructure resource on which ExascaleDbStorageVault resource is created, in the following format: projects/project/locations/ region/cloudExadataInfrastuctures/cloud_extradata_infrastructure Corresponds to the JSON property exadataInfrastructure

Returns:

  • (String)


3612
3613
3614
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3612

def exadata_infrastructure
  @exadata_infrastructure
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle ExascaleDbStorageVault is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3619

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExascaleDbStorageVault. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3624
3625
3626
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3624

def labels
  @labels
end

#nameString

Identifier. The resource name of the ExascaleDbStorageVault. Format: projects/ project/locations/location/exascaleDbStorageVaults/ exascale_db_storage_vault Corresponds to the JSON property name

Returns:

  • (String)


3631
3632
3633
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3631

def name
  @name
end

#propertiesGoogle::Apis::OracledatabaseV1::ExascaleDbStorageVaultProperties

The properties of the ExascaleDbStorageVault. next ID: 12 Corresponds to the JSON property properties



3636
3637
3638
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3636

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3643

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @exadata_infrastructure = args[:exadata_infrastructure] if args.key?(:exadata_infrastructure)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end