Class: Google::Apis::OracledatabaseV1::ExascaleDbStorageVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExascaleDbStorageVault represents a storage vault exadb vm cluster resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExascaleDbStorageVault/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExascaleDbStorageVault

Returns a new instance of ExascaleDbStorageVault.



3561
3562
3563
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time when the ExascaleDbStorageVault was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3522

def create_time
  @create_time
end

#display_nameString

Required. The display name for the ExascaleDbStorageVault. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3529
3530
3531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3529

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExascaleDbStorageVault. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3535
3536
3537
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3535

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle ExascaleDbStorageVault is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3542
3543
3544
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3542

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExascaleDbStorageVault. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3547
3548
3549
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3547

def labels
  @labels
end

#nameString

Identifier. The resource name of the ExascaleDbStorageVault. Format: projects/ project/locations/location/exascaleDbStorageVaults/ exascale_db_storage_vault Corresponds to the JSON property name

Returns:

  • (String)


3554
3555
3556
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3554

def name
  @name
end

#propertiesGoogle::Apis::OracledatabaseV1::ExascaleDbStorageVaultProperties

The properties of the ExascaleDbStorageVault. next ID: 12 Corresponds to the JSON property properties



3559
3560
3561
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3559

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3566
3567
3568
3569
3570
3571
3572
3573
3574
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3566

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end