Class: Google::Apis::OracledatabaseV1::ExascaleDbStorageVault

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

ExascaleDbStorageVault represents a storage vault exadb vm cluster resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/ ExascaleDbStorageVault/

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExascaleDbStorageVault

Returns a new instance of ExascaleDbStorageVault.



3426
3427
3428
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time when the ExascaleDbStorageVault was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3387
3388
3389
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3387

def create_time
  @create_time
end

#display_nameString

Required. The display name for the ExascaleDbStorageVault. The name does not have to be unique within your project. The name must be 1-255 characters long and can only contain alphanumeric characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3394
3395
3396
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3394

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the ExascaleDbStorageVault. Corresponds to the JSON property entitlementId

Returns:

  • (String)


3400
3401
3402
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3400

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle ExascaleDbStorageVault is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


3407
3408
3409
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3407

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the ExascaleDbStorageVault. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3412
3413
3414
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3412

def labels
  @labels
end

#nameString

Identifier. The resource name of the ExascaleDbStorageVault. Format: projects/ project/locations/location/exascaleDbStorageVaults/ exascale_db_storage_vault Corresponds to the JSON property name

Returns:

  • (String)


3419
3420
3421
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3419

def name
  @name
end

#propertiesGoogle::Apis::OracledatabaseV1::ExascaleDbStorageVaultProperties

The properties of the ExascaleDbStorageVault. next ID: 12 Corresponds to the JSON property properties



3424
3425
3426
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3424

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3431

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end