Class: Google::Apis::OracledatabaseV1::GenerateAutonomousDatabaseWalletRequest
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GenerateAutonomousDatabaseWalletRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The request for AutonomousDatabase.GenerateWallet.
Instance Attribute Summary collapse
-
#is_regional ⇒ Boolean
(also: #is_regional?)
Optional.
-
#password ⇒ String
Required.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateAutonomousDatabaseWalletRequest
constructor
A new instance of GenerateAutonomousDatabaseWalletRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateAutonomousDatabaseWalletRequest
Returns a new instance of GenerateAutonomousDatabaseWalletRequest.
3783 3784 3785 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_regional ⇒ Boolean Also known as: is_regional?
Optional. True when requesting regional connection strings in PDB connect info,
applicable to cross-region Data Guard only.
Corresponds to the JSON property isRegional
3768 3769 3770 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3768 def is_regional @is_regional end |
#password ⇒ String
Required. The password used to encrypt the keys inside the wallet. The
password must be a minimum of 8 characters.
Corresponds to the JSON property password
3775 3776 3777 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3775 def password @password end |
#type ⇒ String
Optional. The type of wallet generation for the Autonomous Database. The
default value is SINGLE.
Corresponds to the JSON property type
3781 3782 3783 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3781 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3788 3789 3790 3791 3792 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3788 def update!(**args) @is_regional = args[:is_regional] if args.key?(:is_regional) @password = args[:password] if args.key?(:password) @type = args[:type] if args.key?(:type) end |