Class: Google::Apis::OracledatabaseV1::GenerateAutonomousDatabaseWalletRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The request for AutonomousDatabase.GenerateWallet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateAutonomousDatabaseWalletRequest

Returns a new instance of GenerateAutonomousDatabaseWalletRequest.



3570
3571
3572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_regionalBoolean Also known as: is_regional?

Optional. True when requesting regional connection strings in PDB connect info, applicable to cross-region Data Guard only. Corresponds to the JSON property isRegional

Returns:

  • (Boolean)


3555
3556
3557
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3555

def is_regional
  @is_regional
end

#passwordString

Required. The password used to encrypt the keys inside the wallet. The password must be a minimum of 8 characters. Corresponds to the JSON property password

Returns:

  • (String)


3562
3563
3564
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3562

def password
  @password
end

#typeString

Optional. The type of wallet generation for the Autonomous Database. The default value is SINGLE. Corresponds to the JSON property type

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3568

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3575
3576
3577
3578
3579
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3575

def update!(**args)
  @is_regional = args[:is_regional] if args.key?(:is_regional)
  @password = args[:password] if args.key?(:password)
  @type = args[:type] if args.key?(:type)
end