Class: Google::Apis::OracledatabaseV1::GoldengateAmazonRedshiftConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateAmazonRedshiftConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateAmazonRedshiftConnection.
Instance Attribute Summary collapse
-
#connection_url ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateAmazonRedshiftConnectionProperties
constructor
A new instance of GoldengateAmazonRedshiftConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateAmazonRedshiftConnectionProperties
Returns a new instance of GoldengateAmazonRedshiftConnectionProperties.
4025 4026 4027 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_url ⇒ String
Optional. Connection URL. e.g.: 'jdbc:redshift://aws-redshift-instance.
aaaaaaaaaaaa.us-east-2.redshift.amazonaws.com:5439/mydb'
Corresponds to the JSON property connectionUrl
3999 4000 4001 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3999 def connection_url @connection_url end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Amazon Redshift
connection in plain text.
Corresponds to the JSON property password
4005 4006 4007 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4005 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Amazon Redshift
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
4012 4013 4014 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4012 def password_secret_version @password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of AmazonRedshiftConnection.
Corresponds to the JSON property technologyType
4017 4018 4019 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4017 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
4023 4024 4025 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4023 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4030 4031 4032 4033 4034 4035 4036 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4030 def update!(**args) @connection_url = args[:connection_url] if args.key?(:connection_url) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |