Class: Google::Apis::OracledatabaseV1::GoldengateAmazonRedshiftConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateAmazonRedshiftConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateAmazonRedshiftConnectionProperties

Returns a new instance of GoldengateAmazonRedshiftConnectionProperties.



3863
3864
3865
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_urlString

Optional. Connection URL. e.g.: 'jdbc:redshift://aws-redshift-instance. aaaaaaaaaaaa.us-east-2.redshift.amazonaws.com:5439/mydb' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


3837
3838
3839
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3837

def connection_url
  @connection_url
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Amazon Redshift connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


3843
3844
3845
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3843

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Amazon Redshift connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


3850
3851
3852
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3850

def password_secret_version
  @password_secret_version
end

#technology_typeString

Optional. The technology type of AmazonRedshiftConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


3855
3856
3857
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3855

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


3861
3862
3863
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3861

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3868
3869
3870
3871
3872
3873
3874
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3868

def update!(**args)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end