Class: Google::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateAzureSynapseAnalyticsConnection.
Instance Attribute Summary collapse
-
#connection_string ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateAzureSynapseAnalyticsConnectionProperties
constructor
A new instance of GoldengateAzureSynapseAnalyticsConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateAzureSynapseAnalyticsConnectionProperties
Returns a new instance of GoldengateAzureSynapseAnalyticsConnectionProperties.
4113 4114 4115 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_string ⇒ String
Optional. JDBC connection string. e.g.: 'jdbc:sqlserver://.sql.azuresynapse.
net:1433;database=;encrypt=true;trustServerCertificate=false;
hostNameInCertificate=*.sql.azuresynapse.net;loginTimeout=300;'
Corresponds to the JSON property connectionString
4087 4088 4089 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4087 def connection_string @connection_string end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Azure Synapse
Analytics connection in plain text.
Corresponds to the JSON property password
4093 4094 4095 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4093 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Azure Synapse Analytics
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
4100 4101 4102 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4100 def password_secret_version @password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of AzureSynapseAnalyticsConnection.
Corresponds to the JSON property technologyType
4105 4106 4107 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4105 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
4111 4112 4113 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4111 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4118 4119 4120 4121 4122 4123 4124 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4118 def update!(**args) @connection_string = args[:connection_string] if args.key?(:connection_string) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |