Class: Google::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateAzureSynapseAnalyticsConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateAzureSynapseAnalyticsConnectionProperties

Returns a new instance of GoldengateAzureSynapseAnalyticsConnectionProperties.



4035
4036
4037
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. JDBC connection string. e.g.: 'jdbc:sqlserver://.sql.azuresynapse. net:1433;database=;encrypt=true;trustServerCertificate=false; hostNameInCertificate=*.sql.azuresynapse.net;loginTimeout=300;' Corresponds to the JSON property connectionString

Returns:

  • (String)


4009
4010
4011
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4009

def connection_string
  @connection_string
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Azure Synapse Analytics connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4015

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Azure Synapse Analytics connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4022

def password_secret_version
  @password_secret_version
end

#technology_typeString

Optional. The technology type of AzureSynapseAnalyticsConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


4027
4028
4029
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4027

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4033

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4040
4041
4042
4043
4044
4045
4046
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4040

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end