Class: Google::Apis::OracledatabaseV1::GoldengateConnection
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the GoldengateConnection resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#oci_url ⇒ String
Output only.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Optional.
-
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateConnection
constructor
A new instance of GoldengateConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateConnection
Returns a new instance of GoldengateConnection.
4289 4290 4291 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the GoldengateConnection was created.
Corresponds to the JSON property createTime
4237 4238 4239 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4237 def create_time @create_time end |
#entitlement_id ⇒ String
Output only. The ID of the subscription entitlement associated with the
GoldengateConnection.
Corresponds to the JSON property entitlementId
4243 4244 4245 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4243 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted.
Example: us-east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
4250 4251 4252 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4250 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. The labels or tags associated with the GoldengateConnection.
Corresponds to the JSON property labels
4255 4256 4257 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4255 def labels @labels end |
#name ⇒ String
Identifier. The name of the GoldengateConnection resource in the following
format: projects/project/locations/region/goldengateConnections/
goldengate_connection
Corresponds to the JSON property name
4262 4263 4264 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4262 def name @name end |
#oci_url ⇒ String
Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
Corresponds to the JSON property ociUrl
4267 4268 4269 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4267 def oci_url @oci_url end |
#odb_network ⇒ String
Optional. The name of the OdbNetwork associated with the GoldengateConnection.
The format is projects/project/locations/location/odbNetworks/odb_network
. It is optional but if specified, this should match the parent ODBNetwork of
the OdbSubnet.
Corresponds to the JSON property odbNetwork
4275 4276 4277 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4275 def odb_network @odb_network end |
#odb_subnet ⇒ String
Optional. The name of the OdbSubnet associated with the GoldengateConnection
for IP allocation. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
4282 4283 4284 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4282 def odb_subnet @odb_subnet end |
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Corresponds to the JSON property properties
4287 4288 4289 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4287 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4294 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @oci_url = args[:oci_url] if args.key?(:oci_url) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @properties = args[:properties] if args.key?(:properties) end |