Class: Google::Apis::OracledatabaseV1::GoldengateConnection
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the GoldengateConnection resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#entitlement_id ⇒ String
Output only.
-
#gcp_oracle_zone ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#oci_url ⇒ String
Output only.
-
#odb_network ⇒ String
Optional.
-
#odb_subnet ⇒ String
Optional.
-
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateConnection
constructor
A new instance of GoldengateConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateConnection
Returns a new instance of GoldengateConnection.
4236 4237 4238 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The date and time that the GoldengateConnection was created.
Corresponds to the JSON property createTime
4184 4185 4186 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4184 def create_time @create_time end |
#entitlement_id ⇒ String
Output only. The ID of the subscription entitlement associated with the
GoldengateConnection.
Corresponds to the JSON property entitlementId
4190 4191 4192 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4190 def entitlement_id @entitlement_id end |
#gcp_oracle_zone ⇒ String
Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted.
Example: us-east4-b-r2. If not specified, the system will pick a zone based on
availability.
Corresponds to the JSON property gcpOracleZone
4197 4198 4199 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4197 def gcp_oracle_zone @gcp_oracle_zone end |
#labels ⇒ Hash<String,String>
Optional. The labels or tags associated with the GoldengateConnection.
Corresponds to the JSON property labels
4202 4203 4204 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4202 def labels @labels end |
#name ⇒ String
Identifier. The name of the GoldengateConnection resource in the following
format: projects/project/locations/region/goldengateConnections/
goldengate_connection
Corresponds to the JSON property name
4209 4210 4211 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4209 def name @name end |
#oci_url ⇒ String
Output only. HTTPS link to OCI resources exposed to Customer via UI Interface.
Corresponds to the JSON property ociUrl
4214 4215 4216 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4214 def oci_url @oci_url end |
#odb_network ⇒ String
Optional. The name of the OdbNetwork associated with the GoldengateConnection.
The format is projects/project/locations/location/odbNetworks/odb_network
. It is optional but if specified, this should match the parent ODBNetwork of
the OdbSubnet.
Corresponds to the JSON property odbNetwork
4222 4223 4224 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4222 def odb_network @odb_network end |
#odb_subnet ⇒ String
Optional. The name of the OdbSubnet associated with the GoldengateConnection
for IP allocation. Format: projects/project/locations/location/odbNetworks/
odb_network/odbSubnets/odb_subnet
Corresponds to the JSON property odbSubnet
4229 4230 4231 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4229 def odb_subnet @odb_subnet end |
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateConnectionProperties
The properties of a GoldengateConnection.
Corresponds to the JSON property properties
4234 4235 4236 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4234 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4241 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id) @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @oci_url = args[:oci_url] if args.key?(:oci_url) @odb_network = args[:odb_network] if args.key?(:odb_network) @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet) @properties = args[:properties] if args.key?(:properties) end |