Class: Google::Apis::OracledatabaseV1::GoldengateConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the GoldengateConnection resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateConnection

Returns a new instance of GoldengateConnection.



4158
4159
4160
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the GoldengateConnection was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4106
4107
4108
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4106

def create_time
  @create_time
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the GoldengateConnection. Corresponds to the JSON property entitlementId

Returns:

  • (String)


4112
4113
4114
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4112

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle GoldengateConnection is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4119

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the GoldengateConnection. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4124
4125
4126
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4124

def labels
  @labels
end

#nameString

Identifier. The name of the GoldengateConnection resource in the following format: projects/project/locations/region/goldengateConnections/ goldengate_connection Corresponds to the JSON property name

Returns:

  • (String)


4131
4132
4133
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4131

def name
  @name
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


4136
4137
4138
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4136

def oci_url
  @oci_url
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the GoldengateConnection. The format is projects/project/locations/location/odbNetworks/odb_network . It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


4144
4145
4146
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4144

def odb_network
  @odb_network
end

#odb_subnetString

Optional. The name of the OdbSubnet associated with the GoldengateConnection for IP allocation. Format: projects/project/locations/location/odbNetworks/ odb_network/odbSubnets/odb_subnet Corresponds to the JSON property odbSubnet

Returns:

  • (String)


4151
4152
4153
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4151

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::GoldengateConnectionProperties

The properties of a GoldengateConnection. Corresponds to the JSON property properties



4156
4157
4158
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4156

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4163

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end