Class: Google::Apis::OracledatabaseV1::GoldengateConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of a GoldengateConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateConnectionProperties

Returns a new instance of GoldengateConnectionProperties.



4632
4633
4634
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amazon_kinesis_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonKinesisConnectionProperties

The properties of GoldengateAmazonKinesisConnection. Corresponds to the JSON property amazonKinesisConnectionProperties



4444
4445
4446
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4444

def amazon_kinesis_connection_properties
  @amazon_kinesis_connection_properties
end

#amazon_redshift_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonRedshiftConnectionProperties

The properties of GoldengateAmazonRedshiftConnection. Corresponds to the JSON property amazonRedshiftConnectionProperties



4449
4450
4451
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4449

def amazon_redshift_connection_properties
  @amazon_redshift_connection_properties
end

#amazon_s3_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAmazonS3ConnectionProperties

The properties of GoldengateAmazonS3Connection. Corresponds to the JSON property amazonS3ConnectionProperties



4454
4455
4456
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4454

def amazon_s3_connection_properties
  @amazon_s3_connection_properties
end

#azure_data_lake_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAzureDataLakeStorageConnectionProperties

The properties of GoldengateAzureDataLakeStorageConnection. Corresponds to the JSON property azureDataLakeStorageConnectionProperties



4459
4460
4461
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4459

def azure_data_lake_storage_connection_properties
  @azure_data_lake_storage_connection_properties
end

#azure_synapse_analytics_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateAzureSynapseAnalyticsConnectionProperties

The properties of GoldengateAzureSynapseAnalyticsConnection. Corresponds to the JSON property azureSynapseAnalyticsConnectionProperties



4464
4465
4466
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4464

def azure_synapse_analytics_connection_properties
  @azure_synapse_analytics_connection_properties
end

#connection_typeString

Required. The connection type. Corresponds to the JSON property connectionType

Returns:

  • (String)


4469
4470
4471
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4469

def connection_type
  @connection_type
end

#databricks_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties

The properties of GoldengateDatabricksConnection. Corresponds to the JSON property databricksConnectionProperties



4474
4475
4476
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4474

def databricks_connection_properties
  @databricks_connection_properties
end

#db2_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateDb2ConnectionProperties

The properties of GoldengateDb2Connection. Corresponds to the JSON property db2ConnectionProperties



4479
4480
4481
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4479

def db2_connection_properties
  @db2_connection_properties
end

#descriptionString

Optional. Metadata about this specific object. Corresponds to the JSON property description

Returns:

  • (String)


4484
4485
4486
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4484

def description
  @description
end

#display_nameString

Required. An object's Display Name. Corresponds to the JSON property displayName

Returns:

  • (String)


4489
4490
4491
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4489

def display_name
  @display_name
end

#elasticsearch_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties

The properties of GoldengateElasticsearchConnection. Corresponds to the JSON property elasticsearchConnectionProperties



4494
4495
4496
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4494

def elasticsearch_connection_properties
  @elasticsearch_connection_properties
end

#generic_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGenericConnectionProperties

The properties of GoldengateGenericConnectionProperties. Corresponds to the JSON property genericConnectionProperties



4499
4500
4501
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4499

def generic_connection_properties
  @generic_connection_properties
end

#goldengate_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties

The properties of GoldengateGoldengateConnectionProperties. Corresponds to the JSON property goldengateConnectionProperties



4504
4505
4506
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4504

def goldengate_connection_properties
  @goldengate_connection_properties
end

#google_big_query_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoogleBigQueryConnectionProperties

The properties of GoldengateGoogleBigQueryConnectionProperties. Corresponds to the JSON property googleBigQueryConnectionProperties



4509
4510
4511
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4509

def google_big_query_connection_properties
  @google_big_query_connection_properties
end

#google_cloud_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGoogleCloudStorageConnectionProperties

The properties of GoldengateGoogleCloudStorageConnectionProperties. Corresponds to the JSON property googleCloudStorageConnectionProperties



4514
4515
4516
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4514

def google_cloud_storage_connection_properties
  @google_cloud_storage_connection_properties
end

#google_pubsub_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateGooglePubsubConnectionProperties

The properties of GoldengateGooglePubsubConnection. Corresponds to the JSON property googlePubsubConnectionProperties



4519
4520
4521
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4519

def google_pubsub_connection_properties
  @google_pubsub_connection_properties
end

#hdfs_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateHdfsConnectionProperties

The properties of GoldengateHdfsConnection. Corresponds to the JSON property hdfsConnectionProperties



4524
4525
4526
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4524

def hdfs_connection_properties
  @hdfs_connection_properties
end

#iceberg_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateIcebergConnectionProperties

The properties of GoldengateIcebergConnection. Corresponds to the JSON property icebergConnectionProperties



4529
4530
4531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4529

def iceberg_connection_properties
  @iceberg_connection_properties
end

#ingress_ip_addressesArray<String>

Output only. The Ingress IPs of the GoldengateConnection. Corresponds to the JSON property ingressIpAddresses

Returns:

  • (Array<String>)


4534
4535
4536
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4534

def ingress_ip_addresses
  @ingress_ip_addresses
end

#java_message_service_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties

The properties of GoldengateJavaMessageServiceConnection. Corresponds to the JSON property javaMessageServiceConnectionProperties



4539
4540
4541
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4539

def java_message_service_connection_properties
  @java_message_service_connection_properties
end

#kafka_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties

The properties of GoldengateKafkaConnection. Corresponds to the JSON property kafkaConnectionProperties



4544
4545
4546
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4544

def kafka_connection_properties
  @kafka_connection_properties
end

#kafka_schema_registry_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties

The properties of GoldengateKafkaSchemaRegistryConnection. Corresponds to the JSON property kafkaSchemaRegistryConnectionProperties



4549
4550
4551
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4549

def kafka_schema_registry_connection_properties
  @kafka_schema_registry_connection_properties
end

#lifecycle_detailsString

Output only. Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


4555
4556
4557
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4555

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. The lifecycle state of the connection. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


4560
4561
4562
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4560

def lifecycle_state
  @lifecycle_state
end

#microsoft_fabric_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMicrosoftFabricConnectionProperties

The properties of GoldengateMicrosoftFabricConnection. Corresponds to the JSON property microsoftFabricConnectionProperties



4565
4566
4567
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4565

def microsoft_fabric_connection_properties
  @microsoft_fabric_connection_properties
end

#microsoft_sqlserver_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties

The properties of GoldengateMicrosoftSqlserverConnection. Corresponds to the JSON property microsoftSqlserverConnectionProperties



4570
4571
4572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4570

def microsoft_sqlserver_connection_properties
  @microsoft_sqlserver_connection_properties
end

#mongodb_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

The properties of GoldengateMongodbConnection. Corresponds to the JSON property mongodbConnectionProperties



4575
4576
4577
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4575

def mongodb_connection_properties
  @mongodb_connection_properties
end

#mysql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties

Properties of GoldengateMysqlConnection. Corresponds to the JSON property mysqlConnectionProperties



4580
4581
4582
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4580

def mysql_connection_properties
  @mysql_connection_properties
end

#oci_object_storage_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties

The properties of GoldengateOciObjectStorageConnection. Corresponds to the JSON property ociObjectStorageConnectionProperties



4585
4586
4587
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4585

def oci_object_storage_connection_properties
  @oci_object_storage_connection_properties
end

#ocidString

Output only. The [OCID] of the connection being referenced. Corresponds to the JSON property ocid

Returns:

  • (String)


4590
4591
4592
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4590

def ocid
  @ocid
end

#oracle_ai_data_platform_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties

The properties of GoldengateOracleAIDataPlatformConnection. Corresponds to the JSON property oracleAiDataPlatformConnectionProperties



4595
4596
4597
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4595

def oracle_ai_data_platform_connection_properties
  @oracle_ai_data_platform_connection_properties
end

#oracle_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties

The properties of Goldengate Oracle Database Connection. Corresponds to the JSON property oracleConnectionProperties



4600
4601
4602
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4600

def oracle_connection_properties
  @oracle_connection_properties
end

#oracle_nosql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties

The properties of GoldengateOracleNosqlConnection. Corresponds to the JSON property oracleNosqlConnectionProperties



4605
4606
4607
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4605

def oracle_nosql_connection_properties
  @oracle_nosql_connection_properties
end

#postgresql_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties

The properties of GoldengatePostgresqlConnection. Corresponds to the JSON property postgresqlConnectionProperties



4610
4611
4612
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4610

def postgresql_connection_properties
  @postgresql_connection_properties
end

#redis_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties

The properties of GoldengateRedisConnection. Corresponds to the JSON property redisConnectionProperties



4615
4616
4617
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4615

def redis_connection_properties
  @redis_connection_properties
end

#routing_methodString

Optional. The routing method for the GoldengateConnection. Corresponds to the JSON property routingMethod

Returns:

  • (String)


4620
4621
4622
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4620

def routing_method
  @routing_method
end

#snowflake_connection_propertiesGoogle::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties

The properties of GoldengateSnowflakeConnection. Corresponds to the JSON property snowflakeConnectionProperties



4625
4626
4627
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4625

def snowflake_connection_properties
  @snowflake_connection_properties
end

#update_timeString

Output only. The time the resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4630
4631
4632
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4630

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4637
4638
4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
4649
4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4637

def update!(**args)
  @amazon_kinesis_connection_properties = args[:amazon_kinesis_connection_properties] if args.key?(:amazon_kinesis_connection_properties)
  @amazon_redshift_connection_properties = args[:amazon_redshift_connection_properties] if args.key?(:amazon_redshift_connection_properties)
  @amazon_s3_connection_properties = args[:amazon_s3_connection_properties] if args.key?(:amazon_s3_connection_properties)
  @azure_data_lake_storage_connection_properties = args[:azure_data_lake_storage_connection_properties] if args.key?(:azure_data_lake_storage_connection_properties)
  @azure_synapse_analytics_connection_properties = args[:azure_synapse_analytics_connection_properties] if args.key?(:azure_synapse_analytics_connection_properties)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @databricks_connection_properties = args[:databricks_connection_properties] if args.key?(:databricks_connection_properties)
  @db2_connection_properties = args[:db2_connection_properties] if args.key?(:db2_connection_properties)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @elasticsearch_connection_properties = args[:elasticsearch_connection_properties] if args.key?(:elasticsearch_connection_properties)
  @generic_connection_properties = args[:generic_connection_properties] if args.key?(:generic_connection_properties)
  @goldengate_connection_properties = args[:goldengate_connection_properties] if args.key?(:goldengate_connection_properties)
  @google_big_query_connection_properties = args[:google_big_query_connection_properties] if args.key?(:google_big_query_connection_properties)
  @google_cloud_storage_connection_properties = args[:google_cloud_storage_connection_properties] if args.key?(:google_cloud_storage_connection_properties)
  @google_pubsub_connection_properties = args[:google_pubsub_connection_properties] if args.key?(:google_pubsub_connection_properties)
  @hdfs_connection_properties = args[:hdfs_connection_properties] if args.key?(:hdfs_connection_properties)
  @iceberg_connection_properties = args[:iceberg_connection_properties] if args.key?(:iceberg_connection_properties)
  @ingress_ip_addresses = args[:ingress_ip_addresses] if args.key?(:ingress_ip_addresses)
  @java_message_service_connection_properties = args[:java_message_service_connection_properties] if args.key?(:java_message_service_connection_properties)
  @kafka_connection_properties = args[:kafka_connection_properties] if args.key?(:kafka_connection_properties)
  @kafka_schema_registry_connection_properties = args[:kafka_schema_registry_connection_properties] if args.key?(:kafka_schema_registry_connection_properties)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @microsoft_fabric_connection_properties = args[:microsoft_fabric_connection_properties] if args.key?(:microsoft_fabric_connection_properties)
  @microsoft_sqlserver_connection_properties = args[:microsoft_sqlserver_connection_properties] if args.key?(:microsoft_sqlserver_connection_properties)
  @mongodb_connection_properties = args[:mongodb_connection_properties] if args.key?(:mongodb_connection_properties)
  @mysql_connection_properties = args[:mysql_connection_properties] if args.key?(:mysql_connection_properties)
  @oci_object_storage_connection_properties = args[:oci_object_storage_connection_properties] if args.key?(:oci_object_storage_connection_properties)
  @ocid = args[:ocid] if args.key?(:ocid)
  @oracle_ai_data_platform_connection_properties = args[:oracle_ai_data_platform_connection_properties] if args.key?(:oracle_ai_data_platform_connection_properties)
  @oracle_connection_properties = args[:oracle_connection_properties] if args.key?(:oracle_connection_properties)
  @oracle_nosql_connection_properties = args[:oracle_nosql_connection_properties] if args.key?(:oracle_nosql_connection_properties)
  @postgresql_connection_properties = args[:postgresql_connection_properties] if args.key?(:postgresql_connection_properties)
  @redis_connection_properties = args[:redis_connection_properties] if args.key?(:redis_connection_properties)
  @routing_method = args[:routing_method] if args.key?(:routing_method)
  @snowflake_connection_properties = args[:snowflake_connection_properties] if args.key?(:snowflake_connection_properties)
  @update_time = args[:update_time] if args.key?(:update_time)
end