Class: Google::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateDatabricksConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#client_id ⇒ String
Optional.
-
#client_secret ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#storage_credential ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDatabricksConnectionProperties
constructor
A new instance of GoldengateDatabricksConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDatabricksConnectionProperties
Returns a new instance of GoldengateDatabricksConnectionProperties.
4679 4680 4681 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Databricks.
Corresponds to the JSON property authenticationType
4635 4636 4637 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4635 def authentication_type @authentication_type end |
#client_id ⇒ String
Optional. OAuth client id, only applicable for authentication_type ==
OAUTH_M2M
Corresponds to the JSON property clientId
4641 4642 4643 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4641 def client_id @client_id end |
#client_secret ⇒ String
Optional. OAuth client secret, only applicable for authentication_type ==
OAUTH_M2M
Corresponds to the JSON property clientSecret
4647 4648 4649 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4647 def client_secret @client_secret end |
#connection_url ⇒ String
Optional. Connection URL. e.g.: 'jdbc:databricks://adb-33934.4.azuredatabricks.
net:443/default;transportMode=http;ssl=1;httpPath=sql/protocolv1/o/3393########
44/0##3-7-hlrb'
Corresponds to the JSON property connectionUrl
4654 4655 4656 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4654 def connection_url @connection_url end |
#password ⇒ String
Optional. Input only. The password used to connect to Databricks in plain text.
Corresponds to the JSON property password
4659 4660 4661 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4659 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password used to connect to Databricks. Format: projects/
project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
4666 4667 4668 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4666 def password_secret_version @password_secret_version end |
#storage_credential ⇒ String
Optional. External storage credential name to access files on object storage
such as ADLS Gen2, S3 or Cloud Storage.
Corresponds to the JSON property storageCredential
4672 4673 4674 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4672 def storage_credential @storage_credential end |
#technology_type ⇒ String
Optional. The technology type of DatabricksConnection.
Corresponds to the JSON property technologyType
4677 4678 4679 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4677 def technology_type @technology_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4684 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @connection_url = args[:connection_url] if args.key?(:connection_url) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @storage_credential = args[:storage_credential] if args.key?(:storage_credential) @technology_type = args[:technology_type] if args.key?(:technology_type) end |