Class: Google::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateDatabricksConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDatabricksConnectionProperties

Returns a new instance of GoldengateDatabricksConnectionProperties.



4601
4602
4603
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Authentication type for Databricks. Corresponds to the JSON property authenticationType

Returns:

  • (String)


4557
4558
4559
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4557

def authentication_type
  @authentication_type
end

#client_idString

Optional. OAuth client id, only applicable for authentication_type == OAUTH_M2M Corresponds to the JSON property clientId

Returns:

  • (String)


4563
4564
4565
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4563

def client_id
  @client_id
end

#client_secretString

Optional. OAuth client secret, only applicable for authentication_type == OAUTH_M2M Corresponds to the JSON property clientSecret

Returns:

  • (String)


4569
4570
4571
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4569

def client_secret
  @client_secret
end

#connection_urlString

Optional. Connection URL. e.g.: 'jdbc:databricks://adb-33934.4.azuredatabricks. net:443/default;transportMode=http;ssl=1;httpPath=sql/protocolv1/o/3393######## 44/0##3-7-hlrb' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


4576
4577
4578
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4576

def connection_url
  @connection_url
end

#passwordString

Optional. Input only. The password used to connect to Databricks in plain text. Corresponds to the JSON property password

Returns:

  • (String)


4581
4582
4583
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4581

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password used to connect to Databricks. Format: projects/ project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


4588
4589
4590
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4588

def password_secret_version
  @password_secret_version
end

#storage_credentialString

Optional. External storage credential name to access files on object storage such as ADLS Gen2, S3 or Cloud Storage. Corresponds to the JSON property storageCredential

Returns:

  • (String)


4594
4595
4596
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4594

def storage_credential
  @storage_credential
end

#technology_typeString

Optional. The technology type of DatabricksConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4599

def technology_type
  @technology_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4606

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @storage_credential = args[:storage_credential] if args.key?(:storage_credential)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
end