Class: Google::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDatabricksConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateDatabricksConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#client_id ⇒ String
Optional.
-
#client_secret ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#storage_credential ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDatabricksConnectionProperties
constructor
A new instance of GoldengateDatabricksConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDatabricksConnectionProperties
Returns a new instance of GoldengateDatabricksConnectionProperties.
4601 4602 4603 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Databricks.
Corresponds to the JSON property authenticationType
4557 4558 4559 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4557 def authentication_type @authentication_type end |
#client_id ⇒ String
Optional. OAuth client id, only applicable for authentication_type ==
OAUTH_M2M
Corresponds to the JSON property clientId
4563 4564 4565 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4563 def client_id @client_id end |
#client_secret ⇒ String
Optional. OAuth client secret, only applicable for authentication_type ==
OAUTH_M2M
Corresponds to the JSON property clientSecret
4569 4570 4571 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4569 def client_secret @client_secret end |
#connection_url ⇒ String
Optional. Connection URL. e.g.: 'jdbc:databricks://adb-33934.4.azuredatabricks.
net:443/default;transportMode=http;ssl=1;httpPath=sql/protocolv1/o/3393########
44/0##3-7-hlrb'
Corresponds to the JSON property connectionUrl
4576 4577 4578 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4576 def connection_url @connection_url end |
#password ⇒ String
Optional. Input only. The password used to connect to Databricks in plain text.
Corresponds to the JSON property password
4581 4582 4583 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4581 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password used to connect to Databricks. Format: projects/
project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
4588 4589 4590 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4588 def password_secret_version @password_secret_version end |
#storage_credential ⇒ String
Optional. External storage credential name to access files on object storage
such as ADLS Gen2, S3 or Cloud Storage.
Corresponds to the JSON property storageCredential
4594 4595 4596 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4594 def storage_credential @storage_credential end |
#technology_type ⇒ String
Optional. The technology type of DatabricksConnection.
Corresponds to the JSON property technologyType
4599 4600 4601 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4599 def technology_type @technology_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4606 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @connection_url = args[:connection_url] if args.key?(:connection_url) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @storage_credential = args[:storage_credential] if args.key?(:storage_credential) @technology_type = args[:technology_type] if args.key?(:technology_type) end |