Class: Google::Apis::OracledatabaseV1::GoldengateDb2ConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDb2ConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateDb2Connection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_client_keystash_file ⇒ String
Optional.
-
#ssl_client_keystoredb_file ⇒ String
Optional.
-
#ssl_server_certificate_file ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDb2ConnectionProperties
constructor
A new instance of GoldengateDb2ConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDb2ConnectionProperties
Returns a new instance of GoldengateDb2ConnectionProperties.
4820 4821 4822 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
4757 4758 4759 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4757 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
4762 4763 4764 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4762 def database @database end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
4767 4768 4769 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4767 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Db2 connection
in plain text.
Corresponds to the JSON property password
4773 4774 4775 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4773 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Db2 connection. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
4780 4781 4782 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4780 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
4785 4786 4787 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4785 def port @port end |
#security_protocol ⇒ String
Optional. Security protocol for the DB2 database.
Corresponds to the JSON property securityProtocol
4790 4791 4792 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4790 def security_protocol @security_protocol end |
#ssl_client_keystash_file ⇒ String
Optional. The keystash file which contains the encrypted password to the key
database file. Not supported for IBM Db2 for i.
Corresponds to the JSON property sslClientKeystashFile
4796 4797 4798 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4796 def ssl_client_keystash_file @ssl_client_keystash_file end |
#ssl_client_keystoredb_file ⇒ String
Optional. The keystore file created at the client containing the server
certificate / CA root certificate. Not supported for IBM Db2 for i.
Corresponds to the JSON property sslClientKeystoredbFile
4802 4803 4804 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4802 def ssl_client_keystoredb_file @ssl_client_keystoredb_file end |
#ssl_server_certificate_file ⇒ String
Optional. The file which contains the self-signed server certificate /
Certificate Authority (CA) certificate.
Corresponds to the JSON property sslServerCertificateFile
4808 4809 4810 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4808 def ssl_server_certificate_file @ssl_server_certificate_file end |
#technology_type ⇒ String
Optional. The technology type of Db2Connection.
Corresponds to the JSON property technologyType
4813 4814 4815 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4813 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the DB2 database.
Corresponds to the JSON property username
4818 4819 4820 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4818 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4825 4826 4827 4828 4829 4830 4831 4832 4833 4834 4835 4836 4837 4838 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4825 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_client_keystash_file = args[:ssl_client_keystash_file] if args.key?(:ssl_client_keystash_file) @ssl_client_keystoredb_file = args[:ssl_client_keystoredb_file] if args.key?(:ssl_client_keystoredb_file) @ssl_server_certificate_file = args[:ssl_server_certificate_file] if args.key?(:ssl_server_certificate_file) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |