Class: Google::Apis::OracledatabaseV1::GoldengateDb2ConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateDb2Connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDb2ConnectionProperties

Returns a new instance of GoldengateDb2ConnectionProperties.



4689
4690
4691
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



4626
4627
4628
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4626

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


4631
4632
4633
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4631

def database
  @database
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


4636
4637
4638
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4636

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Db2 connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


4642
4643
4644
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4642

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Db2 connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


4649
4650
4651
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4649

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


4654
4655
4656
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4654

def port
  @port
end

#security_protocolString

Optional. Security protocol for the DB2 database. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


4659
4660
4661
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4659

def security_protocol
  @security_protocol
end

#ssl_client_keystash_fileString

Optional. The keystash file which contains the encrypted password to the key database file. Not supported for IBM Db2 for i. Corresponds to the JSON property sslClientKeystashFile

Returns:

  • (String)


4665
4666
4667
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4665

def ssl_client_keystash_file
  @ssl_client_keystash_file
end

#ssl_client_keystoredb_fileString

Optional. The keystore file created at the client containing the server certificate / CA root certificate. Not supported for IBM Db2 for i. Corresponds to the JSON property sslClientKeystoredbFile

Returns:

  • (String)


4671
4672
4673
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4671

def ssl_client_keystoredb_file
  @ssl_client_keystoredb_file
end

#ssl_server_certificate_fileString

Optional. The file which contains the self-signed server certificate / Certificate Authority (CA) certificate. Corresponds to the JSON property sslServerCertificateFile

Returns:

  • (String)


4677
4678
4679
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4677

def ssl_server_certificate_file
  @ssl_server_certificate_file
end

#technology_typeString

Optional. The technology type of Db2Connection. Corresponds to the JSON property technologyType

Returns:

  • (String)


4682
4683
4684
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4682

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the DB2 database. Corresponds to the JSON property username

Returns:

  • (String)


4687
4688
4689
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4687

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4694

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_client_keystash_file = args[:ssl_client_keystash_file] if args.key?(:ssl_client_keystash_file)
  @ssl_client_keystoredb_file = args[:ssl_client_keystoredb_file] if args.key?(:ssl_client_keystoredb_file)
  @ssl_server_certificate_file = args[:ssl_server_certificate_file] if args.key?(:ssl_server_certificate_file)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end