Class: Google::Apis::OracledatabaseV1::GoldengateDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

GoldengateDeployment Goldengate Deployment resource model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeployment

Returns a new instance of GoldengateDeployment.



4848
4849
4850
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the GoldengateDeployment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4795
4796
4797
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4795

def create_time
  @create_time
end

#display_nameString

Required. The display name for the GoldengateDeployment. Corresponds to the JSON property displayName

Returns:

  • (String)


4800
4801
4802
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4800

def display_name
  @display_name
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the GoldengateDeployment Corresponds to the JSON property entitlementId

Returns:

  • (String)


4806
4807
4808
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4806

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where Oracle GoldengateDeployment is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


4813
4814
4815
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4813

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. The labels or tags associated with the GoldengateDeployment. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4818
4819
4820
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4818

def labels
  @labels
end

#nameString

Identifier. The name of the GoldengateDeployment resource in the following format: projects/project/locations/region/goldengateDeployments/ goldengate_deployment Corresponds to the JSON property name

Returns:

  • (String)


4825
4826
4827
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4825

def name
  @name
end

#oci_urlString

Output only. HTTPS link to OCI resources exposed to Customer via UI Interface. Corresponds to the JSON property ociUrl

Returns:

  • (String)


4830
4831
4832
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4830

def oci_url
  @oci_url
end

#odb_networkString

Optional. The name of the OdbNetwork associated with the GoldengateDeployment. Corresponds to the JSON property odbNetwork

Returns:

  • (String)


4835
4836
4837
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4835

def odb_network
  @odb_network
end

#odb_subnetString

Required. The name of the OdbSubnet associated with the GoldengateDeployment for IP allocation. Corresponds to the JSON property odbSubnet

Returns:

  • (String)


4841
4842
4843
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4841

def odb_subnet
  @odb_subnet
end

#propertiesGoogle::Apis::OracledatabaseV1::GoldengateDeploymentProperties

Properties of GoldengateDeployment. Corresponds to the JSON property properties



4846
4847
4848
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4846

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4853

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @oci_url = args[:oci_url] if args.key?(:oci_url)
  @odb_network = args[:odb_network] if args.key?(:odb_network)
  @odb_subnet = args[:odb_subnet] if args.key?(:odb_subnet)
  @properties = args[:properties] if args.key?(:properties)
end