Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the Goldengate Deployment Environment resource.
Instance Attribute Summary collapse
-
#auto_scaling_enabled ⇒ Boolean
(also: #auto_scaling_enabled?)
Output only.
-
#category ⇒ String
Output only.
-
#default_cpu_core_count ⇒ Fixnum
Output only.
-
#display_name ⇒ String
The display name of the Goldengate Deployment Environment resource.
-
#environment_type ⇒ String
Output only.
-
#max_cpu_core_count ⇒ Fixnum
Output only.
-
#memory_gb_per_cpu_core ⇒ Fixnum
Output only.
-
#min_cpu_core_count ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#network_bandwidth_gbps_per_cpu_core ⇒ Fixnum
Output only.
-
#storage_usage_limit_gb_per_cpu_core ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentEnvironment
constructor
A new instance of GoldengateDeploymentEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentEnvironment
Returns a new instance of GoldengateDeploymentEnvironment.
4937 4938 4939 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_scaling_enabled ⇒ Boolean Also known as: auto_scaling_enabled?
Output only. Whether auto scaling is enabled by default for the Goldengate
Deployment Environment resource.
Corresponds to the JSON property autoScalingEnabled
4875 4876 4877 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4875 def auto_scaling_enabled @auto_scaling_enabled end |
#category ⇒ String
Output only. The category of the Goldengate Deployment Environment resource.
Corresponds to the JSON property category
4881 4882 4883 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4881 def category @category end |
#default_cpu_core_count ⇒ Fixnum
Output only. The default CPU core count of the Goldengate Deployment
Environment resource.
Corresponds to the JSON property defaultCpuCoreCount
4887 4888 4889 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4887 def default_cpu_core_count @default_cpu_core_count end |
#display_name ⇒ String
The display name of the Goldengate Deployment Environment resource.
Corresponds to the JSON property displayName
4892 4893 4894 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4892 def display_name @display_name end |
#environment_type ⇒ String
Output only. The environment type of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property environmentType
4898 4899 4900 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4898 def environment_type @environment_type end |
#max_cpu_core_count ⇒ Fixnum
Output only. The max CPU core count of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property maxCpuCoreCount
4904 4905 4906 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4904 def max_cpu_core_count @max_cpu_core_count end |
#memory_gb_per_cpu_core ⇒ Fixnum
Output only. The memory per CPU core in GBs of the Goldengate Deployment
Environment resource.
Corresponds to the JSON property memoryGbPerCpuCore
4910 4911 4912 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4910 def memory_gb_per_cpu_core @memory_gb_per_cpu_core end |
#min_cpu_core_count ⇒ Fixnum
Output only. The min CPU core count of the Goldengate Deployment Environment
resource.
Corresponds to the JSON property minCpuCoreCount
4916 4917 4918 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4916 def min_cpu_core_count @min_cpu_core_count end |
#name ⇒ String
Identifier. The name of the Goldengate Deployment Environment resource with
the format: projects/project/locations/location/
goldengateDeploymentEnvironments/goldengate_deployment_environment
Corresponds to the JSON property name
4923 4924 4925 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4923 def name @name end |
#network_bandwidth_gbps_per_cpu_core ⇒ Fixnum
Output only. The network bandwidth per CPU core in Gbps of the Goldengate
Deployment Environment resource.
Corresponds to the JSON property networkBandwidthGbpsPerCpuCore
4929 4930 4931 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4929 def network_bandwidth_gbps_per_cpu_core @network_bandwidth_gbps_per_cpu_core end |
#storage_usage_limit_gb_per_cpu_core ⇒ Fixnum
Output only. The storage usage limit per CPU core in GBs of the Goldengate
Deployment Environment resource.
Corresponds to the JSON property storageUsageLimitGbPerCpuCore
4935 4936 4937 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4935 def storage_usage_limit_gb_per_cpu_core @storage_usage_limit_gb_per_cpu_core end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4942 def update!(**args) @auto_scaling_enabled = args[:auto_scaling_enabled] if args.key?(:auto_scaling_enabled) @category = args[:category] if args.key?(:category) @default_cpu_core_count = args[:default_cpu_core_count] if args.key?(:default_cpu_core_count) @display_name = args[:display_name] if args.key?(:display_name) @environment_type = args[:environment_type] if args.key?(:environment_type) @max_cpu_core_count = args[:max_cpu_core_count] if args.key?(:max_cpu_core_count) @memory_gb_per_cpu_core = args[:memory_gb_per_cpu_core] if args.key?(:memory_gb_per_cpu_core) @min_cpu_core_count = args[:min_cpu_core_count] if args.key?(:min_cpu_core_count) @name = args[:name] if args.key?(:name) @network_bandwidth_gbps_per_cpu_core = args[:network_bandwidth_gbps_per_cpu_core] if args.key?(:network_bandwidth_gbps_per_cpu_core) @storage_usage_limit_gb_per_cpu_core = args[:storage_usage_limit_gb_per_cpu_core] if args.key?(:storage_usage_limit_gb_per_cpu_core) end |