Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Goldengate Deployment Environment resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeploymentEnvironment

Returns a new instance of GoldengateDeploymentEnvironment.



4859
4860
4861
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_scaling_enabledBoolean Also known as: auto_scaling_enabled?

Output only. Whether auto scaling is enabled by default for the Goldengate Deployment Environment resource. Corresponds to the JSON property autoScalingEnabled

Returns:

  • (Boolean)


4797
4798
4799
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4797

def auto_scaling_enabled
  @auto_scaling_enabled
end

#categoryString

Output only. The category of the Goldengate Deployment Environment resource. Corresponds to the JSON property category

Returns:

  • (String)


4803
4804
4805
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4803

def category
  @category
end

#default_cpu_core_countFixnum

Output only. The default CPU core count of the Goldengate Deployment Environment resource. Corresponds to the JSON property defaultCpuCoreCount

Returns:

  • (Fixnum)


4809
4810
4811
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4809

def default_cpu_core_count
  @default_cpu_core_count
end

#display_nameString

The display name of the Goldengate Deployment Environment resource. Corresponds to the JSON property displayName

Returns:

  • (String)


4814
4815
4816
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4814

def display_name
  @display_name
end

#environment_typeString

Output only. The environment type of the Goldengate Deployment Environment resource. Corresponds to the JSON property environmentType

Returns:

  • (String)


4820
4821
4822
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4820

def environment_type
  @environment_type
end

#max_cpu_core_countFixnum

Output only. The max CPU core count of the Goldengate Deployment Environment resource. Corresponds to the JSON property maxCpuCoreCount

Returns:

  • (Fixnum)


4826
4827
4828
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4826

def max_cpu_core_count
  @max_cpu_core_count
end

#memory_gb_per_cpu_coreFixnum

Output only. The memory per CPU core in GBs of the Goldengate Deployment Environment resource. Corresponds to the JSON property memoryGbPerCpuCore

Returns:

  • (Fixnum)


4832
4833
4834
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4832

def memory_gb_per_cpu_core
  @memory_gb_per_cpu_core
end

#min_cpu_core_countFixnum

Output only. The min CPU core count of the Goldengate Deployment Environment resource. Corresponds to the JSON property minCpuCoreCount

Returns:

  • (Fixnum)


4838
4839
4840
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4838

def min_cpu_core_count
  @min_cpu_core_count
end

#nameString

Identifier. The name of the Goldengate Deployment Environment resource with the format: projects/project/locations/location/ goldengateDeploymentEnvironments/goldengate_deployment_environment Corresponds to the JSON property name

Returns:

  • (String)


4845
4846
4847
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4845

def name
  @name
end

#network_bandwidth_gbps_per_cpu_coreFixnum

Output only. The network bandwidth per CPU core in Gbps of the Goldengate Deployment Environment resource. Corresponds to the JSON property networkBandwidthGbpsPerCpuCore

Returns:

  • (Fixnum)


4851
4852
4853
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4851

def network_bandwidth_gbps_per_cpu_core
  @network_bandwidth_gbps_per_cpu_core
end

#storage_usage_limit_gb_per_cpu_coreFixnum

Output only. The storage usage limit per CPU core in GBs of the Goldengate Deployment Environment resource. Corresponds to the JSON property storageUsageLimitGbPerCpuCore

Returns:

  • (Fixnum)


4857
4858
4859
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4857

def storage_usage_limit_gb_per_cpu_core
  @storage_usage_limit_gb_per_cpu_core
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4864

def update!(**args)
  @auto_scaling_enabled = args[:auto_scaling_enabled] if args.key?(:auto_scaling_enabled)
  @category = args[:category] if args.key?(:category)
  @default_cpu_core_count = args[:default_cpu_core_count] if args.key?(:default_cpu_core_count)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environment_type = args[:environment_type] if args.key?(:environment_type)
  @max_cpu_core_count = args[:max_cpu_core_count] if args.key?(:max_cpu_core_count)
  @memory_gb_per_cpu_core = args[:memory_gb_per_cpu_core] if args.key?(:memory_gb_per_cpu_core)
  @min_cpu_core_count = args[:min_cpu_core_count] if args.key?(:min_cpu_core_count)
  @name = args[:name] if args.key?(:name)
  @network_bandwidth_gbps_per_cpu_core = args[:network_bandwidth_gbps_per_cpu_core] if args.key?(:network_bandwidth_gbps_per_cpu_core)
  @storage_usage_limit_gb_per_cpu_core = args[:storage_usage_limit_gb_per_cpu_core] if args.key?(:storage_usage_limit_gb_per_cpu_core)
end