Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Properties of GoldengateDeployment.
Instance Attribute Summary collapse
-
#backup_schedule ⇒ Google::Apis::OracledatabaseV1::GoldengateBackupSchedule
The backup schedule of the GoldengateDeployment.
-
#category ⇒ String
Output only.
-
#cpu_core_count ⇒ Fixnum
Optional.
-
#deployment_backup_id ⇒ String
Output only.
-
#deployment_diagnostic_data ⇒ Google::Apis::OracledatabaseV1::DeploymentDiagnosticData
The deployment diagnostic data.
-
#deployment_role ⇒ String
Output only.
-
#deployment_type ⇒ String
Required.
-
#deployment_url ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#environment_type ⇒ String
Optional.
-
#fqdn ⇒ String
Output only.
-
#healthy ⇒ Boolean
(also: #healthy?)
Output only.
-
#ingress_ips ⇒ Array<Google::Apis::OracledatabaseV1::IngressIp>
Output only.
-
#is_auto_scaling_enabled ⇒ Boolean
(also: #is_auto_scaling_enabled?)
Optional.
-
#is_latest_version ⇒ Boolean
(also: #is_latest_version?)
Output only.
-
#is_public ⇒ Boolean
(also: #is_public?)
Output only.
-
#is_storage_utilization_limit_exceeded ⇒ Boolean
(also: #is_storage_utilization_limit_exceeded?)
Output only.
-
#last_backup_schedule_time ⇒ String
Output only.
-
#license_model ⇒ String
Optional.
-
#lifecycle_details ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#lifecycle_sub_state ⇒ String
Output only.
-
#load_balancer_id ⇒ String
Output only.
-
#load_balancer_subnet_id ⇒ String
Output only.
-
#locks ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeploymentLock>
Output only.
-
#maintenance_config ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceConfig
The maintenance configuration of the GoldengateDeployment.
-
#maintenance_window ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceWindow
The maintenance window of the GoldengateDeployment.
-
#next_backup_schedule_time ⇒ String
Output only.
-
#next_maintenance_action_type ⇒ String
Output only.
-
#next_maintenance_description ⇒ String
Output only.
-
#next_maintenance_time ⇒ String
Output only.
-
#nsg_ids ⇒ Array<String>
Output only.
-
#ocid ⇒ String
Output only.
-
#ogg_data ⇒ Google::Apis::OracledatabaseV1::GoldengateOggDeployment
The Ogg data of the GoldengateDeployment.
-
#ogg_version_support_end_time ⇒ String
Output only.
-
#placements ⇒ Array<Google::Apis::OracledatabaseV1::GoldengatePlacement>
Output only.
-
#private_ip_address ⇒ String
Output only.
-
#public_ip_address ⇒ String
Output only.
-
#role_change_time ⇒ String
Output only.
-
#storage_utilization_bytes ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#upgrade_required_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentProperties
constructor
A new instance of GoldengateDeploymentProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentProperties
Returns a new instance of GoldengateDeploymentProperties.
5338 5339 5340 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_schedule ⇒ Google::Apis::OracledatabaseV1::GoldengateBackupSchedule
The backup schedule of the GoldengateDeployment.
Corresponds to the JSON property backupSchedule
5123 5124 5125 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5123 def backup_schedule @backup_schedule end |
#category ⇒ String
Output only. The category of the GoldengateDeployment.
Corresponds to the JSON property category
5128 5129 5130 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5128 def category @category end |
#cpu_core_count ⇒ Fixnum
Optional. The Minimum number of OCPUs to be made available for this Deployment.
Corresponds to the JSON property cpuCoreCount
5133 5134 5135 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5133 def cpu_core_count @cpu_core_count end |
#deployment_backup_id ⇒ String
Output only. The deployment backup id of the GoldengateDeployment.
Corresponds to the JSON property deploymentBackupId
5138 5139 5140 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5138 def deployment_backup_id @deployment_backup_id end |
#deployment_diagnostic_data ⇒ Google::Apis::OracledatabaseV1::DeploymentDiagnosticData
The deployment diagnostic data.
Corresponds to the JSON property deploymentDiagnosticData
5143 5144 5145 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5143 def deployment_diagnostic_data @deployment_diagnostic_data end |
#deployment_role ⇒ String
Output only. The deployment role of the GoldengateDeployment.
Corresponds to the JSON property deploymentRole
5148 5149 5150 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5148 def deployment_role @deployment_role end |
#deployment_type ⇒ String
Required. A valid Goldengate Deployment type. For a list of supported types,
use the ListGoldengateDeploymentTypes operation.
Corresponds to the JSON property deploymentType
5154 5155 5156 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5154 def deployment_type @deployment_type end |
#deployment_url ⇒ String
Output only. The deployment url of the GoldengateDeployment.
Corresponds to the JSON property deploymentUrl
5159 5160 5161 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5159 def deployment_url @deployment_url end |
#description ⇒ String
Optional. The description of the GoldengateDeployment.
Corresponds to the JSON property description
5164 5165 5166 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5164 def description @description end |
#environment_type ⇒ String
Optional. The environment type of the GoldengateDeployment.
Corresponds to the JSON property environmentType
5169 5170 5171 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5169 def environment_type @environment_type end |
#fqdn ⇒ String
Output only. The Fully Qualified Domain Name of the GoldengateDeployment.
Corresponds to the JSON property fqdn
5174 5175 5176 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5174 def fqdn @fqdn end |
#healthy ⇒ Boolean Also known as: healthy?
Output only. Whether the GoldengateDeployment is healthy.
Corresponds to the JSON property healthy
5179 5180 5181 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5179 def healthy @healthy end |
#ingress_ips ⇒ Array<Google::Apis::OracledatabaseV1::IngressIp>
Output only. The ingress ips of the GoldengateDeployment.
Corresponds to the JSON property ingressIps
5185 5186 5187 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5185 def ingress_ips @ingress_ips end |
#is_auto_scaling_enabled ⇒ Boolean Also known as: is_auto_scaling_enabled?
Optional. Indicates if auto scaling is enabled for the Deployment's CPU core
count.
Corresponds to the JSON property isAutoScalingEnabled
5191 5192 5193 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5191 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_latest_version ⇒ Boolean Also known as: is_latest_version?
Output only. Whether the GoldengateDeployment is of the latest version.
Corresponds to the JSON property isLatestVersion
5197 5198 5199 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5197 def is_latest_version @is_latest_version end |
#is_public ⇒ Boolean Also known as: is_public?
Output only. Whether the GoldengateDeployment is public.
Corresponds to the JSON property isPublic
5203 5204 5205 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5203 def is_public @is_public end |
#is_storage_utilization_limit_exceeded ⇒ Boolean Also known as: is_storage_utilization_limit_exceeded?
Output only. Whether storage utilization limit is exceeded of the
GoldengateDeployment.
Corresponds to the JSON property isStorageUtilizationLimitExceeded
5210 5211 5212 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5210 def is_storage_utilization_limit_exceeded @is_storage_utilization_limit_exceeded end |
#last_backup_schedule_time ⇒ String
Output only. The time last backup scheduled of the GoldengateDeployment.
Corresponds to the JSON property lastBackupScheduleTime
5216 5217 5218 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5216 def last_backup_schedule_time @last_backup_schedule_time end |
#license_model ⇒ String
Optional. The Oracle license model that applies to a Deployment.
Corresponds to the JSON property licenseModel
5221 5222 5223 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5221 def license_model @license_model end |
#lifecycle_details ⇒ String
Output only. The lifecycle details of the GoldengateDeployment.
Corresponds to the JSON property lifecycleDetails
5226 5227 5228 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5226 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Output only. State of the GoldengateDeployment.
Corresponds to the JSON property lifecycleState
5231 5232 5233 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5231 def lifecycle_state @lifecycle_state end |
#lifecycle_sub_state ⇒ String
Output only. The lifecycle sub-state of the GoldengateDeployment.
Corresponds to the JSON property lifecycleSubState
5236 5237 5238 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5236 def lifecycle_sub_state @lifecycle_sub_state end |
#load_balancer_id ⇒ String
Output only. The load balancer id of the GoldengateDeployment.
Corresponds to the JSON property loadBalancerId
5241 5242 5243 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5241 def load_balancer_id @load_balancer_id end |
#load_balancer_subnet_id ⇒ String
Output only. The load balancer subnet id of the GoldengateDeployment.
Corresponds to the JSON property loadBalancerSubnetId
5246 5247 5248 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5246 def load_balancer_subnet_id @load_balancer_subnet_id end |
#locks ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeploymentLock>
Output only. The locks of the GoldengateDeployment.
Corresponds to the JSON property locks
5251 5252 5253 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5251 def locks @locks end |
#maintenance_config ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceConfig
The maintenance configuration of the GoldengateDeployment.
Corresponds to the JSON property maintenanceConfig
5256 5257 5258 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5256 def maintenance_config @maintenance_config end |
#maintenance_window ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceWindow
The maintenance window of the GoldengateDeployment.
Corresponds to the JSON property maintenanceWindow
5261 5262 5263 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5261 def maintenance_window @maintenance_window end |
#next_backup_schedule_time ⇒ String
Output only. The time next backup scheduled of the GoldengateDeployment.
Corresponds to the JSON property nextBackupScheduleTime
5266 5267 5268 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5266 def next_backup_schedule_time @next_backup_schedule_time end |
#next_maintenance_action_type ⇒ String
Output only. The next maintenance action type of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceActionType
5271 5272 5273 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5271 def next_maintenance_action_type @next_maintenance_action_type end |
#next_maintenance_description ⇒ String
Output only. The next maintenance description of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceDescription
5276 5277 5278 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5276 def next_maintenance_description @next_maintenance_description end |
#next_maintenance_time ⇒ String
Output only. The time of next maintenance of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceTime
5281 5282 5283 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5281 def next_maintenance_time @next_maintenance_time end |
#nsg_ids ⇒ Array<String>
Output only. The nsg ids of the GoldengateDeployment.
Corresponds to the JSON property nsgIds
5286 5287 5288 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5286 def nsg_ids @nsg_ids end |
#ocid ⇒ String
Output only. OCID of the GoldengateDeployment.
Corresponds to the JSON property ocid
5291 5292 5293 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5291 def ocid @ocid end |
#ogg_data ⇒ Google::Apis::OracledatabaseV1::GoldengateOggDeployment
The Ogg data of the GoldengateDeployment.
Corresponds to the JSON property oggData
5296 5297 5298 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5296 def ogg_data @ogg_data end |
#ogg_version_support_end_time ⇒ String
Output only. The time ogg version supported until of the GoldengateDeployment.
Corresponds to the JSON property oggVersionSupportEndTime
5301 5302 5303 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5301 def ogg_version_support_end_time @ogg_version_support_end_time end |
#placements ⇒ Array<Google::Apis::OracledatabaseV1::GoldengatePlacement>
Output only. The placements of the GoldengateDeployment.
Corresponds to the JSON property placements
5306 5307 5308 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5306 def placements @placements end |
#private_ip_address ⇒ String
Output only. The private ip address of the GoldengateDeployment.
Corresponds to the JSON property privateIpAddress
5311 5312 5313 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5311 def private_ip_address @private_ip_address end |
#public_ip_address ⇒ String
Output only. The public ip address of the GoldengateDeployment.
Corresponds to the JSON property publicIpAddress
5316 5317 5318 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5316 def public_ip_address @public_ip_address end |
#role_change_time ⇒ String
Output only. The time when the role of the GoldengateDeployment was changed.
Corresponds to the JSON property roleChangeTime
5321 5322 5323 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5321 def role_change_time @role_change_time end |
#storage_utilization_bytes ⇒ Fixnum
Output only. The storage utilization in bytes of the GoldengateDeployment.
Corresponds to the JSON property storageUtilizationBytes
5326 5327 5328 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5326 def storage_utilization_bytes @storage_utilization_bytes end |
#update_time ⇒ String
Output only. The time the GoldengateDeployment was updated.
Corresponds to the JSON property updateTime
5331 5332 5333 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5331 def update_time @update_time end |
#upgrade_required_time ⇒ String
Output only. The time upgrade required of the GoldengateDeployment.
Corresponds to the JSON property upgradeRequiredTime
5336 5337 5338 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5336 def upgrade_required_time @upgrade_required_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5343 5344 5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 5378 5379 5380 5381 5382 5383 5384 5385 5386 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5343 def update!(**args) @backup_schedule = args[:backup_schedule] if args.key?(:backup_schedule) @category = args[:category] if args.key?(:category) @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count) @deployment_backup_id = args[:deployment_backup_id] if args.key?(:deployment_backup_id) @deployment_diagnostic_data = args[:deployment_diagnostic_data] if args.key?(:deployment_diagnostic_data) @deployment_role = args[:deployment_role] if args.key?(:deployment_role) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @deployment_url = args[:deployment_url] if args.key?(:deployment_url) @description = args[:description] if args.key?(:description) @environment_type = args[:environment_type] if args.key?(:environment_type) @fqdn = args[:fqdn] if args.key?(:fqdn) @healthy = args[:healthy] if args.key?(:healthy) @ingress_ips = args[:ingress_ips] if args.key?(:ingress_ips) @is_auto_scaling_enabled = args[:is_auto_scaling_enabled] if args.key?(:is_auto_scaling_enabled) @is_latest_version = args[:is_latest_version] if args.key?(:is_latest_version) @is_public = args[:is_public] if args.key?(:is_public) @is_storage_utilization_limit_exceeded = args[:is_storage_utilization_limit_exceeded] if args.key?(:is_storage_utilization_limit_exceeded) @last_backup_schedule_time = args[:last_backup_schedule_time] if args.key?(:last_backup_schedule_time) @license_model = args[:license_model] if args.key?(:license_model) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @lifecycle_sub_state = args[:lifecycle_sub_state] if args.key?(:lifecycle_sub_state) @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id) @load_balancer_subnet_id = args[:load_balancer_subnet_id] if args.key?(:load_balancer_subnet_id) @locks = args[:locks] if args.key?(:locks) @maintenance_config = args[:maintenance_config] if args.key?(:maintenance_config) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @next_backup_schedule_time = args[:next_backup_schedule_time] if args.key?(:next_backup_schedule_time) @next_maintenance_action_type = args[:next_maintenance_action_type] if args.key?(:next_maintenance_action_type) @next_maintenance_description = args[:next_maintenance_description] if args.key?(:next_maintenance_description) @next_maintenance_time = args[:next_maintenance_time] if args.key?(:next_maintenance_time) @nsg_ids = args[:nsg_ids] if args.key?(:nsg_ids) @ocid = args[:ocid] if args.key?(:ocid) @ogg_data = args[:ogg_data] if args.key?(:ogg_data) @ogg_version_support_end_time = args[:ogg_version_support_end_time] if args.key?(:ogg_version_support_end_time) @placements = args[:placements] if args.key?(:placements) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @role_change_time = args[:role_change_time] if args.key?(:role_change_time) @storage_utilization_bytes = args[:storage_utilization_bytes] if args.key?(:storage_utilization_bytes) @update_time = args[:update_time] if args.key?(:update_time) @upgrade_required_time = args[:upgrade_required_time] if args.key?(:upgrade_required_time) end |