Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Properties of GoldengateDeployment.
Instance Attribute Summary collapse
-
#backup_schedule ⇒ Google::Apis::OracledatabaseV1::GoldengateBackupSchedule
The backup schedule of the GoldengateDeployment.
-
#category ⇒ String
Output only.
-
#cpu_core_count ⇒ Fixnum
Optional.
-
#deployment_backup_id ⇒ String
Output only.
-
#deployment_diagnostic_data ⇒ Google::Apis::OracledatabaseV1::DeploymentDiagnosticData
The deployment diagnostic data.
-
#deployment_role ⇒ String
Output only.
-
#deployment_type ⇒ String
Required.
-
#deployment_url ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#environment_type ⇒ String
Optional.
-
#fqdn ⇒ String
Output only.
-
#healthy ⇒ Boolean
(also: #healthy?)
Output only.
-
#ingress_ips ⇒ Array<Google::Apis::OracledatabaseV1::IngressIp>
Output only.
-
#is_auto_scaling_enabled ⇒ Boolean
(also: #is_auto_scaling_enabled?)
Optional.
-
#is_latest_version ⇒ Boolean
(also: #is_latest_version?)
Output only.
-
#is_public ⇒ Boolean
(also: #is_public?)
Output only.
-
#is_storage_utilization_limit_exceeded ⇒ Boolean
(also: #is_storage_utilization_limit_exceeded?)
Output only.
-
#last_backup_schedule_time ⇒ String
Output only.
-
#license_model ⇒ String
Optional.
-
#lifecycle_details ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#lifecycle_sub_state ⇒ String
Output only.
-
#load_balancer_id ⇒ String
Output only.
-
#load_balancer_subnet_id ⇒ String
Output only.
-
#locks ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeploymentLock>
Output only.
-
#maintenance_config ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceConfig
The maintenance configuration of the GoldengateDeployment.
-
#maintenance_window ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceWindow
The maintenance window of the GoldengateDeployment.
-
#next_backup_schedule_time ⇒ String
Output only.
-
#next_maintenance_action_type ⇒ String
Output only.
-
#next_maintenance_description ⇒ String
Output only.
-
#next_maintenance_time ⇒ String
Output only.
-
#nsg_ids ⇒ Array<String>
Output only.
-
#ocid ⇒ String
Output only.
-
#ogg_data ⇒ Google::Apis::OracledatabaseV1::GoldengateOggDeployment
The Ogg data of the GoldengateDeployment.
-
#ogg_version_support_end_time ⇒ String
Output only.
-
#placements ⇒ Array<Google::Apis::OracledatabaseV1::GoldengatePlacement>
Output only.
-
#private_ip_address ⇒ String
Output only.
-
#public_ip_address ⇒ String
Output only.
-
#role_change_time ⇒ String
Output only.
-
#storage_utilization_bytes ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#upgrade_required_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentProperties
constructor
A new instance of GoldengateDeploymentProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentProperties
Returns a new instance of GoldengateDeploymentProperties.
5144 5145 5146 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_schedule ⇒ Google::Apis::OracledatabaseV1::GoldengateBackupSchedule
The backup schedule of the GoldengateDeployment.
Corresponds to the JSON property backupSchedule
4929 4930 4931 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4929 def backup_schedule @backup_schedule end |
#category ⇒ String
Output only. The category of the GoldengateDeployment.
Corresponds to the JSON property category
4934 4935 4936 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4934 def category @category end |
#cpu_core_count ⇒ Fixnum
Optional. The Minimum number of OCPUs to be made available for this Deployment.
Corresponds to the JSON property cpuCoreCount
4939 4940 4941 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4939 def cpu_core_count @cpu_core_count end |
#deployment_backup_id ⇒ String
Output only. The deployment backup id of the GoldengateDeployment.
Corresponds to the JSON property deploymentBackupId
4944 4945 4946 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4944 def deployment_backup_id @deployment_backup_id end |
#deployment_diagnostic_data ⇒ Google::Apis::OracledatabaseV1::DeploymentDiagnosticData
The deployment diagnostic data.
Corresponds to the JSON property deploymentDiagnosticData
4949 4950 4951 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4949 def deployment_diagnostic_data @deployment_diagnostic_data end |
#deployment_role ⇒ String
Output only. The deployment role of the GoldengateDeployment.
Corresponds to the JSON property deploymentRole
4954 4955 4956 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4954 def deployment_role @deployment_role end |
#deployment_type ⇒ String
Required. A valid Goldengate Deployment type. For a list of supported types,
use the ListGoldengateDeploymentTypes operation.
Corresponds to the JSON property deploymentType
4960 4961 4962 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4960 def deployment_type @deployment_type end |
#deployment_url ⇒ String
Output only. The deployment url of the GoldengateDeployment.
Corresponds to the JSON property deploymentUrl
4965 4966 4967 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4965 def deployment_url @deployment_url end |
#description ⇒ String
Optional. The description of the GoldengateDeployment.
Corresponds to the JSON property description
4970 4971 4972 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4970 def description @description end |
#environment_type ⇒ String
Optional. The environment type of the GoldengateDeployment.
Corresponds to the JSON property environmentType
4975 4976 4977 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4975 def environment_type @environment_type end |
#fqdn ⇒ String
Output only. The Fully Qualified Domain Name of the GoldengateDeployment.
Corresponds to the JSON property fqdn
4980 4981 4982 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4980 def fqdn @fqdn end |
#healthy ⇒ Boolean Also known as: healthy?
Output only. Whether the GoldengateDeployment is healthy.
Corresponds to the JSON property healthy
4985 4986 4987 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4985 def healthy @healthy end |
#ingress_ips ⇒ Array<Google::Apis::OracledatabaseV1::IngressIp>
Output only. The ingress ips of the GoldengateDeployment.
Corresponds to the JSON property ingressIps
4991 4992 4993 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4991 def ingress_ips @ingress_ips end |
#is_auto_scaling_enabled ⇒ Boolean Also known as: is_auto_scaling_enabled?
Optional. Indicates if auto scaling is enabled for the Deployment's CPU core
count.
Corresponds to the JSON property isAutoScalingEnabled
4997 4998 4999 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4997 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_latest_version ⇒ Boolean Also known as: is_latest_version?
Output only. Whether the GoldengateDeployment is of the latest version.
Corresponds to the JSON property isLatestVersion
5003 5004 5005 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5003 def is_latest_version @is_latest_version end |
#is_public ⇒ Boolean Also known as: is_public?
Output only. Whether the GoldengateDeployment is public.
Corresponds to the JSON property isPublic
5009 5010 5011 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5009 def is_public @is_public end |
#is_storage_utilization_limit_exceeded ⇒ Boolean Also known as: is_storage_utilization_limit_exceeded?
Output only. Whether storage utilization limit is exceeded of the
GoldengateDeployment.
Corresponds to the JSON property isStorageUtilizationLimitExceeded
5016 5017 5018 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5016 def is_storage_utilization_limit_exceeded @is_storage_utilization_limit_exceeded end |
#last_backup_schedule_time ⇒ String
Output only. The time last backup scheduled of the GoldengateDeployment.
Corresponds to the JSON property lastBackupScheduleTime
5022 5023 5024 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5022 def last_backup_schedule_time @last_backup_schedule_time end |
#license_model ⇒ String
Optional. The Oracle license model that applies to a Deployment.
Corresponds to the JSON property licenseModel
5027 5028 5029 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5027 def license_model @license_model end |
#lifecycle_details ⇒ String
Output only. The lifecycle details of the GoldengateDeployment.
Corresponds to the JSON property lifecycleDetails
5032 5033 5034 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5032 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Output only. State of the GoldengateDeployment.
Corresponds to the JSON property lifecycleState
5037 5038 5039 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5037 def lifecycle_state @lifecycle_state end |
#lifecycle_sub_state ⇒ String
Output only. The lifecycle sub-state of the GoldengateDeployment.
Corresponds to the JSON property lifecycleSubState
5042 5043 5044 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5042 def lifecycle_sub_state @lifecycle_sub_state end |
#load_balancer_id ⇒ String
Output only. The load balancer id of the GoldengateDeployment.
Corresponds to the JSON property loadBalancerId
5047 5048 5049 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5047 def load_balancer_id @load_balancer_id end |
#load_balancer_subnet_id ⇒ String
Output only. The load balancer subnet id of the GoldengateDeployment.
Corresponds to the JSON property loadBalancerSubnetId
5052 5053 5054 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5052 def load_balancer_subnet_id @load_balancer_subnet_id end |
#locks ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateDeploymentLock>
Output only. The locks of the GoldengateDeployment.
Corresponds to the JSON property locks
5057 5058 5059 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5057 def locks @locks end |
#maintenance_config ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceConfig
The maintenance configuration of the GoldengateDeployment.
Corresponds to the JSON property maintenanceConfig
5062 5063 5064 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5062 def maintenance_config @maintenance_config end |
#maintenance_window ⇒ Google::Apis::OracledatabaseV1::GoldengateMaintenanceWindow
The maintenance window of the GoldengateDeployment.
Corresponds to the JSON property maintenanceWindow
5067 5068 5069 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5067 def maintenance_window @maintenance_window end |
#next_backup_schedule_time ⇒ String
Output only. The time next backup scheduled of the GoldengateDeployment.
Corresponds to the JSON property nextBackupScheduleTime
5072 5073 5074 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5072 def next_backup_schedule_time @next_backup_schedule_time end |
#next_maintenance_action_type ⇒ String
Output only. The next maintenance action type of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceActionType
5077 5078 5079 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5077 def next_maintenance_action_type @next_maintenance_action_type end |
#next_maintenance_description ⇒ String
Output only. The next maintenance description of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceDescription
5082 5083 5084 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5082 def next_maintenance_description @next_maintenance_description end |
#next_maintenance_time ⇒ String
Output only. The time of next maintenance of the GoldengateDeployment.
Corresponds to the JSON property nextMaintenanceTime
5087 5088 5089 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5087 def next_maintenance_time @next_maintenance_time end |
#nsg_ids ⇒ Array<String>
Output only. The nsg ids of the GoldengateDeployment.
Corresponds to the JSON property nsgIds
5092 5093 5094 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5092 def nsg_ids @nsg_ids end |
#ocid ⇒ String
Output only. OCID of the GoldengateDeployment.
Corresponds to the JSON property ocid
5097 5098 5099 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5097 def ocid @ocid end |
#ogg_data ⇒ Google::Apis::OracledatabaseV1::GoldengateOggDeployment
The Ogg data of the GoldengateDeployment.
Corresponds to the JSON property oggData
5102 5103 5104 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5102 def ogg_data @ogg_data end |
#ogg_version_support_end_time ⇒ String
Output only. The time ogg version supported until of the GoldengateDeployment.
Corresponds to the JSON property oggVersionSupportEndTime
5107 5108 5109 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5107 def ogg_version_support_end_time @ogg_version_support_end_time end |
#placements ⇒ Array<Google::Apis::OracledatabaseV1::GoldengatePlacement>
Output only. The placements of the GoldengateDeployment.
Corresponds to the JSON property placements
5112 5113 5114 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5112 def placements @placements end |
#private_ip_address ⇒ String
Output only. The private ip address of the GoldengateDeployment.
Corresponds to the JSON property privateIpAddress
5117 5118 5119 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5117 def private_ip_address @private_ip_address end |
#public_ip_address ⇒ String
Output only. The public ip address of the GoldengateDeployment.
Corresponds to the JSON property publicIpAddress
5122 5123 5124 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5122 def public_ip_address @public_ip_address end |
#role_change_time ⇒ String
Output only. The time when the role of the GoldengateDeployment was changed.
Corresponds to the JSON property roleChangeTime
5127 5128 5129 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5127 def role_change_time @role_change_time end |
#storage_utilization_bytes ⇒ Fixnum
Output only. The storage utilization in bytes of the GoldengateDeployment.
Corresponds to the JSON property storageUtilizationBytes
5132 5133 5134 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5132 def storage_utilization_bytes @storage_utilization_bytes end |
#update_time ⇒ String
Output only. The time the GoldengateDeployment was updated.
Corresponds to the JSON property updateTime
5137 5138 5139 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5137 def update_time @update_time end |
#upgrade_required_time ⇒ String
Output only. The time upgrade required of the GoldengateDeployment.
Corresponds to the JSON property upgradeRequiredTime
5142 5143 5144 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5142 def upgrade_required_time @upgrade_required_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5149 def update!(**args) @backup_schedule = args[:backup_schedule] if args.key?(:backup_schedule) @category = args[:category] if args.key?(:category) @cpu_core_count = args[:cpu_core_count] if args.key?(:cpu_core_count) @deployment_backup_id = args[:deployment_backup_id] if args.key?(:deployment_backup_id) @deployment_diagnostic_data = args[:deployment_diagnostic_data] if args.key?(:deployment_diagnostic_data) @deployment_role = args[:deployment_role] if args.key?(:deployment_role) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @deployment_url = args[:deployment_url] if args.key?(:deployment_url) @description = args[:description] if args.key?(:description) @environment_type = args[:environment_type] if args.key?(:environment_type) @fqdn = args[:fqdn] if args.key?(:fqdn) @healthy = args[:healthy] if args.key?(:healthy) @ingress_ips = args[:ingress_ips] if args.key?(:ingress_ips) @is_auto_scaling_enabled = args[:is_auto_scaling_enabled] if args.key?(:is_auto_scaling_enabled) @is_latest_version = args[:is_latest_version] if args.key?(:is_latest_version) @is_public = args[:is_public] if args.key?(:is_public) @is_storage_utilization_limit_exceeded = args[:is_storage_utilization_limit_exceeded] if args.key?(:is_storage_utilization_limit_exceeded) @last_backup_schedule_time = args[:last_backup_schedule_time] if args.key?(:last_backup_schedule_time) @license_model = args[:license_model] if args.key?(:license_model) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @lifecycle_sub_state = args[:lifecycle_sub_state] if args.key?(:lifecycle_sub_state) @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id) @load_balancer_subnet_id = args[:load_balancer_subnet_id] if args.key?(:load_balancer_subnet_id) @locks = args[:locks] if args.key?(:locks) @maintenance_config = args[:maintenance_config] if args.key?(:maintenance_config) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @next_backup_schedule_time = args[:next_backup_schedule_time] if args.key?(:next_backup_schedule_time) @next_maintenance_action_type = args[:next_maintenance_action_type] if args.key?(:next_maintenance_action_type) @next_maintenance_description = args[:next_maintenance_description] if args.key?(:next_maintenance_description) @next_maintenance_time = args[:next_maintenance_time] if args.key?(:next_maintenance_time) @nsg_ids = args[:nsg_ids] if args.key?(:nsg_ids) @ocid = args[:ocid] if args.key?(:ocid) @ogg_data = args[:ogg_data] if args.key?(:ogg_data) @ogg_version_support_end_time = args[:ogg_version_support_end_time] if args.key?(:ogg_version_support_end_time) @placements = args[:placements] if args.key?(:placements) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @role_change_time = args[:role_change_time] if args.key?(:role_change_time) @storage_utilization_bytes = args[:storage_utilization_bytes] if args.key?(:storage_utilization_bytes) @update_time = args[:update_time] if args.key?(:update_time) @upgrade_required_time = args[:upgrade_required_time] if args.key?(:upgrade_required_time) end |