Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of the Goldengate Deployment Version resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateDeploymentVersion

Returns a new instance of GoldengateDeploymentVersion.



5433
5434
5435
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The name of the Goldengate Deployment Version resource with the format: projects/project/locations/location/goldengateDeploymentVersions/ goldengate_deployment_version Corresponds to the JSON property name

Returns:

  • (String)


5420
5421
5422
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5420

def name
  @name
end

#ocidString

Output only. The deployment version ocid of the Goldengate Deployment Version resource. Corresponds to the JSON property ocid

Returns:

  • (String)


5426
5427
5428
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5426

def ocid
  @ocid
end

#propertiesGoogle::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties

Properties of GoldengateDeploymentVersion. Corresponds to the JSON property properties



5431
5432
5433
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5431

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5438
5439
5440
5441
5442
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5438

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @ocid = args[:ocid] if args.key?(:ocid)
  @properties = args[:properties] if args.key?(:properties)
end