Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentVersion
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of the Goldengate Deployment Version resource.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#ocid ⇒ String
Output only.
-
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
Properties of GoldengateDeploymentVersion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentVersion
constructor
A new instance of GoldengateDeploymentVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentVersion
Returns a new instance of GoldengateDeploymentVersion.
5302 5303 5304 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The name of the Goldengate Deployment Version resource with the
format: projects/project/locations/location/goldengateDeploymentVersions/
goldengate_deployment_version
Corresponds to the JSON property name
5289 5290 5291 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5289 def name @name end |
#ocid ⇒ String
Output only. The deployment version ocid of the Goldengate Deployment Version
resource.
Corresponds to the JSON property ocid
5295 5296 5297 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5295 def ocid @ocid end |
#properties ⇒ Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
Properties of GoldengateDeploymentVersion.
Corresponds to the JSON property properties
5300 5301 5302 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5300 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5307 5308 5309 5310 5311 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5307 def update!(**args) @name = args[:name] if args.key?(:name) @ocid = args[:ocid] if args.key?(:ocid) @properties = args[:properties] if args.key?(:properties) end |