Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Properties of GoldengateDeploymentVersion.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Output only.
-
#ogg_version ⇒ String
Output only.
-
#release_time ⇒ String
Output only.
-
#release_type ⇒ String
Output only.
-
#security_fix ⇒ Boolean
(also: #security_fix?)
Optional.
-
#support_end_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentVersionProperties
constructor
A new instance of GoldengateDeploymentVersionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentVersionProperties
Returns a new instance of GoldengateDeploymentVersionProperties.
5428 5429 5430 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Output only. The deployment type of the Goldengate Deployment Version resource.
Corresponds to the JSON property deploymentType
5399 5400 5401 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5399 def deployment_type @deployment_type end |
#ogg_version ⇒ String
Output only. The OGG version of the Goldengate Deployment Version resource.
Corresponds to the JSON property oggVersion
5404 5405 5406 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5404 def ogg_version @ogg_version end |
#release_time ⇒ String
Output only. The release time of the Goldengate Deployment Version resource.
Corresponds to the JSON property releaseTime
5409 5410 5411 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5409 def release_time @release_time end |
#release_type ⇒ String
Output only. The release type of the Goldengate Deployment Version resource.
Corresponds to the JSON property releaseType
5414 5415 5416 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5414 def release_type @release_type end |
#security_fix ⇒ Boolean Also known as: security_fix?
Optional. Whether the Goldengate Deployment Version resource is a security fix.
Corresponds to the JSON property securityFix
5419 5420 5421 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5419 def security_fix @security_fix end |
#support_end_time ⇒ String
Output only. The support end time of the Goldengate Deployment Version
resource.
Corresponds to the JSON property supportEndTime
5426 5427 5428 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5426 def support_end_time @support_end_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5433 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @ogg_version = args[:ogg_version] if args.key?(:ogg_version) @release_time = args[:release_time] if args.key?(:release_time) @release_type = args[:release_type] if args.key?(:release_type) @security_fix = args[:security_fix] if args.key?(:security_fix) @support_end_time = args[:support_end_time] if args.key?(:support_end_time) end |