Class: Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateDeploymentVersionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Properties of GoldengateDeploymentVersion.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Output only.
-
#ogg_version ⇒ String
Output only.
-
#release_time ⇒ String
Output only.
-
#release_type ⇒ String
Output only.
-
#security_fix ⇒ Boolean
(also: #security_fix?)
Optional.
-
#support_end_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateDeploymentVersionProperties
constructor
A new instance of GoldengateDeploymentVersionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateDeploymentVersionProperties
Returns a new instance of GoldengateDeploymentVersionProperties.
5350 5351 5352 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Output only. The deployment type of the Goldengate Deployment Version resource.
Corresponds to the JSON property deploymentType
5321 5322 5323 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5321 def deployment_type @deployment_type end |
#ogg_version ⇒ String
Output only. The OGG version of the Goldengate Deployment Version resource.
Corresponds to the JSON property oggVersion
5326 5327 5328 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5326 def ogg_version @ogg_version end |
#release_time ⇒ String
Output only. The release time of the Goldengate Deployment Version resource.
Corresponds to the JSON property releaseTime
5331 5332 5333 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5331 def release_time @release_time end |
#release_type ⇒ String
Output only. The release type of the Goldengate Deployment Version resource.
Corresponds to the JSON property releaseType
5336 5337 5338 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5336 def release_type @release_type end |
#security_fix ⇒ Boolean Also known as: security_fix?
Optional. Whether the Goldengate Deployment Version resource is a security fix.
Corresponds to the JSON property securityFix
5341 5342 5343 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5341 def security_fix @security_fix end |
#support_end_time ⇒ String
Output only. The support end time of the Goldengate Deployment Version
resource.
Corresponds to the JSON property supportEndTime
5348 5349 5350 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5348 def support_end_time @support_end_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5355 5356 5357 5358 5359 5360 5361 5362 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5355 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @ogg_version = args[:ogg_version] if args.key?(:ogg_version) @release_time = args[:release_time] if args.key?(:release_time) @release_type = args[:release_type] if args.key?(:release_type) @security_fix = args[:security_fix] if args.key?(:security_fix) @support_end_time = args[:support_end_time] if args.key?(:support_end_time) end |