Class: Google::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateElasticsearchConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#fingerprint ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#servers ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateElasticsearchConnectionProperties
constructor
A new instance of GoldengateElasticsearchConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateElasticsearchConnectionProperties
Returns a new instance of GoldengateElasticsearchConnectionProperties.
5494 5495 5496 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Elasticsearch.
Corresponds to the JSON property authenticationType
5450 5451 5452 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5450 def authentication_type @authentication_type end |
#fingerprint ⇒ String
Optional. Fingerprint required by TLS security protocol. Eg.: '
6152b2dfbff200f973c5074a5b91d06ab3b472c07c09a1ea57bb7fd406cdce9c'
Corresponds to the JSON property fingerprint
5456 5457 5458 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5456 def fingerprint @fingerprint end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Elastic Search
connection in plain text.
Corresponds to the JSON property password
5462 5463 5464 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5462 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Elastic Search
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
5469 5470 5471 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5469 def password_secret_version @password_secret_version end |
#security_protocol ⇒ String
Optional. Security protocol for Elasticsearch.
Corresponds to the JSON property securityProtocol
5474 5475 5476 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5474 def security_protocol @security_protocol end |
#servers ⇒ String
Optional. Comma separated list of Elasticsearch server addresses, specified as
host:port entries, where :port is optional. If port is not specified, it
defaults to 9200. Example: "server1.example.com:4000,server2.example.com:4000"
Corresponds to the JSON property servers
5481 5482 5483 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5481 def servers @servers end |
#technology_type ⇒ String
Optional. The technology type of ElasticsearchConnection.
Corresponds to the JSON property technologyType
5486 5487 5488 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5486 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
5492 5493 5494 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5492 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5499 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @servers = args[:servers] if args.key?(:servers) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |