Class: Google::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateElasticsearchConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateElasticsearchConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#fingerprint ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#servers ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateElasticsearchConnectionProperties
constructor
A new instance of GoldengateElasticsearchConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateElasticsearchConnectionProperties
Returns a new instance of GoldengateElasticsearchConnectionProperties.
5416 5417 5418 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Elasticsearch.
Corresponds to the JSON property authenticationType
5372 5373 5374 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5372 def authentication_type @authentication_type end |
#fingerprint ⇒ String
Optional. Fingerprint required by TLS security protocol. Eg.: '
6152b2dfbff200f973c5074a5b91d06ab3b472c07c09a1ea57bb7fd406cdce9c'
Corresponds to the JSON property fingerprint
5378 5379 5380 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5378 def fingerprint @fingerprint end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Elastic Search
connection in plain text.
Corresponds to the JSON property password
5384 5385 5386 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5384 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Elastic Search
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
5391 5392 5393 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5391 def password_secret_version @password_secret_version end |
#security_protocol ⇒ String
Optional. Security protocol for Elasticsearch.
Corresponds to the JSON property securityProtocol
5396 5397 5398 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5396 def security_protocol @security_protocol end |
#servers ⇒ String
Optional. Comma separated list of Elasticsearch server addresses, specified as
host:port entries, where :port is optional. If port is not specified, it
defaults to 9200. Example: "server1.example.com:4000,server2.example.com:4000"
Corresponds to the JSON property servers
5403 5404 5405 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5403 def servers @servers end |
#technology_type ⇒ String
Optional. The technology type of ElasticsearchConnection.
Corresponds to the JSON property technologyType
5408 5409 5410 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5408 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
5414 5415 5416 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5414 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5421 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @servers = args[:servers] if args.key?(:servers) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |