Class: Google::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateGoldengateConnectionProperties.
Instance Attribute Summary collapse
-
#goldengate_deployment_id ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateGoldengateConnectionProperties
constructor
A new instance of GoldengateGoldengateConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateGoldengateConnectionProperties
Returns a new instance of GoldengateGoldengateConnectionProperties.
5696 5697 5698 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5696 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goldengate_deployment_id ⇒ String
Optional. The name of the GoldengateDeployment associated with the
GoldengateConnection. Format: projects/project/locations/location/
goldengateDeployments/goldengate_deployment
Corresponds to the JSON property goldengateDeploymentId
5661 5662 5663 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5661 def goldengate_deployment_id @goldengate_deployment_id end |
#host ⇒ String
Optional. The host of the GoldengateConnection.
Corresponds to the JSON property host
5666 5667 5668 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5666 def host @host end |
#password ⇒ String
Optional. Input only. The password used to connect to the Oracle Goldengate in
plain text.
Corresponds to the JSON property password
5672 5673 5674 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5672 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password used to connect to the Oracle Goldengate. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
5679 5680 5681 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5679 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of the GoldengateConnection.
Corresponds to the JSON property port
5684 5685 5686 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5684 def port @port end |
#technology_type ⇒ String
Optional. The technology type.
Corresponds to the JSON property technologyType
5689 5690 5691 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5689 def technology_type @technology_type end |
#username ⇒ String
Optional. The username credential.
Corresponds to the JSON property username
5694 5695 5696 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5694 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5701 5702 5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5701 def update!(**args) @goldengate_deployment_id = args[:goldengate_deployment_id] if args.key?(:goldengate_deployment_id) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |