Class: Google::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateGoldengateConnectionProperties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateGoldengateConnectionProperties

Returns a new instance of GoldengateGoldengateConnectionProperties.



5580
5581
5582
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#goldengate_deployment_idString

Optional. The name of the GoldengateDeployment associated with the GoldengateConnection. Format: projects/project/locations/location/ goldengateDeployments/goldengate_deployment Corresponds to the JSON property goldengateDeploymentId

Returns:

  • (String)


5545
5546
5547
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5545

def goldengate_deployment_id
  @goldengate_deployment_id
end

#hostString

Optional. The host of the GoldengateConnection. Corresponds to the JSON property host

Returns:

  • (String)


5550
5551
5552
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5550

def host
  @host
end

#passwordString

Optional. Input only. The password used to connect to the Oracle Goldengate in plain text. Corresponds to the JSON property password

Returns:

  • (String)


5556
5557
5558
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5556

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password used to connect to the Oracle Goldengate. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


5563
5564
5565
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5563

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of the GoldengateConnection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


5568
5569
5570
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5568

def port
  @port
end

#technology_typeString

Optional. The technology type. Corresponds to the JSON property technologyType

Returns:

  • (String)


5573
5574
5575
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5573

def technology_type
  @technology_type
end

#usernameString

Optional. The username credential. Corresponds to the JSON property username

Returns:

  • (String)


5578
5579
5580
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5578

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5585

def update!(**args)
  @goldengate_deployment_id = args[:goldengate_deployment_id] if args.key?(:goldengate_deployment_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end