Class: Google::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateGoldengateConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateGoldengateConnectionProperties.
Instance Attribute Summary collapse
-
#goldengate_deployment_id ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateGoldengateConnectionProperties
constructor
A new instance of GoldengateGoldengateConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateGoldengateConnectionProperties
Returns a new instance of GoldengateGoldengateConnectionProperties.
5502 5503 5504 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goldengate_deployment_id ⇒ String
Optional. The name of the GoldengateDeployment associated with the
GoldengateConnection. Format: projects/project/locations/location/
goldengateDeployments/goldengate_deployment
Corresponds to the JSON property goldengateDeploymentId
5467 5468 5469 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5467 def goldengate_deployment_id @goldengate_deployment_id end |
#host ⇒ String
Optional. The host of the GoldengateConnection.
Corresponds to the JSON property host
5472 5473 5474 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5472 def host @host end |
#password ⇒ String
Optional. Input only. The password used to connect to the Oracle Goldengate in
plain text.
Corresponds to the JSON property password
5478 5479 5480 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5478 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password used to connect to the Oracle Goldengate. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
5485 5486 5487 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5485 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of the GoldengateConnection.
Corresponds to the JSON property port
5490 5491 5492 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5490 def port @port end |
#technology_type ⇒ String
Optional. The technology type.
Corresponds to the JSON property technologyType
5495 5496 5497 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5495 def technology_type @technology_type end |
#username ⇒ String
Optional. The username credential.
Corresponds to the JSON property username
5500 5501 5502 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5500 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5507 5508 5509 5510 5511 5512 5513 5514 5515 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5507 def update!(**args) @goldengate_deployment_id = args[:goldengate_deployment_id] if args.key?(:goldengate_deployment_id) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |