Class: Google::Apis::OracledatabaseV1::GoldengateGoogleCloudStorageConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateGoogleCloudStorageConnectionProperties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateGoogleCloudStorageConnectionProperties

Returns a new instance of GoldengateGoogleCloudStorageConnectionProperties.



5690
5691
5692
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_account_key_fileString

Optional. The base64 encoded content of the service account key file containing the credentials required to use Google Cloud Storage. Corresponds to the JSON property serviceAccountKeyFile

Returns:

  • (String)


5683
5684
5685
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5683

def 
  @service_account_key_file
end

#technology_typeString

Optional. The technology type. Corresponds to the JSON property technologyType

Returns:

  • (String)


5688
5689
5690
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5688

def technology_type
  @technology_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5695
5696
5697
5698
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5695

def update!(**args)
  @service_account_key_file = args[:service_account_key_file] if args.key?(:service_account_key_file)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
end