Class: Google::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateJavaMessageServiceConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateJavaMessageServiceConnectionProperties

Returns a new instance of GoldengateJavaMessageServiceConnectionProperties.



5954
5955
5956
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Authentication type for Java Message Service. Corresponds to the JSON property authenticationType

Returns:

  • (String)


5828
5829
5830
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5828

def authentication_type
  @authentication_type
end

#connection_factoryString

Optional. The Java class implementing javax.jms.ConnectionFactory interface supplied by the JMS provider. Corresponds to the JSON property connectionFactory

Returns:

  • (String)


5834
5835
5836
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5834

def connection_factory
  @connection_factory
end

#connection_urlString

Optional. Connection URL of the Java Message Service, specifying the protocol, host, and port. e.g.: 'mq://myjms.host.domain:7676' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


5840
5841
5842
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5840

def connection_url
  @connection_url
end

#jndi_connection_factoryString

Optional. The Connection Factory can be looked up using this name. e.g.: ' ConnectionFactory' Corresponds to the JSON property jndiConnectionFactory

Returns:

  • (String)


5846
5847
5848
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5846

def jndi_connection_factory
  @jndi_connection_factory
end

#jndi_initial_context_factoryString

Optional. The implementation of javax.naming.spi.InitialContextFactory interface used to obtain initial naming context. Corresponds to the JSON property jndiInitialContextFactory

Returns:

  • (String)


5852
5853
5854
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5852

def jndi_initial_context_factory
  @jndi_initial_context_factory
end

#jndi_provider_urlString

Optional. The URL that Java Message Service will use to contact the JNDI provider. e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000' Corresponds to the JSON property jndiProviderUrl

Returns:

  • (String)


5858
5859
5860
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5858

def jndi_provider_url
  @jndi_provider_url
end

#jndi_security_credentials_secretString

Optional. The password associated to the principal. Corresponds to the JSON property jndiSecurityCredentialsSecret

Returns:

  • (String)


5863
5864
5865
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5863

def jndi_security_credentials_secret
  @jndi_security_credentials_secret
end

#jndi_security_principalString

Optional. Specifies the identity of the principal (user) to be authenticated. Corresponds to the JSON property jndiSecurityPrincipal

Returns:

  • (String)


5868
5869
5870
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5868

def jndi_security_principal
  @jndi_security_principal
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


5873
5874
5875
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5873

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


5878
5879
5880
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5878

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


5885
5886
5887
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5885

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect the Java Message Service in plain text. Corresponds to the JSON property password

Returns:

  • (String)


5891
5892
5893
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5891

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the associated Java Message Service. Format: projects/project/secrets/secret/versions/ version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


5899
5900
5901
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5899

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security protocol for Java Message Service. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


5904
5905
5906
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5904

def security_protocol
  @security_protocol
end

#ssl_key_passwordString

Optional. Input only. The password for the cert inside of the KeyStore in plain text. Corresponds to the JSON property sslKeyPassword

Returns:

  • (String)


5910
5911
5912
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5910

def ssl_key_password
  @ssl_key_password
end

#ssl_key_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property sslKeyPasswordSecretVersion

Returns:

  • (String)


5917
5918
5919
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5917

def ssl_key_password_secret_version
  @ssl_key_password_secret_version
end

#technology_typeString

Optional. The technology type of JavaMessageServiceConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


5922
5923
5924
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5922

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


5927
5928
5929
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5927

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


5932
5933
5934
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5932

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


5939
5940
5941
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5939

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#use_jndiBoolean Also known as: use_jndi?

Optional. If set to true, Java Naming and Directory Interface (JNDI) properties should be provided. Corresponds to the JSON property useJndi

Returns:

  • (Boolean)


5945
5946
5947
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5945

def use_jndi
  @use_jndi
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the Java Message Service. Corresponds to the JSON property username

Returns:

  • (String)


5952
5953
5954
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5952

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
5980
5981
5982
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5959

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @connection_factory = args[:connection_factory] if args.key?(:connection_factory)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @jndi_connection_factory = args[:jndi_connection_factory] if args.key?(:jndi_connection_factory)
  @jndi_initial_context_factory = args[:jndi_initial_context_factory] if args.key?(:jndi_initial_context_factory)
  @jndi_provider_url = args[:jndi_provider_url] if args.key?(:jndi_provider_url)
  @jndi_security_credentials_secret = args[:jndi_security_credentials_secret] if args.key?(:jndi_security_credentials_secret)
  @jndi_security_principal = args[:jndi_security_principal] if args.key?(:jndi_security_principal)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password)
  @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @use_jndi = args[:use_jndi] if args.key?(:use_jndi)
  @username = args[:username] if args.key?(:username)
end