Class: Google::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateJavaMessageServiceConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#connection_factory ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#jndi_connection_factory ⇒ String
Optional.
-
#jndi_initial_context_factory ⇒ String
Optional.
-
#jndi_provider_url ⇒ String
Optional.
-
#jndi_security_credentials_secret ⇒ String
Optional.
-
#jndi_security_principal ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_key_password ⇒ String
Optional.
-
#ssl_key_password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#use_jndi ⇒ Boolean
(also: #use_jndi?)
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateJavaMessageServiceConnectionProperties
constructor
A new instance of GoldengateJavaMessageServiceConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateJavaMessageServiceConnectionProperties
Returns a new instance of GoldengateJavaMessageServiceConnectionProperties.
5901 5902 5903 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Java Message Service.
Corresponds to the JSON property authenticationType
5775 5776 5777 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5775 def authentication_type @authentication_type end |
#connection_factory ⇒ String
Optional. The Java class implementing javax.jms.ConnectionFactory interface
supplied by the JMS provider.
Corresponds to the JSON property connectionFactory
5781 5782 5783 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5781 def connection_factory @connection_factory end |
#connection_url ⇒ String
Optional. Connection URL of the Java Message Service, specifying the protocol,
host, and port. e.g.: 'mq://myjms.host.domain:7676'
Corresponds to the JSON property connectionUrl
5787 5788 5789 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5787 def connection_url @connection_url end |
#jndi_connection_factory ⇒ String
Optional. The Connection Factory can be looked up using this name. e.g.: '
ConnectionFactory'
Corresponds to the JSON property jndiConnectionFactory
5793 5794 5795 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5793 def jndi_connection_factory @jndi_connection_factory end |
#jndi_initial_context_factory ⇒ String
Optional. The implementation of javax.naming.spi.InitialContextFactory
interface used to obtain initial naming context.
Corresponds to the JSON property jndiInitialContextFactory
5799 5800 5801 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5799 def jndi_initial_context_factory @jndi_initial_context_factory end |
#jndi_provider_url ⇒ String
Optional. The URL that Java Message Service will use to contact the JNDI
provider. e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000'
Corresponds to the JSON property jndiProviderUrl
5805 5806 5807 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5805 def jndi_provider_url @jndi_provider_url end |
#jndi_security_credentials_secret ⇒ String
Optional. The password associated to the principal.
Corresponds to the JSON property jndiSecurityCredentialsSecret
5810 5811 5812 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5810 def jndi_security_credentials_secret @jndi_security_credentials_secret end |
#jndi_security_principal ⇒ String
Optional. Specifies the identity of the principal (user) to be authenticated.
Corresponds to the JSON property jndiSecurityPrincipal
5815 5816 5817 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5815 def jndi_security_principal @jndi_security_principal end |
#key_store_file ⇒ String
Optional. The base64 encoded content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
5820 5821 5822 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5820 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
5825 5826 5827 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5825 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
5832 5833 5834 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5832 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses to connect the Java
Message Service in plain text.
Corresponds to the JSON property password
5838 5839 5840 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5838 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses to connect the associated
Java Message Service. Format: projects/project/secrets/secret/versions/
version.
Corresponds to the JSON property passwordSecretVersion
5846 5847 5848 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5846 def password_secret_version @password_secret_version end |
#security_protocol ⇒ String
Optional. Security protocol for Java Message Service.
Corresponds to the JSON property securityProtocol
5851 5852 5853 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5851 def security_protocol @security_protocol end |
#ssl_key_password ⇒ String
Optional. Input only. The password for the cert inside of the KeyStore in
plain text.
Corresponds to the JSON property sslKeyPassword
5857 5858 5859 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5857 def ssl_key_password @ssl_key_password end |
#ssl_key_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for the cert inside of the KeyStore. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property sslKeyPasswordSecretVersion
5864 5865 5866 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5864 def ssl_key_password_secret_version @ssl_key_password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of JavaMessageServiceConnection.
Corresponds to the JSON property technologyType
5869 5870 5871 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5869 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The base64 encoded content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
5874 5875 5876 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5874 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
5879 5880 5881 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5879 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
5886 5887 5888 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5886 def trust_store_password_secret_version @trust_store_password_secret_version end |
#use_jndi ⇒ Boolean Also known as: use_jndi?
Optional. If set to true, Java Naming and Directory Interface (JNDI)
properties should be provided.
Corresponds to the JSON property useJndi
5892 5893 5894 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5892 def use_jndi @use_jndi end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the Java Message
Service.
Corresponds to the JSON property username
5899 5900 5901 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5899 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5906 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @connection_factory = args[:connection_factory] if args.key?(:connection_factory) @connection_url = args[:connection_url] if args.key?(:connection_url) @jndi_connection_factory = args[:jndi_connection_factory] if args.key?(:jndi_connection_factory) @jndi_initial_context_factory = args[:jndi_initial_context_factory] if args.key?(:jndi_initial_context_factory) @jndi_provider_url = args[:jndi_provider_url] if args.key?(:jndi_provider_url) @jndi_security_credentials_secret = args[:jndi_security_credentials_secret] if args.key?(:jndi_security_credentials_secret) @jndi_security_principal = args[:jndi_security_principal] if args.key?(:jndi_security_principal) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password) @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @use_jndi = args[:use_jndi] if args.key?(:use_jndi) @username = args[:username] if args.key?(:username) end |