Class: Google::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateJavaMessageServiceConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateJavaMessageServiceConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#connection_factory ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#jndi_connection_factory ⇒ String
Optional.
-
#jndi_initial_context_factory ⇒ String
Optional.
-
#jndi_provider_url ⇒ String
Optional.
-
#jndi_security_credentials_secret ⇒ String
Optional.
-
#jndi_security_principal ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_key_password ⇒ String
Optional.
-
#ssl_key_password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#use_jndi ⇒ Boolean
(also: #use_jndi?)
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateJavaMessageServiceConnectionProperties
constructor
A new instance of GoldengateJavaMessageServiceConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateJavaMessageServiceConnectionProperties
Returns a new instance of GoldengateJavaMessageServiceConnectionProperties.
5823 5824 5825 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Authentication type for Java Message Service.
Corresponds to the JSON property authenticationType
5697 5698 5699 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5697 def authentication_type @authentication_type end |
#connection_factory ⇒ String
Optional. The Java class implementing javax.jms.ConnectionFactory interface
supplied by the JMS provider.
Corresponds to the JSON property connectionFactory
5703 5704 5705 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5703 def connection_factory @connection_factory end |
#connection_url ⇒ String
Optional. Connection URL of the Java Message Service, specifying the protocol,
host, and port. e.g.: 'mq://myjms.host.domain:7676'
Corresponds to the JSON property connectionUrl
5709 5710 5711 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5709 def connection_url @connection_url end |
#jndi_connection_factory ⇒ String
Optional. The Connection Factory can be looked up using this name. e.g.: '
ConnectionFactory'
Corresponds to the JSON property jndiConnectionFactory
5715 5716 5717 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5715 def jndi_connection_factory @jndi_connection_factory end |
#jndi_initial_context_factory ⇒ String
Optional. The implementation of javax.naming.spi.InitialContextFactory
interface used to obtain initial naming context.
Corresponds to the JSON property jndiInitialContextFactory
5721 5722 5723 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5721 def jndi_initial_context_factory @jndi_initial_context_factory end |
#jndi_provider_url ⇒ String
Optional. The URL that Java Message Service will use to contact the JNDI
provider. e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000'
Corresponds to the JSON property jndiProviderUrl
5727 5728 5729 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5727 def jndi_provider_url @jndi_provider_url end |
#jndi_security_credentials_secret ⇒ String
Optional. The password associated to the principal.
Corresponds to the JSON property jndiSecurityCredentialsSecret
5732 5733 5734 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5732 def jndi_security_credentials_secret @jndi_security_credentials_secret end |
#jndi_security_principal ⇒ String
Optional. Specifies the identity of the principal (user) to be authenticated.
Corresponds to the JSON property jndiSecurityPrincipal
5737 5738 5739 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5737 def jndi_security_principal @jndi_security_principal end |
#key_store_file ⇒ String
Optional. The content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
5742 5743 5744 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5742 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
5747 5748 5749 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5747 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
5754 5755 5756 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5754 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses to connect the Java
Message Service in plain text.
Corresponds to the JSON property password
5760 5761 5762 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5760 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses to connect the associated
Java Message Service. Format: projects/project/secrets/secret/versions/
version.
Corresponds to the JSON property passwordSecretVersion
5768 5769 5770 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5768 def password_secret_version @password_secret_version end |
#security_protocol ⇒ String
Optional. Security protocol for Java Message Service.
Corresponds to the JSON property securityProtocol
5773 5774 5775 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5773 def security_protocol @security_protocol end |
#ssl_key_password ⇒ String
Optional. Input only. The password for the cert inside of the KeyStore in
plain text.
Corresponds to the JSON property sslKeyPassword
5779 5780 5781 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5779 def ssl_key_password @ssl_key_password end |
#ssl_key_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for the cert inside of the KeyStore. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property sslKeyPasswordSecretVersion
5786 5787 5788 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5786 def ssl_key_password_secret_version @ssl_key_password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of JavaMessageServiceConnection.
Corresponds to the JSON property technologyType
5791 5792 5793 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5791 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
5796 5797 5798 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5796 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
5801 5802 5803 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5801 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
5808 5809 5810 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5808 def trust_store_password_secret_version @trust_store_password_secret_version end |
#use_jndi ⇒ Boolean Also known as: use_jndi?
Optional. If set to true, Java Naming and Directory Interface (JNDI)
properties should be provided.
Corresponds to the JSON property useJndi
5814 5815 5816 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5814 def use_jndi @use_jndi end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the Java Message
Service.
Corresponds to the JSON property username
5821 5822 5823 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5821 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5828 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @connection_factory = args[:connection_factory] if args.key?(:connection_factory) @connection_url = args[:connection_url] if args.key?(:connection_url) @jndi_connection_factory = args[:jndi_connection_factory] if args.key?(:jndi_connection_factory) @jndi_initial_context_factory = args[:jndi_initial_context_factory] if args.key?(:jndi_initial_context_factory) @jndi_provider_url = args[:jndi_provider_url] if args.key?(:jndi_provider_url) @jndi_security_credentials_secret = args[:jndi_security_credentials_secret] if args.key?(:jndi_security_credentials_secret) @jndi_security_principal = args[:jndi_security_principal] if args.key?(:jndi_security_principal) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password) @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @use_jndi = args[:use_jndi] if args.key?(:use_jndi) @username = args[:username] if args.key?(:username) end |