Class: Google::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateKafkaConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateKafkaConnectionProperties

Returns a new instance of GoldengateKafkaConnectionProperties.



6131
6132
6133
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bootstrap_serversArray<Google::Apis::OracledatabaseV1::KafkaBootstrapServer>

Optional. Kafka bootstrap. Equivalent of bootstrap.servers configuration property in Kafka: list of KafkaBootstrapServer objects specified by host/port. Used for establishing the initial connection to the Kafka cluster. Example: " server1.example.com:9092,server2.example.com:9092" Corresponds to the JSON property bootstrapServers



6026
6027
6028
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6026

def bootstrap_servers
  @bootstrap_servers
end

#cluster_idString

Optional. The OCID of the Kafka cluster being referenced from OCI Streaming with Apache Kafka. Corresponds to the JSON property clusterId

Returns:

  • (String)


6032
6033
6034
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6032

def cluster_id
  @cluster_id
end

#consumer_properties_fileString

Optional. The base64 encoded content of the consumer.properties file. Corresponds to the JSON property consumerPropertiesFile

Returns:

  • (String)


6037
6038
6039
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6037

def consumer_properties_file
  @consumer_properties_file
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


6042
6043
6044
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6042

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


6047
6048
6049
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6047

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


6054
6055
6056
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6054

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password for Kafka basic/SASL auth in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6059
6060
6061
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6059

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for Kafka basic/SASL auth. Format: projects/ project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6066
6067
6068
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6066

def password_secret_version
  @password_secret_version
end

#producer_properties_fileString

Optional. The base64 encoded content of the producer.properties file. Corresponds to the JSON property producerPropertiesFile

Returns:

  • (String)


6071
6072
6073
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6071

def producer_properties_file
  @producer_properties_file
end

#security_protocolString

Optional. Security Type for Kafka. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6076
6077
6078
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6076

def security_protocol
  @security_protocol
end

#ssl_key_passwordString

Optional. Input only. The password for the cert inside of the KeyStore in plain text. Corresponds to the JSON property sslKeyPassword

Returns:

  • (String)


6082
6083
6084
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6082

def ssl_key_password
  @ssl_key_password
end

#ssl_key_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property sslKeyPasswordSecretVersion

Returns:

  • (String)


6089
6090
6091
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6089

def ssl_key_password_secret_version
  @ssl_key_password_secret_version
end

#stream_pool_idString

Optional. The OCID of the stream pool being referenced. Corresponds to the JSON property streamPoolId

Returns:

  • (String)


6094
6095
6096
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6094

def stream_pool_id
  @stream_pool_id
end

#technology_typeString

Optional. The technology type of KafkaConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6099
6100
6101
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6099

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


6104
6105
6106
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6104

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


6109
6110
6111
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6109

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


6116
6117
6118
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6116

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Applicable only for OCI Streaming connections. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6122
6123
6124
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6122

def use_resource_principal
  @use_resource_principal
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


6129
6130
6131
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6129

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6136

def update!(**args)
  @bootstrap_servers = args[:bootstrap_servers] if args.key?(:bootstrap_servers)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @consumer_properties_file = args[:consumer_properties_file] if args.key?(:consumer_properties_file)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @producer_properties_file = args[:producer_properties_file] if args.key?(:producer_properties_file)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password)
  @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version)
  @stream_pool_id = args[:stream_pool_id] if args.key?(:stream_pool_id)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @username = args[:username] if args.key?(:username)
end