Class: Google::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateKafkaConnection.
Instance Attribute Summary collapse
-
#bootstrap_servers ⇒ Array<Google::Apis::OracledatabaseV1::KafkaBootstrapServer>
Optional.
-
#cluster_id ⇒ String
Optional.
-
#consumer_properties_file ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#producer_properties_file ⇒ String
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_key_password ⇒ String
Optional.
-
#ssl_key_password_secret_version ⇒ String
Optional.
-
#stream_pool_id ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#use_resource_principal ⇒ Boolean
(also: #use_resource_principal?)
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateKafkaConnectionProperties
constructor
A new instance of GoldengateKafkaConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateKafkaConnectionProperties
Returns a new instance of GoldengateKafkaConnectionProperties.
6100 6101 6102 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bootstrap_servers ⇒ Array<Google::Apis::OracledatabaseV1::KafkaBootstrapServer>
Optional. Kafka bootstrap. Equivalent of bootstrap.servers configuration
property in Kafka: list of KafkaBootstrapServer objects specified by host/port.
Used for establishing the initial connection to the Kafka cluster. Example: "
server1.example.com:9092,server2.example.com:9092"
Corresponds to the JSON property bootstrapServers
5995 5996 5997 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5995 def bootstrap_servers @bootstrap_servers end |
#cluster_id ⇒ String
Optional. The OCID of the Kafka cluster being referenced from OCI Streaming
with Apache Kafka.
Corresponds to the JSON property clusterId
6001 6002 6003 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6001 def cluster_id @cluster_id end |
#consumer_properties_file ⇒ String
Optional. The base64 encoded content of the consumer.properties file.
Corresponds to the JSON property consumerPropertiesFile
6006 6007 6008 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6006 def consumer_properties_file @consumer_properties_file end |
#key_store_file ⇒ String
Optional. The base64 encoded content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
6011 6012 6013 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6011 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
6016 6017 6018 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6016 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
6023 6024 6025 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6023 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password for Kafka basic/SASL auth in plain text.
Corresponds to the JSON property password
6028 6029 6030 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6028 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for Kafka basic/SASL auth. Format: projects/
project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6035 6036 6037 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6035 def password_secret_version @password_secret_version end |
#producer_properties_file ⇒ String
Optional. The base64 encoded content of the producer.properties file.
Corresponds to the JSON property producerPropertiesFile
6040 6041 6042 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6040 def producer_properties_file @producer_properties_file end |
#security_protocol ⇒ String
Optional. Security Type for Kafka.
Corresponds to the JSON property securityProtocol
6045 6046 6047 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6045 def security_protocol @security_protocol end |
#ssl_key_password ⇒ String
Optional. Input only. The password for the cert inside of the KeyStore in
plain text.
Corresponds to the JSON property sslKeyPassword
6051 6052 6053 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6051 def ssl_key_password @ssl_key_password end |
#ssl_key_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for the cert inside of the KeyStore. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property sslKeyPasswordSecretVersion
6058 6059 6060 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6058 def ssl_key_password_secret_version @ssl_key_password_secret_version end |
#stream_pool_id ⇒ String
Optional. The OCID of the stream pool being referenced.
Corresponds to the JSON property streamPoolId
6063 6064 6065 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6063 def stream_pool_id @stream_pool_id end |
#technology_type ⇒ String
Optional. The technology type of KafkaConnection.
Corresponds to the JSON property technologyType
6068 6069 6070 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6068 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The base64 encoded content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
6073 6074 6075 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6073 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
6078 6079 6080 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6078 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
6085 6086 6087 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6085 def trust_store_password_secret_version @trust_store_password_secret_version end |
#use_resource_principal ⇒ Boolean Also known as: use_resource_principal?
Optional. Specifies that the user intends to authenticate to the instance
using a resource principal. Applicable only for OCI Streaming connections.
Corresponds to the JSON property useResourcePrincipal
6091 6092 6093 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6091 def use_resource_principal @use_resource_principal end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
6098 6099 6100 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6098 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 6121 6122 6123 6124 6125 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6105 def update!(**args) @bootstrap_servers = args[:bootstrap_servers] if args.key?(:bootstrap_servers) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @consumer_properties_file = args[:consumer_properties_file] if args.key?(:consumer_properties_file) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @producer_properties_file = args[:producer_properties_file] if args.key?(:producer_properties_file) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password) @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version) @stream_pool_id = args[:stream_pool_id] if args.key?(:stream_pool_id) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal) @username = args[:username] if args.key?(:username) end |