Class: Google::Apis::OracledatabaseV1::GoldengateKafkaConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateKafkaConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateKafkaConnectionProperties

Returns a new instance of GoldengateKafkaConnectionProperties.



6047
6048
6049
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bootstrap_serversArray<Google::Apis::OracledatabaseV1::KafkaBootstrapServer>

Optional. Kafka bootstrap. Equivalent of bootstrap.servers configuration property in Kafka: list of KafkaBootstrapServer objects specified by host/port. Used for establishing the initial connection to the Kafka cluster. Example: " server1.example.com:9092,server2.example.com:9092" Corresponds to the JSON property bootstrapServers



5942
5943
5944
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5942

def bootstrap_servers
  @bootstrap_servers
end

#cluster_idString

Optional. The OCID of the Kafka cluster being referenced from OCI Streaming with Apache Kafka. Corresponds to the JSON property clusterId

Returns:

  • (String)


5948
5949
5950
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5948

def cluster_id
  @cluster_id
end

#consumer_properties_fileString

Optional. The base64 encoded content of the consumer.properties file. Corresponds to the JSON property consumerPropertiesFile

Returns:

  • (String)


5953
5954
5955
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5953

def consumer_properties_file
  @consumer_properties_file
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


5958
5959
5960
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5958

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


5963
5964
5965
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5963

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


5970
5971
5972
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5970

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password for Kafka basic/SASL auth in plain text. Corresponds to the JSON property password

Returns:

  • (String)


5975
5976
5977
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5975

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for Kafka basic/SASL auth. Format: projects/ project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


5982
5983
5984
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5982

def password_secret_version
  @password_secret_version
end

#producer_properties_fileString

Optional. The base64 encoded content of the producer.properties file. Corresponds to the JSON property producerPropertiesFile

Returns:

  • (String)


5987
5988
5989
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5987

def producer_properties_file
  @producer_properties_file
end

#security_protocolString

Optional. Security Type for Kafka. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


5992
5993
5994
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5992

def security_protocol
  @security_protocol
end

#ssl_key_passwordString

Optional. Input only. The password for the cert inside of the KeyStore in plain text. Corresponds to the JSON property sslKeyPassword

Returns:

  • (String)


5998
5999
6000
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5998

def ssl_key_password
  @ssl_key_password
end

#ssl_key_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property sslKeyPasswordSecretVersion

Returns:

  • (String)


6005
6006
6007
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6005

def ssl_key_password_secret_version
  @ssl_key_password_secret_version
end

#stream_pool_idString

Optional. The OCID of the stream pool being referenced. Corresponds to the JSON property streamPoolId

Returns:

  • (String)


6010
6011
6012
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6010

def stream_pool_id
  @stream_pool_id
end

#technology_typeString

Optional. The technology type of KafkaConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6015

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


6020
6021
6022
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6020

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


6025
6026
6027
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6025

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


6032
6033
6034
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6032

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Applicable only for OCI Streaming connections. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6038
6039
6040
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6038

def use_resource_principal
  @use_resource_principal
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


6045
6046
6047
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6045

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6052

def update!(**args)
  @bootstrap_servers = args[:bootstrap_servers] if args.key?(:bootstrap_servers)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @consumer_properties_file = args[:consumer_properties_file] if args.key?(:consumer_properties_file)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @producer_properties_file = args[:producer_properties_file] if args.key?(:producer_properties_file)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password)
  @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version)
  @stream_pool_id = args[:stream_pool_id] if args.key?(:stream_pool_id)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @username = args[:username] if args.key?(:username)
end