Class: Google::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateKafkaSchemaRegistryConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#ssl_key_password ⇒ String
Optional.
-
#ssl_key_password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#url ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateKafkaSchemaRegistryConnectionProperties
constructor
A new instance of GoldengateKafkaSchemaRegistryConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateKafkaSchemaRegistryConnectionProperties
Returns a new instance of GoldengateKafkaSchemaRegistryConnectionProperties.
6213 6214 6215 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Used authentication mechanism to access Schema Registry.
Corresponds to the JSON property authenticationType
6135 6136 6137 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6135 def authentication_type @authentication_type end |
#key_store_file ⇒ String
Optional. The base64 encoded content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
6140 6141 6142 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6140 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
6145 6146 6147 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6145 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
6152 6153 6154 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6152 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password to access Schema Registry in plain text.
Corresponds to the JSON property password
6157 6158 6159 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6157 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password to access Schema Registry using basic
authentication. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6164 6165 6166 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6164 def password_secret_version @password_secret_version end |
#ssl_key_password ⇒ String
Optional. Input only. The password for the cert inside the KeyStore in plain
text.
Corresponds to the JSON property sslKeyPassword
6170 6171 6172 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6170 def ssl_key_password @ssl_key_password end |
#ssl_key_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for the cert inside the KeyStore. Format: projects/
project/secrets/secret/versions/version.
Corresponds to the JSON property sslKeyPasswordSecretVersion
6177 6178 6179 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6177 def ssl_key_password_secret_version @ssl_key_password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of KafkaSchemaRegistryConnection.
Corresponds to the JSON property technologyType
6182 6183 6184 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6182 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The base64 encoded content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
6187 6188 6189 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6187 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
6192 6193 6194 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6192 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
6199 6200 6201 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6199 def trust_store_password_secret_version @trust_store_password_secret_version end |
#url ⇒ String
Optional. Kafka Schema Registry URL. e.g.: 'https://server1.us.oracle.com:8081'
Corresponds to the JSON property url
6204 6205 6206 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6204 def url @url end |
#username ⇒ String
Optional. The username to access Schema Registry using basic authentication.
This value is injected into 'schema.registry.basic.auth.user.info=user:
password' configuration property.
Corresponds to the JSON property username
6211 6212 6213 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6211 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6218 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password) @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @url = args[:url] if args.key?(:url) @username = args[:username] if args.key?(:username) end |