Class: Google::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateKafkaSchemaRegistryConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateKafkaSchemaRegistryConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#key_store_file ⇒ String
Optional.
-
#key_store_password ⇒ String
Optional.
-
#key_store_password_secret_version ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#ssl_key_password ⇒ String
Optional.
-
#ssl_key_password_secret_version ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#trust_store_file ⇒ String
Optional.
-
#trust_store_password ⇒ String
Optional.
-
#trust_store_password_secret_version ⇒ String
Optional.
-
#url ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateKafkaSchemaRegistryConnectionProperties
constructor
A new instance of GoldengateKafkaSchemaRegistryConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateKafkaSchemaRegistryConnectionProperties
Returns a new instance of GoldengateKafkaSchemaRegistryConnectionProperties.
6082 6083 6084 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Used authentication mechanism to access Schema Registry.
Corresponds to the JSON property authenticationType
6004 6005 6006 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6004 def authentication_type @authentication_type end |
#key_store_file ⇒ String
Optional. The content of the KeyStore file.
Corresponds to the JSON property keyStoreFile
6009 6010 6011 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6009 def key_store_file @key_store_file end |
#key_store_password ⇒ String
Optional. Input only. The KeyStore password in plain text.
Corresponds to the JSON property keyStorePassword
6014 6015 6016 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6014 def key_store_password @key_store_password end |
#key_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the KeyStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property keyStorePasswordSecretVersion
6021 6022 6023 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6021 def key_store_password_secret_version @key_store_password_secret_version end |
#password ⇒ String
Optional. Input only. The password to access Schema Registry in plain text.
Corresponds to the JSON property password
6026 6027 6028 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6026 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password to access Schema Registry using basic
authentication. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6033 6034 6035 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6033 def password_secret_version @password_secret_version end |
#ssl_key_password ⇒ String
Optional. Input only. The password for the cert inside the KeyStore in plain
text.
Corresponds to the JSON property sslKeyPassword
6039 6040 6041 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6039 def ssl_key_password @ssl_key_password end |
#ssl_key_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password for the cert inside the KeyStore. Format: projects/
project/secrets/secret/versions/version.
Corresponds to the JSON property sslKeyPasswordSecretVersion
6046 6047 6048 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6046 def ssl_key_password_secret_version @ssl_key_password_secret_version end |
#technology_type ⇒ String
Optional. The technology type of KafkaSchemaRegistryConnection.
Corresponds to the JSON property technologyType
6051 6052 6053 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6051 def technology_type @technology_type end |
#trust_store_file ⇒ String
Optional. The content of the TrustStore file.
Corresponds to the JSON property trustStoreFile
6056 6057 6058 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6056 def trust_store_file @trust_store_file end |
#trust_store_password ⇒ String
Optional. Input only. The TrustStore password in plain text.
Corresponds to the JSON property trustStorePassword
6061 6062 6063 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6061 def trust_store_password @trust_store_password end |
#trust_store_password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the TrustStore password. Format: projects/project/secrets/
secret/versions/version.
Corresponds to the JSON property trustStorePasswordSecretVersion
6068 6069 6070 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6068 def trust_store_password_secret_version @trust_store_password_secret_version end |
#url ⇒ String
Optional. Kafka Schema Registry URL. e.g.: 'https://server1.us.oracle.com:8081'
Corresponds to the JSON property url
6073 6074 6075 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6073 def url @url end |
#username ⇒ String
Optional. The username to access Schema Registry using basic authentication.
This value is injected into 'schema.registry.basic.auth.user.info=user:
password' configuration property.
Corresponds to the JSON property username
6080 6081 6082 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6080 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6087 6088 6089 6090 6091 6092 6093 6094 6095 6096 6097 6098 6099 6100 6101 6102 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6087 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @key_store_file = args[:key_store_file] if args.key?(:key_store_file) @key_store_password = args[:key_store_password] if args.key?(:key_store_password) @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @ssl_key_password = args[:ssl_key_password] if args.key?(:ssl_key_password) @ssl_key_password_secret_version = args[:ssl_key_password_secret_version] if args.key?(:ssl_key_password_secret_version) @technology_type = args[:technology_type] if args.key?(:technology_type) @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file) @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password) @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version) @url = args[:url] if args.key?(:url) @username = args[:username] if args.key?(:username) end |