Class: Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateMicrosoftSqlserverConnection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#server_certificate_validation_required ⇒ Boolean
(also: #server_certificate_validation_required?)
Optional.
-
#ssl_ca_file ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
constructor
A new instance of GoldengateMicrosoftSqlserverConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
Returns a new instance of GoldengateMicrosoftSqlserverConnectionProperties.
6427 6428 6429 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
6368 6369 6370 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6368 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
6373 6374 6375 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6373 def database @database end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
6378 6379 6380 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6378 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL
Server connection in plain text.
Corresponds to the JSON property password
6384 6385 6386 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6384 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Microsoft SQL Server
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6391 6392 6393 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6391 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
6396 6397 6398 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6396 def port @port end |
#security_protocol ⇒ String
Optional. Security Type for Microsoft SQL Server.
Corresponds to the JSON property securityProtocol
6401 6402 6403 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6401 def security_protocol @security_protocol end |
#server_certificate_validation_required ⇒ Boolean Also known as: server_certificate_validation_required?
Optional. If set to true, the driver validates the certificate that is sent by
the database server.
Corresponds to the JSON property serverCertificateValidationRequired
6407 6408 6409 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6407 def server_certificate_validation_required @server_certificate_validation_required end |
#ssl_ca_file ⇒ String
Optional. Database Certificate - The base64 encoded content of a .pem or .crt
file containing the server public key (for 1-way SSL).
Corresponds to the JSON property sslCaFile
6414 6415 6416 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6414 def ssl_ca_file @ssl_ca_file end |
#technology_type ⇒ String
Optional. The technology type of MicrosoftSqlserverConnection.
Corresponds to the JSON property technologyType
6419 6420 6421 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6419 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL
Server.
Corresponds to the JSON property username
6425 6426 6427 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6425 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6432 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @server_certificate_validation_required = args[:server_certificate_validation_required] if args.key?(:server_certificate_validation_required) @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |