Class: Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateMicrosoftSqlserverConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties

Returns a new instance of GoldengateMicrosoftSqlserverConnectionProperties.



6374
6375
6376
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



6315
6316
6317
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6315

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


6320
6321
6322
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6320

def database
  @database
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


6325
6326
6327
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6325

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL Server connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6331
6332
6333
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6331

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Microsoft SQL Server connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6338
6339
6340
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6338

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6343
6344
6345
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6343

def port
  @port
end

#security_protocolString

Optional. Security Type for Microsoft SQL Server. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6348
6349
6350
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6348

def security_protocol
  @security_protocol
end

#server_certificate_validation_requiredBoolean Also known as: server_certificate_validation_required?

Optional. If set to true, the driver validates the certificate that is sent by the database server. Corresponds to the JSON property serverCertificateValidationRequired

Returns:

  • (Boolean)


6354
6355
6356
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6354

def server_certificate_validation_required
  @server_certificate_validation_required
end

#ssl_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1-way SSL). Corresponds to the JSON property sslCaFile

Returns:

  • (String)


6361
6362
6363
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6361

def ssl_ca_file
  @ssl_ca_file
end

#technology_typeString

Optional. The technology type of MicrosoftSqlserverConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6366
6367
6368
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6366

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL Server. Corresponds to the JSON property username

Returns:

  • (String)


6372
6373
6374
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6372

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6379
6380
6381
6382
6383
6384
6385
6386
6387
6388
6389
6390
6391
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6379

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @server_certificate_validation_required = args[:server_certificate_validation_required] if args.key?(:server_certificate_validation_required)
  @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end