Class: Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateMicrosoftSqlserverConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateMicrosoftSqlserverConnection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#server_certificate_validation_required ⇒ Boolean
(also: #server_certificate_validation_required?)
Optional.
-
#ssl_ca_file ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
constructor
A new instance of GoldengateMicrosoftSqlserverConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateMicrosoftSqlserverConnectionProperties
Returns a new instance of GoldengateMicrosoftSqlserverConnectionProperties.
6296 6297 6298 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
6237 6238 6239 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6237 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
6242 6243 6244 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6242 def database @database end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
6247 6248 6249 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6247 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for Microsoft SQL
Server connection in plain text.
Corresponds to the JSON property password
6253 6254 6255 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6253 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for Microsoft SQL Server
connection. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6260 6261 6262 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6260 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
6265 6266 6267 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6265 def port @port end |
#security_protocol ⇒ String
Optional. Security Type for Microsoft SQL Server.
Corresponds to the JSON property securityProtocol
6270 6271 6272 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6270 def security_protocol @security_protocol end |
#server_certificate_validation_required ⇒ Boolean Also known as: server_certificate_validation_required?
Optional. If set to true, the driver validates the certificate that is sent by
the database server.
Corresponds to the JSON property serverCertificateValidationRequired
6276 6277 6278 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6276 def server_certificate_validation_required @server_certificate_validation_required end |
#ssl_ca_file ⇒ String
Optional. Database Certificate - The content of a .pem or .crt file containing
the server public key (for 1-way SSL).
Corresponds to the JSON property sslCaFile
6283 6284 6285 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6283 def ssl_ca_file @ssl_ca_file end |
#technology_type ⇒ String
Optional. The technology type of MicrosoftSqlserverConnection.
Corresponds to the JSON property technologyType
6288 6289 6290 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6288 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to the Microsoft SQL
Server.
Corresponds to the JSON property username
6294 6295 6296 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6294 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 6313 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6301 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @server_certificate_validation_required = args[:server_certificate_validation_required] if args.key?(:server_certificate_validation_required) @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |