Class: Google::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateMongodbConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMongodbConnectionProperties

Returns a new instance of GoldengateMongodbConnectionProperties.



6514
6515
6516
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com: 27017/recordsrecords' Corresponds to the JSON property connectionString

Returns:

  • (String)


6455
6456
6457
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6455

def connection_string
  @connection_string
end

#database_idString

Optional. The OCID of the Oracle Autonomous Json Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


6460
6461
6462
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6460

def database_id
  @database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6466
6467
6468
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6466

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6473
6474
6475
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6473

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security Type for MongoDB. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6478
6479
6480
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6478

def security_protocol
  @security_protocol
end

#technology_typeString

Optional. The technology type of MongodbConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6483
6484
6485
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6483

def technology_type
  @technology_type
end

#tls_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property tlsCaFile

Returns:

  • (String)


6489
6490
6491
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6489

def tls_ca_file
  @tls_ca_file
end

#tls_certificate_key_fileString

Optional. Client Certificate - The base64 encoded content of a .pem file, containing the client public key (for 2-way SSL). Corresponds to the JSON property tlsCertificateKeyFile

Returns:

  • (String)


6495
6496
6497
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6495

def tls_certificate_key_file
  @tls_certificate_key_file
end

#tls_certificate_key_file_passwordString

Optional. Input only. The Client Certificate key file password in plain text. Corresponds to the JSON property tlsCertificateKeyFilePassword

Returns:

  • (String)


6500
6501
6502
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6500

def tls_certificate_key_file_password
  @tls_certificate_key_file_password
end

#tls_certificate_key_file_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property tlsCertificateKeyFilePasswordSecretVersion

Returns:

  • (String)


6507
6508
6509
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6507

def tls_certificate_key_file_password_secret_version
  @tls_certificate_key_file_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


6512
6513
6514
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6512

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6519
6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6519

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @database_id = args[:database_id] if args.key?(:database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tls_ca_file = args[:tls_ca_file] if args.key?(:tls_ca_file)
  @tls_certificate_key_file = args[:tls_certificate_key_file] if args.key?(:tls_certificate_key_file)
  @tls_certificate_key_file_password = args[:tls_certificate_key_file_password] if args.key?(:tls_certificate_key_file_password)
  @tls_certificate_key_file_password_secret_version = args[:tls_certificate_key_file_password_secret_version] if args.key?(:tls_certificate_key_file_password_secret_version)
  @username = args[:username] if args.key?(:username)
end