Class: Google::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateMongodbConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMongodbConnectionProperties

Returns a new instance of GoldengateMongodbConnectionProperties.



6461
6462
6463
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com: 27017/recordsrecords' Corresponds to the JSON property connectionString

Returns:

  • (String)


6402
6403
6404
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6402

def connection_string
  @connection_string
end

#database_idString

Optional. The OCID of the Oracle Autonomous Json Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


6407
6408
6409
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6407

def database_id
  @database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6413
6414
6415
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6413

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6420
6421
6422
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6420

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security Type for MongoDB. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6425
6426
6427
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6425

def security_protocol
  @security_protocol
end

#technology_typeString

Optional. The technology type of MongodbConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6430
6431
6432
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6430

def technology_type
  @technology_type
end

#tls_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property tlsCaFile

Returns:

  • (String)


6436
6437
6438
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6436

def tls_ca_file
  @tls_ca_file
end

#tls_certificate_key_fileString

Optional. Client Certificate - The base64 encoded content of a .pem file, containing the client public key (for 2-way SSL). Corresponds to the JSON property tlsCertificateKeyFile

Returns:

  • (String)


6442
6443
6444
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6442

def tls_certificate_key_file
  @tls_certificate_key_file
end

#tls_certificate_key_file_passwordString

Optional. Input only. The Client Certificate key file password in plain text. Corresponds to the JSON property tlsCertificateKeyFilePassword

Returns:

  • (String)


6447
6448
6449
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6447

def tls_certificate_key_file_password
  @tls_certificate_key_file_password
end

#tls_certificate_key_file_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property tlsCertificateKeyFilePasswordSecretVersion

Returns:

  • (String)


6454
6455
6456
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6454

def tls_certificate_key_file_password_secret_version
  @tls_certificate_key_file_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


6459
6460
6461
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6459

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
6478
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6466

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @database_id = args[:database_id] if args.key?(:database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tls_ca_file = args[:tls_ca_file] if args.key?(:tls_ca_file)
  @tls_certificate_key_file = args[:tls_certificate_key_file] if args.key?(:tls_certificate_key_file)
  @tls_certificate_key_file_password = args[:tls_certificate_key_file_password] if args.key?(:tls_certificate_key_file_password)
  @tls_certificate_key_file_password_secret_version = args[:tls_certificate_key_file_password_secret_version] if args.key?(:tls_certificate_key_file_password_secret_version)
  @username = args[:username] if args.key?(:username)
end