Class: Google::Apis::OracledatabaseV1::GoldengateMongodbConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateMongodbConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMongodbConnectionProperties

Returns a new instance of GoldengateMongodbConnectionProperties.



6383
6384
6385
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stringString

Optional. MongoDB connection string. e.g.: 'mongodb://mongodb0.example.com: 27017/recordsrecords' Corresponds to the JSON property connectionString

Returns:

  • (String)


6324
6325
6326
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6324

def connection_string
  @connection_string
end

#database_idString

Optional. The OCID of the Oracle Autonomous Json Database. Corresponds to the JSON property databaseId

Returns:

  • (String)


6329
6330
6331
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6329

def database_id
  @database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect the Mongodb connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6335
6336
6337
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6335

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect the Mongodb connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6342
6343
6344
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6342

def password_secret_version
  @password_secret_version
end

#security_protocolString

Optional. Security Type for MongoDB. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6347
6348
6349
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6347

def security_protocol
  @security_protocol
end

#technology_typeString

Optional. The technology type of MongodbConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6352
6353
6354
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6352

def technology_type
  @technology_type
end

#tls_ca_fileString

Optional. Database Certificate - The content of a .pem file, containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property tlsCaFile

Returns:

  • (String)


6358
6359
6360
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6358

def tls_ca_file
  @tls_ca_file
end

#tls_certificate_key_fileString

Optional. Client Certificate - The content of a .pem file, containing the client public key (for 2-way SSL). Corresponds to the JSON property tlsCertificateKeyFile

Returns:

  • (String)


6364
6365
6366
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6364

def tls_certificate_key_file
  @tls_certificate_key_file
end

#tls_certificate_key_file_passwordString

Optional. Input only. The Client Certificate key file password in plain text. Corresponds to the JSON property tlsCertificateKeyFilePassword

Returns:

  • (String)


6369
6370
6371
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6369

def tls_certificate_key_file_password
  @tls_certificate_key_file_password
end

#tls_certificate_key_file_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the Client Certificate key file password in Secret Manager. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property tlsCertificateKeyFilePasswordSecretVersion

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6376

def tls_certificate_key_file_password_secret_version
  @tls_certificate_key_file_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


6381
6382
6383
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6381

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6388
6389
6390
6391
6392
6393
6394
6395
6396
6397
6398
6399
6400
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6388

def update!(**args)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @database_id = args[:database_id] if args.key?(:database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tls_ca_file = args[:tls_ca_file] if args.key?(:tls_ca_file)
  @tls_certificate_key_file = args[:tls_certificate_key_file] if args.key?(:tls_certificate_key_file)
  @tls_certificate_key_file_password = args[:tls_certificate_key_file_password] if args.key?(:tls_certificate_key_file_password)
  @tls_certificate_key_file_password_secret_version = args[:tls_certificate_key_file_password_secret_version] if args.key?(:tls_certificate_key_file_password_secret_version)
  @username = args[:username] if args.key?(:username)
end