Class: Google::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Properties of GoldengateMysqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateMysqlConnectionProperties

Returns a new instance of GoldengateMysqlConnectionProperties.



6622
6623
6624
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



6542
6543
6544
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6542

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


6547
6548
6549
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6547

def database
  @database
end

#db_system_idString

Optional. The OCID of the database system being referenced. Corresponds to the JSON property dbSystemId

Returns:

  • (String)


6552
6553
6554
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6552

def db_system_id
  @db_system_id
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


6557
6558
6559
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6557

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses to connect to MySQL in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6563
6564
6565
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6563

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses to connect to MySQL. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6570
6571
6572
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6570

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6575
6576
6577
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6575

def port
  @port
end

#security_protocolString

Optional. Security Type for MySQL. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6580
6581
6582
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6580

def security_protocol
  @security_protocol
end

#ssl_ca_fileString

Optional. Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1 and 2-way SSL). Corresponds to the JSON property sslCaFile

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6586

def ssl_ca_file
  @ssl_ca_file
end

#ssl_cert_fileString

Optional. Client Certificate - The base64 encoded content of a .pem or .crt file containing the client public key (for 2-way SSL). Corresponds to the JSON property sslCertFile

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6592

def ssl_cert_file
  @ssl_cert_file
end

#ssl_crl_fileString

Optional. The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA). Corresponds to the JSON property sslCrlFile

Returns:

  • (String)


6598
6599
6600
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6598

def ssl_crl_file
  @ssl_crl_file
end

#ssl_key_fileString

Optional. Client Key - The base64 encoded content of a .pem or .crt file containing the client private key (for 2-way SSL). Corresponds to the JSON property sslKeyFile

Returns:

  • (String)


6604
6605
6606
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6604

def ssl_key_file
  @ssl_key_file
end

#ssl_modeString

Optional. SSL modes for MySQL. Corresponds to the JSON property sslMode

Returns:

  • (String)


6609
6610
6611
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6609

def ssl_mode
  @ssl_mode
end

#technology_typeString

Optional. The technology type of MysqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6614
6615
6616
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6614

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


6620
6621
6622
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6620

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6627

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @db_system_id = args[:db_system_id] if args.key?(:db_system_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file)
  @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file)
  @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file)
  @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file)
  @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end