Class: Google::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateMysqlConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Properties of GoldengateMysqlConnection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#db_system_id ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_ca_file ⇒ String
Optional.
-
#ssl_cert_file ⇒ String
Optional.
-
#ssl_crl_file ⇒ String
Optional.
-
#ssl_key_file ⇒ String
Optional.
-
#ssl_mode ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateMysqlConnectionProperties
constructor
A new instance of GoldengateMysqlConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateMysqlConnectionProperties
Returns a new instance of GoldengateMysqlConnectionProperties.
6491 6492 6493 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
6411 6412 6413 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6411 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
6416 6417 6418 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6416 def database @database end |
#db_system_id ⇒ String
Optional. The OCID of the database system being referenced.
Corresponds to the JSON property dbSystemId
6421 6422 6423 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6421 def db_system_id @db_system_id end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
6426 6427 6428 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6426 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses to connect to MySQL
in plain text.
Corresponds to the JSON property password
6432 6433 6434 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6432 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses to connect to MySQL. Format:
projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6439 6440 6441 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6439 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
6444 6445 6446 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6444 def port @port end |
#security_protocol ⇒ String
Optional. Security Type for MySQL.
Corresponds to the JSON property securityProtocol
6449 6450 6451 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6449 def security_protocol @security_protocol end |
#ssl_ca_file ⇒ String
Optional. Database Certificate - The content of a .pem or .crt file containing
the server public key (for 1 and 2-way SSL).
Corresponds to the JSON property sslCaFile
6455 6456 6457 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6455 def ssl_ca_file @ssl_ca_file end |
#ssl_cert_file ⇒ String
Optional. Client Certificate - The content of a .pem or .crt file containing
the client public key (for 2-way SSL).
Corresponds to the JSON property sslCertFile
6461 6462 6463 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6461 def ssl_cert_file @ssl_cert_file end |
#ssl_crl_file ⇒ String
Optional. The list of certificates revoked by the trusted certificate
authorities (Trusted CA).
Corresponds to the JSON property sslCrlFile
6467 6468 6469 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6467 def ssl_crl_file @ssl_crl_file end |
#ssl_key_file ⇒ String
Optional. Client Key - The content of a .pem or .crt file containing the
client private key (for 2-way SSL).
Corresponds to the JSON property sslKeyFile
6473 6474 6475 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6473 def ssl_key_file @ssl_key_file end |
#ssl_mode ⇒ String
Optional. SSL modes for MySQL.
Corresponds to the JSON property sslMode
6478 6479 6480 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6478 def ssl_mode @ssl_mode end |
#technology_type ⇒ String
Optional. The technology type of MysqlConnection.
Corresponds to the JSON property technologyType
6483 6484 6485 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6483 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
6489 6490 6491 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6489 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6496 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @db_system_id = args[:db_system_id] if args.key?(:db_system_id) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file) @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file) @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file) @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file) @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |