Class: Google::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateOciObjectStorageConnection.
Instance Attribute Summary collapse
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#public_key_fingerprint ⇒ String
Optional.
-
#region ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#tenancy_id ⇒ String
Optional.
-
#use_resource_principal ⇒ Boolean
(also: #use_resource_principal?)
Optional.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateOciObjectStorageConnectionProperties
constructor
A new instance of GoldengateOciObjectStorageConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateOciObjectStorageConnectionProperties
Returns a new instance of GoldengateOciObjectStorageConnectionProperties.
6695 6696 6697 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_key_file ⇒ String
Optional. The content of the private key file (PEM file) corresponding to the
API key of the fingerprint.
Corresponds to the JSON property privateKeyFile
6654 6655 6656 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6654 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. The passphrase of the private key.
Corresponds to the JSON property privateKeyPassphraseSecret
6659 6660 6661 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6659 def private_key_passphrase_secret @private_key_passphrase_secret end |
#public_key_fingerprint ⇒ String
Optional. The fingerprint of the API Key of the user specified by the userId.
Corresponds to the JSON property publicKeyFingerprint
6664 6665 6666 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6664 def public_key_fingerprint @public_key_fingerprint end |
#region ⇒ String
Optional. The name of the region of OCI Object Storage. e.g.: us-ashburn-1 If
the region is not provided, backend will default to the default region.
Corresponds to the JSON property region
6670 6671 6672 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6670 def region @region end |
#technology_type ⇒ String
Optional. The technology type of OciObjectStorageConnection.
Corresponds to the JSON property technologyType
6675 6676 6677 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6675 def technology_type @technology_type end |
#tenancy_id ⇒ String
Optional. The OCID of the related OCI tenancy.
Corresponds to the JSON property tenancyId
6680 6681 6682 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6680 def tenancy_id @tenancy_id end |
#use_resource_principal ⇒ Boolean Also known as: use_resource_principal?
Optional. Specifies that the user intends to authenticate to the instance
using a resource principal.
Corresponds to the JSON property useResourcePrincipal
6686 6687 6688 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6686 def use_resource_principal @use_resource_principal end |
#user_id ⇒ String
Optional. The OCID of the OCI user who will access the Object Storage. The
user must have write access to the bucket they want to connect to.
Corresponds to the JSON property userId
6693 6694 6695 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6693 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6700 6701 6702 6703 6704 6705 6706 6707 6708 6709 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6700 def update!(**args) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint) @region = args[:region] if args.key?(:region) @technology_type = args[:technology_type] if args.key?(:technology_type) @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id) @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal) @user_id = args[:user_id] if args.key?(:user_id) end |