Class: Google::Apis::OracledatabaseV1::GoldengateOciObjectStorageConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOciObjectStorageConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOciObjectStorageConnectionProperties

Returns a new instance of GoldengateOciObjectStorageConnectionProperties.



6564
6565
6566
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6523
6524
6525
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6523

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6528
6529
6530
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6528

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the userId. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6533
6534
6535
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6533

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region of OCI Object Storage. e.g.: us-ashburn-1 If the region is not provided, backend will default to the default region. Corresponds to the JSON property region

Returns:

  • (String)


6539
6540
6541
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6539

def region
  @region
end

#technology_typeString

Optional. The technology type of OciObjectStorageConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6544
6545
6546
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6544

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the related OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6549
6550
6551
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6549

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6555
6556
6557
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6555

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access the Object Storage. The user must have write access to the bucket they want to connect to. Corresponds to the JSON property userId

Returns:

  • (String)


6562
6563
6564
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6562

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6569

def update!(**args)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end