Class: Google::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleAIDataPlatformConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleAiDataPlatformConnectionProperties

Returns a new instance of GoldengateOracleAiDataPlatformConnectionProperties.



6871
6872
6873
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_urlString

Optional. Connection URL. It must start with 'jdbc:spark://' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


6826
6827
6828
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6826

def connection_url
  @connection_url
end

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6832
6833
6834
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6832

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6837
6838
6839
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6837

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the user_id. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6842
6843
6844
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6842

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6847
6848
6849
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6847

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleAiDataPlatformConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6852
6853
6854
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6852

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the related OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6857
6858
6859
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6857

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6863
6864
6865
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6863

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access. Corresponds to the JSON property userId

Returns:

  • (String)


6869
6870
6871
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6869

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6876

def update!(**args)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end