Class: Google::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateOracleAIDataPlatformConnection.
Instance Attribute Summary collapse
-
#connection_url ⇒ String
Optional.
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#public_key_fingerprint ⇒ String
Optional.
-
#region ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#tenancy_id ⇒ String
Optional.
-
#use_resource_principal ⇒ Boolean
(also: #use_resource_principal?)
Optional.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateOracleAiDataPlatformConnectionProperties
constructor
A new instance of GoldengateOracleAiDataPlatformConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateOracleAiDataPlatformConnectionProperties
Returns a new instance of GoldengateOracleAiDataPlatformConnectionProperties.
6787 6788 6789 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_url ⇒ String
Optional. Connection URL. It must start with 'jdbc:spark://'
Corresponds to the JSON property connectionUrl
6742 6743 6744 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6742 def connection_url @connection_url end |
#private_key_file ⇒ String
Optional. The content of the private key file (PEM file) corresponding to the
API key of the fingerprint.
Corresponds to the JSON property privateKeyFile
6748 6749 6750 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6748 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. The passphrase of the private key.
Corresponds to the JSON property privateKeyPassphraseSecret
6753 6754 6755 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6753 def private_key_passphrase_secret @private_key_passphrase_secret end |
#public_key_fingerprint ⇒ String
Optional. The fingerprint of the API Key of the user specified by the user_id.
Corresponds to the JSON property publicKeyFingerprint
6758 6759 6760 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6758 def public_key_fingerprint @public_key_fingerprint end |
#region ⇒ String
Optional. The name of the region. e.g.: us-ashburn-1
Corresponds to the JSON property region
6763 6764 6765 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6763 def region @region end |
#technology_type ⇒ String
Optional. The technology type of OracleAiDataPlatformConnection.
Corresponds to the JSON property technologyType
6768 6769 6770 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6768 def technology_type @technology_type end |
#tenancy_id ⇒ String
Optional. The OCID of the related OCI tenancy.
Corresponds to the JSON property tenancyId
6773 6774 6775 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6773 def tenancy_id @tenancy_id end |
#use_resource_principal ⇒ Boolean Also known as: use_resource_principal?
Optional. Specifies that the user intends to authenticate to the instance
using a resource principal.
Corresponds to the JSON property useResourcePrincipal
6779 6780 6781 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6779 def use_resource_principal @use_resource_principal end |
#user_id ⇒ String
Optional. The OCID of the OCI user who will access.
Corresponds to the JSON property userId
6785 6786 6787 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6785 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6792 6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6792 def update!(**args) @connection_url = args[:connection_url] if args.key?(:connection_url) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint) @region = args[:region] if args.key?(:region) @technology_type = args[:technology_type] if args.key?(:technology_type) @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id) @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal) @user_id = args[:user_id] if args.key?(:user_id) end |