Class: Google::Apis::OracledatabaseV1::GoldengateOracleAiDataPlatformConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleAIDataPlatformConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleAiDataPlatformConnectionProperties

Returns a new instance of GoldengateOracleAiDataPlatformConnectionProperties.



6709
6710
6711
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_urlString

Optional. Connection URL. It must start with 'jdbc:spark://' Corresponds to the JSON property connectionUrl

Returns:

  • (String)


6664
6665
6666
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6664

def connection_url
  @connection_url
end

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6670
6671
6672
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6670

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6675
6676
6677
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6675

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the user_id. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6680
6681
6682
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6680

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6685
6686
6687
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6685

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleAiDataPlatformConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6690
6691
6692
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6690

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the related OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6695
6696
6697
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6695

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6701
6702
6703
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6701

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access. Corresponds to the JSON property userId

Returns:

  • (String)


6707
6708
6709
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6707

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6714

def update!(**args)
  @connection_url = args[:connection_url] if args.key?(:connection_url)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end