Class: Google::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of Goldengate Oracle Database Connection.
Instance Attribute Summary collapse
-
#authentication_mode ⇒ String
Optional.
-
#connection_string ⇒ String
Optional.
-
#gcp_oracle_database_id ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#session_mode ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
-
#wallet_file ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateOracleConnectionProperties
constructor
A new instance of GoldengateOracleConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateOracleConnectionProperties
Returns a new instance of GoldengateOracleConnectionProperties.
6915 6916 6917 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_mode ⇒ String
Optional. Authentication mode.
Corresponds to the JSON property authenticationMode
6865 6866 6867 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6865 def authentication_mode @authentication_mode end |
#connection_string ⇒ String
Optional. Connect descriptor or Easy Connect Naming method used to connect to
a database.
Corresponds to the JSON property connectionString
6871 6872 6873 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6871 def connection_string @connection_string end |
#gcp_oracle_database_id ⇒ String
Optional. Autonomous AI Database instance id of database in Oracle Database @
Google Cloud. If gcp_oracle_database_id is provided, connection_string must be
empty. Format: projects/project/locations/location/autonomousDatabases/
autonomous_database
Corresponds to the JSON property gcpOracleDatabaseId
6879 6880 6881 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6879 def gcp_oracle_database_id @gcp_oracle_database_id end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses in plain text.
Corresponds to the JSON property password
6884 6885 6886 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6884 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses. Format: projects/project/
secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
6891 6892 6893 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6891 def password_secret_version @password_secret_version end |
#session_mode ⇒ String
Optional. The mode of the database connection session to be established by the
data client.
Corresponds to the JSON property sessionMode
6897 6898 6899 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6897 def session_mode @session_mode end |
#technology_type ⇒ String
Optional. The technology type.
Corresponds to the JSON property technologyType
6902 6903 6904 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6902 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect.
Corresponds to the JSON property username
6907 6908 6909 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6907 def username @username end |
#wallet_file ⇒ String
Optional. The wallet contents Oracle Goldengate uses to make connections to a
database. This attribute is expected to be base64 encoded.
Corresponds to the JSON property walletFile
6913 6914 6915 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6913 def wallet_file @wallet_file end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6920 def update!(**args) @authentication_mode = args[:authentication_mode] if args.key?(:authentication_mode) @connection_string = args[:connection_string] if args.key?(:connection_string) @gcp_oracle_database_id = args[:gcp_oracle_database_id] if args.key?(:gcp_oracle_database_id) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @session_mode = args[:session_mode] if args.key?(:session_mode) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) @wallet_file = args[:wallet_file] if args.key?(:wallet_file) end |