Class: Google::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of Goldengate Oracle Database Connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleConnectionProperties

Returns a new instance of GoldengateOracleConnectionProperties.



6862
6863
6864
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_modeString

Optional. Authentication mode. Corresponds to the JSON property authenticationMode

Returns:

  • (String)


6812
6813
6814
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6812

def authentication_mode
  @authentication_mode
end

#connection_stringString

Optional. Connect descriptor or Easy Connect Naming method used to connect to a database. Corresponds to the JSON property connectionString

Returns:

  • (String)


6818
6819
6820
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6818

def connection_string
  @connection_string
end

#gcp_oracle_database_idString

Optional. Autonomous AI Database instance id of database in Oracle Database @ Google Cloud. If gcp_oracle_database_id is provided, connection_string must be empty. Format: projects/project/locations/location/autonomousDatabases/ autonomous_database Corresponds to the JSON property gcpOracleDatabaseId

Returns:

  • (String)


6826
6827
6828
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6826

def gcp_oracle_database_id
  @gcp_oracle_database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6831
6832
6833
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6831

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses. Format: projects/project/ secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6838
6839
6840
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6838

def password_secret_version
  @password_secret_version
end

#session_modeString

Optional. The mode of the database connection session to be established by the data client. Corresponds to the JSON property sessionMode

Returns:

  • (String)


6844
6845
6846
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6844

def session_mode
  @session_mode
end

#technology_typeString

Optional. The technology type. Corresponds to the JSON property technologyType

Returns:

  • (String)


6849
6850
6851
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6849

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect. Corresponds to the JSON property username

Returns:

  • (String)


6854
6855
6856
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6854

def username
  @username
end

#wallet_fileString

Optional. The wallet contents Oracle Goldengate uses to make connections to a database. This attribute is expected to be base64 encoded. Corresponds to the JSON property walletFile

Returns:

  • (String)


6860
6861
6862
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6860

def wallet_file
  @wallet_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6867

def update!(**args)
  @authentication_mode = args[:authentication_mode] if args.key?(:authentication_mode)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @gcp_oracle_database_id = args[:gcp_oracle_database_id] if args.key?(:gcp_oracle_database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @session_mode = args[:session_mode] if args.key?(:session_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
  @wallet_file = args[:wallet_file] if args.key?(:wallet_file)
end