Class: Google::Apis::OracledatabaseV1::GoldengateOracleConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of Goldengate Oracle Database Connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleConnectionProperties

Returns a new instance of GoldengateOracleConnectionProperties.



6782
6783
6784
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_modeString

Optional. Authentication mode. Corresponds to the JSON property authenticationMode

Returns:

  • (String)


6734
6735
6736
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6734

def authentication_mode
  @authentication_mode
end

#connection_stringString

Optional. Connect descriptor or Easy Connect Naming method used to connect to a database. Corresponds to the JSON property connectionString

Returns:

  • (String)


6740
6741
6742
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6740

def connection_string
  @connection_string
end

#gcp_oracle_database_idString

Optional. Database instance id of database in Oracle Database @ Google Cloud. If gcp_oracle_database_id is provided, connection_string must be empty. Corresponds to the JSON property gcpOracleDatabaseId

Returns:

  • (String)


6746
6747
6748
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6746

def gcp_oracle_database_id
  @gcp_oracle_database_id
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6751
6752
6753
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6751

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses. Format: projects/project/ secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6758
6759
6760
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6758

def password_secret_version
  @password_secret_version
end

#session_modeString

Optional. The mode of the database connection session to be established by the data client. Corresponds to the JSON property sessionMode

Returns:

  • (String)


6764
6765
6766
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6764

def session_mode
  @session_mode
end

#technology_typeString

Optional. The technology type. Corresponds to the JSON property technologyType

Returns:

  • (String)


6769
6770
6771
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6769

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect. Corresponds to the JSON property username

Returns:

  • (String)


6774
6775
6776
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6774

def username
  @username
end

#wallet_fileString

Optional. The wallet contents Oracle Goldengate uses to make connections to a database. Corresponds to the JSON property walletFile

Returns:

  • (String)


6780
6781
6782
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6780

def wallet_file
  @wallet_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6787
6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6787

def update!(**args)
  @authentication_mode = args[:authentication_mode] if args.key?(:authentication_mode)
  @connection_string = args[:connection_string] if args.key?(:connection_string)
  @gcp_oracle_database_id = args[:gcp_oracle_database_id] if args.key?(:gcp_oracle_database_id)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @session_mode = args[:session_mode] if args.key?(:session_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
  @wallet_file = args[:wallet_file] if args.key?(:wallet_file)
end