Class: Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleNosqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties

Returns a new instance of GoldengateOracleNosqlConnectionProperties.



7011
7012
7013
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6972
6973
6974
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6972

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6977
6978
6979
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6977

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the userId. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6982
6983
6984
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6982

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6987
6988
6989
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6987

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleNosqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6992
6993
6994
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6992

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6997
6998
6999
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6997

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


7003
7004
7005
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7003

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access the Oracle NoSQL database. Corresponds to the JSON property userId

Returns:

  • (String)


7009
7010
7011
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7009

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7016

def update!(**args)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end