Class: Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleNosqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties

Returns a new instance of GoldengateOracleNosqlConnectionProperties.



6927
6928
6929
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6888
6889
6890
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6888

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6893
6894
6895
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6893

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the userId. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6898
6899
6900
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6898

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6903
6904
6905
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6903

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleNosqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6908
6909
6910
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6908

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6913
6914
6915
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6913

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6919
6920
6921
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6919

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access the Oracle NoSQL database. Corresponds to the JSON property userId

Returns:

  • (String)


6925
6926
6927
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6925

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6932
6933
6934
6935
6936
6937
6938
6939
6940
6941
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6932

def update!(**args)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end