Class: Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateOracleNosqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties

Returns a new instance of GoldengateOracleNosqlConnectionProperties.



6849
6850
6851
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_key_fileString

Optional. The content of the private key file (PEM file) corresponding to the API key of the fingerprint. Corresponds to the JSON property privateKeyFile

Returns:

  • (String)


6810
6811
6812
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6810

def private_key_file
  @private_key_file
end

#private_key_passphrase_secretString

Optional. The passphrase of the private key. Corresponds to the JSON property privateKeyPassphraseSecret

Returns:

  • (String)


6815
6816
6817
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6815

def private_key_passphrase_secret
  @private_key_passphrase_secret
end

#public_key_fingerprintString

Optional. The fingerprint of the API Key of the user specified by the userId. Corresponds to the JSON property publicKeyFingerprint

Returns:

  • (String)


6820
6821
6822
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6820

def public_key_fingerprint
  @public_key_fingerprint
end

#regionString

Optional. The name of the region. e.g.: us-ashburn-1 Corresponds to the JSON property region

Returns:

  • (String)


6825
6826
6827
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6825

def region
  @region
end

#technology_typeString

Optional. The technology type of OracleNosqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6830
6831
6832
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6830

def technology_type
  @technology_type
end

#tenancy_idString

Optional. The OCID of the OCI tenancy. Corresponds to the JSON property tenancyId

Returns:

  • (String)


6835
6836
6837
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6835

def tenancy_id
  @tenancy_id
end

#use_resource_principalBoolean Also known as: use_resource_principal?

Optional. Specifies that the user intends to authenticate to the instance using a resource principal. Corresponds to the JSON property useResourcePrincipal

Returns:

  • (Boolean)


6841
6842
6843
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6841

def use_resource_principal
  @use_resource_principal
end

#user_idString

Optional. The OCID of the OCI user who will access the Oracle NoSQL database. Corresponds to the JSON property userId

Returns:

  • (String)


6847
6848
6849
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6847

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6854

def update!(**args)
  @private_key_file = args[:private_key_file] if args.key?(:private_key_file)
  @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret)
  @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint)
  @region = args[:region] if args.key?(:region)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id)
  @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal)
  @user_id = args[:user_id] if args.key?(:user_id)
end