Class: Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateOracleNosqlConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateOracleNosqlConnection.
Instance Attribute Summary collapse
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#public_key_fingerprint ⇒ String
Optional.
-
#region ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#tenancy_id ⇒ String
Optional.
-
#use_resource_principal ⇒ Boolean
(also: #use_resource_principal?)
Optional.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties
constructor
A new instance of GoldengateOracleNosqlConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateOracleNosqlConnectionProperties
Returns a new instance of GoldengateOracleNosqlConnectionProperties.
6847 6848 6849 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_key_file ⇒ String
Optional. The content of the private key file (PEM file) corresponding to the
API key of the fingerprint.
Corresponds to the JSON property privateKeyFile
6808 6809 6810 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6808 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. The passphrase of the private key.
Corresponds to the JSON property privateKeyPassphraseSecret
6813 6814 6815 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6813 def private_key_passphrase_secret @private_key_passphrase_secret end |
#public_key_fingerprint ⇒ String
Optional. The fingerprint of the API Key of the user specified by the userId.
Corresponds to the JSON property publicKeyFingerprint
6818 6819 6820 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6818 def public_key_fingerprint @public_key_fingerprint end |
#region ⇒ String
Optional. The name of the region. e.g.: us-ashburn-1
Corresponds to the JSON property region
6823 6824 6825 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6823 def region @region end |
#technology_type ⇒ String
Optional. The technology type of OracleNosqlConnection.
Corresponds to the JSON property technologyType
6828 6829 6830 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6828 def technology_type @technology_type end |
#tenancy_id ⇒ String
Optional. The OCID of the OCI tenancy.
Corresponds to the JSON property tenancyId
6833 6834 6835 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6833 def tenancy_id @tenancy_id end |
#use_resource_principal ⇒ Boolean Also known as: use_resource_principal?
Optional. Specifies that the user intends to authenticate to the instance
using a resource principal.
Corresponds to the JSON property useResourcePrincipal
6839 6840 6841 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6839 def use_resource_principal @use_resource_principal end |
#user_id ⇒ String
Optional. The OCID of the OCI user who will access the Oracle NoSQL database.
Corresponds to the JSON property userId
6845 6846 6847 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6845 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6852 def update!(**args) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @public_key_fingerprint = args[:public_key_fingerprint] if args.key?(:public_key_fingerprint) @region = args[:region] if args.key?(:region) @technology_type = args[:technology_type] if args.key?(:technology_type) @tenancy_id = args[:tenancy_id] if args.key?(:tenancy_id) @use_resource_principal = args[:use_resource_principal] if args.key?(:use_resource_principal) @user_id = args[:user_id] if args.key?(:user_id) end |