Class: Google::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengatePostgresqlConnection.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional.
-
#database ⇒ String
Optional.
-
#db_system_id ⇒ String
Optional.
-
#host ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#port ⇒ Fixnum
Optional.
-
#security_protocol ⇒ String
Optional.
-
#ssl_ca_file ⇒ String
Optional.
-
#ssl_cert_file ⇒ String
Optional.
-
#ssl_crl_file ⇒ String
Optional.
-
#ssl_key_file ⇒ String
Optional.
-
#ssl_mode ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengatePostgresqlConnectionProperties
constructor
A new instance of GoldengatePostgresqlConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengatePostgresqlConnectionProperties
Returns a new instance of GoldengatePostgresqlConnectionProperties.
7055 7056 7057 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<Google::Apis::OracledatabaseV1::NameValuePair>
Optional. An array of name-value pair attribute entries. Used as additional
parameters in connection string.
Corresponds to the JSON property additionalAttributes
6977 6978 6979 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6977 def additional_attributes @additional_attributes end |
#database ⇒ String
Optional. The name of the database.
Corresponds to the JSON property database
6982 6983 6984 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6982 def database @database end |
#db_system_id ⇒ String
Optional. The OCID of the database system being referenced.
Corresponds to the JSON property dbSystemId
6987 6988 6989 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6987 def db_system_id @db_system_id end |
#host ⇒ String
Optional. The name or address of a host.
Corresponds to the JSON property host
6992 6993 6994 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6992 def host @host end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses for PostgreSQL
connection in plain text.
Corresponds to the JSON property password
6998 6999 7000 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6998 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses for PostgreSQL connection.
Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
7005 7006 7007 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7005 def password_secret_version @password_secret_version end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
7010 7011 7012 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7010 def port @port end |
#security_protocol ⇒ String
Optional. Security protocol for PostgreSQL.
Corresponds to the JSON property securityProtocol
7015 7016 7017 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7015 def security_protocol @security_protocol end |
#ssl_ca_file ⇒ String
Optional. The base64 encoded certificate of the trusted certificate
authorities (Trusted CA) for PostgreSQL.
Corresponds to the JSON property sslCaFile
7021 7022 7023 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7021 def ssl_ca_file @ssl_ca_file end |
#ssl_cert_file ⇒ String
Optional. The base64 encoded certificate of the PostgreSQL server.
Corresponds to the JSON property sslCertFile
7026 7027 7028 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7026 def ssl_cert_file @ssl_cert_file end |
#ssl_crl_file ⇒ String
Optional. The base64 encoded list of certificates revoked by the trusted
certificate authorities (Trusted CA).
Corresponds to the JSON property sslCrlFile
7032 7033 7034 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7032 def ssl_crl_file @ssl_crl_file end |
#ssl_key_file ⇒ String
Optional. The base64 encoded private key of the PostgreSQL server.
Corresponds to the JSON property sslKeyFile
7037 7038 7039 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7037 def ssl_key_file @ssl_key_file end |
#ssl_mode ⇒ String
Optional. SSL modes for PostgreSQL.
Corresponds to the JSON property sslMode
7042 7043 7044 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7042 def ssl_mode @ssl_mode end |
#technology_type ⇒ String
Optional. The technology type of PostgresqlConnection.
Corresponds to the JSON property technologyType
7047 7048 7049 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7047 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect the associated system
of the given technology.
Corresponds to the JSON property username
7053 7054 7055 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7053 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7060 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @database = args[:database] if args.key?(:database) @db_system_id = args[:db_system_id] if args.key?(:db_system_id) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @port = args[:port] if args.key?(:port) @security_protocol = args[:security_protocol] if args.key?(:security_protocol) @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file) @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file) @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file) @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file) @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |