Class: Google::Apis::OracledatabaseV1::GoldengatePostgresqlConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengatePostgresqlConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengatePostgresqlConnectionProperties

Returns a new instance of GoldengatePostgresqlConnectionProperties.



6975
6976
6977
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<Google::Apis::OracledatabaseV1::NameValuePair>

Optional. An array of name-value pair attribute entries. Used as additional parameters in connection string. Corresponds to the JSON property additionalAttributes



6897
6898
6899
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6897

def additional_attributes
  @additional_attributes
end

#databaseString

Optional. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


6902
6903
6904
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6902

def database
  @database
end

#db_system_idString

Optional. The OCID of the database system being referenced. Corresponds to the JSON property dbSystemId

Returns:

  • (String)


6907
6908
6909
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6907

def db_system_id
  @db_system_id
end

#hostString

Optional. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


6912
6913
6914
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6912

def host
  @host
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for PostgreSQL connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


6918
6919
6920
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6918

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for PostgreSQL connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


6925
6926
6927
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6925

def password_secret_version
  @password_secret_version
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6930
6931
6932
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6930

def port
  @port
end

#security_protocolString

Optional. Security protocol for PostgreSQL. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


6935
6936
6937
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6935

def security_protocol
  @security_protocol
end

#ssl_ca_fileString

Optional. The certificate of the trusted certificate authorities (Trusted CA) for PostgreSQL. Corresponds to the JSON property sslCaFile

Returns:

  • (String)


6941
6942
6943
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6941

def ssl_ca_file
  @ssl_ca_file
end

#ssl_cert_fileString

Optional. The certificate of the PostgreSQL server. Corresponds to the JSON property sslCertFile

Returns:

  • (String)


6946
6947
6948
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6946

def ssl_cert_file
  @ssl_cert_file
end

#ssl_crl_fileString

Optional. The list of certificates revoked by the trusted certificate authorities (Trusted CA). Corresponds to the JSON property sslCrlFile

Returns:

  • (String)


6952
6953
6954
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6952

def ssl_crl_file
  @ssl_crl_file
end

#ssl_key_fileString

Optional. The private key of the PostgreSQL server. Corresponds to the JSON property sslKeyFile

Returns:

  • (String)


6957
6958
6959
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6957

def ssl_key_file
  @ssl_key_file
end

#ssl_modeString

Optional. SSL modes for PostgreSQL. Corresponds to the JSON property sslMode

Returns:

  • (String)


6962
6963
6964
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6962

def ssl_mode
  @ssl_mode
end

#technology_typeString

Optional. The technology type of PostgresqlConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


6967
6968
6969
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6967

def technology_type
  @technology_type
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


6973
6974
6975
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6973

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6980
6981
6982
6983
6984
6985
6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 6980

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @database = args[:database] if args.key?(:database)
  @db_system_id = args[:db_system_id] if args.key?(:db_system_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @port = args[:port] if args.key?(:port)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @ssl_ca_file = args[:ssl_ca_file] if args.key?(:ssl_ca_file)
  @ssl_cert_file = args[:ssl_cert_file] if args.key?(:ssl_cert_file)
  @ssl_crl_file = args[:ssl_crl_file] if args.key?(:ssl_crl_file)
  @ssl_key_file = args[:ssl_key_file] if args.key?(:ssl_key_file)
  @ssl_mode = args[:ssl_mode] if args.key?(:ssl_mode)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @username = args[:username] if args.key?(:username)
end