Class: Google::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateRedisConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateRedisConnectionProperties

Returns a new instance of GoldengateRedisConnectionProperties.



7163
7164
7165
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Authentication type for Redis. Corresponds to the JSON property authenticationType

Returns:

  • (String)


7086
7087
7088
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7086

def authentication_type
  @authentication_type
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


7091
7092
7093
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7091

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


7096
7097
7098
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7096

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


7103
7104
7105
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7103

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Redis connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


7109
7110
7111
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7109

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Redis connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


7116
7117
7118
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7116

def password_secret_version
  @password_secret_version
end

#redis_cluster_idString

Optional. The OCID of the Redis cluster. Corresponds to the JSON property redisClusterId

Returns:

  • (String)


7121
7122
7123
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7121

def redis_cluster_id
  @redis_cluster_id
end

#security_protocolString

Optional. Security protocol for Redis. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


7126
7127
7128
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7126

def security_protocol
  @security_protocol
end

#serversString

Optional. Comma separated list of Redis server addresses, specified as host: port entries, where :port is optional. If port is not specified, it defaults to 6379. Example: "server1.example.com:6379,server2.example.com:6379" Corresponds to the JSON property servers

Returns:

  • (String)


7133
7134
7135
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7133

def servers
  @servers
end

#technology_typeString

Optional. The technology type of RedisConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


7138
7139
7140
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7138

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


7143
7144
7145
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7143

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


7148
7149
7150
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7148

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


7155
7156
7157
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7155

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


7161
7162
7163
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7161

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7168

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @redis_cluster_id = args[:redis_cluster_id] if args.key?(:redis_cluster_id)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @servers = args[:servers] if args.key?(:servers)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @username = args[:username] if args.key?(:username)
end