Class: Google::Apis::OracledatabaseV1::GoldengateRedisConnectionProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of GoldengateRedisConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoldengateRedisConnectionProperties

Returns a new instance of GoldengateRedisConnectionProperties.



7085
7086
7087
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. Authentication type for Redis. Corresponds to the JSON property authenticationType

Returns:

  • (String)


7008
7009
7010
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7008

def authentication_type
  @authentication_type
end

#key_store_fileString

Optional. The base64 encoded content of the KeyStore file. Corresponds to the JSON property keyStoreFile

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7013

def key_store_file
  @key_store_file
end

#key_store_passwordString

Optional. Input only. The KeyStore password in plain text. Corresponds to the JSON property keyStorePassword

Returns:

  • (String)


7018
7019
7020
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7018

def key_store_password
  @key_store_password
end

#key_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the KeyStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property keyStorePasswordSecretVersion

Returns:

  • (String)


7025
7026
7027
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7025

def key_store_password_secret_version
  @key_store_password_secret_version
end

#passwordString

Optional. Input only. The password Oracle Goldengate uses for Redis connection in plain text. Corresponds to the JSON property password

Returns:

  • (String)


7031
7032
7033
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7031

def password
  @password
end

#password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the password Oracle Goldengate uses for Redis connection. Format: projects/project/secrets/secret/versions/version. Corresponds to the JSON property passwordSecretVersion

Returns:

  • (String)


7038
7039
7040
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7038

def password_secret_version
  @password_secret_version
end

#redis_cluster_idString

Optional. The OCID of the Redis cluster. Corresponds to the JSON property redisClusterId

Returns:

  • (String)


7043
7044
7045
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7043

def redis_cluster_id
  @redis_cluster_id
end

#security_protocolString

Optional. Security protocol for Redis. Corresponds to the JSON property securityProtocol

Returns:

  • (String)


7048
7049
7050
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7048

def security_protocol
  @security_protocol
end

#serversString

Optional. Comma separated list of Redis server addresses, specified as host: port entries, where :port is optional. If port is not specified, it defaults to 6379. Example: "server1.example.com:6379,server2.example.com:6379" Corresponds to the JSON property servers

Returns:

  • (String)


7055
7056
7057
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7055

def servers
  @servers
end

#technology_typeString

Optional. The technology type of RedisConnection. Corresponds to the JSON property technologyType

Returns:

  • (String)


7060
7061
7062
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7060

def technology_type
  @technology_type
end

#trust_store_fileString

Optional. The base64 encoded content of the TrustStore file. Corresponds to the JSON property trustStoreFile

Returns:

  • (String)


7065
7066
7067
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7065

def trust_store_file
  @trust_store_file
end

#trust_store_passwordString

Optional. Input only. The TrustStore password in plain text. Corresponds to the JSON property trustStorePassword

Returns:

  • (String)


7070
7071
7072
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7070

def trust_store_password
  @trust_store_password
end

#trust_store_password_secret_versionString

Optional. Input only. The resource name of a secret version in Secret Manager which contains the TrustStore password. Format: projects/project/secrets/ secret/versions/version. Corresponds to the JSON property trustStorePasswordSecretVersion

Returns:

  • (String)


7077
7078
7079
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7077

def trust_store_password_secret_version
  @trust_store_password_secret_version
end

#usernameString

Optional. The username Oracle Goldengate uses to connect the associated system of the given technology. Corresponds to the JSON property username

Returns:

  • (String)


7083
7084
7085
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7083

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7090

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @key_store_file = args[:key_store_file] if args.key?(:key_store_file)
  @key_store_password = args[:key_store_password] if args.key?(:key_store_password)
  @key_store_password_secret_version = args[:key_store_password_secret_version] if args.key?(:key_store_password_secret_version)
  @password = args[:password] if args.key?(:password)
  @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version)
  @redis_cluster_id = args[:redis_cluster_id] if args.key?(:redis_cluster_id)
  @security_protocol = args[:security_protocol] if args.key?(:security_protocol)
  @servers = args[:servers] if args.key?(:servers)
  @technology_type = args[:technology_type] if args.key?(:technology_type)
  @trust_store_file = args[:trust_store_file] if args.key?(:trust_store_file)
  @trust_store_password = args[:trust_store_password] if args.key?(:trust_store_password)
  @trust_store_password_secret_version = args[:trust_store_password_secret_version] if args.key?(:trust_store_password_secret_version)
  @username = args[:username] if args.key?(:username)
end