Class: Google::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateSnowflakeConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateSnowflakeConnectionProperties
constructor
A new instance of GoldengateSnowflakeConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateSnowflakeConnectionProperties
Returns a new instance of GoldengateSnowflakeConnectionProperties.
7234 7235 7236 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Used authentication mechanism to access Snowflake.
Corresponds to the JSON property authenticationType
7193 7194 7195 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7193 def authentication_type @authentication_type end |
#connection_url ⇒ String
Optional. JDBC connection URL. e.g.: 'jdbc:snowflake://.snowflakecomputing.com/
?warehouse=&db='
Corresponds to the JSON property connectionUrl
7199 7200 7201 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7199 def connection_url @connection_url end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses to connect to
Snowflake platform in plain text.
Corresponds to the JSON property password
7205 7206 7207 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7205 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses to connect to Snowflake
platform. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
7212 7213 7214 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7212 def password_secret_version @password_secret_version end |
#private_key_file ⇒ String
Optional. The content of private key file in PEM format.
Corresponds to the JSON property privateKeyFile
7217 7218 7219 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7217 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. Password if the private key file is encrypted.
Corresponds to the JSON property privateKeyPassphraseSecret
7222 7223 7224 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7222 def private_key_passphrase_secret @private_key_passphrase_secret end |
#technology_type ⇒ String
Optional. The technology type of SnowflakeConnection.
Corresponds to the JSON property technologyType
7227 7228 7229 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7227 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to Snowflake.
Corresponds to the JSON property username
7232 7233 7234 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7232 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7239 7240 7241 7242 7243 7244 7245 7246 7247 7248 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7239 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @connection_url = args[:connection_url] if args.key?(:connection_url) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |