Class: Google::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::GoldengateSnowflakeConnectionProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of GoldengateSnowflakeConnection.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#connection_url ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#password_secret_version ⇒ String
Optional.
-
#private_key_file ⇒ String
Optional.
-
#private_key_passphrase_secret ⇒ String
Optional.
-
#technology_type ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoldengateSnowflakeConnectionProperties
constructor
A new instance of GoldengateSnowflakeConnectionProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoldengateSnowflakeConnectionProperties
Returns a new instance of GoldengateSnowflakeConnectionProperties.
7154 7155 7156 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. Used authentication mechanism to access Snowflake.
Corresponds to the JSON property authenticationType
7113 7114 7115 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7113 def authentication_type @authentication_type end |
#connection_url ⇒ String
Optional. JDBC connection URL. e.g.: 'jdbc:snowflake://.snowflakecomputing.com/
?warehouse=&db='
Corresponds to the JSON property connectionUrl
7119 7120 7121 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7119 def connection_url @connection_url end |
#password ⇒ String
Optional. Input only. The password Oracle Goldengate uses to connect to
Snowflake platform in plain text.
Corresponds to the JSON property password
7125 7126 7127 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7125 def password @password end |
#password_secret_version ⇒ String
Optional. Input only. The resource name of a secret version in Secret Manager
which contains the password Oracle Goldengate uses to connect to Snowflake
platform. Format: projects/project/secrets/secret/versions/version.
Corresponds to the JSON property passwordSecretVersion
7132 7133 7134 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7132 def password_secret_version @password_secret_version end |
#private_key_file ⇒ String
Optional. The content of private key file in PEM format.
Corresponds to the JSON property privateKeyFile
7137 7138 7139 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7137 def private_key_file @private_key_file end |
#private_key_passphrase_secret ⇒ String
Optional. Password if the private key file is encrypted.
Corresponds to the JSON property privateKeyPassphraseSecret
7142 7143 7144 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7142 def private_key_passphrase_secret @private_key_passphrase_secret end |
#technology_type ⇒ String
Optional. The technology type of SnowflakeConnection.
Corresponds to the JSON property technologyType
7147 7148 7149 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7147 def technology_type @technology_type end |
#username ⇒ String
Optional. The username Oracle Goldengate uses to connect to Snowflake.
Corresponds to the JSON property username
7152 7153 7154 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7152 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7159 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @connection_url = args[:connection_url] if args.key?(:connection_url) @password = args[:password] if args.key?(:password) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @private_key_file = args[:private_key_file] if args.key?(:private_key_file) @private_key_passphrase_secret = args[:private_key_passphrase_secret] if args.key?(:private_key_passphrase_secret) @technology_type = args[:technology_type] if args.key?(:technology_type) @username = args[:username] if args.key?(:username) end |