Class: Google::Apis::OracledatabaseV1::IdentityConnector
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::IdentityConnector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The identity connector details which will allow OCI to securely access the resources in the customer project.
Instance Attribute Summary collapse
-
#connection_state ⇒ String
Output only.
-
#service_agent_email ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityConnector
constructor
A new instance of IdentityConnector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityConnector
Returns a new instance of IdentityConnector.
3646 3647 3648 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_state ⇒ String
Output only. The connection state of the identity connector.
Corresponds to the JSON property connectionState
3637 3638 3639 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3637 def connection_state @connection_state end |
#service_agent_email ⇒ String
Output only. A google managed service account on which customers can grant
roles to access resources in the customer project. Example: p176944527254-55-
75119d87fd8f@gcp-sa-oci.iam.gserviceaccount.com
Corresponds to the JSON property serviceAgentEmail
3644 3645 3646 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3644 def service_agent_email @service_agent_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3651 3652 3653 3654 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3651 def update!(**args) @connection_state = args[:connection_state] if args.key?(:connection_state) @service_agent_email = args[:service_agent_email] if args.key?(:service_agent_email) end |