Class: Google::Apis::OracledatabaseV1::KafkaBootstrapServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents a Kafka bootstrap server with host name, optional port defaults to 9092, and an optional private ip.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KafkaBootstrapServer

Returns a new instance of KafkaBootstrapServer.



7436
7437
7438
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Required. The name or address of a host. Corresponds to the JSON property host

Returns:

  • (String)


7418
7419
7420
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7418

def host
  @host
end

#portFixnum

Optional. The port of an endpoint usually specified for a connection. Corresponds to the JSON property port

Returns:

  • (Fixnum)


7423
7424
7425
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7423

def port
  @port
end

#private_ip_addressString

Optional. The private IP address of the connection's endpoint in the customer' s VCN, typically a database endpoint or a big data endpoint (e.g. Kafka bootstrap server). In case the privateIp is provided, the subnetId must also be provided. In case the privateIp (and the subnetId) is not provided it is assumed the datasource is publicly accessible. In case the connection is accessible only privately, the lack of privateIp will result in not being able to access the connection. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


7434
7435
7436
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7434

def private_ip_address
  @private_ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7441
7442
7443
7444
7445
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7441

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
end