Class: Google::Apis::OracledatabaseV1::KafkaBootstrapServer
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::KafkaBootstrapServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents a Kafka bootstrap server with host name, optional port defaults to 9092, and an optional private ip.
Instance Attribute Summary collapse
-
#host ⇒ String
Required.
-
#port ⇒ Fixnum
Optional.
-
#private_ip_address ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KafkaBootstrapServer
constructor
A new instance of KafkaBootstrapServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KafkaBootstrapServer
Returns a new instance of KafkaBootstrapServer.
7356 7357 7358 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Required. The name or address of a host.
Corresponds to the JSON property host
7338 7339 7340 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7338 def host @host end |
#port ⇒ Fixnum
Optional. The port of an endpoint usually specified for a connection.
Corresponds to the JSON property port
7343 7344 7345 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7343 def port @port end |
#private_ip_address ⇒ String
Optional. The private IP address of the connection's endpoint in the customer'
s VCN, typically a database endpoint or a big data endpoint (e.g. Kafka
bootstrap server). In case the privateIp is provided, the subnetId must also
be provided. In case the privateIp (and the subnetId) is not provided it is
assumed the datasource is publicly accessible. In case the connection is
accessible only privately, the lack of privateIp will result in not being able
to access the connection.
Corresponds to the JSON property privateIpAddress
7354 7355 7356 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7354 def private_ip_address @private_ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7361 7362 7363 7364 7365 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 7361 def update!(**args) @host = args[:host] if args.key?(:host) @port = args[:port] if args.key?(:port) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) end |