Class: Google::Apis::OracledatabaseV1::ListCloudExadataInfrastructuresResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListCloudExadataInfrastructuresResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for CloudExadataInfrastructures.list.
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructures ⇒ Array<Google::Apis::OracledatabaseV1::CloudExadataInfrastructure>
The list of Exadata Infrastructures.
-
#next_page_token ⇒ String
A token for fetching next page of response.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCloudExadataInfrastructuresResponse
constructor
A new instance of ListCloudExadataInfrastructuresResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCloudExadataInfrastructuresResponse
Returns a new instance of ListCloudExadataInfrastructuresResponse.
3784 3785 3786 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_exadata_infrastructures ⇒ Array<Google::Apis::OracledatabaseV1::CloudExadataInfrastructure>
The list of Exadata Infrastructures.
Corresponds to the JSON property cloudExadataInfrastructures
3771 3772 3773 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3771 def cloud_exadata_infrastructures @cloud_exadata_infrastructures end |
#next_page_token ⇒ String
A token for fetching next page of response.
Corresponds to the JSON property nextPageToken
3776 3777 3778 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3776 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
3782 3783 3784 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3782 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3789 3790 3791 3792 3793 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3789 def update!(**args) @cloud_exadata_infrastructures = args[:cloud_exadata_infrastructures] if args.key?(:cloud_exadata_infrastructures) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |