Class: Google::Apis::OracledatabaseV1::ListCloudVmClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListCloudVmClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for CloudVmCluster.List.
Instance Attribute Summary collapse
-
#cloud_vm_clusters ⇒ Array<Google::Apis::OracledatabaseV1::CloudVmCluster>
The list of VM Clusters.
-
#next_page_token ⇒ String
A token to fetch the next page of results.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCloudVmClustersResponse
constructor
A new instance of ListCloudVmClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCloudVmClustersResponse
Returns a new instance of ListCloudVmClustersResponse.
3816 3817 3818 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_vm_clusters ⇒ Array<Google::Apis::OracledatabaseV1::CloudVmCluster>
The list of VM Clusters.
Corresponds to the JSON property cloudVmClusters
3803 3804 3805 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3803 def cloud_vm_clusters @cloud_vm_clusters end |
#next_page_token ⇒ String
A token to fetch the next page of results.
Corresponds to the JSON property nextPageToken
3808 3809 3810 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3808 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
3814 3815 3816 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3814 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3821 3822 3823 3824 3825 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3821 def update!(**args) @cloud_vm_clusters = args[:cloud_vm_clusters] if args.key?(:cloud_vm_clusters) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |