Class: Google::Apis::OracledatabaseV1::ListCloudVmClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListCloudVmClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for CloudVmCluster.List.
Instance Attribute Summary collapse
-
#cloud_vm_clusters ⇒ Array<Google::Apis::OracledatabaseV1::CloudVmCluster>
The list of VM Clusters.
-
#next_page_token ⇒ String
A token to fetch the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCloudVmClustersResponse
constructor
A new instance of ListCloudVmClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCloudVmClustersResponse
Returns a new instance of ListCloudVmClustersResponse.
3796 3797 3798 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_vm_clusters ⇒ Array<Google::Apis::OracledatabaseV1::CloudVmCluster>
The list of VM Clusters.
Corresponds to the JSON property cloudVmClusters
3789 3790 3791 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3789 def cloud_vm_clusters @cloud_vm_clusters end |
#next_page_token ⇒ String
A token to fetch the next page of results.
Corresponds to the JSON property nextPageToken
3794 3795 3796 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3794 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3801 3802 3803 3804 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3801 def update!(**args) @cloud_vm_clusters = args[:cloud_vm_clusters] if args.key?(:cloud_vm_clusters) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |