Class: Google::Apis::OracledatabaseV1::ListDatabasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDatabasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for Database.List.
Instance Attribute Summary collapse
-
#databases ⇒ Array<Google::Apis::OracledatabaseV1::Database>
The list of Databases.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDatabasesResponse
constructor
A new instance of ListDatabasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDatabasesResponse
Returns a new instance of ListDatabasesResponse.
3867 3868 3869 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#databases ⇒ Array<Google::Apis::OracledatabaseV1::Database>
The list of Databases.
Corresponds to the JSON property databases
3860 3861 3862 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3860 def databases @databases end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3865 3866 3867 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3865 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3872 3873 3874 3875 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3872 def update!(**args) @databases = args[:databases] if args.key?(:databases) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |