Class: Google::Apis::OracledatabaseV1::ListDbSystemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDbSystemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DbSystem.List.
Instance Attribute Summary collapse
-
#db_systems ⇒ Array<Google::Apis::OracledatabaseV1::DbSystem>
The list of DbSystems.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDbSystemsResponse
constructor
A new instance of ListDbSystemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDbSystemsResponse
Returns a new instance of ListDbSystemsResponse.
3998 3999 4000 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_systems ⇒ Array<Google::Apis::OracledatabaseV1::DbSystem>
The list of DbSystems.
Corresponds to the JSON property dbSystems
3985 3986 3987 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3985 def db_systems @db_systems end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3990 3991 3992 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3990 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
3996 3997 3998 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3996 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4003 4004 4005 4006 4007 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4003 def update!(**args) @db_systems = args[:db_systems] if args.key?(:db_systems) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |