Class: Google::Apis::OracledatabaseV1::ListDbSystemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListDbSystemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for DbSystem.List.
Instance Attribute Summary collapse
-
#db_systems ⇒ Array<Google::Apis::OracledatabaseV1::DbSystem>
The list of DbSystems.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDbSystemsResponse
constructor
A new instance of ListDbSystemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDbSystemsResponse
Returns a new instance of ListDbSystemsResponse.
3971 3972 3973 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_systems ⇒ Array<Google::Apis::OracledatabaseV1::DbSystem>
The list of DbSystems.
Corresponds to the JSON property dbSystems
3964 3965 3966 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3964 def db_systems @db_systems end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3969 3970 3971 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3969 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3976 3977 3978 3979 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 3976 def update!(**args) @db_systems = args[:db_systems] if args.key?(:db_systems) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |