Class: Google::Apis::OracledatabaseV1::ListGoldengateConnectionAssignmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListGoldengateConnectionAssignmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Response message for listing GoldengateConnectionAssignments.
Instance Attribute Summary collapse
-
#goldengate_connection_assignments ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateConnectionAssignment>
The list of GoldengateConnectionAssignments.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGoldengateConnectionAssignmentsResponse
constructor
A new instance of ListGoldengateConnectionAssignmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGoldengateConnectionAssignmentsResponse
Returns a new instance of ListGoldengateConnectionAssignmentsResponse.
8017 8018 8019 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goldengate_connection_assignments ⇒ Array<Google::Apis::OracledatabaseV1::GoldengateConnectionAssignment>
The list of GoldengateConnectionAssignments.
Corresponds to the JSON property goldengateConnectionAssignments
8003 8004 8005 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8003 def goldengate_connection_assignments @goldengate_connection_assignments end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
8009 8010 8011 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8009 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
8015 8016 8017 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8015 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8022 8023 8024 8025 8026 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8022 def update!(**args) @goldengate_connection_assignments = args[:goldengate_connection_assignments] if args.key?(:goldengate_connection_assignments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |