Class: Google::Apis::OracledatabaseV1::ListOdbNetworksResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListOdbNetworksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for OdbNetwork.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#odb_networks ⇒ Array<Google::Apis::OracledatabaseV1::OdbNetwork>
The list of ODB Networks.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOdbNetworksResponse
constructor
A new instance of ListOdbNetworksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOdbNetworksResponse
Returns a new instance of ListOdbNetworksResponse.
8236 8237 8238 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
8223 8224 8225 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8223 def next_page_token @next_page_token end |
#odb_networks ⇒ Array<Google::Apis::OracledatabaseV1::OdbNetwork>
The list of ODB Networks.
Corresponds to the JSON property odbNetworks
8228 8229 8230 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8228 def odb_networks @odb_networks end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
8234 8235 8236 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8234 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8241 8242 8243 8244 8245 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8241 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @odb_networks = args[:odb_networks] if args.key?(:odb_networks) @unreachable = args[:unreachable] if args.key?(:unreachable) end |