Class: Google::Apis::OracledatabaseV1::ListOdbNetworksResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListOdbNetworksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for OdbNetwork.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#odb_networks ⇒ Array<Google::Apis::OracledatabaseV1::OdbNetwork>
The list of ODB Networks.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOdbNetworksResponse
constructor
A new instance of ListOdbNetworksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOdbNetworksResponse
Returns a new instance of ListOdbNetworksResponse.
4180 4181 4182 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4167 4168 4169 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4167 def next_page_token @next_page_token end |
#odb_networks ⇒ Array<Google::Apis::OracledatabaseV1::OdbNetwork>
The list of ODB Networks.
Corresponds to the JSON property odbNetworks
4172 4173 4174 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4172 def odb_networks @odb_networks end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
4178 4179 4180 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4178 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4185 4186 4187 4188 4189 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4185 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @odb_networks = args[:odb_networks] if args.key?(:odb_networks) @unreachable = args[:unreachable] if args.key?(:unreachable) end |