Class: Google::Apis::OracledatabaseV1::ListOdbSubnetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListOdbSubnetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for OdbSubnet.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#odb_subnets ⇒ Array<Google::Apis::OracledatabaseV1::OdbSubnet>
The list of ODB Subnets.
-
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using wildcard location '-'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOdbSubnetsResponse
constructor
A new instance of ListOdbSubnetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOdbSubnetsResponse
Returns a new instance of ListOdbSubnetsResponse.
4254 4255 4256 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4241 4242 4243 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4241 def next_page_token @next_page_token end |
#odb_subnets ⇒ Array<Google::Apis::OracledatabaseV1::OdbSubnet>
The list of ODB Subnets.
Corresponds to the JSON property odbSubnets
4246 4247 4248 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4246 def odb_subnets @odb_subnets end |
#unreachable ⇒ Array<String>
Unreachable locations when listing resources across all locations using
wildcard location '-'.
Corresponds to the JSON property unreachable
4252 4253 4254 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4252 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4259 4260 4261 4262 4263 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4259 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @odb_subnets = args[:odb_subnets] if args.key?(:odb_subnets) @unreachable = args[:unreachable] if args.key?(:unreachable) end |