Class: Google::Apis::OracledatabaseV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::OracledatabaseV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
8221 8222 8223 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
8206 8207 8208 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8206 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::OracledatabaseV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
8211 8212 8213 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8211 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
8219 8220 8221 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8219 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8226 8227 8228 8229 8230 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8226 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |