Class: Google::Apis::OracledatabaseV1::ListPluggableDatabasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ListPluggableDatabasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The response for PluggableDatabase.List.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#pluggable_databases ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabase>
The list of PluggableDatabases.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPluggableDatabasesResponse
constructor
A new instance of ListPluggableDatabasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPluggableDatabasesResponse
Returns a new instance of ListPluggableDatabasesResponse.
4272 4273 4274 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4265 4266 4267 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4265 def next_page_token @next_page_token end |
#pluggable_databases ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabase>
The list of PluggableDatabases.
Corresponds to the JSON property pluggableDatabases
4270 4271 4272 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4270 def pluggable_databases @pluggable_databases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4277 4278 4279 4280 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4277 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pluggable_databases = args[:pluggable_databases] if args.key?(:pluggable_databases) end |