Class: Google::Apis::OracledatabaseV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



8372
8373
8374
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


8347
8348
8349
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8347

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8353
8354
8355
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8353

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


8358
8359
8360
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8358

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


8364
8365
8366
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8364

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


8370
8371
8372
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8370

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8377
8378
8379
8380
8381
8382
8383
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8377

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end