Class: Google::Apis::OracledatabaseV1::MaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Maintenance window as defined by Oracle. https://docs.oracle.com/en-us/iaas/ api/#/en/database/20160918/datatypes/MaintenanceWindow

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceWindow

Returns a new instance of MaintenanceWindow.



8388
8389
8390
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_action_timeout_minsFixnum

Optional. Determines the amount of time the system will wait before the start of each database server patching operation. Custom action timeout is in minutes and valid value is between 15 to 120 (inclusive). Corresponds to the JSON property customActionTimeoutMins

Returns:

  • (Fixnum)


8335
8336
8337
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8335

def custom_action_timeout_mins
  @custom_action_timeout_mins
end

#days_of_weekArray<String>

Optional. Days during the week when maintenance should be performed. Corresponds to the JSON property daysOfWeek

Returns:

  • (Array<String>)


8340
8341
8342
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8340

def days_of_week
  @days_of_week
end

#hours_of_dayArray<Fixnum>

Optional. The window of hours during the day when maintenance should be performed. The window is a 4 hour slot. Valid values are: 0 - represents time slot 0:00 - 3:59 UTC 4 - represents time slot 4:00 - 7:59 UTC 8 - represents time slot 8:00 - 11:59 UTC 12 - represents time slot 12:00 - 15:59 UTC 16 - represents time slot 16:00 - 19:59 UTC 20 - represents time slot 20:00 - 23:59 UTC Corresponds to the JSON property hoursOfDay

Returns:

  • (Array<Fixnum>)


8350
8351
8352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8350

def hours_of_day
  @hours_of_day
end

#is_custom_action_timeout_enabledBoolean Also known as: is_custom_action_timeout_enabled?

Optional. If true, enables the configuration of a custom action timeout ( waiting period) between database server patching operations. Corresponds to the JSON property isCustomActionTimeoutEnabled

Returns:

  • (Boolean)


8356
8357
8358
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8356

def is_custom_action_timeout_enabled
  @is_custom_action_timeout_enabled
end

#lead_time_weekFixnum

Optional. Lead time window allows user to set a lead time to prepare for a down time. The lead time is in weeks and valid value is between 1 to 4. Corresponds to the JSON property leadTimeWeek

Returns:

  • (Fixnum)


8363
8364
8365
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8363

def lead_time_week
  @lead_time_week
end

#monthsArray<String>

Optional. Months during the year when maintenance should be performed. Corresponds to the JSON property months

Returns:

  • (Array<String>)


8368
8369
8370
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8368

def months
  @months
end

#patching_modeString

Optional. Cloud CloudExadataInfrastructure node patching method, either " ROLLING" or "NONROLLING". Default value is ROLLING. Corresponds to the JSON property patchingMode

Returns:

  • (String)


8374
8375
8376
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8374

def patching_mode
  @patching_mode
end

#preferenceString

Optional. The maintenance window scheduling preference. Corresponds to the JSON property preference

Returns:

  • (String)


8379
8380
8381
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8379

def preference
  @preference
end

#weeks_of_monthArray<Fixnum>

Optional. Weeks during the month when maintenance should be performed. Weeks start on the 1st, 8th, 15th, and 22nd days of the month, and have a duration of 7 days. Weeks start and end based on calendar dates, not days of the week. Corresponds to the JSON property weeksOfMonth

Returns:

  • (Array<Fixnum>)


8386
8387
8388
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8386

def weeks_of_month
  @weeks_of_month
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8393
8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8393

def update!(**args)
  @custom_action_timeout_mins = args[:custom_action_timeout_mins] if args.key?(:custom_action_timeout_mins)
  @days_of_week = args[:days_of_week] if args.key?(:days_of_week)
  @hours_of_day = args[:hours_of_day] if args.key?(:hours_of_day)
  @is_custom_action_timeout_enabled = args[:is_custom_action_timeout_enabled] if args.key?(:is_custom_action_timeout_enabled)
  @lead_time_week = args[:lead_time_week] if args.key?(:lead_time_week)
  @months = args[:months] if args.key?(:months)
  @patching_mode = args[:patching_mode] if args.key?(:patching_mode)
  @preference = args[:preference] if args.key?(:preference)
  @weeks_of_month = args[:weeks_of_month] if args.key?(:weeks_of_month)
end