Class: Google::Apis::OracledatabaseV1::OdbNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents OdbNetwork resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OdbNetwork

Returns a new instance of OdbNetwork.



8533
8534
8535
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the OdbNetwork was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8497
8498
8499
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8497

def create_time
  @create_time
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the OdbNetwork. Corresponds to the JSON property entitlementId

Returns:

  • (String)


8503
8504
8505
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8503

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where OdbNetwork is hosted. Example: us-east4-b- r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


8509
8510
8511
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8509

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. Labels or tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8514
8515
8516
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8514

def labels
  @labels
end

#nameString

Identifier. The name of the OdbNetwork resource in the following format: projects/project/locations/region/odbNetworks/odb_network Corresponds to the JSON property name

Returns:

  • (String)


8520
8521
8522
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8520

def name
  @name
end

#networkString

Required. The name of the VPC network in the following format: projects/ project/global/networks/network Corresponds to the JSON property network

Returns:

  • (String)


8526
8527
8528
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8526

def network
  @network
end

#stateString

Output only. State of the ODB Network. Corresponds to the JSON property state

Returns:

  • (String)


8531
8532
8533
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8531

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8538
8539
8540
8541
8542
8543
8544
8545
8546
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8538

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @state = args[:state] if args.key?(:state)
end