Class: Google::Apis::OracledatabaseV1::OdbNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents OdbNetwork resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OdbNetwork

Returns a new instance of OdbNetwork.



4507
4508
4509
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The date and time that the OdbNetwork was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4471
4472
4473
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4471

def create_time
  @create_time
end

#entitlement_idString

Output only. The ID of the subscription entitlement associated with the OdbNetwork. Corresponds to the JSON property entitlementId

Returns:

  • (String)


4477
4478
4479
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4477

def entitlement_id
  @entitlement_id
end

#gcp_oracle_zoneString

Optional. The GCP Oracle zone where OdbNetwork is hosted. Example: us-east4-b- r2. If not specified, the system will pick a zone based on availability. Corresponds to the JSON property gcpOracleZone

Returns:

  • (String)


4483
4484
4485
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4483

def gcp_oracle_zone
  @gcp_oracle_zone
end

#labelsHash<String,String>

Optional. Labels or tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4488
4489
4490
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4488

def labels
  @labels
end

#nameString

Identifier. The name of the OdbNetwork resource in the following format: projects/project/locations/region/odbNetworks/odb_network Corresponds to the JSON property name

Returns:

  • (String)


4494
4495
4496
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4494

def name
  @name
end

#networkString

Required. The name of the VPC network in the following format: projects/ project/global/networks/network Corresponds to the JSON property network

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4500

def network
  @network
end

#stateString

Output only. State of the ODB Network. Corresponds to the JSON property state

Returns:

  • (String)


4505
4506
4507
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4505

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4512
4513
4514
4515
4516
4517
4518
4519
4520
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4512

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entitlement_id = args[:entitlement_id] if args.key?(:entitlement_id)
  @gcp_oracle_zone = args[:gcp_oracle_zone] if args.key?(:gcp_oracle_zone)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @state = args[:state] if args.key?(:state)
end