Class: Google::Apis::OracledatabaseV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



8876
8877
8878
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


8834
8835
8836
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8834

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8839
8840
8841
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8839

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


8844
8845
8846
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8844

def end_time
  @end_time
end

#percent_completeFloat

Output only. An estimated percentage of the operation that has been completed at a given moment of time, between 0 and 100. Corresponds to the JSON property percentComplete

Returns:

  • (Float)


8850
8851
8852
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8850

def percent_complete
  @percent_complete
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


8858
8859
8860
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8858

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. The status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


8864
8865
8866
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8864

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


8869
8870
8871
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8869

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


8874
8875
8876
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8874

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8881
8882
8883
8884
8885
8886
8887
8888
8889
8890
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8881

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @percent_complete = args[:percent_complete] if args.key?(:percent_complete)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end