Class: Google::Apis::OracledatabaseV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#percent_complete ⇒ Float
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
8711 8712 8713 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
8669 8670 8671 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8669 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
8674 8675 8676 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8674 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
8679 8680 8681 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8679 def end_time @end_time end |
#percent_complete ⇒ Float
Output only. An estimated percentage of the operation that has been completed
at a given moment of time, between 0 and 100.
Corresponds to the JSON property percentComplete
8685 8686 8687 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8685 def percent_complete @percent_complete end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
8693 8694 8695 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8693 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. The status of the operation.
Corresponds to the JSON property statusMessage
8699 8700 8701 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8699 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
8704 8705 8706 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8704 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
8709 8710 8711 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8709 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8716 8717 8718 8719 8720 8721 8722 8723 8724 8725 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8716 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @percent_complete = args[:percent_complete] if args.key?(:percent_complete) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |