Class: Google::Apis::OracledatabaseV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#percent_complete ⇒ Float
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
4727 4728 4729 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
4685 4686 4687 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4685 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
4690 4691 4692 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4690 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
4695 4696 4697 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4695 def end_time @end_time end |
#percent_complete ⇒ Float
Output only. An estimated percentage of the operation that has been completed
at a given moment of time, between 0 and 100.
Corresponds to the JSON property percentComplete
4701 4702 4703 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4701 def percent_complete @percent_complete end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
4709 4710 4711 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4709 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. The status of the operation.
Corresponds to the JSON property statusMessage
4715 4716 4717 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4715 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
4720 4721 4722 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4720 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
4725 4726 4727 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4725 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4732 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @percent_complete = args[:percent_complete] if args.key?(:percent_complete) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |