Class: Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The connection strings used to connect to the Oracle Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PluggableDatabaseConnectionStrings

Returns a new instance of PluggableDatabaseConnectionStrings.



8788
8789
8790
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_connection_stringsHash<String,String>

Optional. All connection strings to use to connect to the pluggable database. Corresponds to the JSON property allConnectionStrings

Returns:

  • (Hash<String,String>)


8774
8775
8776
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8774

def all_connection_strings
  @all_connection_strings
end

#pdb_defaultString

Optional. The default connection string to use to connect to the pluggable database. Corresponds to the JSON property pdbDefault

Returns:

  • (String)


8780
8781
8782
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8780

def pdb_default
  @pdb_default
end

#pdb_ip_defaultString

Optional. The default connection string to use to connect to the pluggable database using IP. Corresponds to the JSON property pdbIpDefault

Returns:

  • (String)


8786
8787
8788
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8786

def pdb_ip_default
  @pdb_ip_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8793
8794
8795
8796
8797
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8793

def update!(**args)
  @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings)
  @pdb_default = args[:pdb_default] if args.key?(:pdb_default)
  @pdb_ip_default = args[:pdb_ip_default] if args.key?(:pdb_ip_default)
end