Class: Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The connection strings used to connect to the Oracle Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PluggableDatabaseConnectionStrings

Returns a new instance of PluggableDatabaseConnectionStrings.



4762
4763
4764
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_connection_stringsHash<String,String>

Optional. All connection strings to use to connect to the pluggable database. Corresponds to the JSON property allConnectionStrings

Returns:

  • (Hash<String,String>)


4748
4749
4750
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4748

def all_connection_strings
  @all_connection_strings
end

#pdb_defaultString

Optional. The default connection string to use to connect to the pluggable database. Corresponds to the JSON property pdbDefault

Returns:

  • (String)


4754
4755
4756
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4754

def pdb_default
  @pdb_default
end

#pdb_ip_defaultString

Optional. The default connection string to use to connect to the pluggable database using IP. Corresponds to the JSON property pdbIpDefault

Returns:

  • (String)


4760
4761
4762
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4760

def pdb_ip_default
  @pdb_ip_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4767
4768
4769
4770
4771
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4767

def update!(**args)
  @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings)
  @pdb_default = args[:pdb_default] if args.key?(:pdb_default)
  @pdb_ip_default = args[:pdb_ip_default] if args.key?(:pdb_ip_default)
end