Class: Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The connection strings used to connect to the Oracle Database.
Instance Attribute Summary collapse
-
#all_connection_strings ⇒ Hash<String,String>
Optional.
-
#pdb_default ⇒ String
Optional.
-
#pdb_ip_default ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PluggableDatabaseConnectionStrings
constructor
A new instance of PluggableDatabaseConnectionStrings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PluggableDatabaseConnectionStrings
Returns a new instance of PluggableDatabaseConnectionStrings.
4762 4763 4764 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_connection_strings ⇒ Hash<String,String>
Optional. All connection strings to use to connect to the pluggable database.
Corresponds to the JSON property allConnectionStrings
4748 4749 4750 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4748 def all_connection_strings @all_connection_strings end |
#pdb_default ⇒ String
Optional. The default connection string to use to connect to the pluggable
database.
Corresponds to the JSON property pdbDefault
4754 4755 4756 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4754 def pdb_default @pdb_default end |
#pdb_ip_default ⇒ String
Optional. The default connection string to use to connect to the pluggable
database using IP.
Corresponds to the JSON property pdbIpDefault
4760 4761 4762 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4760 def pdb_ip_default @pdb_ip_default end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4767 4768 4769 4770 4771 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4767 def update!(**args) @all_connection_strings = args[:all_connection_strings] if args.key?(:all_connection_strings) @pdb_default = args[:pdb_default] if args.key?(:pdb_default) @pdb_ip_default = args[:pdb_ip_default] if args.key?(:pdb_ip_default) end |