Class: Google::Apis::OracledatabaseV1::PluggableDatabaseProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of a PluggableDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PluggableDatabaseProperties

Returns a new instance of PluggableDatabaseProperties.



9039
9040
9041
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compartment_idString

Required. The OCID of the compartment. Corresponds to the JSON property compartmentId

Returns:

  • (String)


8972
8973
8974
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8972

def compartment_id
  @compartment_id
end

#connection_stringsGoogle::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings

The connection strings used to connect to the Oracle Database. Corresponds to the JSON property connectionStrings



8977
8978
8979
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8977

def connection_strings
  @connection_strings
end

#container_database_ocidString

Required. The OCID of the CDB. Corresponds to the JSON property containerDatabaseOcid

Returns:

  • (String)


8982
8983
8984
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8982

def container_database_ocid
  @container_database_ocid
end

#database_management_configGoogle::Apis::OracledatabaseV1::DatabaseManagementConfig

The configuration of the Database Management service. Corresponds to the JSON property databaseManagementConfig



8987
8988
8989
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8987

def database_management_config
  @database_management_config
end

#defined_tagsHash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>

Optional. Defined tags for this resource. Each key is predefined and scoped to a namespace. Corresponds to the JSON property definedTags



8993
8994
8995
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8993

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String,String>

Optional. Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Corresponds to the JSON property freeformTags

Returns:

  • (Hash<String,String>)


8999
9000
9001
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8999

def freeform_tags
  @freeform_tags
end

#is_restrictedBoolean Also known as: is_restricted?

Optional. The restricted mode of the pluggable database. If a pluggable database is opened in restricted mode, the user needs both create a session and have restricted session privileges to connect to it. Corresponds to the JSON property isRestricted

Returns:

  • (Boolean)


9006
9007
9008
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9006

def is_restricted
  @is_restricted
end

#lifecycle_detailsString

Output only. Additional information about the current lifecycle state. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


9012
9013
9014
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9012

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. The current state of the pluggable database. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


9017
9018
9019
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9017

def lifecycle_state
  @lifecycle_state
end

#ocidString

Output only. The OCID of the pluggable database. Corresponds to the JSON property ocid

Returns:

  • (String)


9022
9023
9024
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9022

def ocid
  @ocid
end

#operations_insights_stateString

Output only. The status of Operations Insights for this Database. Corresponds to the JSON property operationsInsightsState

Returns:

  • (String)


9027
9028
9029
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9027

def operations_insights_state
  @operations_insights_state
end

#pdb_nameString

Required. The database name. Corresponds to the JSON property pdbName

Returns:

  • (String)


9032
9033
9034
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9032

def pdb_name
  @pdb_name
end

#pdb_node_level_detailsArray<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>

Optional. Pluggable Database Node Level Details Corresponds to the JSON property pdbNodeLevelDetails



9037
9038
9039
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9037

def pdb_node_level_details
  @pdb_node_level_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9044

def update!(**args)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @connection_strings = args[:connection_strings] if args.key?(:connection_strings)
  @container_database_ocid = args[:container_database_ocid] if args.key?(:container_database_ocid)
  @database_management_config = args[:database_management_config] if args.key?(:database_management_config)
  @defined_tags = args[:defined_tags] if args.key?(:defined_tags)
  @freeform_tags = args[:freeform_tags] if args.key?(:freeform_tags)
  @is_restricted = args[:is_restricted] if args.key?(:is_restricted)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @ocid = args[:ocid] if args.key?(:ocid)
  @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state)
  @pdb_name = args[:pdb_name] if args.key?(:pdb_name)
  @pdb_node_level_details = args[:pdb_node_level_details] if args.key?(:pdb_node_level_details)
end