Class: Google::Apis::OracledatabaseV1::PluggableDatabaseProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The properties of a PluggableDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PluggableDatabaseProperties

Returns a new instance of PluggableDatabaseProperties.



8986
8987
8988
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compartment_idString

Required. The OCID of the compartment. Corresponds to the JSON property compartmentId

Returns:

  • (String)


8919
8920
8921
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8919

def compartment_id
  @compartment_id
end

#connection_stringsGoogle::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings

The connection strings used to connect to the Oracle Database. Corresponds to the JSON property connectionStrings



8924
8925
8926
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8924

def connection_strings
  @connection_strings
end

#container_database_ocidString

Required. The OCID of the CDB. Corresponds to the JSON property containerDatabaseOcid

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8929

def container_database_ocid
  @container_database_ocid
end

#database_management_configGoogle::Apis::OracledatabaseV1::DatabaseManagementConfig

The configuration of the Database Management service. Corresponds to the JSON property databaseManagementConfig



8934
8935
8936
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8934

def database_management_config
  @database_management_config
end

#defined_tagsHash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>

Optional. Defined tags for this resource. Each key is predefined and scoped to a namespace. Corresponds to the JSON property definedTags



8940
8941
8942
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8940

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String,String>

Optional. Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Corresponds to the JSON property freeformTags

Returns:

  • (Hash<String,String>)


8946
8947
8948
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8946

def freeform_tags
  @freeform_tags
end

#is_restrictedBoolean Also known as: is_restricted?

Optional. The restricted mode of the pluggable database. If a pluggable database is opened in restricted mode, the user needs both create a session and have restricted session privileges to connect to it. Corresponds to the JSON property isRestricted

Returns:

  • (Boolean)


8953
8954
8955
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8953

def is_restricted
  @is_restricted
end

#lifecycle_detailsString

Output only. Additional information about the current lifecycle state. Corresponds to the JSON property lifecycleDetails

Returns:

  • (String)


8959
8960
8961
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8959

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Output only. The current state of the pluggable database. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


8964
8965
8966
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8964

def lifecycle_state
  @lifecycle_state
end

#ocidString

Output only. The OCID of the pluggable database. Corresponds to the JSON property ocid

Returns:

  • (String)


8969
8970
8971
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8969

def ocid
  @ocid
end

#operations_insights_stateString

Output only. The status of Operations Insights for this Database. Corresponds to the JSON property operationsInsightsState

Returns:

  • (String)


8974
8975
8976
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8974

def operations_insights_state
  @operations_insights_state
end

#pdb_nameString

Required. The database name. Corresponds to the JSON property pdbName

Returns:

  • (String)


8979
8980
8981
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8979

def pdb_name
  @pdb_name
end

#pdb_node_level_detailsArray<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>

Optional. Pluggable Database Node Level Details Corresponds to the JSON property pdbNodeLevelDetails



8984
8985
8986
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8984

def pdb_node_level_details
  @pdb_node_level_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8991
8992
8993
8994
8995
8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8991

def update!(**args)
  @compartment_id = args[:compartment_id] if args.key?(:compartment_id)
  @connection_strings = args[:connection_strings] if args.key?(:connection_strings)
  @container_database_ocid = args[:container_database_ocid] if args.key?(:container_database_ocid)
  @database_management_config = args[:database_management_config] if args.key?(:database_management_config)
  @defined_tags = args[:defined_tags] if args.key?(:defined_tags)
  @freeform_tags = args[:freeform_tags] if args.key?(:freeform_tags)
  @is_restricted = args[:is_restricted] if args.key?(:is_restricted)
  @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @ocid = args[:ocid] if args.key?(:ocid)
  @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state)
  @pdb_name = args[:pdb_name] if args.key?(:pdb_name)
  @pdb_node_level_details = args[:pdb_node_level_details] if args.key?(:pdb_node_level_details)
end