Class: Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of a PluggableDatabase.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Required.
-
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
-
#container_database_ocid ⇒ String
Required.
-
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
-
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional.
-
#freeform_tags ⇒ Hash<String,String>
Optional.
-
#is_restricted ⇒ Boolean
(also: #is_restricted?)
Optional.
-
#lifecycle_details ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#ocid ⇒ String
Output only.
-
#operations_insights_state ⇒ String
Output only.
-
#pdb_name ⇒ String
Required.
-
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PluggableDatabaseProperties
constructor
A new instance of PluggableDatabaseProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PluggableDatabaseProperties
Returns a new instance of PluggableDatabaseProperties.
8906 8907 8908 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compartment_id ⇒ String
Required. The OCID of the compartment.
Corresponds to the JSON property compartmentId
8839 8840 8841 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8839 def compartment_id @compartment_id end |
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
Corresponds to the JSON property connectionStrings
8844 8845 8846 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8844 def connection_strings @connection_strings end |
#container_database_ocid ⇒ String
Required. The OCID of the CDB.
Corresponds to the JSON property containerDatabaseOcid
8849 8850 8851 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8849 def container_database_ocid @container_database_ocid end |
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
Corresponds to the JSON property databaseManagementConfig
8854 8855 8856 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8854 def database_management_config @database_management_config end |
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional. Defined tags for this resource. Each key is predefined and scoped to
a namespace.
Corresponds to the JSON property definedTags
8860 8861 8862 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8860 def @defined_tags end |
#freeform_tags ⇒ Hash<String,String>
Optional. Free-form tags for this resource. Each tag is a simple key-value
pair with no predefined name, type, or namespace.
Corresponds to the JSON property freeformTags
8866 8867 8868 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8866 def @freeform_tags end |
#is_restricted ⇒ Boolean Also known as: is_restricted?
Optional. The restricted mode of the pluggable database. If a pluggable
database is opened in restricted mode, the user needs both create a session
and have restricted session privileges to connect to it.
Corresponds to the JSON property isRestricted
8873 8874 8875 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8873 def is_restricted @is_restricted end |
#lifecycle_details ⇒ String
Output only. Additional information about the current lifecycle state.
Corresponds to the JSON property lifecycleDetails
8879 8880 8881 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8879 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Output only. The current state of the pluggable database.
Corresponds to the JSON property lifecycleState
8884 8885 8886 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8884 def lifecycle_state @lifecycle_state end |
#ocid ⇒ String
Output only. The OCID of the pluggable database.
Corresponds to the JSON property ocid
8889 8890 8891 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8889 def ocid @ocid end |
#operations_insights_state ⇒ String
Output only. The status of Operations Insights for this Database.
Corresponds to the JSON property operationsInsightsState
8894 8895 8896 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8894 def operations_insights_state @operations_insights_state end |
#pdb_name ⇒ String
Required. The database name.
Corresponds to the JSON property pdbName
8899 8900 8901 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8899 def pdb_name @pdb_name end |
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional. Pluggable Database Node Level Details
Corresponds to the JSON property pdbNodeLevelDetails
8904 8905 8906 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8904 def pdb_node_level_details @pdb_node_level_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 8925 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 8911 def update!(**args) @compartment_id = args[:compartment_id] if args.key?(:compartment_id) @connection_strings = args[:connection_strings] if args.key?(:connection_strings) @container_database_ocid = args[:container_database_ocid] if args.key?(:container_database_ocid) @database_management_config = args[:database_management_config] if args.key?(:database_management_config) @defined_tags = args[:defined_tags] if args.key?(:defined_tags) @freeform_tags = args[:freeform_tags] if args.key?(:freeform_tags) @is_restricted = args[:is_restricted] if args.key?(:is_restricted) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @ocid = args[:ocid] if args.key?(:ocid) @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state) @pdb_name = args[:pdb_name] if args.key?(:pdb_name) @pdb_node_level_details = args[:pdb_node_level_details] if args.key?(:pdb_node_level_details) end |