Class: Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of a PluggableDatabase.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Required.
-
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
-
#container_database_ocid ⇒ String
Required.
-
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
-
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional.
-
#freeform_tags ⇒ Hash<String,String>
Optional.
-
#is_restricted ⇒ Boolean
(also: #is_restricted?)
Optional.
-
#lifecycle_details ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#ocid ⇒ String
Output only.
-
#operations_insights_state ⇒ String
Output only.
-
#pdb_name ⇒ String
Required.
-
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PluggableDatabaseProperties
constructor
A new instance of PluggableDatabaseProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PluggableDatabaseProperties
Returns a new instance of PluggableDatabaseProperties.
4921 4922 4923 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compartment_id ⇒ String
Required. The OCID of the compartment.
Corresponds to the JSON property compartmentId
4854 4855 4856 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4854 def compartment_id @compartment_id end |
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
Corresponds to the JSON property connectionStrings
4859 4860 4861 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4859 def connection_strings @connection_strings end |
#container_database_ocid ⇒ String
Required. The OCID of the CDB.
Corresponds to the JSON property containerDatabaseOcid
4864 4865 4866 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4864 def container_database_ocid @container_database_ocid end |
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
Corresponds to the JSON property databaseManagementConfig
4869 4870 4871 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4869 def database_management_config @database_management_config end |
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional. Defined tags for this resource. Each key is predefined and scoped to
a namespace.
Corresponds to the JSON property definedTags
4875 4876 4877 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4875 def @defined_tags end |
#freeform_tags ⇒ Hash<String,String>
Optional. Free-form tags for this resource. Each tag is a simple key-value
pair with no predefined name, type, or namespace.
Corresponds to the JSON property freeformTags
4881 4882 4883 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4881 def @freeform_tags end |
#is_restricted ⇒ Boolean Also known as: is_restricted?
Optional. The restricted mode of the pluggable database. If a pluggable
database is opened in restricted mode, the user needs both create a session
and have restricted session privileges to connect to it.
Corresponds to the JSON property isRestricted
4888 4889 4890 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4888 def is_restricted @is_restricted end |
#lifecycle_details ⇒ String
Output only. Additional information about the current lifecycle state.
Corresponds to the JSON property lifecycleDetails
4894 4895 4896 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4894 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Output only. The current state of the pluggable database.
Corresponds to the JSON property lifecycleState
4899 4900 4901 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4899 def lifecycle_state @lifecycle_state end |
#ocid ⇒ String
Output only. The OCID of the pluggable database.
Corresponds to the JSON property ocid
4904 4905 4906 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4904 def ocid @ocid end |
#operations_insights_state ⇒ String
Output only. The status of Operations Insights for this Database.
Corresponds to the JSON property operationsInsightsState
4909 4910 4911 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4909 def operations_insights_state @operations_insights_state end |
#pdb_name ⇒ String
Required. The database name.
Corresponds to the JSON property pdbName
4914 4915 4916 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4914 def pdb_name @pdb_name end |
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional. Pluggable Database Node Level Details
Corresponds to the JSON property pdbNodeLevelDetails
4919 4920 4921 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4919 def pdb_node_level_details @pdb_node_level_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 4936 4937 4938 4939 4940 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4926 def update!(**args) @compartment_id = args[:compartment_id] if args.key?(:compartment_id) @connection_strings = args[:connection_strings] if args.key?(:connection_strings) @container_database_ocid = args[:container_database_ocid] if args.key?(:container_database_ocid) @database_management_config = args[:database_management_config] if args.key?(:database_management_config) @defined_tags = args[:defined_tags] if args.key?(:defined_tags) @freeform_tags = args[:freeform_tags] if args.key?(:freeform_tags) @is_restricted = args[:is_restricted] if args.key?(:is_restricted) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @ocid = args[:ocid] if args.key?(:ocid) @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state) @pdb_name = args[:pdb_name] if args.key?(:pdb_name) @pdb_node_level_details = args[:pdb_node_level_details] if args.key?(:pdb_node_level_details) end |