Class: Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::PluggableDatabaseProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The properties of a PluggableDatabase.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Required.
-
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
-
#container_database_ocid ⇒ String
Required.
-
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
-
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional.
-
#freeform_tags ⇒ Hash<String,String>
Optional.
-
#is_restricted ⇒ Boolean
(also: #is_restricted?)
Optional.
-
#lifecycle_details ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#ocid ⇒ String
Output only.
-
#operations_insights_state ⇒ String
Output only.
-
#pdb_name ⇒ String
Required.
-
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PluggableDatabaseProperties
constructor
A new instance of PluggableDatabaseProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PluggableDatabaseProperties
Returns a new instance of PluggableDatabaseProperties.
4879 4880 4881 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compartment_id ⇒ String
Required. The OCID of the compartment.
Corresponds to the JSON property compartmentId
4812 4813 4814 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4812 def compartment_id @compartment_id end |
#connection_strings ⇒ Google::Apis::OracledatabaseV1::PluggableDatabaseConnectionStrings
The connection strings used to connect to the Oracle Database.
Corresponds to the JSON property connectionStrings
4817 4818 4819 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4817 def connection_strings @connection_strings end |
#container_database_ocid ⇒ String
Required. The OCID of the CDB.
Corresponds to the JSON property containerDatabaseOcid
4822 4823 4824 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4822 def container_database_ocid @container_database_ocid end |
#database_management_config ⇒ Google::Apis::OracledatabaseV1::DatabaseManagementConfig
The configuration of the Database Management service.
Corresponds to the JSON property databaseManagementConfig
4827 4828 4829 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4827 def database_management_config @database_management_config end |
#defined_tags ⇒ Hash<String,Google::Apis::OracledatabaseV1::DefinedTagValue>
Optional. Defined tags for this resource. Each key is predefined and scoped to
a namespace.
Corresponds to the JSON property definedTags
4833 4834 4835 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4833 def @defined_tags end |
#freeform_tags ⇒ Hash<String,String>
Optional. Free-form tags for this resource. Each tag is a simple key-value
pair with no predefined name, type, or namespace.
Corresponds to the JSON property freeformTags
4839 4840 4841 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4839 def @freeform_tags end |
#is_restricted ⇒ Boolean Also known as: is_restricted?
Optional. The restricted mode of the pluggable database. If a pluggable
database is opened in restricted mode, the user needs both create a session
and have restricted session privileges to connect to it.
Corresponds to the JSON property isRestricted
4846 4847 4848 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4846 def is_restricted @is_restricted end |
#lifecycle_details ⇒ String
Output only. Additional information about the current lifecycle state.
Corresponds to the JSON property lifecycleDetails
4852 4853 4854 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4852 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Output only. The current state of the pluggable database.
Corresponds to the JSON property lifecycleState
4857 4858 4859 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4857 def lifecycle_state @lifecycle_state end |
#ocid ⇒ String
Output only. The OCID of the pluggable database.
Corresponds to the JSON property ocid
4862 4863 4864 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4862 def ocid @ocid end |
#operations_insights_state ⇒ String
Output only. The status of Operations Insights for this Database.
Corresponds to the JSON property operationsInsightsState
4867 4868 4869 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4867 def operations_insights_state @operations_insights_state end |
#pdb_name ⇒ String
Required. The database name.
Corresponds to the JSON property pdbName
4872 4873 4874 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4872 def pdb_name @pdb_name end |
#pdb_node_level_details ⇒ Array<Google::Apis::OracledatabaseV1::PluggableDatabaseNodeLevelDetails>
Optional. Pluggable Database Node Level Details
Corresponds to the JSON property pdbNodeLevelDetails
4877 4878 4879 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4877 def pdb_node_level_details @pdb_node_level_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4884 def update!(**args) @compartment_id = args[:compartment_id] if args.key?(:compartment_id) @connection_strings = args[:connection_strings] if args.key?(:connection_strings) @container_database_ocid = args[:container_database_ocid] if args.key?(:container_database_ocid) @database_management_config = args[:database_management_config] if args.key?(:database_management_config) @defined_tags = args[:defined_tags] if args.key?(:defined_tags) @freeform_tags = args[:freeform_tags] if args.key?(:freeform_tags) @is_restricted = args[:is_restricted] if args.key?(:is_restricted) @lifecycle_details = args[:lifecycle_details] if args.key?(:lifecycle_details) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @ocid = args[:ocid] if args.key?(:ocid) @operations_insights_state = args[:operations_insights_state] if args.key?(:operations_insights_state) @pdb_name = args[:pdb_name] if args.key?(:pdb_name) @pdb_node_level_details = args[:pdb_node_level_details] if args.key?(:pdb_node_level_details) end |