Class: Google::Apis::OracledatabaseV1::RefreshAutonomousDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::RefreshAutonomousDatabaseRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Request message for RefreshAutonomousDatabase method.
Instance Attribute Summary collapse
-
#refresh_cutoff_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RefreshAutonomousDatabaseRequest
constructor
A new instance of RefreshAutonomousDatabaseRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RefreshAutonomousDatabaseRequest
Returns a new instance of RefreshAutonomousDatabaseRequest.
9146 9147 9148 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#refresh_cutoff_time ⇒ String
Required. The timestamp to which the Autonomous Database refreshable clone
will be refreshed. Changes made in the primary database after this timestamp
are not part of the data refresh.
Corresponds to the JSON property refreshCutoffTime
9144 9145 9146 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9144 def refresh_cutoff_time @refresh_cutoff_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9151 9152 9153 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9151 def update!(**args) @refresh_cutoff_time = args[:refresh_cutoff_time] if args.key?(:refresh_cutoff_time) end |