Class: Google::Apis::OracledatabaseV1::RemoveVirtualMachineExadbVmClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The request for ExadbVmCluster.RemoveVirtualMachine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveVirtualMachineExadbVmClusterRequest

Returns a new instance of RemoveVirtualMachineExadbVmClusterRequest.



9176
9177
9178
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostnamesArray<String>

Required. The list of host names of db nodes to be removed from the ExadbVmCluster. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


9164
9165
9166
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9164

def hostnames
  @hostnames
end

#request_idString

Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


9174
9175
9176
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9174

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9181
9182
9183
9184
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9181

def update!(**args)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @request_id = args[:request_id] if args.key?(:request_id)
end