Class: Google::Apis::OracledatabaseV1::RemoveVirtualMachineExadbVmClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::RemoveVirtualMachineExadbVmClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The request for ExadbVmCluster.RemoveVirtualMachine.
Instance Attribute Summary collapse
-
#hostnames ⇒ Array<String>
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveVirtualMachineExadbVmClusterRequest
constructor
A new instance of RemoveVirtualMachineExadbVmClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveVirtualMachineExadbVmClusterRequest
Returns a new instance of RemoveVirtualMachineExadbVmClusterRequest.
9145 9146 9147 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hostnames ⇒ Array<String>
Required. The list of host names of db nodes to be removed from the
ExadbVmCluster.
Corresponds to the JSON property hostnames
9133 9134 9135 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9133 def hostnames @hostnames end |
#request_id ⇒ String
Optional. An optional ID to identify the request. This value is used to
identify duplicate requests. If you make a request with the same request ID
and the original request is still in progress or completed, the server ignores
the second request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
9143 9144 9145 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9143 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9150 9151 9152 9153 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9150 def update!(**args) @hostnames = args[:hostnames] if args.key?(:hostnames) @request_id = args[:request_id] if args.key?(:request_id) end |