Class: Google::Apis::OracledatabaseV1::RemoveVirtualMachineExadbVmClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The request for ExadbVmCluster.RemoveVirtualMachine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveVirtualMachineExadbVmClusterRequest

Returns a new instance of RemoveVirtualMachineExadbVmClusterRequest.



4963
4964
4965
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostnamesArray<String>

Required. The list of host names of db nodes to be removed from the ExadbVmCluster. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


4951
4952
4953
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4951

def hostnames
  @hostnames
end

#request_idString

Optional. An optional ID to identify the request. This value is used to identify duplicate requests. If you make a request with the same request ID and the original request is still in progress or completed, the server ignores the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4961
4962
4963
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4961

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4968
4969
4970
4971
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4968

def update!(**args)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @request_id = args[:request_id] if args.key?(:request_id)
end