Class: Google::Apis::OracledatabaseV1::ScheduledOperationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Details of scheduled operation. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/datatypes/ScheduledOperationDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledOperationDetails

Returns a new instance of ScheduledOperationDetails.



9269
9270
9271
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Output only. Day of week. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


9253
9254
9255
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9253

def day_of_week
  @day_of_week
end

#start_timeGoogle::Apis::OracledatabaseV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



9260
9261
9262
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9260

def start_time
  @start_time
end

#stop_timeGoogle::Apis::OracledatabaseV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property stopTime



9267
9268
9269
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9267

def stop_time
  @stop_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9274
9275
9276
9277
9278
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9274

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @start_time = args[:start_time] if args.key?(:start_time)
  @stop_time = args[:stop_time] if args.key?(:stop_time)
end