Class: Google::Apis::OracledatabaseV1::ScheduledOperationDetails
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ScheduledOperationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of scheduled operation. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/datatypes/ScheduledOperationDetails
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day.
-
#stop_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScheduledOperationDetails
constructor
A new instance of ScheduledOperationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScheduledOperationDetails
Returns a new instance of ScheduledOperationDetails.
9164 9165 9166 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_week ⇒ String
Output only. Day of week.
Corresponds to the JSON property dayOfWeek
9148 9149 9150 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9148 def day_of_week @day_of_week end |
#start_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
9155 9156 9157 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9155 def start_time @start_time end |
#stop_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property stopTime
9162 9163 9164 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9162 def stop_time @stop_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9169 9170 9171 9172 9173 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9169 def update!(**args) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @start_time = args[:start_time] if args.key?(:start_time) @stop_time = args[:stop_time] if args.key?(:stop_time) end |