Class: Google::Apis::OracledatabaseV1::ScheduledOperationDetails
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::ScheduledOperationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Details of scheduled operation. https://docs.oracle.com/en-us/iaas/api/#/en/ database/20160918/datatypes/ScheduledOperationDetails
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day.
-
#stop_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScheduledOperationDetails
constructor
A new instance of ScheduledOperationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScheduledOperationDetails
Returns a new instance of ScheduledOperationDetails.
4988 4989 4990 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_week ⇒ String
Output only. Day of week.
Corresponds to the JSON property dayOfWeek
4972 4973 4974 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4972 def day_of_week @day_of_week end |
#start_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
4979 4980 4981 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4979 def start_time @start_time end |
#stop_time ⇒ Google::Apis::OracledatabaseV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property stopTime
4986 4987 4988 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4986 def stop_time @stop_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4993 4994 4995 4996 4997 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 4993 def update!(**args) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @start_time = args[:start_time] if args.key?(:start_time) @stop_time = args[:stop_time] if args.key?(:stop_time) end |