Class: Google::Apis::OracledatabaseV1::SourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

The source configuration for the standby Autonomous Database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceConfig

Returns a new instance of SourceConfig.



9324
9325
9326
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_refresh_frequency_secondsFixnum

Optional. The frequency in seconds a refreshable clone is refreshed after auto- refresh is enabled. Corresponds to the JSON property autoRefreshFrequencySeconds

Returns:

  • (Fixnum)


9258
9259
9260
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9258

def auto_refresh_frequency_seconds
  @auto_refresh_frequency_seconds
end

#auto_refresh_point_lag_secondsFixnum

Optional. The time, in seconds, the data of the automatic refreshable clone lags the primary database at the point of refresh. Corresponds to the JSON property autoRefreshPointLagSeconds

Returns:

  • (Fixnum)


9264
9265
9266
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9264

def auto_refresh_point_lag_seconds
  @auto_refresh_point_lag_seconds
end

#auto_refresh_start_timeString

Optional. The date and time that auto-refreshing will begin for an Autonomous Database refreshable clone. This value controls only the start time for the first refresh operation. Corresponds to the JSON property autoRefreshStartTime

Returns:

  • (String)


9271
9272
9273
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9271

def auto_refresh_start_time
  @auto_refresh_start_time
end

#automatic_backups_replication_enabledBoolean Also known as: automatic_backups_replication_enabled?

Optional. This field specifies if the replication of automatic backups is enabled when creating a Data Guard. Corresponds to the JSON property automaticBackupsReplicationEnabled

Returns:

  • (Boolean)


9277
9278
9279
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9277

def automatic_backups_replication_enabled
  @automatic_backups_replication_enabled
end

#autonomous_databaseString

Optional. The name of the primary Autonomous Database that is used to create a Peer Autonomous Database from a source. Corresponds to the JSON property autonomousDatabase

Returns:

  • (String)


9284
9285
9286
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9284

def autonomous_database
  @autonomous_database
end

#autonomous_database_backupString

Optional. The name of the Autonomous Database Backup resource with the format: projects/project/locations/region/autonomousDatabaseBackups/ autonomous_database_backup Required when source_type is BACKUP_FROM_ID. Corresponds to the JSON property autonomousDatabaseBackup

Returns:

  • (String)


9291
9292
9293
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9291

def autonomous_database_backup
  @autonomous_database_backup
end

#backup_timeString

Optional. The timestamp specified for the point-in-time clone of the source Autonomous Database. This field is only applicable in case of BACKUP_FROM_TIMESTAMP source type and when use_latest_available_backup is false. Corresponds to the JSON property backupTime

Returns:

  • (String)


9299
9300
9301
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9299

def backup_time
  @backup_time
end

#clone_typeString

Optional. The clone type of the Autonomous Database. This field is only applicable in case of cloning Corresponds to the JSON property cloneType

Returns:

  • (String)


9305
9306
9307
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9305

def clone_type
  @clone_type
end

#refreshable_modeString

Optional. The refresh mode of the clone. Corresponds to the JSON property refreshableMode

Returns:

  • (String)


9310
9311
9312
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9310

def refreshable_mode
  @refreshable_mode
end

#source_typeString

Optional. The source type of the Autonomous Database. Corresponds to the JSON property sourceType

Returns:

  • (String)


9315
9316
9317
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9315

def source_type
  @source_type
end

#use_latest_available_backupBoolean Also known as: use_latest_available_backup?

Optional. Clone from latest available backup timestamp. This field is only applicable in case of BACKUP_FROM_TIMESTAMP source type. Corresponds to the JSON property useLatestAvailableBackup

Returns:

  • (Boolean)


9321
9322
9323
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9321

def use_latest_available_backup
  @use_latest_available_backup
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9329
9330
9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9329

def update!(**args)
  @auto_refresh_frequency_seconds = args[:auto_refresh_frequency_seconds] if args.key?(:auto_refresh_frequency_seconds)
  @auto_refresh_point_lag_seconds = args[:auto_refresh_point_lag_seconds] if args.key?(:auto_refresh_point_lag_seconds)
  @auto_refresh_start_time = args[:auto_refresh_start_time] if args.key?(:auto_refresh_start_time)
  @automatic_backups_replication_enabled = args[:automatic_backups_replication_enabled] if args.key?(:automatic_backups_replication_enabled)
  @autonomous_database = args[:autonomous_database] if args.key?(:autonomous_database)
  @autonomous_database_backup = args[:autonomous_database_backup] if args.key?(:autonomous_database_backup)
  @backup_time = args[:backup_time] if args.key?(:backup_time)
  @clone_type = args[:clone_type] if args.key?(:clone_type)
  @refreshable_mode = args[:refreshable_mode] if args.key?(:refreshable_mode)
  @source_type = args[:source_type] if args.key?(:source_type)
  @use_latest_available_backup = args[:use_latest_available_backup] if args.key?(:use_latest_available_backup)
end