Class: Google::Apis::OracledatabaseV1::SourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::SourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The source configuration for the standby Autonomous Database.
Instance Attribute Summary collapse
-
#automatic_backups_replication_enabled ⇒ Boolean
(also: #automatic_backups_replication_enabled?)
Optional.
-
#autonomous_database ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceConfig
constructor
A new instance of SourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceConfig
Returns a new instance of SourceConfig.
5017 5018 5019 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_backups_replication_enabled ⇒ Boolean Also known as: automatic_backups_replication_enabled?
Optional. This field specifies if the replication of automatic backups is
enabled when creating a Data Guard.
Corresponds to the JSON property automaticBackupsReplicationEnabled
5008 5009 5010 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5008 def automatic_backups_replication_enabled @automatic_backups_replication_enabled end |
#autonomous_database ⇒ String
Optional. The name of the primary Autonomous Database that is used to create a
Peer Autonomous Database from a source.
Corresponds to the JSON property autonomousDatabase
5015 5016 5017 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5015 def autonomous_database @autonomous_database end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5022 5023 5024 5025 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 5022 def update!(**args) @automatic_backups_replication_enabled = args[:automatic_backups_replication_enabled] if args.key?(:automatic_backups_replication_enabled) @autonomous_database = args[:autonomous_database] if args.key?(:autonomous_database) end |