Class: Google::Apis::OracledatabaseV1::Status
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::Status
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Status
constructor
A new instance of Status.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Status
Returns a new instance of Status.
9428 9429 9430 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
9413 9414 9415 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9413 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
9419 9420 9421 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9419 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English. Any user-facing
error message should be localized and sent in the google.rpc.Status.details
field, or localized by the client.
Corresponds to the JSON property message
9426 9427 9428 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9426 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9433 9434 9435 9436 9437 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9433 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |