Class: Google::Apis::OracledatabaseV1::TestConnectionAssignmentError
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::TestConnectionAssignmentError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Error details for TestGoldengateConnectionAssignment.
Instance Attribute Summary collapse
-
#action ⇒ String
The text describing the action required to fix the issue.
-
#code ⇒ String
A short error code that defines the error, meant for programmatic parsing.
-
#issue ⇒ String
The text describing the root cause of the reported issue.
-
#message ⇒ String
A human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestConnectionAssignmentError
constructor
A new instance of TestConnectionAssignmentError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestConnectionAssignmentError
Returns a new instance of TestConnectionAssignmentError.
9570 9571 9572 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The text describing the action required to fix the issue.
Corresponds to the JSON property action
9553 9554 9555 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9553 def action @action end |
#code ⇒ String
A short error code that defines the error, meant for programmatic parsing.
Corresponds to the JSON property code
9558 9559 9560 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9558 def code @code end |
#issue ⇒ String
The text describing the root cause of the reported issue.
Corresponds to the JSON property issue
9563 9564 9565 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9563 def issue @issue end |
#message ⇒ String
A human-readable error message.
Corresponds to the JSON property message
9568 9569 9570 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9568 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9575 9576 9577 9578 9579 9580 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9575 def update!(**args) @action = args[:action] if args.key?(:action) @code = args[:code] if args.key?(:code) @issue = args[:issue] if args.key?(:issue) @message = args[:message] if args.key?(:message) end |