Class: Google::Apis::OracledatabaseV1::TestConnectionAssignmentError
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::TestConnectionAssignmentError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Error details for TestGoldengateConnectionAssignment.
Instance Attribute Summary collapse
-
#action ⇒ String
The text describing the action required to fix the issue.
-
#code ⇒ String
A short error code that defines the error, meant for programmatic parsing.
-
#issue ⇒ String
The text describing the root cause of the reported issue.
-
#message ⇒ String
A human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestConnectionAssignmentError
constructor
A new instance of TestConnectionAssignmentError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestConnectionAssignmentError
Returns a new instance of TestConnectionAssignmentError.
9507 9508 9509 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The text describing the action required to fix the issue.
Corresponds to the JSON property action
9490 9491 9492 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9490 def action @action end |
#code ⇒ String
A short error code that defines the error, meant for programmatic parsing.
Corresponds to the JSON property code
9495 9496 9497 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9495 def code @code end |
#issue ⇒ String
The text describing the root cause of the reported issue.
Corresponds to the JSON property issue
9500 9501 9502 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9500 def issue @issue end |
#message ⇒ String
A human-readable error message.
Corresponds to the JSON property message
9505 9506 9507 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9505 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9512 9513 9514 9515 9516 9517 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9512 def update!(**args) @action = args[:action] if args.key?(:action) @code = args[:code] if args.key?(:code) @issue = args[:issue] if args.key?(:issue) @message = args[:message] if args.key?(:message) end |