Class: Google::Apis::OracledatabaseV1::TestConnectionAssignmentError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Error details for TestGoldengateConnectionAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestConnectionAssignmentError

Returns a new instance of TestConnectionAssignmentError.



9367
9368
9369
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The text describing the action required to fix the issue. Corresponds to the JSON property action

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9350

def action
  @action
end

#codeString

A short error code that defines the error, meant for programmatic parsing. Corresponds to the JSON property code

Returns:

  • (String)


9355
9356
9357
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9355

def code
  @code
end

#issueString

The text describing the root cause of the reported issue. Corresponds to the JSON property issue

Returns:

  • (String)


9360
9361
9362
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9360

def issue
  @issue
end

#messageString

A human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


9365
9366
9367
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9365

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9372
9373
9374
9375
9376
9377
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9372

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @code = args[:code] if args.key?(:code)
  @issue = args[:issue] if args.key?(:issue)
  @message = args[:message] if args.key?(:message)
end