Class: Google::Apis::OracledatabaseV1::TestConnectionAssignmentError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb

Overview

Error details for TestGoldengateConnectionAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestConnectionAssignmentError

Returns a new instance of TestConnectionAssignmentError.



9287
9288
9289
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The text describing the action required to fix the issue. Corresponds to the JSON property action

Returns:

  • (String)


9270
9271
9272
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9270

def action
  @action
end

#codeString

A short error code that defines the error, meant for programmatic parsing. Corresponds to the JSON property code

Returns:

  • (String)


9275
9276
9277
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9275

def code
  @code
end

#issueString

The text describing the root cause of the reported issue. Corresponds to the JSON property issue

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9280

def issue
  @issue
end

#messageString

A human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


9285
9286
9287
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9285

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9292
9293
9294
9295
9296
9297
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9292

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @code = args[:code] if args.key?(:code)
  @issue = args[:issue] if args.key?(:issue)
  @message = args[:message] if args.key?(:message)
end