Class: Google::Apis::OracledatabaseV1::TimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::OracledatabaseV1::TimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/oracledatabase_v1/classes.rb,
lib/google/apis/oracledatabase_v1/representations.rb,
lib/google/apis/oracledatabase_v1/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeOfDay
constructor
A new instance of TimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeOfDay
Returns a new instance of TimeOfDay.
9667 9668 9669 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
9646 9647 9648 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9646 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
9652 9653 9654 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9652 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
9658 9659 9660 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9658 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
9665 9666 9667 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9665 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9672 9673 9674 9675 9676 9677 |
# File 'lib/google/apis/oracledatabase_v1/classes.rb', line 9672 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |